@@ -2039,7 +2039,7 @@ namespace Magick
                            ( Color(histogram_array[i].pixel.red,
                                    histogram_array[i].pixel.green,
                                    histogram_array[i].pixel.blue),
-                                   histogram_array[i].count) );
+                                   (unsigned long) histogram_array[i].count) );
       }
     
     // Deallocate histogram array
@@ -2100,8 +2100,8 @@ namespace Magick
     MagickLib::ExceptionInfo exceptionInfo;
     MagickLib::GetExceptionInfo( &exceptionInfo );
     linkImages( first_, last_ );
-    MagickLib::Image* image = MagickLib::FlattenImages( first_->image(),
-							&exceptionInfo );
+    MagickLib::Image* image = MagickLib::MergeImageLayers( first_->image(),
+		  FlattenLayer,&exceptionInfo );
     unlinkImages( first_, last_ );
     flattendImage_->replaceImage( image );
     throwException( exceptionInfo );
@@ -2252,8 +2252,8 @@ namespace Magick
     MagickLib::ExceptionInfo exceptionInfo;
     MagickLib::GetExceptionInfo( &exceptionInfo );
     linkImages( first_, last_ );
-    MagickLib::Image* image = MagickLib::MosaicImages( first_->image(),
-						       &exceptionInfo ); 
+    MagickLib::Image* image = MagickLib::MergeImageLayers( first_->image(),
+			 MosaicLayer,&exceptionInfo ); 
     unlinkImages( first_, last_ );
     mosaicImage_->replaceImage( image );
     throwException( exceptionInfo );
