@@ -52,9 +52,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -210,22 +211,23 @@ static Image *ReadARTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterARTImage method is:
 %
-%      RegisterARTImage(void)
+%      unsigned long RegisterARTImage(void)
 %
 */
-ModuleExport void RegisterARTImage(void)
+ModuleExport unsigned long RegisterARTImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("ART");
-  entry->decoder=(DecoderHandler *) ReadARTImage;
-  entry->encoder=(EncoderHandler *) WriteARTImage;
+  entry->decoder=(DecodeImageHandler *) ReadARTImage;
+  entry->encoder=(EncodeImageHandler *) WriteARTImage;
   entry->raw=MagickTrue;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("PFS: 1st Publisher Clip Art");
   entry->module=ConstantString("ART");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
