@@ -60,9 +60,10 @@
 #include "magick/monitor.h"
 #include "magick/profile.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/utility.h"
 
 #if defined(HasJPEG)
@@ -1199,21 +1200,21 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
               image->y_resolution=(double) jpeg_info.Y_density;
               units=(unsigned long) jpeg_info.density_unit;
             }
-            value=GetImageProperty(image,"EXIF:XResolution");
+            value=GetImageProperty(image,"exif:XResolution");
             if (value != (char *) NULL)
             {
               (void) ParseGeometry(value,&geometry_info);
               if (geometry_info.sigma != 0)
                 image->x_resolution=geometry_info.rho/geometry_info.sigma;
-              (void) SetImageProperty(image,"EXIF:XResolution",(char *) NULL);
+              (void) SetImageProperty(image,"exif:XResolution",(char *) NULL);
             }
-            value=GetImageProperty(image,"EXIF:YResolution");
+            value=GetImageProperty(image,"exif:YResolution");
             if (value != (char *) NULL)
             {
               (void) ParseGeometry(value,&geometry_info);
               if (geometry_info.sigma != 0)
                 image->y_resolution=geometry_info.rho/geometry_info.sigma;
-              (void) SetImageProperty(image,"EXIF:YResolution",(char *) NULL);
+              (void) SetImageProperty(image,"exif:YResolution",(char *) NULL);
             }
             if (units == 1)
               image->units=PixelsPerInchResolution;
@@ -2138,20 +2139,21 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterAVIImage method is:
 %
-%      RegisterAVIImage(void)
+%      unsigned long RegisterAVIImage(void)
 %
 */
-ModuleExport void RegisterAVIImage(void)
+ModuleExport unsigned long RegisterAVIImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("AVI");
-  entry->decoder=(DecoderHandler *) ReadAVIImage;
-  entry->magick=(MagickHandler *) IsAVI;
+  entry->decoder=(DecodeImageHandler *) ReadAVIImage;
+  entry->magick=(IsImageFormatHandler *) IsAVI;
   entry->description=ConstantString("Microsoft Audio/Visual Interleaved");
   entry->module=ConstantString("AVI");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
