@@ -51,9 +51,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -142,7 +143,7 @@ static Image *ReadAVSImage(const ImageInfo *image_info,ExceptionInfo *exception)
   */
   width=ReadBlobMSBLong(image);
   height=ReadBlobMSBLong(image);
-  if ((width == ~0UL) || (height == ~0UL))
+  if ((width == 0UL) || (height == 0UL))
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   do
   {
@@ -211,7 +212,7 @@ static Image *ReadAVSImage(const ImageInfo *image_info,ExceptionInfo *exception)
         break;
     width=ReadBlobMSBLong(image);
     height=ReadBlobMSBLong(image);
-    if ((width != ~0UL) && (height != ~0UL))
+    if ((width != 0UL) && (height != 0UL))
       {
         /*
           Allocate next image structure.
@@ -231,7 +232,7 @@ static Image *ReadAVSImage(const ImageInfo *image_info,ExceptionInfo *exception)
               break;
           }
       }
-  } while ((width != ~0UL) && (height != ~0UL));
+  } while ((width != 0UL) && (height != 0UL));
   CloseBlob(image);
   return(GetFirstImageInList(image));
 }
@@ -255,20 +256,21 @@ static Image *ReadAVSImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterAVSImage method is:
 %
-%      RegisterAVSImage(void)
+%      unsigned long RegisterAVSImage(void)
 %
 */
-ModuleExport void RegisterAVSImage(void)
+ModuleExport unsigned long RegisterAVSImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("AVS");
-  entry->decoder=(DecoderHandler *) ReadAVSImage;
-  entry->encoder=(EncoderHandler *) WriteAVSImage;
+  entry->decoder=(DecodeImageHandler *) ReadAVSImage;
+  entry->encoder=(EncodeImageHandler *) WriteAVSImage;
   entry->description=ConstantString("AVS X image");
   entry->module=ConstantString("AVS");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
