@@ -55,9 +55,10 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/profile.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/transform.h"
 
 /*
@@ -163,8 +164,8 @@ static MagickBooleanType
 %    o pixels:  The address of a byte (8 bits) array of pixel data created by
 %      the decoding process.
 %
-%
 */
+
 static inline long MagickAbsoluteValue(const long x)
 {
   if (x < 0)
@@ -355,7 +356,6 @@ static MagickBooleanType DecodeImage(Image *image,
 %    o compressed_pixels:  The address of a byte (8 bits) array of compressed
 %      pixel data.
 %
-%
 */
 static size_t EncodeImage(Image *image,const unsigned long bytes_per_line,
   const unsigned char *pixels,unsigned char *compressed_pixels)
@@ -449,7 +449,6 @@ static size_t EncodeImage(Image *image,const unsigned long bytes_per_line,
 %
 %    o length: Specifies the length of the magick string.
 %
-%
 */
 static MagickBooleanType IsBMP(const unsigned char *magick,const size_t length)
 {
@@ -641,8 +640,8 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
         */
         if (bmp_info.size < 40)
           ThrowReaderException(CorruptImageError,"NonOS2HeaderSizeError");
-        bmp_info.width=(short) ReadBlobLSBLong(image);
-        bmp_info.height=(short) ReadBlobLSBLong(image);
+        bmp_info.width=(long) ReadBlobLSBLong(image);
+        bmp_info.height=(long) ReadBlobLSBLong(image);
         bmp_info.planes=ReadBlobLSBShort(image);
         bmp_info.bits_per_pixel=ReadBlobLSBShort(image);
         bmp_info.compression=ReadBlobLSBLong(image);
@@ -808,6 +807,12 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
         (bmp_info.bits_per_pixel != 8) && (bmp_info.bits_per_pixel != 16) &&
         (bmp_info.bits_per_pixel != 24) && (bmp_info.bits_per_pixel != 32))
       ThrowReaderException(CorruptImageError,"UnrecognizedBitsPerPixel");
+    if (bmp_info.number_colors > (1UL << bmp_info.bits_per_pixel))
+      {
+        if (bmp_info.bits_per_pixel < 24)
+          ThrowReaderException(CorruptImageError,"UnrecognizedNumberOfColors");
+        bmp_info.number_colors=0;
+      }
     if (bmp_info.compression > 3)
       ThrowReaderException(CorruptImageError,"UnrecognizedImageCompression");
     if ((bmp_info.compression == 1) && (bmp_info.bits_per_pixel != 8))
@@ -824,13 +829,13 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
       case BI_BITFIELDS:
         break;
       case BI_JPEG:
-        ThrowReaderException(CoderError,"JPEGCompressionNotSupported");
+        ThrowReaderException(CoderError,"JPEGCompressNotSupported");
       case BI_PNG:
-        ThrowReaderException(CoderError,"PNGCompressionNotSupported");
+        ThrowReaderException(CoderError,"PNGCompressNotSupported");
       default:
         ThrowReaderException(CorruptImageError,"UnrecognizedImageCompression");
     }
-    image->columns=(unsigned long) bmp_info.width;
+    image->columns=(unsigned long) MagickAbsoluteValue(bmp_info.width);
     image->rows=(unsigned long) MagickAbsoluteValue(bmp_info.height);
     image->depth=8;
     image->matte=bmp_info.alpha_mask != 0 ? MagickTrue : MagickFalse;
@@ -857,8 +862,8 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
             "  Reading colormap of %ld colors",image->colors);
         if (AllocateImageColormap(image,image->colors) == MagickFalse)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-        bmp_colormap=(unsigned char *)
-          AcquireMagickMemory((size_t) (4*image->colors));
+        bmp_colormap=(unsigned char *) AcquireQuantumMemory((size_t)
+          image->colors,4*sizeof(*bmp_colormap));
         if (bmp_colormap == (unsigned char *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         if ((bmp_info.size == 12) || (bmp_info.size == 64))
@@ -888,6 +893,11 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
     /*
       Read image data.
     */
+    if (SetImageExtent(image,0,0) == MagickFalse)
+      {
+        InheritException(exception,&image->exception);
+        return(DestroyImageList(image));
+      }
     offset=SeekBlob(image,start_position+bmp_info.offset_bits,SEEK_SET);
     if (offset < 0)
       ThrowReaderException(CorruptImageError,"ImproperImageHeader");
@@ -895,8 +905,8 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
       bmp_info.bits_per_pixel<<=1;
     bytes_per_line=4*((image->columns*bmp_info.bits_per_pixel+31)/32);
     length=(size_t) bytes_per_line*image->rows;
-    pixels=(unsigned char *) AcquireMagickMemory((size_t) MagickMax(
-      bytes_per_line,image->columns+256)*image->rows*sizeof(*pixels));
+    pixels=(unsigned char *) AcquireQuantumMemory((size_t) image->rows,
+      MagickMax(bytes_per_line,image->columns+256UL)*sizeof(*pixels));
     if (pixels == (unsigned char *) NULL)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     if ((bmp_info.compression == BI_RGB) ||
@@ -1361,39 +1371,40 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterBMPImage method is:
 %
-%      RegisterBMPImage(void)
+%      unsigned long RegisterBMPImage(void)
 %
 */
-ModuleExport void RegisterBMPImage(void)
+ModuleExport unsigned long RegisterBMPImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("BMP");
-  entry->decoder=(DecoderHandler *) ReadBMPImage;
-  entry->encoder=(EncoderHandler *) WriteBMPImage;
-  entry->magick=(MagickHandler *) IsBMP;
+  entry->decoder=(DecodeImageHandler *) ReadBMPImage;
+  entry->encoder=(EncodeImageHandler *) WriteBMPImage;
+  entry->magick=(IsImageFormatHandler *) IsBMP;
   entry->description=ConstantString("Microsoft Windows bitmap image");
   entry->module=ConstantString("BMP");
   entry->adjoin=MagickFalse;
   entry->seekable_stream=MagickTrue;
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("BMP2");
-  entry->encoder=(EncoderHandler *) WriteBMPImage;
-  entry->magick=(MagickHandler *) IsBMP;
+  entry->encoder=(EncodeImageHandler *) WriteBMPImage;
+  entry->magick=(IsImageFormatHandler *) IsBMP;
   entry->description=ConstantString("Microsoft Windows bitmap image v2");
   entry->module=ConstantString("BMP");
   entry->adjoin=MagickFalse;
   entry->seekable_stream=MagickTrue;
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("BMP3");
-  entry->encoder=(EncoderHandler *) WriteBMPImage;
-  entry->magick=(MagickHandler *) IsBMP;
+  entry->encoder=(EncodeImageHandler *) WriteBMPImage;
+  entry->magick=(IsImageFormatHandler *) IsBMP;
   entry->description=ConstantString("Microsoft Windows bitmap image v3");
   entry->module=ConstantString("BMP");
   entry->adjoin=MagickFalse;
   entry->seekable_stream=MagickTrue;
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -1447,7 +1458,6 @@ ModuleExport void UnregisterBMPImage(void)
 %
 %    o image:  The image.
 %
-%
 */
 static MagickBooleanType WriteBMPImage(const ImageInfo *image_info,Image *image)
 {
@@ -1624,7 +1634,8 @@ static MagickBooleanType WriteBMPImage(const ImageInfo *image_info,Image *image)
     /*
       Convert MIFF to BMP raster pixels.
     */
-    pixels=(unsigned char *) AcquireMagickMemory((size_t) bmp_info.image_size);
+    pixels=(unsigned char *) AcquireQuantumMemory((size_t) bmp_info.image_size,
+      sizeof(*pixels));
     if (pixels == (unsigned char *) NULL)
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
     (void) ResetMagickMemory(pixels,0,(size_t) bmp_info.image_size);
@@ -1803,15 +1814,18 @@ static MagickBooleanType WriteBMPImage(const ImageInfo *image_info,Image *image)
             Convert run-length encoded raster pixels.
           */
           length=(size_t) (2*(bytes_per_line+2)*(image->rows+2)+2);
-          bmp_data=(unsigned char *) AcquireMagickMemory(length+bytes_per_line);
+          bmp_data=(unsigned char *) NULL;
+          if (~length >= bytes_per_line)
+            bmp_data=(unsigned char *) AcquireQuantumMemory(length+
+              bytes_per_line,sizeof(*bmp_data));
           if (bmp_data == (unsigned char *) NULL)
             {
               pixels=(unsigned char *) RelinquishMagickMemory(pixels);
               ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
             }
           bmp_info.file_size-=bmp_info.image_size;
-          bmp_info.image_size=(unsigned long)
-            EncodeImage(image,bytes_per_line,pixels,bmp_data);
+          bmp_info.image_size=(unsigned long) EncodeImage(image,
+            bytes_per_line,pixels,bmp_data);
           bmp_info.file_size+=bmp_info.image_size;
           pixels=(unsigned char *) RelinquishMagickMemory(pixels);
           pixels=bmp_data;
@@ -1995,8 +2009,8 @@ static MagickBooleanType WriteBMPImage(const ImageInfo *image_info,Image *image)
         if (image->debug != MagickFalse)
           (void) LogMagickEvent(CoderEvent,GetMagickModule(),
             "  Colormap: %ld entries",image->colors);
-        bmp_colormap=(unsigned char *)
-          AcquireMagickMemory((size_t) (4*(1 << bmp_info.bits_per_pixel)));
+        bmp_colormap=(unsigned char *) AcquireQuantumMemory((size_t) 
+          (1UL << bmp_info.bits_per_pixel),4*sizeof(*bmp_colormap));
         if (bmp_colormap == (unsigned char *) NULL)
           ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
         q=bmp_colormap;
