@@ -53,9 +53,10 @@
 #include "magick/memory_.h"
 #include "magick/option.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -228,20 +229,21 @@ static Image *ReadCAPTIONImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterCAPTIONImage method is:
 %
-%      RegisterCAPTIONImage(void)
+%      unsigned long RegisterCAPTIONImage(void)
 %
 */
-ModuleExport void RegisterCAPTIONImage(void)
+ModuleExport unsigned long RegisterCAPTIONImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("CAPTION");
-  entry->decoder=(DecoderHandler *) ReadCAPTIONImage;
+  entry->decoder=(DecodeImageHandler *) ReadCAPTIONImage;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Image caption");
   entry->module=ConstantString("CAPTION");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
