@@ -61,10 +61,11 @@
 #include "magick/option.h"
 #include "magick/profile.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Typedef declaration.
@@ -401,9 +402,6 @@ static Image *ReadCINImage(const ImageInfo *image_info,
   QuantumType
     quantum_type;
 
-  register const unsigned char
-    *p;
-
   register long
     i;
 
@@ -700,6 +698,7 @@ static Image *ReadCINImage(const ImageInfo *image_info,
     Convert CIN raster image to pixel packets.
   */
   GetQuantumInfo(image_info,&quantum_info);
+  quantum_info.quantum=32;
   quantum_info.pack=MagickFalse;
   quantum_type=RGBQuantum;
   length=GetBytesPerRow(image->columns,3,image->depth,MagickTrue);
@@ -708,7 +707,12 @@ static Image *ReadCINImage(const ImageInfo *image_info,
       quantum_type=GrayQuantum;
       length=GetBytesPerRow(image->columns,1,image->depth,MagickTrue);
     }
-  pixels=(unsigned char *) AcquireMagickMemory(length);
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
+  pixels=(unsigned char *) AcquireQuantumMemory(length,sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   for (y=0; y < (long) image->rows; y++)
@@ -716,10 +720,10 @@ static Image *ReadCINImage(const ImageInfo *image_info,
     q=SetImagePixels(image,0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
       break;
-    p=ReadBlobStream(image,length,pixels,&count);
+    count=ReadBlob(image,length,pixels);
     if ((size_t) count != length)
       break;
-    status=ExportQuantumPixels(image,&quantum_info,quantum_type,p);
+    status=ExportQuantumPixels(image,&quantum_info,quantum_type,pixels);
     if (status == MagickFalse)
       break;
     if (SyncImagePixels(image) == MagickFalse)
@@ -762,21 +766,22 @@ static Image *ReadCINImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterCINImage method is:
 %
-%      RegisterCINImage(void)
+%      unsigned long RegisterCINImage(void)
 %
 */
-ModuleExport void RegisterCINImage(void)
+ModuleExport unsigned long RegisterCINImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("CIN");
-  entry->decoder=(DecoderHandler *) ReadCINImage;
-  entry->encoder=(EncoderHandler *) WriteCINImage;
-  entry->magick=(MagickHandler *) IsCIN;
+  entry->decoder=(DecodeImageHandler *) ReadCINImage;
+  entry->encoder=(EncodeImageHandler *) WriteCINImage;
+  entry->magick=(IsImageFormatHandler *) IsCIN;
   entry->description=ConstantString("Cineon Image File");
   entry->module=ConstantString("CIN");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -973,7 +978,7 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
     offset+=WriteBlobFloat(image,cin.image.channel[0].min_quantity);
     cin.image.channel[i].max_data=(float) ((1UL << image->depth)-1UL);
     offset+=WriteBlobFloat(image,cin.image.channel[0].max_data);
-    cin.image.channel[i].max_quantity=2.048;
+    cin.image.channel[i].max_quantity=2.048f;
     offset+=WriteBlobFloat(image,cin.image.channel[0].max_quantity);
   }
   offset+=WriteBlobFloat(image,image->chromaticity.white_point.x);
@@ -1137,6 +1142,7 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
     Convert pixel packets to CIN raster image.
   */
   GetQuantumInfo(image_info,&quantum_info);
+  quantum_info.quantum=32;
   quantum_info.pack=MagickFalse;
   quantum_type=RGBQuantum;
   length=GetBytesPerRow(image->columns,3,image->depth,MagickTrue);
@@ -1145,7 +1151,7 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
       quantum_type=GrayQuantum;
       length=GetBytesPerRow(image->columns,3,image->depth,MagickTrue);
     }
-  pixels=(unsigned char *) AcquireMagickMemory(length);
+  pixels=(unsigned char *) AcquireQuantumMemory(length,sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
   for (y=0; y < (long) image->rows; y++)
