@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -48,9 +48,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -78,19 +79,20 @@ static MagickBooleanType
 %
 %  The format of the RegisterCLIPImage method is:
 %
-%      RegisterCLIPImage(void)
+%      unsigned long RegisterCLIPImage(void)
 %
 */
-ModuleExport void RegisterCLIPImage(void)
+ModuleExport unsigned long RegisterCLIPImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("CLIP");
-  entry->encoder=(EncoderHandler *) WriteCLIPImage;
+  entry->encoder=(EncodeImageHandler *) WriteCLIPImage;
   entry->description=ConstantString("Image Clip Mask");
   entry->module=ConstantString("CLIP");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -128,12 +130,13 @@ ModuleExport void UnregisterCLIPImage(void)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Function WriteCLIPImage() writes an image of clip bytes to a file.  It
-%  consists of data from the clip component of the image [0..255].
+%  WriteCLIPImage() writes an image of clip bytes to a file.  It consists of
+%  data from the clip mask of the image.
 %
 %  The format of the WriteCLIPImage method is:
 %
-%      MagickBooleanType WriteCLIPImage(const ImageInfo *image_info,Image *image)
+%      MagickBooleanType WriteCLIPImage(const ImageInfo *image_info,
+%        Image *image)
 %
 %  A description of each parameter follows.
 %
@@ -148,9 +151,14 @@ static MagickBooleanType WriteCLIPImage(const ImageInfo *image_info,
   Image
     *clip_image;
 
+  ImageInfo
+    *write_info;
+
   MagickBooleanType
     status;
 
+  if (image->clip_mask == (Image *) NULL)
+    (void) ClipImage(image);
   if (image->clip_mask == (Image *) NULL)
     ThrowWriterException(CoderError,"ImageDoesNotHaveAClipMask");
   clip_image=CloneImage(image->clip_mask,0,0,MagickTrue,&image->exception);
@@ -158,7 +166,13 @@ static MagickBooleanType WriteCLIPImage(const ImageInfo *image_info,
     return(MagickFalse);
   (void) SetImageType(clip_image,TrueColorType);
   (void) CopyMagickString(clip_image->filename,image->filename,MaxTextExtent);
-  status=WriteImage(image_info,clip_image);
+  write_info=CloneImageInfo(image_info);
+  (void) SetImageInfo(write_info,MagickTrue,&image->exception);
+  if (LocaleCompare(write_info->magick,"CLIP") == 0)
+    (void) FormatMagickString(clip_image->filename,MaxTextExtent,"miff:%s",
+      write_info->filename);
+  status=WriteImage(write_info,clip_image);
   clip_image=DestroyImage(clip_image);
+  write_info=DestroyImageInfo(write_info);
   return(status);
 }
