@@ -12,7 +12,7 @@
 %                                 May 2002                                    %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -39,7 +39,7 @@
 #  if defined(__CYGWIN__)
 #    include <windows.h>
 #  else
-     // All MinGW needs ...
+     /* All MinGW needs ... */
 #    include <wingdi.h>
 #  endif
 #endif
@@ -53,8 +53,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/nt-feature.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -90,7 +92,6 @@ static MagickBooleanType
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 #if defined(HasWINGDI32)
 static Image *ReadCLIPBOARDImage(const ImageInfo *image_info,
@@ -111,7 +112,8 @@ static Image *ReadCLIPBOARDImage(const ImageInfo *image_info,
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -147,7 +149,7 @@ static Image *ReadCLIPBOARDImage(const ImageInfo *image_info,
         *pBits,
         *ppBits;
 
-      // create an offscreen DC for the source
+      /* create an offscreen DC for the source */
       hMemDC=CreateCompatibleDC(NULL);
       hOldBitmap=SelectObject(hMemDC,bitmapH);
       GetObject(bitmapH,sizeof(BITMAP),(LPSTR) &bitmap);
@@ -174,7 +176,7 @@ static Image *ReadCLIPBOARDImage(const ImageInfo *image_info,
       ReleaseDC(NULL,hDC);
       if (hBitmap == 0)
         ThrowReaderException(CoderError,"UnableToCreateBitmap");
-      // create an offscreen DC
+      /* create an offscreen DC */
       hDC=CreateCompatibleDC(NULL);
       if (hDC == 0)
         {
@@ -190,13 +192,13 @@ static Image *ReadCLIPBOARDImage(const ImageInfo *image_info,
         }
       if (hPal != NULL)
       {
-        // Kenichi Masuko says this is needed
+        /* Kenichi Masuko says this is needed */
         SelectPalette(hDC, hPal, FALSE);
         RealizePalette(hDC);
       }
-      // bitblt from the memory to the DIB-based one
+      /* bitblt from the memory to the DIB-based one */
       BitBlt(hDC,0,0,image->columns,image->rows,hMemDC,0,0,SRCCOPY);
-      // finally copy the pixels!
+      /* finally copy the pixels! */
       pBits=ppBits;
       for (y=0; y < (long) image->rows; y++)
       {
@@ -244,23 +246,24 @@ static Image *ReadCLIPBOARDImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterCLIPBOARDImage method is:
 %
-%      RegisterCLIPBOARDImage(void)
+%      unsigned long RegisterCLIPBOARDImage(void)
 %
 */
-ModuleExport void RegisterCLIPBOARDImage(void)
+ModuleExport unsigned long RegisterCLIPBOARDImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("CLIPBOARD");
 #if defined(HasWINGDI32)
-  entry->decoder=(DecoderHandler *) ReadCLIPBOARDImage;
-  entry->encoder=(EncoderHandler *) WriteCLIPBOARDImage;
+  entry->decoder=(DecodeImageHandler *) ReadCLIPBOARDImage;
+  entry->encoder=(EncodeImageHandler *) WriteCLIPBOARDImage;
 #endif
   entry->adjoin=MagickFalse;
-  entry->description=AcquireString("The system clipboard");
-  entry->module=AcquireString("CLIPBOARD");
+  entry->description=ConstantString("The system clipboard");
+  entry->module=ConstantString("CLIPBOARD");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -311,7 +314,6 @@ ModuleExport void UnregisterCLIPBOARDImage(void)
 %
 %    o image:  The image.
 %
-%
 */
 #if defined(HasWINGDI32)
 static MagickBooleanType WriteCLIPBOARDImage(const ImageInfo *image_info,
@@ -325,7 +327,7 @@ static MagickBooleanType WriteCLIPBOARDImage(const ImageInfo *image_info,
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   {
     HBITMAP
       bitmapH;
