@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -52,11 +52,12 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/utility.h"
 
 /*
@@ -91,7 +92,6 @@ static MagickBooleanType
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadCMYKImage(const ImageInfo *image_info,
   ExceptionInfo *exception)
@@ -127,7 +127,6 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
     *pixels;
 
   unsigned long
-    depth,
     width;
 
   assert(image_info != (const ImageInfo *) NULL);
@@ -152,20 +151,29 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
           return((Image *) NULL);
         }
       for (i=0; i < image->offset; i++)
-        (void) ReadBlobByte(image);
+        if (ReadBlobByte(image) == EOF)
+          {
+            ThrowFileException(exception,CorruptImageError,
+              "UnexpectedEndOfFile",image->filename);
+            break;
+          }
     }
   /*
     Allocate memory for a pixels.
   */
-  depth=GetImageQuantumDepth(image,MagickFalse);
-  packet_size=(size_t) (4*depth/8);
+  packet_size=(size_t) ((4*image->depth+7)/8);
   if (LocaleCompare(image_info->magick,"CMYKA") == 0)
     {
-      packet_size+=depth/8;
+      packet_size+=(image->depth+7)/8;
       image->matte=MagickTrue;
     }
-  pixels=(unsigned char *)
-    AcquireMagickMemory(packet_size*image->extract_info.width*sizeof(*pixels));
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
+  pixels=(unsigned char *) AcquireQuantumMemory(image->extract_info.width,
+    packet_size*sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   if (image_info->number_scenes != 0)
@@ -209,7 +217,7 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         }
         for (y=0; y < (long) image->rows; y++)
         {
-          if ((y > 0) || (GetPreviousImageInList(image) == (Image *) NULL))
+          if ((y != 0) || (GetPreviousImageInList(image) == (Image *) NULL))
             {
               count=ReadBlob(image,packet_size*image->extract_info.width,
                 pixels);
@@ -251,7 +259,7 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         /*
           Line interlacing:  CCC...MMM...YYY...KKK...CCC...MMM...YYY...KKK...
         */
-        packet_size=(size_t) (image->depth > 8 ? 2 : 1);
+        packet_size=(size_t) ((image->depth+7)/8);
         for (y=0; y < image->extract_info.y; y++)
         {
           count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
@@ -260,7 +268,7 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         }
         for (y=0; y < (long) image->rows; y++)
         {
-          if ((y > 0) || (GetPreviousImageInList(image) == (Image *) NULL))
+          if ((y != 0) || (GetPreviousImageInList(image) == (Image *) NULL))
             {
               count=ReadBlob(image,packet_size*image->extract_info.width,
                 pixels);
@@ -336,7 +344,7 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
                 return((Image *) NULL);
               }
           }
-        packet_size=(size_t) (image->depth > 8 ? 2 : 1);
+        packet_size=(size_t) ((image->depth+7)/8);
         for (y=0; y < image->extract_info.y; y++)
         {
           count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
@@ -347,7 +355,7 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         span=image->rows*(image->matte != MagickFalse ? 5 : 4);
         for (y=0; y < (long) image->rows; y++)
         {
-          if ((y > 0) || (GetPreviousImageInList(image) == (Image *) NULL))
+          if ((y != 0) || (GetPreviousImageInList(image) == (Image *) NULL))
             {
               count=ReadBlob(image,packet_size*image->extract_info.width,
                 pixels);
@@ -639,17 +647,17 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterCMYKImage method is:
 %
-%      RegisterCMYKImage(void)
+%      unsigned long RegisterCMYKImage(void)
 %
 */
-ModuleExport void RegisterCMYKImage(void)
+ModuleExport unsigned long RegisterCMYKImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("CMYK");
-  entry->decoder=(DecoderHandler *) ReadCMYKImage;
-  entry->encoder=(EncoderHandler *) WriteCMYKImage;
+  entry->decoder=(DecodeImageHandler *) ReadCMYKImage;
+  entry->encoder=(EncodeImageHandler *) WriteCMYKImage;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->description=ConstantString(
@@ -657,14 +665,15 @@ ModuleExport void RegisterCMYKImage(void)
   entry->module=ConstantString("CMYK");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("CMYKA");
-  entry->decoder=(DecoderHandler *) ReadCMYKImage;
-  entry->encoder=(EncoderHandler *) WriteCMYKImage;
+  entry->decoder=(DecodeImageHandler *) ReadCMYKImage;
+  entry->encoder=(EncodeImageHandler *) WriteCMYKImage;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->description=ConstantString(
     "Raw cyan, magenta, yellow, black, and opacity samples");
   entry->module=ConstantString("CMYK");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -717,7 +726,6 @@ ModuleExport void UnregisterCMYKImage(void)
 %
 %    o image:  The image.
 %
-%
 */
 static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
   Image *image)
@@ -743,9 +751,6 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
   unsigned char
     *pixels;
 
-  unsigned long
-    depth;
-
   /*
     Allocate memory for pixels.
   */
@@ -755,12 +760,11 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  depth=GetImageQuantumDepth(image,MagickFalse);
-  packet_size=(size_t) (4*depth/8);
+  packet_size=(size_t) ((4*image->depth+7)/8);
   if (LocaleCompare(image_info->magick,"CMYKA") == 0)
-    packet_size+=depth/8;
-  pixels=(unsigned char *)
-    AcquireMagickMemory(packet_size*image->columns*sizeof(*pixels));
+    packet_size+=(image->depth+7)/8;
+  pixels=(unsigned char *) AcquireQuantumMemory(image->columns,packet_size*
+    sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
   if (image_info->interlace != PartitionInterlace)
@@ -826,7 +830,7 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
         /*
           Line interlacing:  CCC...MMM...YYY...KKK...CCC...MMM...YYY...KKK...
         */
-        packet_size=depth/8;
+        packet_size=(image->depth+7)/8;
         for (y=0; y < (long) image->rows; y++)
         {
           p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
@@ -863,7 +867,7 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
         /*
           Plane interlacing:  CCCCCC...MMMMMM...YYYYYY...KKKKKK...
         */
-        packet_size=depth/8;
+        packet_size=(image->depth+7)/8;
         if (image_info->interlace == PartitionInterlace)
           {
             AppendImageFormat("C",image->filename);
