@@ -56,9 +56,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/transform.h"
 
 /*
@@ -921,24 +922,25 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterDIBImage method is:
 %
-%      RegisterDIBImage(void)
+%      unsigned long RegisterDIBImage(void)
 %
 */
-ModuleExport void RegisterDIBImage(void)
+ModuleExport unsigned long RegisterDIBImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("DIB");
-  entry->decoder=(DecoderHandler *) ReadDIBImage;
-  entry->encoder=(EncoderHandler *) WriteDIBImage;
-  entry->magick=(MagickHandler *) IsDIB;
+  entry->decoder=(DecodeImageHandler *) ReadDIBImage;
+  entry->encoder=(EncodeImageHandler *) WriteDIBImage;
+  entry->magick=(IsImageFormatHandler *) IsDIB;
   entry->adjoin=MagickFalse;
   entry->stealth=MagickTrue;
   entry->description=ConstantString(
     "Microsoft Windows 3.X Packed Device-Independent Bitmap");
   entry->module=ConstantString("DIB");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
