@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -49,9 +49,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #if defined(HasDJVU)
 #include <libdjvu/ddjvuapi.h>
 #endif
@@ -81,7 +82,6 @@
 %
 %    o length: Specifies the length of the magick string.
 %
-%
 */
 static MagickBooleanType IsDJVU(const unsigned char *magick,const size_t length)
 {
@@ -617,8 +617,8 @@ ReadOneDJVUImage(LoadContext* lc, const int pagenum, const ImageInfo *image_info
                 image->depth =  8UL;    /* i only support that? */
                 image->colors= 2;
                 if (AllocateImageColormap(image,image->colors) == MagickFalse)
-                        ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-                SetImageType(image, BilevelType);
+                  ThrowReaderException(ResourceLimitError,
+                   "MemoryAllocationFailed");
         } else {
                 image->colorspace = RGBColorspace;
                 image->storage_class = DirectClass;
@@ -627,7 +627,6 @@ ReadOneDJVUImage(LoadContext* lc, const int pagenum, const ImageInfo *image_info
 
                 image->matte = MagickTrue;
                 /* is this useful? */
-                SetImageType(image, TrueColorType);/* GrayscaleType*/
         }
 #if DEBUG        
         printf("now filling %ld x %ld\n", image->columns,image->rows);
@@ -757,7 +756,7 @@ static Image *ReadDJVUImage(const ImageInfo *image_info,ExceptionInfo *exception
   /*
    * Allocate a LoadContext structure.
    */
-  lc = (LoadContext *) AcquireMagickMemory(sizeof(LoadContext));
+  lc = (LoadContext *) AcquireMagickMemory(sizeof(*lc));
   if (lc == NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
 
@@ -867,10 +866,10 @@ static Image *ReadDJVUImage(const ImageInfo *image_info,ExceptionInfo *exception
 %
 %  The format of the RegisterDJVUImage method is:
 %
-%      RegisterDJVUImage(void)
+%      unsigned long RegisterDJVUImage(void)
 %
 */
-ModuleExport void RegisterDJVUImage(void)
+ModuleExport unsigned long RegisterDJVUImage(void)
 {
   char
     version[MaxTextExtent];
@@ -893,10 +892,10 @@ ModuleExport void RegisterDJVUImage(void)
 #endif
   entry=SetMagickInfo("DJVU");
 #if defined(HasDJVU)
-  entry->decoder=(DecoderHandler *) ReadDJVUImage;
+  entry->decoder=(DecodeImageHandler *) ReadDJVUImage;
 #endif
   entry->raw=MagickTrue;
-  entry->magick=(MagickHandler *) IsDJVU;
+  entry->magick=(IsImageFormatHandler *) IsDJVU;
   entry->adjoin=MagickFalse;
   entry->thread_support=MagickTrue;
   entry->description=AcquireString("Dj vu");
@@ -905,6 +904,7 @@ ModuleExport void RegisterDJVUImage(void)
     entry->version=AcquireString(version);
   entry->note=AcquireString(DJVUNote);
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
