@@ -51,9 +51,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/utility.h"
 #include "magick/xwindow-private.h"
 #if defined(HasDPS)
@@ -556,22 +557,23 @@ static Image *ReadDPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterDPSImage method is:
 %
-%      RegisterDPSImage(void)
+%      unsigned long RegisterDPSImage(void)
 %
 */
-ModuleExport void RegisterDPSImage(void)
+ModuleExport unsigned long RegisterDPSImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("DPS");
 #if defined(HasDPS)
-  entry->decoder=(DecoderHandler *) ReadDPSImage;
+  entry->decoder=(DecodeImageHandler *) ReadDPSImage;
 #endif
   entry->blob_support=MagickFalse;
   entry->description=ConstantString("Display Postscript Interpreter");
   entry->module=ConstantString("DPS");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
