@@ -55,10 +55,11 @@
 #include "magick/option.h"
 #include "magick/profile.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
-#include "magick/version.h"
+#include "magick/module.h"
+#include "magick/module.h"
 
 /*
   Typedef declaration.
@@ -520,6 +521,7 @@ static void TimeCodeToString(const unsigned long timestamp,char *code)
   register long
     i;
 
+  *code='\0';
   shift=4*TimeFields;
   for (i=0; i <= TimeFields; i++)
   {
@@ -529,8 +531,8 @@ static void TimeCodeToString(const unsigned long timestamp,char *code)
     if (((i % 2) != 0) && (i < TimeFields))
       *code++=':';
     shift-=4;
+    *code='\0';
   }
-  *code='\0';
 }
 
 static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
@@ -608,6 +610,7 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   image->endian=LSBEndian;
   if (LocaleNCompare(magick,"SDPX",4) == 0)
     image->endian=MSBEndian;
+  (void) ResetMagickMemory(&dpx,0,sizeof(dpx));
   dpx.file.image_offset=ReadBlobLong(image);
   offset+=4;
   offset+=ReadBlob(image,sizeof(dpx.file.version),(unsigned char *)
@@ -1007,6 +1010,11 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Convert DPX raster image to pixel packets.
   */
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   GetQuantumInfo(image_info,&quantum_info);
   quantum_info.quantum=32;
   quantum_info.pack=dpx.image.image_element[0].packing == 0 ? MagickTrue :
@@ -1056,35 +1064,90 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   }
   length=GetBytesPerRow(image->columns,samples_per_pixel,image->depth,
     dpx.image.image_element[0].packing == 0 ? MagickFalse : MagickTrue);
-  pixels=(unsigned char *) AcquireMagickMemory(length*sizeof(*pixels));
+  pixels=(unsigned char *) AcquireQuantumMemory(length,sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-  for (y=0; y < (long) image->rows; y++)
-  {
-    /*
-      DPX any-bit pixel format.
-    */
-    q=SetImagePixels(image,0,y,image->columns,1);
-    if (q == (PixelPacket *) NULL)
-      break;
-    count=ReadBlob(image,length,pixels);
-    if ((size_t) count != length)
-      break;
-    status=ExportQuantumPixels(image,&quantum_info,quantum_type,pixels);
-    if (status == MagickFalse)
-      break;
-    if (SyncImagePixels(image) == MagickFalse)
-      break;
-    if (image->previous == (Image *) NULL)
-      if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-          (QuantumTick(y,image->rows) != MagickFalse))
+  if ((quantum_type == GrayQuantum) && (quantum_info.pack == MagickFalse) &&
+      (image->depth == 10) && (image->endian == MSBEndian))
+    {
+      register long
+        x;
+
+      unsigned long
+        pixel;
+
+      pixel=0UL;
+      i=0;
+      for (y=0; y < (long) image->rows; y++)
+      {
+        q=SetImagePixels(image,0,y,image->columns,1);
+        if (q == (PixelPacket *) NULL)
+          break;
+        for (x=0; x < (long) image->columns; x++)
         {
-          status=image->progress_monitor(LoadImageTag,y,image->rows,
-            image->client_data);
-          if (status == MagickFalse)
-            break;
+          switch (i++ % 3)
+          {
+            case 0:
+            {
+              pixel=ReadBlobMSBLong(image);
+              q->red=ScaleAnyToQuantum((pixel >> 0) & 0x3ff,image->depth);
+              break;
+            }
+            case 1:
+            {
+              q->red=ScaleAnyToQuantum((pixel >> 10) & 0x3ff,image->depth);
+              break;
+            }
+            case 2:
+            {
+              q->red=ScaleAnyToQuantum((pixel >> 20) & 0x3ff,image->depth);
+              break;
+            }
+          }
+          q->green=q->red;
+          q->blue=q->red;
+          q++;
         }
-  }
+        if (SyncImagePixels(image) == MagickFalse)
+          break;
+        if (image->previous == (Image *) NULL)
+          if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+              (QuantumTick(y,image->rows) != MagickFalse))
+            {
+              status=image->progress_monitor(LoadImageTag,y,image->rows,
+                image->client_data);
+              if (status == MagickFalse)
+                break;
+            }
+      }
+    }
+  else
+    for (y=0; y < (long) image->rows; y++)
+    {
+      /*
+        DPX any-bit pixel format.
+      */
+      q=SetImagePixels(image,0,y,image->columns,1);
+      if (q == (PixelPacket *) NULL)
+        break;
+      count=ReadBlob(image,length,pixels);
+      if ((size_t) count != length)
+        break;
+      status=ExportQuantumPixels(image,&quantum_info,quantum_type,pixels);
+      if (status == MagickFalse)
+        break;
+      if (SyncImagePixels(image) == MagickFalse)
+        break;
+      if (image->previous == (Image *) NULL)
+        if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+            (QuantumTick(y,image->rows) != MagickFalse))
+          {
+            status=image->progress_monitor(LoadImageTag,y,image->rows,
+              image->client_data);
+            if (status == MagickFalse)
+              break;
+          }
+    }
   pixels=(unsigned char *) RelinquishMagickMemory(pixels);
   if (EOFBlob(image) != MagickFalse)
     ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
@@ -1113,10 +1176,10 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterDPXImage method is:
 %
-%      RegisterDPXImage(void)
+%      unsigned long RegisterDPXImage(void)
 %
 */
-ModuleExport void RegisterDPXImage(void)
+ModuleExport unsigned long RegisterDPXImage(void)
 {
   MagickInfo
     *entry;
@@ -1129,13 +1192,14 @@ ModuleExport void RegisterDPXImage(void)
     };
 
   entry=SetMagickInfo("DPX");
-  entry->decoder=(DecoderHandler *) ReadDPXImage;
-  entry->encoder=(EncoderHandler *) WriteDPXImage;
-  entry->magick=(MagickHandler *) IsDPX;
+  entry->decoder=(DecodeImageHandler *) ReadDPXImage;
+  entry->encoder=(EncodeImageHandler *) WriteDPXImage;
+  entry->magick=(IsImageFormatHandler *) IsDPX;
   entry->description=ConstantString("SMPTE 268M-2003 (DPX 2.0)");
   entry->note=ConstantString(DPXNote);
   entry->module=ConstantString("DPX");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -1412,6 +1476,19 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
   /*
     Write orientation header.
   */
+  if ((image->rows != image->magick_rows) ||
+      (image->columns != image->magick_columns))
+    {
+      /*
+        These properties are not valid if image size changed.
+      */
+      (void) DeleteImageProperty(image,"dpx:orientation.x_offset");
+      (void) DeleteImageProperty(image,"dpx:orientation.y_offset");
+      (void) DeleteImageProperty(image,"dpx:orientation.x_center");
+      (void) DeleteImageProperty(image,"dpx:orientation.y_center");
+      (void) DeleteImageProperty(image,"dpx:orientation.x_size");
+      (void) DeleteImageProperty(image,"dpx:orientation.y_size");
+    }
   dpx.orientation.x_offset=0UL;
   value=GetDPXProperty(image_info,image,"dpx:orientation.x_offset");
   if (value != (const char *) NULL)
@@ -1671,7 +1748,7 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
       quantum_type=GrayQuantum;
       length=GetBytesPerRow(image->columns,3,image->depth,MagickTrue);
     }
-  pixels=(unsigned char *) AcquireMagickMemory(length);
+  pixels=(unsigned char *) AcquireQuantumMemory(length,sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
   for (y=0; y < (long) image->rows; y++)
