@@ -57,9 +57,10 @@
 #include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -359,9 +360,9 @@ static Image *ReadEMFImage(const ImageInfo *image_info,
           if (image->units == PixelsPerCentimeterResolution)
             x_resolution*=CENTIMETERS_INCH;
         }
-      image->rows=(unsigned long) ((height*CENTIMETERS_INCH)/1000*
+      image->rows=(unsigned long) ((height/1000.0/CENTIMETERS_INCH)*
         y_resolution+0.5);
-      image->columns=(unsigned long) ((width*CENTIMETERS_INCH)/1000*
+      image->columns=(unsigned long) ((width/1000.0/CENTIMETERS_INCH)*
         x_resolution+0.5);
     }
   if (image_info->size != (char *) NULL)
@@ -527,10 +528,10 @@ static Image *ReadEMFImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterEMFImage method is:
 %
-%      RegisterEMFImage(void)
+%      unsigned long RegisterEMFImage(void)
 %
 */
-ModuleExport void RegisterEMFImage(void)
+ModuleExport unsigned long RegisterEMFImage(void)
 {
   MagickInfo
     *entry;
@@ -541,7 +542,7 @@ ModuleExport void RegisterEMFImage(void)
 #endif
   entry->description=ConstantString(
     "Windows WIN32 API rendered Enhanced Meta File");
-  entry->magick=(MagickHandler *) IsEMF;
+  entry->magick=(IsImageFormatHandler *) IsEMF;
   entry->blob_support=MagickFalse;
   entry->module=ConstantString("WMF");
   (void) RegisterMagickInfo(entry);
@@ -550,10 +551,11 @@ ModuleExport void RegisterEMFImage(void)
   entry->decoder=ReadEMFImage;
 #endif
   entry->description=ConstantString("Windows WIN32 API rendered Meta File");
-  entry->magick=(MagickHandler *) IsWMF;
+  entry->magick=(IsImageFormatHandler *) IsWMF;
   entry->blob_support=MagickFalse;
   entry->module=ConstantString("WMFWIN32");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
