@@ -57,9 +57,10 @@
 #include "magick/monitor.h"
 #include "magick/quantize.h"
 #include "magick/resource_.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/transform.h"
 #include "magick/utility.h"
 
@@ -199,9 +200,10 @@ static Image *ReadEPTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   ept_info.tiff_offset=(MagickOffsetType) ReadBlobLSBLong(image);
   ept_info.tiff_length=ReadBlobLSBLong(image);
   (void) ReadBlobLSBShort(image);
-  ept_info.postscript=(unsigned char *) AcquireMagickMemory(
-    ept_info.postscript_length);
-  ept_info.tiff=(unsigned char *) AcquireMagickMemory(ept_info.tiff_length);
+  ept_info.postscript=(unsigned char *) AcquireQuantumMemory(
+    ept_info.postscript_length,sizeof(*ept_info.postscript));
+  ept_info.tiff=(unsigned char *) AcquireQuantumMemory(ept_info.tiff_length,
+    sizeof(*ept_info.tiff));
   if ((ept_info.postscript == (unsigned char *) NULL) ||
       (ept_info.tiff == (unsigned char *) NULL))
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
@@ -257,18 +259,18 @@ static Image *ReadEPTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterEPTImage method is:
 %
-%      RegisterEPTImage(void)
+%      unsigned long RegisterEPTImage(void)
 %
 */
-ModuleExport void RegisterEPTImage(void)
+ModuleExport unsigned long RegisterEPTImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("EPT");
-  entry->decoder=(DecoderHandler *) ReadEPTImage;
-  entry->encoder=(EncoderHandler *) WriteEPTImage;
-  entry->magick=(MagickHandler *) IsEPT;
+  entry->decoder=(DecodeImageHandler *) ReadEPTImage;
+  entry->encoder=(EncodeImageHandler *) WriteEPTImage;
+  entry->magick=(IsImageFormatHandler *) IsEPT;
   entry->adjoin=MagickFalse;
   entry->blob_support=MagickFalse;
   entry->description=ConstantString(
@@ -276,9 +278,9 @@ ModuleExport void RegisterEPTImage(void)
   entry->module=ConstantString("EPT");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("EPT2");
-  entry->decoder=(DecoderHandler *) ReadEPTImage;
-  entry->encoder=(EncoderHandler *) WriteEPTImage;
-  entry->magick=(MagickHandler *) IsEPT;
+  entry->decoder=(DecodeImageHandler *) ReadEPTImage;
+  entry->encoder=(EncodeImageHandler *) WriteEPTImage;
+  entry->magick=(IsImageFormatHandler *) IsEPT;
   entry->adjoin=MagickFalse;
   entry->blob_support=MagickFalse;
   entry->description=ConstantString(
@@ -286,14 +288,15 @@ ModuleExport void RegisterEPTImage(void)
   entry->module=ConstantString("EPT");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("EPT3");
-  entry->decoder=(DecoderHandler *) ReadEPTImage;
-  entry->encoder=(EncoderHandler *) WriteEPTImage;
-  entry->magick=(MagickHandler *) IsEPT;
+  entry->decoder=(DecodeImageHandler *) ReadEPTImage;
+  entry->encoder=(EncodeImageHandler *) WriteEPTImage;
+  entry->magick=(IsImageFormatHandler *) IsEPT;
   entry->blob_support=MagickFalse;
   entry->description=ConstantString(
     "Encapsulated PostScript Level III with TIFF preview");
   entry->module=ConstantString("EPT");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
