@@ -52,9 +52,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -167,14 +168,19 @@ static Image *ReadFAXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   image->colormap[0].red=(Quantum) QuantumRange;
   image->colormap[0].green=(Quantum) QuantumRange;
   image->colormap[0].blue=(Quantum) QuantumRange;
-  image->colormap[1].red=0;
-  image->colormap[1].green=0;
-  image->colormap[1].blue=0;
+  image->colormap[1].red=(Quantum) 0;
+  image->colormap[1].green=(Quantum) 0;
+  image->colormap[1].blue=(Quantum) 0;
   if (image_info->ping != MagickFalse)
     {
       CloseBlob(image);
       return(GetFirstImageInList(image));
     }
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   status=HuffmanDecodeImage(image);
   if (status == MagickFalse)
     ThrowReaderException(CorruptImageError,"UnableToReadImageData");
@@ -205,10 +211,10 @@ static Image *ReadFAXImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterFAXImage method is:
 %
-%      RegisterFAXImage(void)
+%      unsigned long RegisterFAXImage(void)
 %
 */
-ModuleExport void RegisterFAXImage(void)
+ModuleExport unsigned long RegisterFAXImage(void)
 {
   MagickInfo
     *entry;
@@ -216,28 +222,29 @@ ModuleExport void RegisterFAXImage(void)
   static const char
     *Note=
     {
-      "See TIFF format.  Note that FAX machines use non-square pixels which\n"
-      "are 1.5 times wider than they are tall but computer displays use\n"
-      "square pixels. FAX images may appear to be narrow unless they are\n"
-      "explicitly resized using a resize specification of \"150x100%\"."
+      "FAX machines use non-square pixels which are 1.5 times wider than they\n"
+      "are tall but computer displays use square pixels, therefore FAX images\n"
+      "may appear to be narrow unless they are explicitly resized using a\n"
+      "geometry of \"150x100%\".\n"
     };
 
   entry=SetMagickInfo("FAX");
-  entry->decoder=(DecoderHandler *) ReadFAXImage;
-  entry->encoder=(EncoderHandler *) WriteFAXImage;
-  entry->magick=(MagickHandler *) IsFAX;
+  entry->decoder=(DecodeImageHandler *) ReadFAXImage;
+  entry->encoder=(EncodeImageHandler *) WriteFAXImage;
+  entry->magick=(IsImageFormatHandler *) IsFAX;
   entry->description=ConstantString("Group 3 FAX");
   entry->note=ConstantString(Note);
   entry->module=ConstantString("FAX");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("G3");
-  entry->decoder=(DecoderHandler *) ReadFAXImage;
-  entry->encoder=(EncoderHandler *) WriteFAXImage;
-  entry->magick=(MagickHandler *) IsFAX;
+  entry->decoder=(DecodeImageHandler *) ReadFAXImage;
+  entry->encoder=(EncodeImageHandler *) WriteFAXImage;
+  entry->magick=(IsImageFormatHandler *) IsFAX;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Group 3 FAX");
   entry->module=ConstantString("FAX");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
