@@ -54,12 +54,13 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
-#include "magick/version.h"
+#include "magick/module.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -652,30 +653,31 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterFITSImage method is:
 %
-%      RegisterFITSImage(void)
+%      unsigned long RegisterFITSImage(void)
 %
 */
-ModuleExport void RegisterFITSImage(void)
+ModuleExport unsigned long RegisterFITSImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("FITS");
-  entry->decoder=(DecoderHandler *) ReadFITSImage;
-  entry->encoder=(EncoderHandler *) WriteFITSImage;
-  entry->magick=(MagickHandler *) IsFITS;
+  entry->decoder=(DecodeImageHandler *) ReadFITSImage;
+  entry->encoder=(EncodeImageHandler *) WriteFITSImage;
+  entry->magick=(IsImageFormatHandler *) IsFITS;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Flexible Image Transport System");
   entry->module=ConstantString("FITS");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("FTS");
-  entry->decoder=(DecoderHandler *) ReadFITSImage;
-  entry->encoder=(EncoderHandler *) WriteFITSImage;
-  entry->magick=(MagickHandler *) IsFITS;
+  entry->decoder=(DecodeImageHandler *) ReadFITSImage;
+  entry->encoder=(EncodeImageHandler *) WriteFITSImage;
+  entry->magick=(IsImageFormatHandler *) IsFITS;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Flexible Image Transport System");
   entry->module=ConstantString("FTS");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
