@@ -57,9 +57,10 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/pixel.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #if defined(HasFPX)
 #if !defined(vms) && !defined(macintosh) && !defined(__WINDOWS__)
 #include <fpxlib.h>
@@ -189,17 +190,21 @@ static Image *ReadFPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     *g,
     *r;
 
+  size_t
+    memory_limit;
+
   unsigned char
     *scanline;
 
-  unsigned long
+  unsigned int
     height,
-    memory_limit,
-    scene,
     tile_width,
     tile_height,
     width;
 
+  unsigned long
+    scene;
+
   /*
     Open image.
   */
@@ -330,7 +335,7 @@ static Image *ReadFPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
         (void) CopyMagickString(comments,(char *) summary_info.comments.ptr,
           summary_info.comments.length+1);
-        (void) SetImageProperty(image,"Comment",comments);
+        (void) SetImageProperty(image,"comment",comments);
         comments=DestroyString(comments);
       }
   /*
@@ -518,26 +523,27 @@ static Image *ReadFPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterFPXImage method is:
 %
-%      RegisterFPXImage(void)
+%      unsigned long RegisterFPXImage(void)
 %
 */
-ModuleExport void RegisterFPXImage(void)
+ModuleExport unsigned long RegisterFPXImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("FPX");
 #if defined(HasFPX)
-  entry->decoder=(DecoderHandler *) ReadFPXImage;
-  entry->encoder=(EncoderHandler *) WriteFPXImage;
+  entry->decoder=(DecodeImageHandler *) ReadFPXImage;
+  entry->encoder=(EncodeImageHandler *) WriteFPXImage;
 #endif
   entry->adjoin=MagickFalse;
   entry->seekable_stream=MagickTrue;
   entry->blob_support=MagickFalse;
-  entry->magick=(MagickHandler *) IsFPX;
+  entry->magick=(IsImageFormatHandler *) IsFPX;
   entry->description=ConstantString("FlashPix Format");
   entry->module=ConstantString("FPX");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -823,11 +829,13 @@ static MagickBooleanType WriteFPXImage(const ImageInfo *image_info,Image *image)
   register long
     i;
 
+  size_t
+    memory_limit;
+
   unsigned char
     *pixels;
 
-  unsigned long
-    memory_limit,
+  unsigned int
     tile_height,
     tile_width;
 
@@ -918,7 +926,7 @@ static MagickBooleanType WriteFPXImage(const ImageInfo *image_info,Image *image)
   summary_info.thumbnail_valid=MagickFalse;
   summary_info.appname_valid=MagickFalse;
   summary_info.security_valid=MagickFalse;
-  label=GetImageProperty(image,"Label");
+  label=GetImageProperty(image,"label");
   if (label != (const char *) NULL)
     {
       size_t
@@ -938,7 +946,7 @@ static MagickBooleanType WriteFPXImage(const ImageInfo *image_info,Image *image)
       (void) CopyMagickString((char *) summary_info.title.ptr,label,
         MaxTextExtent);
     }
-  comment=GetImageProperty(image,"Comment");
+  comment=GetImageProperty(image,"comment");
   if (comment != (const char *) NULL)
     {
       /*
