@@ -57,9 +57,10 @@
 #include "magick/option.h"
 #include "magick/property.h"
 #include "magick/quantize.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Define declarations.
@@ -199,9 +200,9 @@ static LZWInfo *AcquireLZWInfo(Image *image,const unsigned long data_size)
   lzw_info->maximum_data_value=(1UL << data_size)-1;
   lzw_info->clear_code=lzw_info->maximum_data_value+1;
   lzw_info->end_code=lzw_info->maximum_data_value+2;
-  lzw_info->table[0]=(unsigned long *) AcquireMagickMemory(MaximumLZWCode*
+  lzw_info->table[0]=(unsigned long *) AcquireQuantumMemory(MaximumLZWCode,
     sizeof(*lzw_info->table));
-  lzw_info->table[1]=(unsigned long *) AcquireMagickMemory(MaximumLZWCode*
+  lzw_info->table[1]=(unsigned long *) AcquireQuantumMemory(MaximumLZWCode,
     sizeof(*lzw_info->table));
   if ((lzw_info->table[0] == (unsigned long *) NULL) ||
       (lzw_info->table[1] == (unsigned long *) NULL))
@@ -227,8 +228,8 @@ static LZWInfo *AcquireLZWInfo(Image *image,const unsigned long data_size)
       lzw_info=RelinquishLZWInfo(lzw_info);
       return((LZWInfo *) NULL);
     }
-  lzw_info->stack->codes=(unsigned long *) AcquireMagickMemory(2*MaximumLZWCode*
-    sizeof(*lzw_info->stack->codes));
+  lzw_info->stack->codes=(unsigned long *) AcquireQuantumMemory(2UL*
+    MaximumLZWCode,sizeof(*lzw_info->stack->codes));
   if (lzw_info->stack->codes == (unsigned long *) NULL)
     {
       lzw_info=RelinquishLZWInfo(lzw_info);
@@ -428,7 +429,8 @@ static MagickBooleanType DecodeImage(Image *image,const Quantum opacity)
       q->red=image->colormap[(long) index].red;
       q->green=image->colormap[(long) index].green;
       q->blue=image->colormap[(long) index].blue;
-      q->opacity=index == opacity ? TransparentOpacity : OpaqueOpacity;
+      q->opacity=index == opacity ? (Quantum) TransparentOpacity :
+        (Quantum) OpaqueOpacity;
       indexes[x]=index;
       x++;
       q++;
@@ -613,10 +615,10 @@ static MagickBooleanType EncodeImage(const ImageInfo *image_info,Image *image,
     Allocate encoder tables.
   */
   assert(image != (Image *) NULL);
-  packet=(unsigned char *) AcquireMagickMemory(256*sizeof(*packet));
-  hash_code=(short *) AcquireMagickMemory(MaxHashTable*sizeof(*hash_code));
-  hash_prefix=(short *) AcquireMagickMemory(MaxHashTable*sizeof(*hash_prefix));
-  hash_suffix=(unsigned char *) AcquireMagickMemory(MaxHashTable*
+  packet=(unsigned char *) AcquireQuantumMemory(256,sizeof(*packet));
+  hash_code=(short *) AcquireQuantumMemory(MaxHashTable,sizeof(*hash_code));
+  hash_prefix=(short *) AcquireQuantumMemory(MaxHashTable,sizeof(*hash_prefix));
+  hash_suffix=(unsigned char *) AcquireQuantumMemory(MaxHashTable,
     sizeof(*hash_suffix));
   if ((packet == (unsigned char *) NULL) || (hash_code == (short *) NULL) ||
       (hash_prefix == (short *) NULL) ||
@@ -968,7 +970,7 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     *image;
 
   int
-    num_app_exts=0;
+    number_extensionss=0;
 
   long
     opacity;
@@ -1033,8 +1035,8 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   background=(unsigned char) ReadBlobByte(image);
   c=(unsigned char) ReadBlobByte(image);  /* reserved */
   global_colors=1UL << (((unsigned long) flag & 0x07)+1);
-  global_colormap=(unsigned char *) AcquireMagickMemory((size_t)
-    (3*MagickMax(global_colors,256))*sizeof(*global_colormap));
+  global_colormap=(unsigned char *) AcquireQuantumMemory((size_t)
+    MagickMax(global_colors,256),3UL*sizeof(*global_colormap));
   if (global_colormap == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   if (BitSet((int) flag,0x80) != 0)
@@ -1096,7 +1098,7 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
               header[count]='\0';
               (void) ConcatenateString(&comments,(const char *) header);
             }
-            (void) SetImageProperty(image,"Comment",comments);
+            (void) SetImageProperty(image,"comment",comments);
             comments=DestroyString(comments);
             break;
           }
@@ -1115,77 +1117,78 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
               loop=LocaleNCompare((char *) header,"NETSCAPE2.0",11) == 0 ?
                 MagickTrue : MagickFalse;
             if (loop != MagickFalse)
-            {
-              while (ReadBlobBlock(image,header) != 0)
-                iterations=(unsigned long) ((header[2] << 8) | header[1]);
-              break;
-            }
-            else
-            {
-              /* store GIF application extension as a generic profile */
-              char
-                name[MaxTextExtent];
-
-              StringInfo
-                *profile;
-
-              unsigned char
-                *info;
-
-              MagickBooleanType
-                i8bim,
-                icc,
-                iptc;
-
-              int
-                 block_length,
-                 info_length,
-                 reserved_length;
-
-              i8bim=LocaleNCompare((char *) header,"MGK8BIM0000",11) == 0 ?
-                MagickTrue : MagickFalse;
-              icc=LocaleNCompare((char *) header,"ICCRGBG1012",11) == 0 ?
-                MagickTrue : MagickFalse;
-              iptc=LocaleNCompare((char *) header,"MGKIPTC0000",11) == 0 ?
-                MagickTrue : MagickFalse;
-
-              num_app_exts++;
-              (void) LogMagickEvent(CoderEvent,GetMagickModule(),
-                  "    Reading GIF application extension");
-
-              info=(unsigned char *) AcquireMagickMemory(255);
-              info_length=0;
-              reserved_length=255;
-              for (;;)
               {
-                block_length=(int) ReadBlobBlock(image,&info[info_length]);
-                if (block_length == 0)
-                   break;
-                info_length += block_length;
-                if (info_length > reserved_length - 255)
-                {
-                   reserved_length += 4096;
-                   info=(unsigned char *) ResizeMagickMemory(info,
-                     (size_t) reserved_length);
-                }
+                while (ReadBlobBlock(image,header) != 0)
+                  iterations=(unsigned long) ((header[2] << 8) | header[1]);
+                break;
               }
-              info=(unsigned char *) ResizeMagickMemory(info,(size_t)
-                info_length);
-              profile=AcquireStringInfo((size_t) info_length);
-              SetStringInfoDatum(profile,(const unsigned char *) info);
-              if (i8bim == MagickTrue)
-                (void) CopyMagickString(name,"8bim",sizeof(name));
-              if (icc == MagickTrue)
-                (void) CopyMagickString(name,"icc",sizeof(name));
-              else if (iptc == MagickTrue)
-                (void) CopyMagickString(name,"iptc",sizeof(name));
-              else
-                (void) FormatMagickString(name,sizeof(name),"gif:%.11s",header);
-              (void) SetImageProfile(image,name,profile);
-              profile=DestroyStringInfo(profile);
-              (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+            else
+              {
+                /* store GIF application extension as a generic profile */
+                char
+                  name[MaxTextExtent];
+
+                StringInfo
+                  *profile;
+
+                unsigned char
+                  *info;
+
+                MagickBooleanType
+                  i8bim,
+                  icc,
+                  iptc;
+
+                int
+                   block_length,
+                   info_length,
+                   reserved_length;
+
+                i8bim=LocaleNCompare((char *) header,"MGK8BIM0000",11) == 0 ?
+                  MagickTrue : MagickFalse;
+                icc=LocaleNCompare((char *) header,"ICCRGBG1012",11) == 0 ?
+                  MagickTrue : MagickFalse;
+                iptc=LocaleNCompare((char *) header,"MGKIPTC0000",11) == 0 ?
+                  MagickTrue : MagickFalse;
+                number_extensionss++;
+                (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+                  "    Reading GIF application extension");
+                info=(unsigned char *) AcquireQuantumMemory(255UL,
+                  sizeof(*info));
+                info_length=0;
+                reserved_length=255;
+                for ( ; ; )
+                {
+                  block_length=(int) ReadBlobBlock(image,&info[info_length]);
+                  if (block_length == 0)
+                    break;
+                  info_length+=block_length;
+                  if (info_length > (reserved_length-255))
+                    {
+                       reserved_length+=4096;
+                       info=(unsigned char *) ResizeQuantumMemory(info,
+                         (size_t) reserved_length,sizeof(*info));
+                    }
+                }
+                info=(unsigned char *) ResizeQuantumMemory(info,(size_t)
+                  (info_length+1),sizeof(*info));
+                profile=AcquireStringInfo((size_t) info_length);
+                SetStringInfoDatum(profile,(const unsigned char *) info);
+                if (i8bim == MagickTrue)
+                  (void) CopyMagickString(name,"8bim",sizeof(name));
+                if (icc == MagickTrue)
+                  (void) CopyMagickString(name,"icc",sizeof(name));
+                else
+                  if (iptc == MagickTrue)
+                    (void) CopyMagickString(name,"iptc",sizeof(name));
+                  else
+                    (void) FormatMagickString(name,sizeof(name),"gif:%.11s",
+                      header);
+                (void) SetImageProfile(image,name,profile);
+                profile=DestroyStringInfo(profile);
+                (void) LogMagickEvent(CoderEvent,GetMagickModule(),
                   "      profile name=%s",name);
-            }
+              }
             break;
           }
           default:
@@ -1277,7 +1280,7 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
           image->colormap[i].blue=ScaleCharToQuantum(*p++);
           if (i == opacity)
             {
-              image->colormap[i].opacity=TransparentOpacity;
+              image->colormap[i].opacity=(Quantum) TransparentOpacity;
               image->transparent_color=image->colormap[opacity];
             }
         }
@@ -1292,8 +1295,8 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Read local colormap.
         */
-        colormap=(unsigned char *) AcquireMagickMemory((3*image->colors)*
-          sizeof(*colormap));
+        colormap=(unsigned char *) AcquireQuantumMemory(image->colors,
+          3*sizeof(*colormap));
         if (colormap == (unsigned char *) NULL)
           {
             global_colormap=(unsigned char *) RelinquishMagickMemory(
@@ -1316,7 +1319,7 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
           image->colormap[i].green=ScaleCharToQuantum(*p++);
           image->colormap[i].blue=ScaleCharToQuantum(*p++);
           if (i == opacity)
-            image->colormap[i].opacity=TransparentOpacity;
+            image->colormap[i].opacity=(Quantum) TransparentOpacity;
         }
         colormap=(unsigned char *) RelinquishMagickMemory(colormap);
       }
@@ -1329,7 +1332,14 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if (image_info->ping != MagickFalse)
       status=PingGIFImage(image);
     else
-      status=DecodeImage(image,(Quantum) opacity);
+      {
+        if (SetImageExtent(image,0,0) == MagickFalse)
+          {
+            InheritException(exception,&image->exception);
+            return(DestroyImageList(image));
+          }
+        status=DecodeImage(image,(Quantum) opacity);
+      }
     if ((image_info->ping == MagickFalse) && (status == MagickFalse))
       {
         global_colormap=(unsigned char *) RelinquishMagickMemory(
@@ -1368,30 +1378,31 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterGIFImage method is:
 %
-%      RegisterGIFImage(void)
+%      unsigned long RegisterGIFImage(void)
 %
 */
-ModuleExport void RegisterGIFImage(void)
+ModuleExport unsigned long RegisterGIFImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("GIF");
-  entry->decoder=(DecoderHandler *) ReadGIFImage;
-  entry->encoder=(EncoderHandler *) WriteGIFImage;
-  entry->magick=(MagickHandler *) IsGIF;
+  entry->decoder=(DecodeImageHandler *) ReadGIFImage;
+  entry->encoder=(EncodeImageHandler *) WriteGIFImage;
+  entry->magick=(IsImageFormatHandler *) IsGIF;
   entry->description=ConstantString("CompuServe graphics interchange format");
   entry->module=ConstantString("GIF");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("GIF87");
-  entry->decoder=(DecoderHandler *) ReadGIFImage;
-  entry->encoder=(EncoderHandler *) WriteGIFImage;
-  entry->magick=(MagickHandler *) IsGIF;
+  entry->decoder=(DecodeImageHandler *) ReadGIFImage;
+  entry->encoder=(EncodeImageHandler *) WriteGIFImage;
+  entry->magick=(IsImageFormatHandler *) IsGIF;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("CompuServe graphics interchange format");
   entry->version=ConstantString("version 87a");
   entry->module=ConstantString("GIF");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -1503,9 +1514,9 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
   /*
     Allocate colormap.
   */
-  global_colormap=(unsigned char *) AcquireMagickMemory(768*
+  global_colormap=(unsigned char *) AcquireQuantumMemory(768UL,
     sizeof(*global_colormap));
-  colormap=(unsigned char *) AcquireMagickMemory(768*sizeof(*colormap));
+  colormap=(unsigned char *) AcquireQuantumMemory(768UL,sizeof(*colormap));
   if ((global_colormap == (unsigned char *) NULL) ||
       (colormap == (unsigned char *) NULL))
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
@@ -1583,9 +1594,9 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
                   opacity=i;
                   continue;
                 }
-              alpha=TransparentOpacity-(MagickRealType)
+              alpha=(MagickRealType) TransparentOpacity-(MagickRealType)
                 image->colormap[i].opacity;
-              beta=TransparentOpacity-(MagickRealType)
+              beta=(MagickRealType) TransparentOpacity-(MagickRealType)
                 image->colormap[opacity].opacity;
               if (alpha < beta)
                 opacity=i;
@@ -1601,9 +1612,9 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
                       opacity=i;
                       continue;
                     }
-                  alpha=TransparentOpacity-(MagickRealType)
+                  alpha=(Quantum) TransparentOpacity-(MagickRealType)
                     image->colormap[i].opacity;
-                  beta=TransparentOpacity-(MagickRealType)
+                  beta=(Quantum) TransparentOpacity-(MagickRealType)
                     image->colormap[opacity].opacity;
                   if (alpha < beta)
                     opacity=i;
@@ -1672,7 +1683,7 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
           0));
         (void) WriteBlobByte(image,(unsigned char) 0x00);
         if ((LocaleCompare(write_info->magick,"GIF87") != 0) &&
-            (GetImageProperty(image,"Comment") != (const char *) NULL))
+            (GetImageProperty(image,"comment") != (const char *) NULL))
           {
             const char
               *value;
@@ -1688,7 +1699,7 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
             */
             (void) WriteBlobByte(image,(unsigned char) 0x21);
             (void) WriteBlobByte(image,(unsigned char) 0xfe);
-            value=GetImageProperty(image,"Comment");
+            value=GetImageProperty(image,"comment");
             p=value;
             while (strlen(p) != 0)
             {
@@ -1717,16 +1728,15 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
             (void) WriteBlobLSBShort(image,(unsigned short) image->iterations);
             (void) WriteBlobByte(image,(unsigned char) 0x00);
           }
-
         ResetImageProfileIterator(image);
-        for (;;)
+        for ( ; ; )
         {
-          const StringInfo
-            *profile;
-
           char
             *name;
 
+          const StringInfo
+            *profile;
+
           name=GetNextImageProfile(image);
           if (name == (const char *) NULL)
             break;
@@ -1739,68 +1749,76 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
                 (LocaleCompare(name,"8BIM") == 0) ||
                 (LocaleNCompare(name,"gif:",4) == 0))
             {
-               int
-                 profile_length,
-                 profile_ptr;
-              
+               size_t
+                 length;
+
+               ssize_t
+                 offset;
+
                unsigned char
-                 *profile_data;
-
-               profile_data=GetStringInfoDatum(profile);
-               profile_length=(int) GetStringInfoLength(profile);
+                 *datum;
 
+               datum=GetStringInfoDatum(profile);
+               length=GetStringInfoLength(profile);
                (void) WriteBlobByte(image,(unsigned char) 0x21);
                (void) WriteBlobByte(image,(unsigned char) 0xff);
                (void) WriteBlobByte(image,(unsigned char) 0x0b);
-
                if ((LocaleCompare(name,"ICC") == 0) ||
                    (LocaleCompare(name,"ICM") == 0))
-               {
-                 /* write ICC extension */
-                 (void) WriteBlob(image,11,(unsigned char *)"ICCRGBG1012");
-                 (void) LogMagickEvent(CoderEvent,GetMagickModule(),
-                     "  Writing GIF Extension %s","ICCRGBG1012");
-               }
-               else if ((LocaleCompare(name,"IPTC") == 0))
-               {
-                 /* write IPTC extension */
-                 (void) WriteBlob(image,11,(unsigned char *)"MGKIPTC0000");
-                 (void) LogMagickEvent(CoderEvent,GetMagickModule(),
-                     "  Writing GIF Extension %s","MGKIPTC0000");
-               }
-               else if ((LocaleCompare(name,"8BIM") == 0))
-               {
-                 /* write 8BIM extension */
-                 (void) WriteBlob(image,11,(unsigned char *)"MGK8BIM0000");
-                 (void) LogMagickEvent(CoderEvent,GetMagickModule(),
-                     "  Writing GIF Extension %s","MGK8BIM0000");
-               }
+                 {
+                   /*
+                     Write ICC extension.
+                   */
+                   (void) WriteBlob(image,11,(unsigned char *)"ICCRGBG1012");
+                   (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+                       "  Writing GIF Extension %s","ICCRGBG1012");
+                 }
                else
-               {
-                 char
-                   extension[MaxTextExtent];
+                 if ((LocaleCompare(name,"IPTC") == 0))
+                   {
+                     /*
+                       write IPTC extension.
+                     */
+                     (void) WriteBlob(image,11,(unsigned char *)"MGKIPTC0000");
+                     (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+                         "  Writing GIF Extension %s","MGKIPTC0000");
+                   }
+                 else
+                   if ((LocaleCompare(name,"8BIM") == 0))
+                     {
+                       /*
+                         Write 8BIM extension>
+                       */
+                        (void) WriteBlob(image,11,(unsigned char *)
+                          "MGK8BIM0000");
+                        (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+                          "  Writing GIF Extension %s","MGK8BIM0000");
+                     }
+                   else
+                     {
+                       char
+                         extension[MaxTextExtent];
 
-                 /* write generic extension */
-                 (void) CopyMagickString(extension,name+4,sizeof(extension));
-                 (void) WriteBlob(image,11,(unsigned char *) extension);
-                 (void) LogMagickEvent(CoderEvent,GetMagickModule(),
-                     "  Writing GIF Extension %s",name);
-               }
-
-               profile_ptr=0;
-               while (profile_length > profile_ptr)
+                       /* write generic extension */
+                       (void) CopyMagickString(extension,name+4,
+                         sizeof(extension));
+                       (void) WriteBlob(image,11,(unsigned char *) extension);
+                       (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+                          "  Writing GIF Extension %s",name);
+                     }
+               offset=0;
+               while ((ssize_t) length > offset)
                {
-                 int
+                 size_t
                    block_length;
 
-                 if (profile_length - profile_ptr < 255)
-                   block_length=profile_length-profile_ptr;
+                 if ((length-offset) < 255)
+                   block_length=length-offset;
                  else
                    block_length=255;
                  (void) WriteBlobByte(image,(unsigned char) block_length);
-                 (void) WriteBlob(image,(size_t) block_length,
-                   &profile_data[profile_ptr]);
-                 profile_ptr+=block_length;
+                 (void) WriteBlob(image,(size_t) block_length,datum+offset);
+                 offset+=(ssize_t) block_length;
                }
                (void) WriteBlobByte(image,(unsigned char) 0x00);
             }
