@@ -52,11 +52,12 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -287,22 +288,23 @@ static Image *ReadGRAYImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterGRAYImage method is:
 %
-%      RegisterGRAYImage(void)
+%      unsigned long RegisterGRAYImage(void)
 %
 */
-ModuleExport void RegisterGRAYImage(void)
+ModuleExport unsigned long RegisterGRAYImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("GRAY");
-  entry->decoder=(DecoderHandler *) ReadGRAYImage;
-  entry->encoder=(EncoderHandler *) WriteGRAYImage;
+  entry->decoder=(DecodeImageHandler *) ReadGRAYImage;
+  entry->encoder=(EncodeImageHandler *) WriteGRAYImage;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->description=ConstantString("Raw gray samples");
   entry->module=ConstantString("GRAY");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
