@@ -54,10 +54,11 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/resource_.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -85,20 +86,21 @@ static MagickBooleanType
 %
 %  The format of the RegisterHISTOGRAMImage method is:
 %
-%      RegisterHISTOGRAMImage(void)
+%      unsigned long RegisterHISTOGRAMImage(void)
 %
 */
-ModuleExport void RegisterHISTOGRAMImage(void)
+ModuleExport unsigned long RegisterHISTOGRAMImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("HISTOGRAM");
-  entry->encoder=(EncoderHandler *) WriteHISTOGRAMImage;
+  entry->encoder=(EncodeImageHandler *) WriteHISTOGRAMImage;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Histogram of the image");
   entry->module=ConstantString("HISTOGRAM");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -242,10 +244,10 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
   /*
     Allocate histogram count arrays.
   */
-  length=MagickMax((size_t) ScaleQuantumToChar((Quantum) QuantumRange)+1,
+  length=MagickMax((size_t) ScaleQuantumToChar((Quantum) QuantumRange)+1UL,
     histogram_image->columns);
-  histogram=(MagickPixelPacket *)
-    AcquireMagickMemory(length*sizeof(*histogram));
+  histogram=(MagickPixelPacket *) AcquireQuantumMemory(length,
+    sizeof(*histogram));
   if (histogram == (MagickPixelPacket *) NULL)
     {
       histogram_image=DestroyImage(histogram_image);
@@ -356,10 +358,10 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
       */
       (void) GetNumberColors(image,file,&image->exception);
       (void) fclose(file);
-      property=FileToString(filename,~0,&image->exception);
+      property=FileToString(filename,~0UL,&image->exception);
       if (property != (char *) NULL)
         {
-          (void) SetImageProperty(histogram_image,"Comment",property);
+          (void) SetImageProperty(histogram_image,"comment",property);
           property=DestroyString(property);
         }
     }
