@@ -54,9 +54,10 @@
 #include "magick/monitor.h"
 #include "magick/nt-feature.h"
 #include "magick/quantize.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Define declarations.
@@ -501,7 +502,7 @@ static Image *ReadICONImage(const ImageInfo *image_info,
             q->green=ScaleCharToQuantum((unsigned char) ReadBlobByte(image));
             q->red=ScaleCharToQuantum((unsigned char) ReadBlobByte(image));
             if (icon_info.bits_per_pixel == 32)
-              q->opacity=QuantumRange-ScaleCharToQuantum(
+              q->opacity=(Quantum) QuantumRange-ScaleCharToQuantum(
                 (unsigned char) ReadBlobByte(image));
             q++;
           }
@@ -610,38 +611,39 @@ static Image *ReadICONImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterICONImage method is:
 %
-%      RegisterICONImage(void)
+%      unsigned long RegisterICONImage(void)
 %
 */
-ModuleExport void RegisterICONImage(void)
+ModuleExport unsigned long RegisterICONImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("CUR");
-  entry->decoder=(DecoderHandler *) ReadICONImage;
-  entry->encoder=(EncoderHandler *) WriteICONImage;
+  entry->decoder=(DecodeImageHandler *) ReadICONImage;
+  entry->encoder=(EncodeImageHandler *) WriteICONImage;
   entry->adjoin=MagickFalse;
   entry->seekable_stream=MagickTrue;
   entry->description=ConstantString("Microsoft icon");
   entry->module=ConstantString("CUR");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("ICO");
-  entry->decoder=(DecoderHandler *) ReadICONImage;
-  entry->encoder=(EncoderHandler *) WriteICONImage;
+  entry->decoder=(DecodeImageHandler *) ReadICONImage;
+  entry->encoder=(EncodeImageHandler *) WriteICONImage;
   entry->adjoin=MagickTrue;
   entry->seekable_stream=MagickTrue;
   entry->description=ConstantString("Microsoft icon");
   entry->module=ConstantString("ICON");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("ICON");
-  entry->decoder=(DecoderHandler *) ReadICONImage;
-  entry->encoder=(EncoderHandler *) WriteICONImage;
+  entry->decoder=(DecodeImageHandler *) ReadICONImage;
+  entry->encoder=(EncodeImageHandler *) WriteICONImage;
   entry->adjoin=MagickFalse;
   entry->seekable_stream=MagickTrue;
   entry->description=ConstantString("Microsoft icon");
   entry->module=ConstantString("ICON");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -1095,7 +1097,8 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
       for (x=0; x < (long) next->columns; x++)
       {
         byte<<=1;
-        if ((next->matte == MagickTrue) && (p->opacity == TransparentOpacity))
+        if ((next->matte == MagickTrue) &&
+            (p->opacity == (Quantum) TransparentOpacity))
           byte|=0x01;
         bit++;
         if (bit == 8)
