@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -55,9 +55,10 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/nt-feature.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #if defined(HasJBIG)
 #include "jbig.h"
 #endif
@@ -158,18 +159,18 @@ static Image *ReadJBIGImage(const ImageInfo *image_info,
     Initialize JBIG toolkit.
   */
   jbg_dec_init(&jbig_info);
-  jbg_dec_maxsize(&jbig_info,(unsigned long) image->columns,
-    (unsigned long) image->rows);
-  image->columns= jbg_dec_getwidth(&jbig_info);
-  image->rows= jbg_dec_getheight(&jbig_info);
+  jbg_dec_maxsize(&jbig_info,(unsigned long) image->columns,(unsigned long)
+    image->rows);
+  image->columns=jbg_dec_getwidth(&jbig_info);
+  image->rows=jbg_dec_getheight(&jbig_info);
   image->depth=8;
   image->storage_class=PseudoClass;
   image->colors=2;
   /*
     Read JBIG file.
   */
-  buffer=(unsigned char *) AcquireMagickMemory(MagickMaxBufferSize*
-    sizeof(buffer));
+  buffer=(unsigned char *) AcquireQuantumMemory(MagickMaxBufferSize,
+    sizeof(*buffer));
   if (buffer == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   status=JBG_EAGAIN;
@@ -216,6 +217,11 @@ static Image *ReadJBIGImage(const ImageInfo *image_info,
   /*
     Convert X bitmap image to pixel packets.
   */
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   p=jbg_dec_getimage(&jbig_info,0);
   for (y=0; y < (long) image->rows; y++)
   {
@@ -235,7 +241,7 @@ static Image *ReadJBIGImage(const ImageInfo *image_info,
       if (bit == 8)
         bit=0;
       indexes[x]=index;
-      *q++=image->colormap[index];
+      *q++=image->colormap[(long) index];
     }
     if (SyncImagePixels(image) == MagickFalse)
       break;
@@ -278,10 +284,10 @@ static Image *ReadJBIGImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterJBIGImage method is:
 %
-%      RegisterJBIGImage(void)
+%      unsigned long RegisterJBIGImage(void)
 %
 */
-ModuleExport void RegisterJBIGImage(void)
+ModuleExport unsigned long RegisterJBIGImage(void)
 {
 #define JBIGDescription  "Joint Bi-level Image experts Group interchange format"
 
@@ -297,8 +303,8 @@ ModuleExport void RegisterJBIGImage(void)
 #endif
   entry=SetMagickInfo("BIE");
 #if defined(HasJBIG)
-  entry->decoder=(DecoderHandler *) ReadJBIGImage;
-  entry->encoder=(EncoderHandler *) WriteJBIGImage;
+  entry->decoder=(DecodeImageHandler *) ReadJBIGImage;
+  entry->encoder=(EncodeImageHandler *) WriteJBIGImage;
 #endif
   entry->adjoin=MagickFalse;
   entry->description=ConstantString(JBIGDescription);
@@ -308,8 +314,8 @@ ModuleExport void RegisterJBIGImage(void)
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("JBG");
 #if defined(HasJBIG)
-  entry->decoder=(DecoderHandler *) ReadJBIGImage;
-  entry->encoder=(EncoderHandler *) WriteJBIGImage;
+  entry->decoder=(DecodeImageHandler *) ReadJBIGImage;
+  entry->encoder=(EncodeImageHandler *) WriteJBIGImage;
 #endif
   entry->description=ConstantString(JBIGDescription);
   if (*version != '\0')
@@ -318,14 +324,15 @@ ModuleExport void RegisterJBIGImage(void)
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("JBIG");
 #if defined(HasJBIG)
-  entry->decoder=(DecoderHandler *) ReadJBIGImage;
-  entry->encoder=(EncoderHandler *) WriteJBIGImage;
+  entry->decoder=(DecodeImageHandler *) ReadJBIGImage;
+  entry->encoder=(EncodeImageHandler *) WriteJBIGImage;
 #endif
   entry->description=ConstantString(JBIGDescription);
   if (*version != '\0')
     entry->version=ConstantString(version);
   entry->module=ConstantString("JBIG");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -449,8 +456,9 @@ static MagickBooleanType WriteJBIGImage(const ImageInfo *image_info,
     */
     if (image_info->colorspace == UndefinedColorspace)
       (void) SetImageColorspace(image,RGBColorspace);
-    number_packets=((image->columns+7) >> 3)*image->rows;
-    pixels=(unsigned char *) AcquireMagickMemory(number_packets);
+    number_packets=(image->columns+7)/8;
+    pixels=(unsigned char *) AcquireQuantumMemory(number_packets,
+      image->rows*sizeof(*pixels));
     if (pixels == (unsigned char *) NULL)
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
     /*
