@@ -55,11 +55,18 @@
 #include "magick/monitor.h"
 #include "magick/option.h"
 #include "magick/profile.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #if defined(HasJP2)
+#ifndef JAS_IMAGE_CM_GRAY
+#define JAS_IMAGE_CM_GRAY JAS_IMAGE_CS_GRAY
+#endif
+#ifndef JAS_IMAGE_CM_RGB
+#define JAS_IMAGE_CM_RGB JAS_IMAGE_CS_RGB
+#endif
 #if !defined(uchar)
 #define uchar  unsigned char
 #endif
@@ -213,7 +220,7 @@ static int BlobRead(jas_stream_obj_t *object,char *buffer,const int length)
 
 static int BlobWrite(jas_stream_obj_t *object,char *buffer,const int length)
 {
-  size_t
+  ssize_t
     count;
 
   StreamManager
@@ -230,7 +237,7 @@ static long BlobSeek(jas_stream_obj_t *object,long offset,int origin)
     *source;
 
   source=(StreamManager *) object;
-  return(SeekBlob(source->image,offset,origin));
+  return((long) SeekBlob(source->image,offset,origin));
 }
 
 static int BlobClose(jas_stream_obj_t *object)
@@ -445,9 +452,9 @@ static Image *ReadJP2Image(const ImageInfo *image_info,ExceptionInfo *exception)
   image->rows=jas_image_height(jp2_image);
   for (i=0; i < (long) number_components; i++)
   {
-    if ((((jas_image_cmptwidth(jp2_image,components[i])*
+    if ((((long) (jas_image_cmptwidth(jp2_image,components[i])*
           jas_image_cmpthstep(jp2_image,components[i])) != (long) image->columns)) ||
-        (((jas_image_cmptheight(jp2_image,components[i])*
+        (((long) (jas_image_cmptheight(jp2_image,components[i])*
           jas_image_cmptvstep(jp2_image,components[i])) != (long) image->rows)) ||
         (jas_image_cmpttlx(jp2_image,components[i]) != 0) ||
         (jas_image_cmpttly(jp2_image,components[i]) != 0) ||
@@ -457,25 +464,31 @@ static Image *ReadJP2Image(const ImageInfo *image_info,ExceptionInfo *exception)
         jas_image_destroy(jp2_image);
         ThrowReaderException(CoderError,"IrregularChannelGeometryNotSupported");
       }
-    x_step[i]=jas_image_cmpthstep(jp2_image,components[i]);
-    y_step[i]=jas_image_cmptvstep(jp2_image,components[i]);
+    x_step[i]=(unsigned int) jas_image_cmpthstep(jp2_image,components[i]);
+    y_step[i]=(unsigned int) jas_image_cmptvstep(jp2_image,components[i]);
   }
   /*
     Convert JPEG 2000 pixels.
   */
+  image->matte=number_components > 3 ? MagickTrue : MagickFalse;
   if (image_info->ping != MagickFalse)
     {
       (void) jas_stream_close(jp2_stream);
       jas_image_destroy(jp2_image);
       return(GetFirstImageInList(image));
     }
-  image->matte=number_components > 3 ? MagickTrue : MagickFalse;
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   maximum_component_depth=0;
   for (i=0; i < (long) number_components; i++)
   {
-    maximum_component_depth=(unsigned int) MagickMax(jas_image_cmptprec(
-      jp2_image,components[i]),(long) maximum_component_depth);
-    pixels[i]=jas_matrix_create(1,((unsigned int) image->columns)/x_step[i]);
+    maximum_component_depth=(unsigned int) MagickMax((size_t)
+      jas_image_cmptprec(jp2_image,components[i]),(size_t)
+      maximum_component_depth);
+    pixels[i]=jas_matrix_create(1,(int) image->columns/x_step[i]);
     if (pixels[i] == (jas_matrix_t *) NULL)
       {
         jas_image_destroy(jp2_image);
@@ -490,12 +503,12 @@ static Image *ReadJP2Image(const ImageInfo *image_info,ExceptionInfo *exception)
   {
     scale[i]=1;
     if (jas_image_cmptprec(jp2_image,components[i]) < 16)
-      scale[i]=(1 << (16-jas_image_cmptprec(jp2_image,components[i])));
+      scale[i]=(1U << (16-jas_image_cmptprec(jp2_image,components[i])));
   }
   if (number_components == 1)
     {
       image->storage_class=PseudoClass;
-      image->colors=(image->depth == 8 ? 256 : MaxColormapSize);
+      image->colors=(image->depth == 8 ? 256UL : MaxColormapSize);
       if (AllocateImageColormap(image,image->colors) == MagickFalse)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     }
@@ -572,7 +585,7 @@ static Image *ReadJP2Image(const ImageInfo *image_info,ExceptionInfo *exception)
             jas_matrix_getv(pixels[1],x/x_step[1])));
           q->blue=ScaleShortToQuantum((unsigned short) (scale[2]*
             jas_matrix_getv(pixels[2],x/x_step[2])));
-          q->opacity=QuantumRange-ScaleShortToQuantum((unsigned short)
+          q->opacity=(Quantum) QuantumRange-ScaleShortToQuantum((unsigned short)
             (scale[3]*jas_matrix_getv(pixels[3],x/x_step[3])));
           q++;
         }
@@ -623,9 +636,9 @@ static Image *ReadJP2Image(const ImageInfo *image_info,ExceptionInfo *exception)
           SetStringInfoDatum(profile,blob->buf_);
           icc_profile=(StringInfo *) GetImageProfile(image,"icc");
           if (icc_profile == (StringInfo *) NULL)
-            SetImageProfile(image,"icc",profile);
+            (void) SetImageProfile(image,"icc",profile);
           else
-            ConcatenateStringInfo(icc_profile,profile);
+            (void) ConcatenateStringInfo(icc_profile,profile);
           profile=DestroyStringInfo(profile);
           (void) jas_stream_close(icc_stream);
         }
@@ -657,10 +670,10 @@ static Image *ReadJP2Image(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterJP2Image method is:
 %
-%      RegisterJP2Image(void)
+%      unsigned long RegisterJP2Image(void)
 %
 */
-ModuleExport void RegisterJP2Image(void)
+ModuleExport unsigned long RegisterJP2Image(void)
 {
   MagickInfo
     *entry;
@@ -668,53 +681,54 @@ ModuleExport void RegisterJP2Image(void)
   entry=SetMagickInfo("JP2");
   entry->description=ConstantString("JPEG-2000 File Format Syntax");
   entry->module=ConstantString("JP2");
-  entry->magick=(MagickHandler *) IsJP2;
+  entry->magick=(IsImageFormatHandler *) IsJP2;
   entry->adjoin=MagickFalse;
   entry->seekable_stream=MagickTrue;
   entry->thread_support=NoThreadSupport;
 #if defined(HasJP2)
-  entry->decoder=(DecoderHandler *) ReadJP2Image;
-  entry->encoder=(EncoderHandler *) WriteJP2Image;
+  entry->decoder=(DecodeImageHandler *) ReadJP2Image;
+  entry->encoder=(EncodeImageHandler *) WriteJP2Image;
 #endif
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("JPC");
   entry->description=ConstantString("JPEG-2000 Code Stream Syntax");
   entry->module=ConstantString("JPC");
-  entry->magick=(MagickHandler *) IsJPC;
+  entry->magick=(IsImageFormatHandler *) IsJPC;
   entry->adjoin=MagickFalse;
   entry->seekable_stream=MagickTrue;
   entry->thread_support=NoThreadSupport;
 #if defined(HasJP2)
-  entry->decoder=(DecoderHandler *) ReadJP2Image;
-  entry->encoder=(EncoderHandler *) WriteJP2Image;
+  entry->decoder=(DecodeImageHandler *) ReadJP2Image;
+  entry->encoder=(EncodeImageHandler *) WriteJP2Image;
 #endif
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("JPX");
   entry->description=ConstantString("JPEG-2000 File Format Syntax");
   entry->module=ConstantString("JPX");
-  entry->magick=(MagickHandler *) IsJPC;
+  entry->magick=(IsImageFormatHandler *) IsJPC;
   entry->adjoin=MagickFalse;
   entry->seekable_stream=MagickTrue;
   entry->thread_support=NoThreadSupport;
 #if defined(HasJP2)
-  entry->decoder=(DecoderHandler *) ReadJP2Image;
-  entry->encoder=(EncoderHandler *) WriteJP2Image;
+  entry->decoder=(DecodeImageHandler *) ReadJP2Image;
+  entry->encoder=(EncodeImageHandler *) WriteJP2Image;
 #endif
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PGX");
   entry->description=ConstantString("JPEG-2000 VM Format");
   entry->module=ConstantString("PGX");
-  entry->magick=(MagickHandler *) IsJPC;
+  entry->magick=(IsImageFormatHandler *) IsJPC;
   entry->adjoin=MagickFalse;
   entry->seekable_stream=MagickTrue;
   entry->thread_support=NoThreadSupport;
 #if defined(HasJP2)
-  entry->decoder=(DecoderHandler *) ReadJP2Image;
+  entry->decoder=(DecodeImageHandler *) ReadJP2Image;
 #endif
   (void) RegisterMagickInfo(entry);
 #if defined(HasJP2)
   jas_init();
 #endif
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -834,7 +848,7 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
   jp2_stream=JP2StreamManager(image);
   if (jp2_stream == (jas_stream_t *) NULL)
     ThrowWriterException(DelegateError,"UnableToManageJP2Stream");
-  number_components=image->matte ? 4 : 3;
+  number_components=image->matte ? 4UL : 3UL;
   if ((image_info->type != TrueColorType) &&
       IsGrayImage(image,&image->exception))
     number_components=1;
@@ -846,10 +860,10 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
     component_info[i].vstep=1;
     component_info[i].width=(unsigned int) image->columns;
     component_info[i].height=(unsigned int) image->rows;
-    component_info[i].prec=(unsigned int) MagickMin(image->depth,16);
+    component_info[i].prec=(int) MagickMin(image->depth,16);
     component_info[i].sgnd=MagickFalse;
   }
-  jp2_image=jas_image_create(number_components,component_info,
+  jp2_image=jas_image_create((int) number_components,component_info,
     JAS_CLRSPC_UNKNOWN);
   if (jp2_image == (jas_image_t *) NULL)
     ThrowWriterException(DelegateError,"UnableToCreateImage");
@@ -882,7 +896,7 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
   */
   for (i=0; i < (long) number_components; i++)
   {
-    pixels[i]=jas_matrix_create(1,(unsigned int) image->columns);
+    pixels[i]=jas_matrix_create(1,(int) image->columns);
     if (pixels[i] == (jas_matrix_t *) NULL)
       {
         for (x=0; x < i; x++)
@@ -941,10 +955,10 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
       {
         if (LocaleNCompare(key,"jp2:",4) == 0)
           {
-            ConcatenateString(&options,key+4);
-            ConcatenateString(&options,"=");
-            ConcatenateString(&options,option);
-            ConcatenateString(&options," ");
+            (void) ConcatenateString(&options,key+4);
+            (void) ConcatenateString(&options,"=");
+            (void) ConcatenateString(&options,option);
+            (void) ConcatenateString(&options," ");
           }
        }
     key=GetNextImageOption(image_info);
@@ -953,7 +967,7 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
   if ((option == (const char *) NULL) &&
       (image->compression != LosslessJPEGCompression) &&
       (image->quality != UndefinedCompressionQuality) &&
-      (image->quality < 99.5) && ((image->rows*image->columns) > 2500))
+      (image->quality <= 99) && ((image->rows*image->columns) > 2500))
     {
       char
         option[MaxTextExtent];
@@ -965,7 +979,7 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
         rate,
         target_size;
 
-      alpha=115-image->quality;
+      alpha=115.0-image->quality;
       rate=100.0/(alpha*alpha);
       header_size=550.0;
       header_size+=(number_components-1)*142;
@@ -973,8 +987,8 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
         (GetImageQuantumDepth(image,MagickTrue)/8);
       target_size=(number_pixels*rate)+header_size;
       rate=target_size/number_pixels;
-      FormatMagickString(option,MaxTextExtent,"rate=%g",rate);
-      ConcatenateString(&options,option);
+      (void) FormatMagickString(option,MaxTextExtent,"rate=%g",rate);
+      (void) ConcatenateString(&options,option);
     }
   status=jas_image_encode(jp2_image,jp2_stream,format,options) != 0 ?
     MagickTrue : MagickFalse;
