@@ -63,11 +63,12 @@
 #include "magick/option.h"
 #include "magick/profile.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/resource_.h"
 #include "magick/splay-tree.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/utility.h"
 #include <setjmp.h>
 #if defined(HasJPEG)
@@ -323,7 +324,7 @@ static boolean ReadComment(j_decompress_ptr jpeg_info)
   for (p=comment; i-- >= 0; p++)
     *p=(char) GetCharacter(jpeg_info);
   *p='\0';
-  (void) SetImageProperty(image,"Comment",comment);
+  (void) SetImageProperty(image,"comment",comment);
   comment=DestroyString(comment);
   return(MagickTrue);
 }
@@ -1109,14 +1110,14 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
           else
             for (x=0; x < (long) image->columns; x++)
             {
-              q->red=QuantumRange-ScaleShortToQuantum((unsigned char)
+              q->red=(Quantum) QuantumRange-ScaleShortToQuantum((unsigned char)
                 (GETJSAMPLE(*p++) << 4));
-              q->green=QuantumRange-ScaleShortToQuantum((unsigned char)
-                (GETJSAMPLE(*p++) << 4));
-              q->blue=QuantumRange-ScaleShortToQuantum((unsigned char)
-                (GETJSAMPLE(*p++) << 4));
-              indexes[x]=QuantumRange-ScaleShortToQuantum((unsigned char)
+              q->green=(Quantum) QuantumRange-ScaleShortToQuantum(
+                (unsigned char) (GETJSAMPLE(*p++) << 4));
+              q->blue=(Quantum) QuantumRange-ScaleShortToQuantum((unsigned char)
                 (GETJSAMPLE(*p++) << 4));
+              indexes[x]=(IndexPacket) QuantumRange-ScaleShortToQuantum(
+                (unsigned char) (GETJSAMPLE(*p++) << 4));
               q++;
             }
       }
@@ -1141,14 +1142,14 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
         else
           for (x=0; x < (long) image->columns; x++)
           {
-            q->red=QuantumRange-ScaleCharToQuantum((unsigned char)
+            q->red=(Quantum) QuantumRange-ScaleCharToQuantum((unsigned char)
               GETJSAMPLE(*p++));
-            q->green=QuantumRange-ScaleCharToQuantum((unsigned char)
+            q->green=(Quantum) QuantumRange-ScaleCharToQuantum((unsigned char)
               GETJSAMPLE(*p++));
-            q->blue=QuantumRange-ScaleCharToQuantum((unsigned char)
-              GETJSAMPLE(*p++));
-            indexes[x]=QuantumRange-ScaleCharToQuantum((unsigned char)
+            q->blue=(Quantum) QuantumRange-ScaleCharToQuantum((unsigned char)
               GETJSAMPLE(*p++));
+            indexes[x]=(IndexPacket) QuantumRange-ScaleCharToQuantum(
+              (unsigned char) GETJSAMPLE(*p++));
             q++;
           }
     if (SyncImagePixels(image) == MagickFalse)
@@ -1194,10 +1195,10 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterJPEGImage method is:
 %
-%      RegisterJPEGImage(void)
+%      unsigned long RegisterJPEGImage(void)
 %
 */
-ModuleExport void RegisterJPEGImage(void)
+ModuleExport unsigned long RegisterJPEGImage(void)
 {
   MagickInfo
     *entry;
@@ -1205,10 +1206,10 @@ ModuleExport void RegisterJPEGImage(void)
   entry=SetMagickInfo("JPEG");
   entry->thread_support=NoThreadSupport;
 #if defined(HasJPEG)
-  entry->decoder=(DecoderHandler *) ReadJPEGImage;
-  entry->encoder=(EncoderHandler *) WriteJPEGImage;
+  entry->decoder=(DecodeImageHandler *) ReadJPEGImage;
+  entry->encoder=(EncodeImageHandler *) WriteJPEGImage;
 #endif
-  entry->magick=(MagickHandler *) IsJPEG;
+  entry->magick=(IsImageFormatHandler *) IsJPEG;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString(
     "Joint Photographic Experts Group JFIF format");
@@ -1226,8 +1227,8 @@ ModuleExport void RegisterJPEGImage(void)
   entry=SetMagickInfo("JPG");
   entry->thread_support=NoThreadSupport;
 #if defined(HasJPEG)
-  entry->decoder=(DecoderHandler *) ReadJPEGImage;
-  entry->encoder=(EncoderHandler *) WriteJPEGImage;
+  entry->decoder=(DecodeImageHandler *) ReadJPEGImage;
+  entry->encoder=(EncodeImageHandler *) WriteJPEGImage;
 #endif
   entry->adjoin=MagickFalse;
   entry->description=ConstantString(
@@ -1237,14 +1238,15 @@ ModuleExport void RegisterJPEGImage(void)
   entry=SetMagickInfo("PJPEG");
   entry->thread_support=NoThreadSupport;
 #if defined(HasJPEG)
-  entry->decoder=(DecoderHandler *) ReadJPEGImage;
-  entry->encoder=(EncoderHandler *) WriteJPEGImage;
+  entry->decoder=(DecodeImageHandler *) ReadJPEGImage;
+  entry->encoder=(EncodeImageHandler *) WriteJPEGImage;
 #endif
   entry->adjoin=MagickFalse;
   entry->description=ConstantString(
     "Progessive Joint Photographic Experts Group JFIF");
   entry->module=ConstantString("JPEG");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -1934,7 +1936,7 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
   /*
     Write JPEG profiles.
   */
-  value=GetImageProperty(image,"Comment");
+  value=GetImageProperty(image,"comment");
   if (value != (char *) NULL)
     for (i=0; i < (long) strlen(value); i+=65533L)
       jpeg_write_marker(&jpeg_info,JPEG_COM,(unsigned char *) value+i,
