@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -52,10 +52,11 @@
 #include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -88,7 +89,6 @@ static MagickBooleanType
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadMAPImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
@@ -130,7 +130,8 @@ static Image *ReadMAPImage(const ImageInfo *image_info,ExceptionInfo *exception)
     *pixels;
 
   unsigned long
-    depth;
+    depth,
+    quantum;
 
   /*
     Open image file.
@@ -161,9 +162,11 @@ static Image *ReadMAPImage(const ImageInfo *image_info,ExceptionInfo *exception)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   depth=GetImageQuantumDepth(image,MagickTrue);
   packet_size=(size_t) (depth/8);
-  pixels=(unsigned char *) AcquireMagickMemory(packet_size*image->columns);
-  packet_size=(size_t) (image->colors > 256 ? 6 : 3);
-  colormap=(unsigned char *) AcquireMagickMemory(packet_size*image->colors);
+  pixels=(unsigned char *) AcquireQuantumMemory(image->columns,packet_size*
+    sizeof(*pixels));
+  packet_size=(size_t) (image->colors > 256 ? 6UL : 3UL);
+  colormap=(unsigned char *) AcquireQuantumMemory(image->colors,packet_size*
+    sizeof(*colormap));
   if ((pixels == (unsigned char *) NULL) ||
       (colormap == (unsigned char *) NULL))
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
@@ -184,12 +187,15 @@ static Image *ReadMAPImage(const ImageInfo *image_info,ExceptionInfo *exception)
   else
     for (i=0; i < (long) image->colors; i++)
     {
-      image->colormap[i].red=(Quantum) (*p++ << 8);
-      image->colormap[i].red|=(*p++);
-      image->colormap[i].green=(Quantum) (*p++ << 8);
-      image->colormap[i].green|=(*p++);
-      image->colormap[i].blue=(Quantum) (*p++ << 8);
-      image->colormap[i].blue|=(*p++);
+      quantum=(*p++ << 8);
+      quantum|=(*p++);
+      image->colormap[i].red=(Quantum) quantum;
+      quantum=(*p++ << 8);
+      quantum|=(*p++);
+      image->colormap[i].green=(Quantum) quantum;
+      quantum=(*p++ << 8);
+      quantum|=(*p++);
+      image->colormap[i].blue=(Quantum) quantum;
     }
   colormap=(unsigned char *) RelinquishMagickMemory(colormap);
   if (image_info->ping != MagickFalse)
@@ -200,6 +206,11 @@ static Image *ReadMAPImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Read image pixels.
   */
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   packet_size=(size_t) (depth/8);
   for (y=0; y < (long) image->rows; y++)
   {
@@ -217,11 +228,11 @@ static Image *ReadMAPImage(const ImageInfo *image_info,ExceptionInfo *exception)
       p++;
       if (image->colors > 256)
         {
-          index=ConstrainColormapIndex(image,(index << 8)+(*p));
+          index=ConstrainColormapIndex(image,((unsigned long) index << 8)+(*p));
           p++;
         }
       indexes[x]=(IndexPacket) index;
-      *q++=image->colormap[index];
+      *q++=image->colormap[(long) index];
     }
     if (SyncImagePixels(image) == MagickFalse)
       break;
@@ -254,23 +265,24 @@ static Image *ReadMAPImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterMAPImage method is:
 %
-%      RegisterMAPImage(void)
+%      unsigned long RegisterMAPImage(void)
 %
 */
-ModuleExport void RegisterMAPImage(void)
+ModuleExport unsigned long RegisterMAPImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("MAP");
-  entry->decoder=(DecoderHandler *) ReadMAPImage;
-  entry->encoder=(EncoderHandler *) WriteMAPImage;
+  entry->decoder=(DecodeImageHandler *) ReadMAPImage;
+  entry->encoder=(EncodeImageHandler *) WriteMAPImage;
   entry->adjoin=MagickFalse;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->description=ConstantString("Colormap intensities and indices");
   entry->module=ConstantString("MAP");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -375,9 +387,11 @@ static MagickBooleanType WriteMAPImage(const ImageInfo *image_info,Image *image)
     (void) SetImageType(image,PaletteType);
   depth=GetImageQuantumDepth(image,MagickTrue);
   packet_size=(size_t) (depth/8);
-  pixels=(unsigned char *) AcquireMagickMemory(packet_size*image->columns);
-  packet_size=(size_t) (image->colors > 256 ? 6 : 3);
-  colormap=(unsigned char *) AcquireMagickMemory(packet_size*image->colors);
+  pixels=(unsigned char *) AcquireQuantumMemory(image->columns,packet_size*
+    sizeof(*pixels));
+  packet_size=(size_t) (image->colors > 256 ? 6UL : 3UL);
+  colormap=(unsigned char *) AcquireQuantumMemory(image->colors,packet_size*
+    sizeof(*colormap));
   if ((pixels == (unsigned char *) NULL) ||
       (colormap == (unsigned char *) NULL))
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
@@ -417,7 +431,7 @@ static MagickBooleanType WriteMAPImage(const ImageInfo *image_info,Image *image)
     for (x=0; x < (long) image->columns; x++)
     {
       if (image->colors > 256)
-        *q++=(unsigned char) (indexes[x] >> 8);
+        *q++=(unsigned char) ((unsigned long) indexes[x] >> 8);
       *q++=(unsigned char) indexes[x];
     }
     (void) WriteBlob(image,(size_t) (q-pixels),pixels);
