@@ -51,9 +51,10 @@
 #include "magick/memory_.h"
 #include "magick/profile.h"
 #include "magick/splay-tree.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/token.h"
 #include "magick/utility.h"
 
@@ -150,7 +151,7 @@ typedef struct _html_code
     val;
 } html_code;
 
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 static html_code html_codes[] = {
 #ifdef HANDLE_GT_LT
   { 4,"&lt;",'<' },
@@ -887,6 +888,7 @@ static int jpeg_skip_variable2(Image *ifile, Image *ofile)
   unsigned int  length;
   int c1,c2;
 
+  (void) ofile;
   if ((c1 = ReadBlobByte(ifile)) == EOF) return M_EOI;
   if ((c2 = ReadBlobByte(ifile)) == EOF) return M_EOI;
 
@@ -1148,7 +1150,7 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
         }
       profile=AcquireStringInfo((size_t) GetBlobSize(buff));
       SetStringInfoDatum(profile,GetBlobStreamData(buff));
-      status=SetImageProfile(image,"iptc",profile);
+      status=SetImageProfile(image,"8bim",profile);
       profile=DestroyStringInfo(profile);
       if (status == MagickFalse)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
@@ -1394,17 +1396,17 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterMETAImage method is:
 %
-%      RegisterMETAImage(void)
+%      unsigned long RegisterMETAImage(void)
 %
 */
-ModuleExport void RegisterMETAImage(void)
+ModuleExport unsigned long RegisterMETAImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("8BIM");
-  entry->decoder=(DecoderHandler *) ReadMETAImage;
-  entry->encoder=(EncoderHandler *) WriteMETAImage;
+  entry->decoder=(DecodeImageHandler *) ReadMETAImage;
+  entry->encoder=(EncodeImageHandler *) WriteMETAImage;
   entry->adjoin=MagickFalse;
   entry->stealth=MagickTrue;
   entry->seekable_stream=MagickTrue;
@@ -1413,8 +1415,8 @@ ModuleExport void RegisterMETAImage(void)
   (void) RegisterMagickInfo(entry);
 
   entry=SetMagickInfo("8BIMTEXT");
-  entry->decoder=(DecoderHandler *) ReadMETAImage;
-  entry->encoder=(EncoderHandler *) WriteMETAImage;
+  entry->decoder=(DecodeImageHandler *) ReadMETAImage;
+  entry->encoder=(EncodeImageHandler *) WriteMETAImage;
   entry->adjoin=MagickFalse;
   entry->stealth=MagickTrue;
   entry->seekable_stream=MagickTrue;
@@ -1423,8 +1425,8 @@ ModuleExport void RegisterMETAImage(void)
   (void) RegisterMagickInfo(entry);
 
   entry=SetMagickInfo("8BIMWTEXT");
-  entry->decoder=(DecoderHandler *) ReadMETAImage;
-  entry->encoder=(EncoderHandler *) WriteMETAImage;
+  entry->decoder=(DecodeImageHandler *) ReadMETAImage;
+  entry->encoder=(EncodeImageHandler *) WriteMETAImage;
   entry->adjoin=MagickFalse;
   entry->stealth=MagickTrue;
   entry->seekable_stream=MagickTrue;
@@ -1433,8 +1435,8 @@ ModuleExport void RegisterMETAImage(void)
   (void) RegisterMagickInfo(entry);
 
   entry=SetMagickInfo("APP1");
-  entry->decoder=(DecoderHandler *) ReadMETAImage;
-  entry->encoder=(EncoderHandler *) WriteMETAImage;
+  entry->decoder=(DecodeImageHandler *) ReadMETAImage;
+  entry->encoder=(EncodeImageHandler *) WriteMETAImage;
   entry->adjoin=MagickFalse;
   entry->stealth=MagickTrue;
   entry->seekable_stream=MagickTrue;
@@ -1443,8 +1445,8 @@ ModuleExport void RegisterMETAImage(void)
   (void) RegisterMagickInfo(entry);
 
   entry=SetMagickInfo("APP1JPEG");
-  entry->decoder=(DecoderHandler *) ReadMETAImage;
-  entry->encoder=(EncoderHandler *) WriteMETAImage;
+  entry->decoder=(DecodeImageHandler *) ReadMETAImage;
+  entry->encoder=(EncodeImageHandler *) WriteMETAImage;
   entry->adjoin=MagickFalse;
   entry->stealth=MagickTrue;
   entry->seekable_stream=MagickTrue;
@@ -1453,8 +1455,8 @@ ModuleExport void RegisterMETAImage(void)
   (void) RegisterMagickInfo(entry);
 
   entry=SetMagickInfo("EXIF");
-  entry->decoder=(DecoderHandler *) ReadMETAImage;
-  entry->encoder=(EncoderHandler *) WriteMETAImage;
+  entry->decoder=(DecodeImageHandler *) ReadMETAImage;
+  entry->encoder=(EncodeImageHandler *) WriteMETAImage;
   entry->adjoin=MagickFalse;
   entry->stealth=MagickTrue;
   entry->seekable_stream=MagickTrue;
@@ -1463,8 +1465,8 @@ ModuleExport void RegisterMETAImage(void)
   (void) RegisterMagickInfo(entry);
 
   entry=SetMagickInfo("XMP");
-  entry->decoder=(DecoderHandler *) ReadMETAImage;
-  entry->encoder=(EncoderHandler *) WriteMETAImage;
+  entry->decoder=(DecodeImageHandler *) ReadMETAImage;
+  entry->encoder=(EncodeImageHandler *) WriteMETAImage;
   entry->adjoin=MagickFalse;
   entry->stealth=MagickTrue;
   entry->seekable_stream=MagickTrue;
@@ -1473,8 +1475,8 @@ ModuleExport void RegisterMETAImage(void)
   (void) RegisterMagickInfo(entry);
 
   entry=SetMagickInfo("ICM");
-  entry->decoder=(DecoderHandler *) ReadMETAImage;
-  entry->encoder=(EncoderHandler *) WriteMETAImage;
+  entry->decoder=(DecodeImageHandler *) ReadMETAImage;
+  entry->encoder=(EncodeImageHandler *) WriteMETAImage;
   entry->adjoin=MagickFalse;
   entry->stealth=MagickTrue;
   entry->seekable_stream=MagickTrue;
@@ -1483,8 +1485,8 @@ ModuleExport void RegisterMETAImage(void)
   (void) RegisterMagickInfo(entry);
 
   entry=SetMagickInfo("ICC");
-  entry->decoder=(DecoderHandler *) ReadMETAImage;
-  entry->encoder=(EncoderHandler *) WriteMETAImage;
+  entry->decoder=(DecodeImageHandler *) ReadMETAImage;
+  entry->encoder=(EncodeImageHandler *) WriteMETAImage;
   entry->adjoin=MagickFalse;
   entry->stealth=MagickTrue;
   entry->seekable_stream=MagickTrue;
@@ -1493,8 +1495,8 @@ ModuleExport void RegisterMETAImage(void)
   (void) RegisterMagickInfo(entry);
 
   entry=SetMagickInfo("IPTC");
-  entry->decoder=(DecoderHandler *) ReadMETAImage;
-  entry->encoder=(EncoderHandler *) WriteMETAImage;
+  entry->decoder=(DecodeImageHandler *) ReadMETAImage;
+  entry->encoder=(EncodeImageHandler *) WriteMETAImage;
   entry->adjoin=MagickFalse;
   entry->stealth=MagickTrue;
   entry->seekable_stream=MagickTrue;
@@ -1503,8 +1505,8 @@ ModuleExport void RegisterMETAImage(void)
   (void) RegisterMagickInfo(entry);
 
   entry=SetMagickInfo("IPTCTEXT");
-  entry->decoder=(DecoderHandler *) ReadMETAImage;
-  entry->encoder=(EncoderHandler *) WriteMETAImage;
+  entry->decoder=(DecodeImageHandler *) ReadMETAImage;
+  entry->encoder=(EncodeImageHandler *) WriteMETAImage;
   entry->adjoin=MagickFalse;
   entry->stealth=MagickTrue;
   entry->seekable_stream=MagickTrue;
@@ -1513,14 +1515,15 @@ ModuleExport void RegisterMETAImage(void)
   (void) RegisterMagickInfo(entry);
 
   entry=SetMagickInfo("IPTCWTEXT");
-  entry->decoder=(DecoderHandler *) ReadMETAImage;
-  entry->encoder=(EncoderHandler *) WriteMETAImage;
+  entry->decoder=(DecodeImageHandler *) ReadMETAImage;
+  entry->encoder=(EncodeImageHandler *) WriteMETAImage;
   entry->adjoin=MagickFalse;
   entry->stealth=MagickTrue;
   entry->seekable_stream=MagickTrue;
   entry->description=ConstantString("IPTC Newsphoto text format");
   entry->module=ConstantString("META");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -2007,22 +2010,26 @@ static int formatIPTCfromBuffer(Image *ofile, char *s, long len)
       if (tags[i].id == (short) recnum)
         break;
     if (i < tagcount)
-      readable = (unsigned char *) tags[i].name;
+      readable=(unsigned char *) tags[i].name;
     else
-      readable = (unsigned char *) "";
+      readable=(unsigned char *) "";
     /*
       We decode the length of the block that follows - long or short fmt.
     */
-    c = *s++; len--;
-    if (len < 0) return -1;
+    c=(*s++);
+    len--;
+    if (len < 0)
+      return(-1);
     if (c & (unsigned char) 0x80)
-      return 0;
+      return(0);
     else
       {
-        s--; len++;
-        taglen = readWordFromBuffer(&s, &len);
+        s--;
+        len++;
+        taglen=readWordFromBuffer(&s, &len);
       }
-    if (taglen < 0) return -1;
+    if (taglen < 0)
+      return(-1);
     /* make a buffer to hold the tag data and snag it from the input stream */
     str=(unsigned char *) AcquireQuantumMemory((size_t) (taglen+MaxTextExtent),
       sizeof(*str));
@@ -2034,10 +2041,11 @@ static int formatIPTCfromBuffer(Image *ofile, char *s, long len)
     for (tagindx=0; tagindx<taglen; tagindx++)
     {
       c = *s++; len--;
-      if (len < 0) return -1;
-      str[tagindx] = (unsigned char) c;
+      if (len < 0)
+        return(-1);
+      str[tagindx]=(unsigned char) c;
     }
-    str[ taglen ] = 0;
+    str[taglen]=0;
 
     /* now finish up by formatting this binary data into ASCII equivalent */
     if (strlen((char *)readable) > 0)
@@ -2076,10 +2084,9 @@ static int format8BIM(Image *ifile, Image *ofile)
     *PString,
     *str;
 
-  resCount = 0;
-  foundOSType = 0; /* found the OSType */
-
-  c =ReadBlobByte(ifile);
+  resCount=0;
+  foundOSType=0; /* found the OSType */
+  c=ReadBlobByte(ifile);
   while (c != EOF)
   {
     if (c == '8')
@@ -2087,16 +2094,17 @@ static int format8BIM(Image *ifile, Image *ofile)
         unsigned char
           buffer[5];
 
-        buffer[0] = (unsigned char) c;
+        buffer[0]=(unsigned char) c;
         for (i=1; i<4; i++)
         {
           c=ReadBlobByte(ifile);
-          if (c == EOF) return -1;
+          if (c == EOF)
+            return(-1);
           buffer[i] = (unsigned char) c;
         }
-        buffer[4] = 0;
+        buffer[4]=0;
         if (strcmp((const char *)buffer, "8BIM") == 0)
-          foundOSType = 1;
+          foundOSType=1;
         else
           continue;
       }
@@ -2108,22 +2116,24 @@ static int format8BIM(Image *ifile, Image *ofile)
     /*
       We found the OSType (8BIM) and now grab the ID, PString, and Size fields.
     */
-    ID = (int) ReadBlobMSBShort(ifile);
-    if (ID < 0) return -1;
+    ID=(int) ReadBlobMSBShort(ifile);
+    if (ID < 0)
+      return(-1);
     {
       unsigned char
         plen;
 
       c=ReadBlobByte(ifile);
-      if (c == EOF) return -1;
+      if (c == EOF)
+        return(-1);
       plen = (unsigned char) c;
       PString=(unsigned char *) AcquireQuantumMemory((size_t) (plen+
         MaxTextExtent),sizeof(*PString));
       if (PString == (unsigned char *) NULL)
-      {
-        printf("MemoryAllocationFailed");
-        return 0;
-      }
+        {
+          printf("MemoryAllocationFailed");
+          return 0;
+        }
       for (i=0; i<plen; i++)
       {
         c=ReadBlobByte(ifile);
@@ -2134,7 +2144,8 @@ static int format8BIM(Image *ifile, Image *ofile)
       if ((plen & 0x01) == 0)
       {
         c=ReadBlobByte(ifile);
-        if (c == EOF) return -1;
+        if (c == EOF)
+          return(-1);
       }
     }
     count = (ssize_t) ReadBlobMSBLong(ifile);
@@ -2149,8 +2160,9 @@ static int format8BIM(Image *ifile, Image *ofile)
     for (i=0; i < (long) count; i++)
     {
       c=ReadBlobByte(ifile);
-      if (c == EOF) return -1;
-      str[i] = (unsigned char) c;
+      if (c == EOF)
+        return(-1);
+      str[i]=(unsigned char) c;
     }
 
     /* we currently skip thumbnails, since it does not make
@@ -2208,11 +2220,9 @@ static MagickBooleanType WriteMETAImage(const ImageInfo *image_info,
   if (LocaleCompare(image_info->magick,"8BIM") == 0)
     {
       /*
-        (void) Write 8BIM image.
+        Write 8BIM image.
       */
       profile=GetImageProfile(image,"8bim");
-      if (profile == (StringInfo *) NULL)
-        profile=GetImageProfile(image,"iptc");
       if (profile == (StringInfo *) NULL)
         ThrowWriterException(CoderError,"No8BIMDataIsAvailable");
       status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
@@ -2232,8 +2242,6 @@ static MagickBooleanType WriteMETAImage(const ImageInfo *image_info,
         *info;
 
       profile=GetImageProfile(image,"iptc");
-      if (profile == (StringInfo *) NULL)
-        profile=GetImageProfile(image,"8bim");
       if (profile == (StringInfo *) NULL)
         ThrowWriterException(CoderError,"No8BIMDataIsAvailable");
       status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
@@ -2252,8 +2260,6 @@ static MagickBooleanType WriteMETAImage(const ImageInfo *image_info,
         *buff;
 
       profile=GetImageProfile(image,"8bim");
-      if (profile == (StringInfo *) NULL)
-        profile=GetImageProfile(image,"iptc");
       if (profile == (StringInfo *) NULL)
         ThrowWriterException(CoderError,"No8BIMDataIsAvailable");
       status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
@@ -2262,7 +2268,8 @@ static MagickBooleanType WriteMETAImage(const ImageInfo *image_info,
       buff=AllocateImage((ImageInfo *) NULL);
       if (buff == (Image *) NULL)
         ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
-      AttachBlob(buff->blob,GetStringInfoDatum(profile),GetStringInfoLength(profile));
+      AttachBlob(buff->blob,GetStringInfoDatum(profile),
+        GetStringInfoLength(profile));
       format8BIM(buff,image);
       (void) DetachBlob(buff->blob);
       buff=DestroyImage(buff);
@@ -2270,9 +2277,7 @@ static MagickBooleanType WriteMETAImage(const ImageInfo *image_info,
       return(MagickTrue);
     }
   if (LocaleCompare(image_info->magick,"8BIMWTEXT") == 0)
-    {
-      return(MagickFalse);
-    }
+    return(MagickFalse);
   if (LocaleCompare(image_info->magick,"IPTCTEXT") == 0)
     {
       Image
@@ -2317,7 +2322,8 @@ static MagickBooleanType WriteMETAImage(const ImageInfo *image_info,
       status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
       if (status == MagickFalse)
         return(status);
-      (void) WriteBlob(image,GetStringInfoLength(profile),GetStringInfoDatum(profile));
+      (void) WriteBlob(image,GetStringInfoLength(profile),
+        GetStringInfoDatum(profile));
       CloseBlob(image);
       return(MagickTrue);
     }
@@ -2333,7 +2339,8 @@ static MagickBooleanType WriteMETAImage(const ImageInfo *image_info,
       status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
       if (status == MagickFalse)
         return(status);
-      (void) WriteBlob(image,GetStringInfoLength(profile),GetStringInfoDatum(profile));
+      (void) WriteBlob(image,GetStringInfoLength(profile),
+        GetStringInfoDatum(profile));
       CloseBlob(image);
       return(MagickTrue);
     }
