@@ -60,10 +60,11 @@
 #include "magick/pixel.h"
 #include "magick/profile.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #if defined(HasZLIB)
 #include "zlib.h"
 #endif
@@ -149,6 +150,7 @@ static MagickBooleanType IsMIFF(const unsigned char *magick,const size_t length)
 #if defined(HasBZLIB)
 static void *AcquireBZIPMemory(void *context,int items,int size)
 {
+  (void) context;
   return((void *) AcquireQuantumMemory((size_t) items,(size_t) size));
 }
 #endif
@@ -157,6 +159,7 @@ static void *AcquireBZIPMemory(void *context,int items,int size)
 static voidpf AcquireZIPMemory(voidpf context,unsigned int items,
   unsigned int size)
 {
+  (void) context;
   return((voidpf) AcquireQuantumMemory(items,size));
 }
 #endif
@@ -175,39 +178,9 @@ static inline size_t MagickMin(const size_t x,const size_t y)
   return(y);
 }
 
-static inline unsigned char PushCharPixel(const unsigned char **pixels)
-{
-  unsigned char
-    pixel;
-
-  pixel=(unsigned char) *(*pixels)++;
-  return(pixel);
-}
-
-static inline unsigned long PushLongPixel(const unsigned char **pixels)
-{
-  unsigned long
-    pixel;
-
-  pixel=(unsigned long) (*(*pixels)++ << 24);
-  pixel|=(unsigned long) (*(*pixels)++ << 16);
-  pixel|=(unsigned long) (*(*pixels)++ << 8);
-  pixel|=(unsigned long) (*(*pixels)++);
-  return(pixel);
-}
-
-static inline unsigned short PushShortPixel(const unsigned char **pixels)
-{
-  unsigned short
-    pixel;
-
-  pixel=(unsigned short) (*(*pixels)++ << 8);
-  pixel|=(unsigned short) (*(*pixels)++);
-  return(pixel);
-}
-
-static void PushRunlengthPacket(Image *image,const unsigned char *pixels,
-  size_t *length,PixelPacket *pixel,IndexPacket *index)
+static void PushRunlengthPacket(Image *image,const QuantumState *quantum_state,
+  const unsigned char *pixels,size_t *length,PixelPacket *pixel,
+  IndexPacket *index)
 {
   const unsigned char
     *p;
@@ -263,7 +236,7 @@ static void PushRunlengthPacket(Image *image,const unsigned char *pixels,
 
           if (image->matte != MagickFalse)
             {
-              quantum=PushShortPixel(&p);
+              quantum=PushShortPixel(quantum_state,&p);
               pixel->opacity=(Quantum) (quantum >> (image->depth-QuantumDepth));
             }
           break;
@@ -275,7 +248,7 @@ static void PushRunlengthPacket(Image *image,const unsigned char *pixels,
 
           if (image->matte != MagickFalse)
             {
-              quantum=PushLongPixel(&p);
+              quantum=PushLongPixel(quantum_state,&p);
               pixel->opacity=(Quantum) (quantum >> (image->depth-QuantumDepth));
             }
           break;
@@ -317,20 +290,20 @@ static void PushRunlengthPacket(Image *image,const unsigned char *pixels,
       unsigned short
         quantum;
 
-      quantum=PushShortPixel(&p);
+      quantum=PushShortPixel(quantum_state,&p);
       pixel->red=(Quantum) (quantum >> (image->depth-QuantumDepth));
-      quantum=PushShortPixel(&p);
+      quantum=PushShortPixel(quantum_state,&p);
       pixel->green=(Quantum) (quantum >> (image->depth-QuantumDepth));
-      quantum=PushShortPixel(&p);
+      quantum=PushShortPixel(quantum_state,&p);
       pixel->blue=(Quantum) (quantum >> (image->depth-QuantumDepth));
       if (image->matte != MagickFalse)
         {
-          quantum=PushShortPixel(&p);
+          quantum=PushShortPixel(quantum_state,&p);
           pixel->opacity=(Quantum) (quantum >> (image->depth-QuantumDepth));
         }
       if (image->colorspace == CMYKColorspace)
         {
-          quantum=PushShortPixel(&p);
+          quantum=PushShortPixel(quantum_state,&p);
           *index=(IndexPacket) (quantum >> (image->depth-QuantumDepth));
         }
       break;
@@ -340,20 +313,20 @@ static void PushRunlengthPacket(Image *image,const unsigned char *pixels,
       unsigned long
         quantum;
 
-      quantum=PushLongPixel(&p);
+      quantum=PushLongPixel(quantum_state,&p);
       pixel->red=(Quantum) (quantum >> (image->depth-QuantumDepth));
-      quantum=PushLongPixel(&p);
+      quantum=PushLongPixel(quantum_state,&p);
       pixel->green=(Quantum) (quantum >> (image->depth-QuantumDepth));
-      quantum=PushLongPixel(&p);
+      quantum=PushLongPixel(quantum_state,&p);
       pixel->blue=(Quantum) (quantum >> (image->depth-QuantumDepth));
       if (image->matte != MagickFalse)
         {
-          quantum=PushLongPixel(&p);
+          quantum=PushLongPixel(quantum_state,&p);
           pixel->opacity=(Quantum) (quantum >> (image->depth-QuantumDepth));
         }
       if (image->colorspace == CMYKColorspace)
         {
-          quantum=PushLongPixel(&p);
+          quantum=PushLongPixel(quantum_state,&p);
           *index=(IndexPacket) (quantum >> (image->depth-QuantumDepth));
         }
       break;
@@ -368,6 +341,7 @@ static void PushRunlengthPacket(Image *image,const unsigned char *pixels,
 #if defined(HasZLIB)
 static void RelinquishZIPMemory(voidpf context,voidpf memory)
 {
+  (void) context;
   memory=RelinquishMagickMemory(memory);
 }
 #endif
@@ -375,6 +349,7 @@ static void RelinquishZIPMemory(voidpf context,voidpf memory)
 #if defined(HasBZLIB)
 static void RelinquishBZIPMemory(void *context,void *memory)
 {
+  (void) context;
   memory=RelinquishMagickMemory(memory);
 }
 #endif
@@ -423,21 +398,24 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
   long
     y;
 
+  MagickBooleanType
+    status;
+
+  MagickStatusType
+    flags;
+
   PixelPacket
     pixel;
 
   QuantumInfo
     quantum_info;
 
+  QuantumState
+    quantum_state;
+
   QuantumType
     quantum_type;
 
-  MagickBooleanType
-    status;
-
-  MagickStatusType
-    flags;
-
   register IndexPacket
     *indexes;
 
@@ -506,6 +484,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
     image->depth=8UL;
     image->compression=NoCompression;
     GetQuantumInfo(image_info,&quantum_info);
+    InitializeQuantumState(&quantum_info,MSBEndian,&quantum_state);
     while ((isgraph(c) != MagickFalse) && (c != (int) ':'))
     {
       register char
@@ -541,7 +520,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
           if (comment == (char *) NULL)
             ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
           *p='\0';
-          (void) SetImageProperty(image,"Comment",comment);
+          (void) SetImageProperty(image,"comment",comment);
           comment=DestroyString(comment);
           c=ReadBlobByte(image);
         }
@@ -1066,11 +1045,11 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
 
                 for (i=0; i < (long) image->colors; i++)
                 {
-                  pixel=PushShortPixel(&p);
+                  pixel=PushShortPixel(&quantum_state,&p);
                   image->colormap[i].red=ScaleShortToQuantum(pixel);
-                  pixel=PushShortPixel(&p);
+                  pixel=PushShortPixel(&quantum_state,&p);
                   image->colormap[i].green=ScaleShortToQuantum(pixel);
-                  pixel=PushShortPixel(&p);
+                  pixel=PushShortPixel(&quantum_state,&p);
                   image->colormap[i].blue=ScaleShortToQuantum(pixel);
                 }
                 break;
@@ -1082,11 +1061,11 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
 
                 for (i=0; i < (long) image->colors; i++)
                 {
-                  pixel=PushLongPixel(&p);
+                  pixel=PushLongPixel(&quantum_state,&p);
                   image->colormap[i].red=ScaleLongToQuantum(pixel);
-                  pixel=PushLongPixel(&p);
+                  pixel=PushLongPixel(&quantum_state,&p);
                   image->colormap[i].green=ScaleLongToQuantum(pixel);
-                  pixel=PushLongPixel(&p);
+                  pixel=PushLongPixel(&quantum_state,&p);
                   image->colormap[i].blue=ScaleLongToQuantum(pixel);
                 }
                 break;
@@ -1248,7 +1227,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
           if (y == 0)
             {
               (void) ResetMagickMemory(&pixel,0,sizeof(pixel));
-              pixel.opacity=TransparentOpacity;
+              pixel.opacity=(Quantum) TransparentOpacity;
               index=(IndexPacket) 0;
             }
           for (x=0; x < (long) image->columns; x++)
@@ -1256,7 +1235,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
             if (length == 0)
               {
                 count=ReadBlob(image,packet_size,pixels);
-                PushRunlengthPacket(image,pixels,&length,&pixel,&index);
+                PushRunlengthPacket(image,&quantum_state,pixels,&length,&pixel,
+                  &index);
               }
             length--;
             if ((image->storage_class == PseudoClass) ||
@@ -1343,10 +1323,10 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterMIFFImage method is:
 %
-%      RegisterMIFFImage(void)
+%      unsigned long RegisterMIFFImage(void)
 %
 */
-ModuleExport void RegisterMIFFImage(void)
+ModuleExport unsigned long RegisterMIFFImage(void)
 {
   char
     version[MaxTextExtent];
@@ -1355,7 +1335,7 @@ ModuleExport void RegisterMIFFImage(void)
     *entry;
 
   *version='\0';
-#if defined(MagickLibVersionText)
+#if defined(MagickImageCoderSignatureText)
   (void) CopyMagickString(version,MagickLibVersionText,MaxTextExtent);
 #if defined(ZLIB_VERSION)
   (void) ConcatenateMagickString(version," with Zlib ",MaxTextExtent);
@@ -1366,14 +1346,15 @@ ModuleExport void RegisterMIFFImage(void)
 #endif
 #endif
   entry=SetMagickInfo("MIFF");
-  entry->decoder=(DecoderHandler *) ReadMIFFImage;
-  entry->encoder=(EncoderHandler *) WriteMIFFImage;
-  entry->magick=(MagickHandler *) IsMIFF;
+  entry->decoder=(DecodeImageHandler *) ReadMIFFImage;
+  entry->encoder=(EncodeImageHandler *) WriteMIFFImage;
+  entry->magick=(IsImageFormatHandler *) IsMIFF;
   entry->description=ConstantString("Magick Image File Format");
   if (*version != '\0')
     entry->version=ConstantString(version);
   entry->module=ConstantString("MIFF");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -1428,30 +1409,8 @@ ModuleExport void UnregisterMIFFImage(void)
 %
 */
 
-static inline void PopCharPixel(const unsigned char pixel,
-  unsigned char **pixels)
-{
-  *(*pixels)++=(unsigned char) (pixel);
-}
-
-static inline void PopShortPixel(const unsigned short pixel,
-  unsigned char **pixels)
-{
-  *(*pixels)++=(unsigned char) ((pixel) >> 8);
-  *(*pixels)++=(unsigned char) (pixel);
-}
-
-static inline void PopLongPixel(const unsigned long pixel,
-  unsigned char **pixels)
-{
-  *(*pixels)++=(unsigned char) ((pixel) >> 24);
-  *(*pixels)++=(unsigned char) ((pixel) >> 16);
-  *(*pixels)++=(unsigned char) ((pixel) >> 8);
-  *(*pixels)++=(unsigned char) (pixel);
-}
-
-static size_t PopRunlengthPacket(Image *image,unsigned char *pixels,
-  size_t length,PixelPacket pixel,IndexPacket index)
+static size_t PopRunlengthPacket(Image *image,const QuantumState *quantum_state,
+  unsigned char *pixels,size_t length,PixelPacket pixel,IndexPacket index)
 {
   unsigned char
     *q;
@@ -1487,7 +1446,7 @@ static size_t PopRunlengthPacket(Image *image,unsigned char *pixels,
           if (image->matte != MagickFalse)
             {
               value=ScaleQuantumToLong(pixel.opacity);
-              PopLongPixel(value,&q);
+              PopLongPixel(quantum_state,value,&q);
             }
           break;
         }
@@ -1499,7 +1458,7 @@ static size_t PopRunlengthPacket(Image *image,unsigned char *pixels,
           if (image->matte != MagickFalse)
             {
               value=ScaleQuantumToShort(pixel.opacity);
-              PopShortPixel(value,&q);
+              PopShortPixel(quantum_state,value,&q);
             }
           break;
         }
@@ -1530,20 +1489,20 @@ static size_t PopRunlengthPacket(Image *image,unsigned char *pixels,
         value;
 
       value=ScaleQuantumToLong(pixel.red);
-      PopLongPixel(value,&q);
+      PopLongPixel(quantum_state,value,&q);
       value=ScaleQuantumToLong(pixel.green);
-      PopLongPixel(value,&q);
+      PopLongPixel(quantum_state,value,&q);
       value=ScaleQuantumToLong(pixel.blue);
-      PopLongPixel(value,&q);
+      PopLongPixel(quantum_state,value,&q);
       if (image->matte != MagickFalse)
         {
           value=ScaleQuantumToLong(pixel.opacity);
-          PopLongPixel(value,&q);
+          PopLongPixel(quantum_state,value,&q);
         }
       if (image->colorspace == CMYKColorspace)
         {
           value=ScaleQuantumToLong(index);
-          PopLongPixel(value,&q);
+          PopLongPixel(quantum_state,value,&q);
         }
       break;
     }
@@ -1553,20 +1512,20 @@ static size_t PopRunlengthPacket(Image *image,unsigned char *pixels,
         value;
 
       value=ScaleQuantumToShort(pixel.red);
-      PopShortPixel(value,&q);
+      PopShortPixel(quantum_state,value,&q);
       value=ScaleQuantumToShort(pixel.green);
-      PopShortPixel(value,&q);
+      PopShortPixel(quantum_state,value,&q);
       value=ScaleQuantumToShort(pixel.blue);
-      PopShortPixel(value,&q);
+      PopShortPixel(quantum_state,value,&q);
       if (image->matte != MagickFalse)
         {
           value=ScaleQuantumToShort(pixel.opacity);
-          PopShortPixel(value,&q);
+          PopShortPixel(quantum_state,value,&q);
         }
       if (image->colorspace == CMYKColorspace)
         {
           value=ScaleQuantumToShort(index);
-          PopShortPixel(value,&q);
+          PopShortPixel(quantum_state,value,&q);
         }
       break;
     }
@@ -1640,6 +1599,9 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
   QuantumInfo
     quantum_info;
 
+  QuantumState
+    quantum_state;
+
   QuantumType
     quantum_type;
 
@@ -1905,28 +1867,26 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
         (void) WriteBlobString(image,"quantum-format=floating-point\n");
         quantum_info.scale=1.0/QuantumRange;
       }
+    InitializeQuantumState(&quantum_info,MSBEndian,&quantum_state);
     ResetImagePropertyIterator(image);
     property=GetNextImageProperty(image);
     while (property != (const char *) NULL)
     {
-      if (*property != '[')
+      (void) FormatMagickString(buffer,MaxTextExtent,"%s=",property);
+      (void) WriteBlobString(image,buffer);
+      value=GetImageProperty(image,property);
+      if (value != (const char *) NULL)
         {
-          (void) FormatMagickString(buffer,MaxTextExtent,"%s=",property);
-          (void) WriteBlobString(image,buffer);
-          value=GetImageProperty(image,property);
-          if (value != (const char *) NULL)
-             {
-               for (i=0; i < (long) strlen(value); i++)
-                 if (isspace((int) ((unsigned char) value[i])) != 0)
-                   break;
-               if (i <= (long) strlen(value))
-                 (void) WriteBlobByte(image,'{');
-               (void) WriteBlob(image,strlen(value),(unsigned char *) value);
-               if (i <= (long) strlen(value))
-                 (void) WriteBlobByte(image,'}');
-             }
-          (void) WriteBlobByte(image,'\n');
+          for (i=0; i < (long) strlen(value); i++)
+            if (isspace((int) ((unsigned char) value[i])) != 0)
+              break;
+          if (i <= (long) strlen(value))
+            (void) WriteBlobByte(image,'{');
+          (void) WriteBlob(image,strlen(value),(unsigned char *) value);
+          if (i <= (long) strlen(value))
+            (void) WriteBlobByte(image,'}');
         }
+      (void) WriteBlobByte(image,'\n');
       property=GetNextImageProperty(image);
     }
     (void) WriteBlobString(image,"\f\n:\032");
@@ -1994,11 +1954,11 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
                 pixel;
 
               pixel=ScaleQuantumToLong(image->colormap[i].red);
-              PopLongPixel(pixel,&q);
+              PopLongPixel(&quantum_state,pixel,&q);
               pixel=ScaleQuantumToLong(image->colormap[i].green);
-              PopLongPixel(pixel,&q);
+              PopLongPixel(&quantum_state,pixel,&q);
               pixel=ScaleQuantumToLong(image->colormap[i].blue);
-              PopLongPixel(pixel,&q);
+              PopLongPixel(&quantum_state,pixel,&q);
               break;
             }
             case 16:
@@ -2007,11 +1967,11 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
                 pixel;
 
               pixel=ScaleQuantumToShort(image->colormap[i].red);
-              PopShortPixel(pixel,&q);
+              PopShortPixel(&quantum_state,pixel,&q);
               pixel=ScaleQuantumToShort(image->colormap[i].green);
-              PopShortPixel(pixel,&q);
+              PopShortPixel(&quantum_state,pixel,&q);
               pixel=ScaleQuantumToShort(image->colormap[i].blue);
-              PopShortPixel(pixel,&q);
+              PopShortPixel(&quantum_state,pixel,&q);
               break;
             }
             case 8:
@@ -2183,7 +2143,8 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
             else
               {
                 if (x > 0)
-                  q+=PopRunlengthPacket(image,q,length,pixel,index);
+                  q+=PopRunlengthPacket(image,&quantum_state,q,length,pixel,
+                    index);
                 length=0;
               }
             pixel=(*p);
@@ -2191,7 +2152,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
               index=indexes[x];
             p++;
           }
-          q+=PopRunlengthPacket(image,q,length,pixel,index);
+          q+=PopRunlengthPacket(image,&quantum_state,q,length,pixel,index);
           (void) WriteBlob(image,(size_t) (q-pixels),pixels);
           break;
         }
