@@ -41,6 +41,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
+#include "magick/artifact.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/cache.h"
@@ -60,11 +61,11 @@
 #include "magick/option.h"
 #include "magick/profile.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
 #include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/utility.h"
 
 /*
@@ -98,7 +99,6 @@ static MagickBooleanType
 %
 %    o length: Specifies the length of the magick string.
 %
-%
 */
 static MagickBooleanType IsMPC(const unsigned char *magick,const size_t length)
 {
@@ -169,6 +169,12 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
   MagickStatusType
     flags;
 
+  QuantumInfo
+    quantum_info;
+
+  QuantumState
+    quantum_state;
+
   register long
     i;
 
@@ -224,6 +230,8 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
     quantum_depth=QuantumDepth;
     image->depth=8;
     image->compression=NoCompression;
+    GetQuantumInfo(image_info,&quantum_info);
+    InitializeQuantumState(&quantum_info,MSBEndian,&quantum_state);
     while ((isgraph(c) != MagickFalse) && (c != (int) ':'))
     {
       register char
@@ -248,8 +256,8 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
               {
                 *p='\0';
                 length<<=1;
-                comment=(char *) ResizeMagickMemory(comment,
-                  (length+MaxTextExtent)*sizeof(*comment));
+                comment=(char *) ResizeQuantumMemory(comment,length+
+                  MaxTextExtent,sizeof(*comment));
                 if (comment == (char *) NULL)
                   break;
                 p=comment+strlen(comment);
@@ -259,7 +267,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (comment == (char *) NULL)
             ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
           *p='\0';
-          (void) SetImageProperty(image,"Comment",comment);
+          (void) SetImageProperty(image,"comment",comment);
           comment=DestroyString(comment);
           c=ReadBlobByte(image);
         }
@@ -296,8 +304,8 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     {
                       *p='\0';
                       length<<=1;
-                      options=(char *) ResizeMagickMemory(options,
-                        (length+MaxTextExtent)*sizeof(*options));
+                      options=(char *) ResizeQuantumMemory(options,length+
+                        MaxTextExtent,sizeof(*options));
                       if (options == (char *) NULL)
                         break;
                       p=options+strlen(options);
@@ -371,7 +379,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 if (LocaleCompare(keyword,"compression") == 0)
                   {
                     image->compression=(CompressionType) ParseMagickOption(
-                      MagickCompressionOptions,MagickFalse,options);
+                      MagickCompressOptions,MagickFalse,options);
                     break;
                   }
                 if (LocaleCompare(keyword,"columns") == 0)
@@ -689,8 +697,8 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 Allocate more memory for the image directory.
               */
               length<<=1;
-              image->directory=(char *) ResizeMagickMemory(image->directory,
-                (length+MaxTextExtent)*sizeof(*image->directory));
+              image->directory=(char *) ResizeQuantumMemory(image->directory,
+                length+MaxTextExtent,sizeof(*image->directory));
               if (image->directory == (char *) NULL)
                 ThrowReaderException(CorruptImageError,"UnableToReadImageData");
               p=image->directory+strlen(image->directory);
@@ -747,9 +755,9 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
             /*
               Read image colormap from file.
             */
-            packet_size=(size_t) (3*depth/8);
-            colormap=(unsigned char *)
-              AcquireMagickMemory(packet_size*image->colors);
+            packet_size=(size_t) (3UL*depth/8UL);
+            colormap=(unsigned char *) AcquireQuantumMemory(image->colors,
+              packet_size*sizeof(*colormap));
             if (colormap == (unsigned char *) NULL)
               ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
             count=ReadBlob(image,packet_size*image->colors,colormap);
@@ -785,11 +793,11 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
                 for (i=0; i < (long) image->colors; i++)
                 {
-                  pixel=PushShortPixel(MSBEndian,&p);
+                  pixel=PushShortPixel(&quantum_state,&p);
                   image->colormap[i].red=ScaleShortToQuantum(pixel);
-                  pixel=PushShortPixel(MSBEndian,&p);
+                  pixel=PushShortPixel(&quantum_state,&p);
                   image->colormap[i].green=ScaleShortToQuantum(pixel);
-                  pixel=PushShortPixel(MSBEndian,&p);
+                  pixel=PushShortPixel(&quantum_state,&p);
                   image->colormap[i].blue=ScaleShortToQuantum(pixel);
                 }
                 break;
@@ -801,11 +809,11 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
                 for (i=0; i < (long) image->colors; i++)
                 {
-                  pixel=PushLongPixel(MSBEndian,&p);
+                  pixel=PushLongPixel(&quantum_state,&p);
                   image->colormap[i].red=ScaleLongToQuantum(pixel);
-                  pixel=PushLongPixel(MSBEndian,&p);
+                  pixel=PushLongPixel(&quantum_state,&p);
                   image->colormap[i].green=ScaleLongToQuantum(pixel);
-                  pixel=PushLongPixel(MSBEndian,&p);
+                  pixel=PushLongPixel(&quantum_state,&p);
                   image->colormap[i].blue=ScaleLongToQuantum(pixel);
                 }
                 break;
@@ -823,6 +831,11 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
+    if (SetImageExtent(image,0,0) == MagickFalse)
+      {
+        InheritException(exception,&image->exception);
+        return(DestroyImageList(image));
+      }
     /*
       Attach persistent pixel cache.
     */
@@ -881,10 +894,10 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterMPCImage method is:
 %
-%      RegisterMPCImage(void)
+%      unsigned long RegisterMPCImage(void)
 %
 */
-ModuleExport void RegisterMPCImage(void)
+ModuleExport unsigned long RegisterMPCImage(void)
 {
   MagickInfo
     *entry;
@@ -892,14 +905,16 @@ ModuleExport void RegisterMPCImage(void)
   entry=SetMagickInfo("CACHE");
   entry->description=ConstantString("Magick Persistent Cache image format");
   entry->module=ConstantString("CACHE");
+  entry->stealth=MagickTrue;
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("MPC");
-  entry->decoder=(DecoderHandler *) ReadMPCImage;
-  entry->encoder=(EncoderHandler *) WriteMPCImage;
-  entry->magick=(MagickHandler *) IsMPC;
+  entry->decoder=(DecodeImageHandler *) ReadMPCImage;
+  entry->encoder=(EncodeImageHandler *) WriteMPCImage;
+  entry->magick=(IsImageFormatHandler *) IsMPC;
   entry->description=ConstantString("Magick Persistent Cache image format");
   entry->module=ConstantString("MPC");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -951,7 +966,6 @@ ModuleExport void UnregisterMPCImage(void)
 %    o image: The image.
 %
 */
-
 static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
 {
   char
@@ -969,6 +983,12 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
     offset,
     scene;
 
+  QuantumInfo
+    quantum_info;
+
+  QuantumState
+    quantum_state;
+
   register long
     i;
 
@@ -1029,7 +1049,7 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
       {
         (void) FormatMagickString(buffer,MaxTextExtent,
           "compression=%s  quality=%lu\n",
-          MagickOptionToMnemonic(MagickCompressionOptions,image->compression),
+          MagickOptionToMnemonic(MagickCompressOptions,image->compression),
           image->quality);
         (void) WriteBlobString(image,buffer);
       }
@@ -1179,30 +1199,35 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
           image->montage);
         (void) WriteBlobString(image,buffer);
       }
+    GetQuantumInfo(image_info,&quantum_info);
+    if (quantum_info.format == FloatingPointQuantumFormat)
+      {
+        (void) WriteBlobString(image,"quantum-format=floating-point\n");
+        quantum_info.scale=1.0/QuantumRange;
+      }
+    InitializeQuantumState(&quantum_info,MSBEndian,&quantum_state);
     ResetImagePropertyIterator(image);
     property=GetNextImageProperty(image);
     while (property != (const char *) NULL)
     {
-      if (*property != '[')
+      (void) FormatMagickString(buffer,MaxTextExtent,"%s=",property);
+      (void) WriteBlobString(image,buffer);
+      value=GetImageProperty(image,property);
+      if (value != (const char *) NULL)
         {
-          (void) FormatMagickString(buffer,MaxTextExtent,"%s=",property);
-          (void) WriteBlobString(image,buffer);
-          value=GetImageProperty(image,property);
-          if (value != (const char *) NULL)
-            {
-              for (i=0; i < (long) strlen(value); i++)
-                if (isspace((int) ((unsigned char) value[i])) != 0)
-                  break;
-              if (i <= (long) strlen(value))
-                (void) WriteBlobByte(image,'{');
-              (void) WriteBlob(image,strlen(value),(unsigned char *) value);
-              if (i <= (long) strlen(value))
-                (void) WriteBlobByte(image,'}');
-            }
-          (void) WriteBlobByte(image,'\n');
+          for (i=0; i < (long) strlen(value); i++)
+            if (isspace((int) ((unsigned char) value[i])) != 0)
+              break;
+          if (i <= (long) strlen(value))
+            (void) WriteBlobByte(image,'{');
+          (void) WriteBlob(image,strlen(value),(unsigned char *) value);
+          if (i <= (long) strlen(value))
+            (void) WriteBlobByte(image,'}');
         }
+      (void) WriteBlobByte(image,'\n');
       property=GetNextImageProperty(image);
     }
+    ResetImageArtifactIterator(image);
     (void) WriteBlobString(image,"\f\n:\032");
     if (image->montage != (char *) NULL)
       {
@@ -1246,9 +1271,9 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
         /*
           Allocate colormap.
         */
-        packet_size=(size_t) (3*depth/8);
-        colormap=(unsigned char *)
-          AcquireMagickMemory(packet_size*image->colors*sizeof(*colormap));
+        packet_size=(size_t) (3UL*depth/8UL);
+        colormap=(unsigned char *) AcquireQuantumMemory(image->colors,
+          packet_size*sizeof(*colormap));
         if (colormap == (unsigned char *) NULL)
           return(MagickFalse);
         /*
@@ -1267,11 +1292,11 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
                 pixel;
 
               pixel=ScaleQuantumToLong(image->colormap[i].red);
-              PopLongPixel(MSBEndian,pixel,&q);
+              PopLongPixel(&quantum_state,pixel,&q);
               pixel=ScaleQuantumToLong(image->colormap[i].green);
-              PopLongPixel(MSBEndian,pixel,&q);
+              PopLongPixel(&quantum_state,pixel,&q);
               pixel=ScaleQuantumToLong(image->colormap[i].blue);
-              PopLongPixel(MSBEndian,pixel,&q);
+              PopLongPixel(&quantum_state,pixel,&q);
             }
             case 16:
             {
@@ -1279,11 +1304,11 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
                 pixel;
 
               pixel=ScaleQuantumToShort(image->colormap[i].red);
-              PopShortPixel(MSBEndian,pixel,&q);
+              PopShortPixel(&quantum_state,pixel,&q);
               pixel=ScaleQuantumToShort(image->colormap[i].green);
-              PopShortPixel(MSBEndian,pixel,&q);
+              PopShortPixel(&quantum_state,pixel,&q);
               pixel=ScaleQuantumToShort(image->colormap[i].blue);
-              PopShortPixel(MSBEndian,pixel,&q);
+              PopShortPixel(&quantum_state,pixel,&q);
               break;
             }
             case 8:
