@@ -10,14 +10,14 @@
 %                        M   M  P      EEEEE   GGGG                           %
 %                                                                             %
 %                                                                             %
-%                          Write MPEG Image Format.                           %
+%                       Read/Write MPEG Image Format.                         %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
 %                                 July 1999                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -54,9 +54,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/resource_.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/transform.h"
 #include "magick/utility.h"
 
@@ -91,7 +92,6 @@ static MagickBooleanType
 %
 %    o length: Specifies the length of the magick string.
 %
-%
 */
 static MagickBooleanType IsMPEG(const unsigned char *magick,const size_t length)
 {
@@ -115,9 +115,7 @@ static MagickBooleanType IsMPEG(const unsigned char *magick,const size_t length)
 %
 %  ReadMPEGImage() reads an binary file in the MPEG video stream format
 %  and returns it.  It allocates the memory necessary for the new Image
-%  structure and returns a pointer to the new image.  This method differs from
-%  the other decoder methods in that only the Photoshop resource (MPEG)
-%  information is useful in the returned image.
+%  structure and returns a pointer to the new image.
 %
 %  The format of the ReadMPEGImage method is:
 %
@@ -130,7 +128,6 @@ static MagickBooleanType IsMPEG(const unsigned char *magick,const size_t length)
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadMPEGImage(const ImageInfo *image_info,
   ExceptionInfo *exception)
@@ -172,7 +169,7 @@ static Image *ReadMPEGImage(const ImageInfo *image_info,
   */
   image=AllocateImage(image_info);
   read_info=CloneImageInfo(image_info);
-  (void) InvokeDelegate(read_info,image,"mpeg-decode",(char *) NULL,exception);
+  (void) InvokeDelegate(read_info,image,"mpeg:decode",(char *) NULL,exception);
   image=DestroyImage(image);
   /*
     Read PPM files.
@@ -180,8 +177,8 @@ static Image *ReadMPEGImage(const ImageInfo *image_info,
   images=NewImageList();
   for (i=(long) read_info->scene; ; i++)
   {
-    (void) FormatMagickString(read_info->filename,MaxTextExtent,
-      "%s%ld.ppm",read_info->unique,i);
+    (void) FormatMagickString(read_info->filename,MaxTextExtent,"%s%ld.ppm",
+      read_info->unique,i);
     if (IsAccessible(read_info->filename) == MagickFalse)
       break;
     image=ReadImage(read_info,exception);
@@ -199,11 +196,11 @@ static Image *ReadMPEGImage(const ImageInfo *image_info,
   */
   for (i=0; ; i++)
   {
-    (void) FormatMagickString(read_info->filename,MaxTextExtent,
-      "%s%ld.ppm",read_info->unique,i);
+    (void) FormatMagickString(read_info->filename,MaxTextExtent,"%s%ld.ppm",
+      read_info->unique,i);
     if (IsAccessible(read_info->filename) == MagickFalse)
       break;
-    (void) remove(read_info->filename);
+    (void) RelinquishUniqueFileResource(read_info->filename);
   }
   read_info=DestroyImageInfo(read_info);
   return(images);
@@ -229,38 +226,39 @@ static Image *ReadMPEGImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterMPEGImage method is:
 %
-%      RegisterMPEGImage(void)
+%      unsigned long RegisterMPEGImage(void)
 %
 */
-ModuleExport void RegisterMPEGImage(void)
+ModuleExport unsigned long RegisterMPEGImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("MPEG");
-  entry->decoder=(DecoderHandler *) ReadMPEGImage;
-  entry->encoder=(EncoderHandler *) WriteMPEGImage;
-  entry->magick=(MagickHandler *) IsMPEG;
+  entry->decoder=(DecodeImageHandler *) ReadMPEGImage;
+  entry->encoder=(EncodeImageHandler *) WriteMPEGImage;
+  entry->magick=(IsImageFormatHandler *) IsMPEG;
   entry->blob_support=MagickFalse;
   entry->description=ConstantString("MPEG Video Stream");
   entry->module=ConstantString("MPEG");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("MPG");
-  entry->decoder=(DecoderHandler *) ReadMPEGImage;
-  entry->encoder=(EncoderHandler *) WriteMPEGImage;
-  entry->magick=(MagickHandler *) IsMPEG;
+  entry->decoder=(DecodeImageHandler *) ReadMPEGImage;
+  entry->encoder=(EncodeImageHandler *) WriteMPEGImage;
+  entry->magick=(IsImageFormatHandler *) IsMPEG;
   entry->blob_support=MagickFalse;
   entry->description=ConstantString("MPEG Video Stream");
   entry->module=ConstantString("MPEG");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("M2V");
-  entry->decoder=(DecoderHandler *) ReadMPEGImage;
-  entry->encoder=(EncoderHandler *) WriteMPEGImage;
-  entry->magick=(MagickHandler *) IsMPEG;
+  entry->decoder=(DecodeImageHandler *) ReadMPEGImage;
+  entry->encoder=(EncodeImageHandler *) WriteMPEGImage;
+  entry->magick=(IsImageFormatHandler *) IsMPEG;
   entry->blob_support=MagickFalse;
   entry->description=ConstantString("MPEG Video Stream");
   entry->module=ConstantString("MPEG");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -314,9 +312,22 @@ ModuleExport void UnregisterMPEGImage(void)
 %
 %    o image:  The image.
 %
-%
 */
 
+static inline double MagickMax(const double x,const double y)
+{
+  if (x > y)
+    return(x);
+  return(y);
+}
+
+static inline double MagickMin(const double x,const double y)
+{
+  if (x < y)
+    return(x);
+  return(y);
+}
+
 static MagickBooleanType WriteMPEGParameterFiles(const ImageInfo *image_info,
   Image *image,const char *basename)
 {
@@ -324,6 +335,7 @@ static MagickBooleanType WriteMPEGParameterFiles(const ImageInfo *image_info,
     filename[MaxTextExtent];
 
   double
+    delay,
     q;
 
   FILE
@@ -359,9 +371,6 @@ static MagickBooleanType WriteMPEGParameterFiles(const ImageInfo *image_info,
       27, 29, 35, 38, 46, 56, 69, 83
     };
 
-  unsigned long
-    delay;
-
   /*
     Write parameter file (see mpeg2encode documentation for details).
   */
@@ -385,10 +394,10 @@ static MagickBooleanType WriteMPEGParameterFiles(const ImageInfo *image_info,
         return(MagickFalse);
       if (image->quality >= 75)
         {
-          q=(double) Max((image->quality-75)*2,1);
+          q=MagickMax(2.0*(image->quality-75.0),1.0);
           for (i=0; i < 64; i++)
           {
-            quant=(long) Min(Max(q_matrix[i]/q,1.0),255.0);
+            quant=(long) MagickMin(MagickMax(q_matrix[i]/q,1.0),255.0);
             (void) fprintf(parameter_file," %ld",quant);
             if ((i % 8) == 7)
               (void) fprintf(parameter_file,"\n");
@@ -396,10 +405,10 @@ static MagickBooleanType WriteMPEGParameterFiles(const ImageInfo *image_info,
         }
       else
         {
-          q=(double) Max((75-image->quality)/8,1);
+          q=MagickMax((75.0-image->quality)/8.0,1.0);
           for (i=0; i < 64; i++)
           {
-            quant=(long) Min(Max(q*q_matrix[i]+0.5,1.0),255.0);
+            quant=(long) MagickMin(MagickMax(q*q_matrix[i]+0.5,1.0),255.0);
             (void) fprintf(parameter_file," %ld",quant);
             if ((i % 8) == 7)
               (void) fprintf(parameter_file,"\n");
@@ -419,7 +428,7 @@ static MagickBooleanType WriteMPEGParameterFiles(const ImageInfo *image_info,
       parameter_file=MagickOpenStream(filename,"w");
       if (parameter_file == (FILE *) NULL)
         return(MagickFalse);
-      q=Min(Max(66.0-(2*image->quality)/3.0,1.0),255);
+      q=MagickMin(MagickMax(66.0-(2*image->quality)/3.0,1.0),255);
       for (i=0; i < 64; i++)
       {
         (void) fprintf(parameter_file," %d",(int) q);
@@ -433,8 +442,8 @@ static MagickBooleanType WriteMPEGParameterFiles(const ImageInfo *image_info,
   count=0;
   for (p=image; p != (Image *) NULL; p=GetNextImageInList(p))
   {
-    delay=100*p->delay/Max(p->ticks_per_second,1);
-    count+=Max((delay+1)/3,1);
+    delay=100.0*p->delay/MagickMax(1.0*p->ticks_per_second,1.0);
+    count+=(ssize_t) MagickMax((1.0*delay+1.0)/3.0,1.0);
   }
   (void) fprintf(file,"%lu\n",(unsigned long) count); /* number of frames */
   (void) fprintf(file,"0\n");  /* number of first frame */
@@ -539,6 +548,9 @@ static MagickBooleanType WriteMPEGImage(const ImageInfo *image_info,
     basename[MaxTextExtent],
     filename[MaxTextExtent];
 
+  double
+    delay;
+
   Image
     *coalesce_image,
     *next_image;
@@ -566,7 +578,6 @@ static MagickBooleanType WriteMPEGImage(const ImageInfo *image_info,
 
   unsigned long
     count,
-    delay,
     scene;
 
   /*
@@ -616,15 +627,15 @@ static MagickBooleanType WriteMPEGImage(const ImageInfo *image_info,
     {
       if (coalesce_image != image)
         coalesce_image=DestroyImage(coalesce_image);
-      (void) remove(basename);
+      (void) RelinquishUniqueFileResource(basename);
       if (image->quality != UndefinedCompressionQuality)
         {
           (void) FormatMagickString(filename,MaxTextExtent,"%s.iqm",
             basename);
-          (void) remove(filename);
+          (void) RelinquishUniqueFileResource(filename);
           (void) FormatMagickString(filename,MaxTextExtent,"%s.niq",
             basename);
-          (void) remove(filename);
+          (void) RelinquishUniqueFileResource(filename);
         }
       ThrowWriterException(CoderError,"UnableToWriteMPEGParameters");
     }
@@ -638,8 +649,8 @@ static MagickBooleanType WriteMPEGImage(const ImageInfo *image_info,
     blob=(unsigned char *) NULL;
     length=0;
     scene=p->scene;
-    delay=100*p->delay/Max(p->ticks_per_second,1);
-    for (i=0; i < (long) Max((delay+1)/3,1); i++)
+    delay=100.0*p->delay/MagickMax(1.0*p->ticks_per_second,1.0);
+    for (i=0; i < (long) MagickMax((1.0*delay+1.0)/3.0,1.0); i++)
     {
       p->scene=count;
       count++;
@@ -667,7 +678,7 @@ static MagickBooleanType WriteMPEGImage(const ImageInfo *image_info,
         case 1:
         {
           blob=(unsigned char *)
-            FileToBlob(previous_image,~0,&length,&image->exception);
+            FileToBlob(previous_image,~0UL,&length,&image->exception);
         }
         default:
         {
@@ -700,7 +711,7 @@ static MagickBooleanType WriteMPEGImage(const ImageInfo *image_info,
     Convert YUV to MPEG.
   */
   (void) CopyMagickString(coalesce_image->filename,basename,MaxTextExtent);
-  status=InvokeDelegate(write_info,coalesce_image,(char *) NULL,"mpeg-encode",
+  status=InvokeDelegate(write_info,coalesce_image,(char *) NULL,"mpeg:encode",
     &image->exception);
   write_info=DestroyImageInfo(write_info);
   /*
@@ -709,22 +720,22 @@ static MagickBooleanType WriteMPEGImage(const ImageInfo *image_info,
   count=0;
   for (p=coalesce_image; p != (Image *) NULL; p=GetNextImageInList(p))
   {
-    delay=100*p->delay/Max(p->ticks_per_second,1);
-    for (i=0; i < (long) Max((delay+1)/3,1); i++)
+    delay=100.0*p->delay/MagickMax(1.0*p->ticks_per_second,1.0);
+    for (i=0; i < (long) MagickMax((1.0*delay+1.0)/3.0,1.0); i++)
     {
       (void) FormatMagickString(p->filename,MaxTextExtent,"%s.%lu.yuv",
         basename,count++);
-      (void) remove(p->filename);
+      (void) RelinquishUniqueFileResource(p->filename);
     }
     (void) CopyMagickString(p->filename,image_info->filename,MaxTextExtent);
   }
   (void) RelinquishUniqueFileResource(basename);
   (void) FormatMagickString(filename,MaxTextExtent,"%s.iqm",basename);
-  (void) remove(filename);
+  (void) RelinquishUniqueFileResource(filename);
   (void) FormatMagickString(filename,MaxTextExtent,"%s.niq",basename);
-  (void) remove(filename);
+  (void) RelinquishUniqueFileResource(filename);
   (void) FormatMagickString(filename,MaxTextExtent,"%s.log",basename);
-  (void) remove(filename);
+  (void) RelinquishUniqueFileResource(filename);
   if (coalesce_image != image)
     coalesce_image=DestroyImage(coalesce_image);
   if (image->debug != MagickFalse)
