@@ -47,9 +47,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/registry.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -121,31 +122,32 @@ static Image *ReadMPRImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterMPRImage method is:
 %
-%      RegisterMPRImage(void)
+%      unsigned long RegisterMPRImage(void)
 %
 */
-ModuleExport void RegisterMPRImage(void)
+ModuleExport unsigned long RegisterMPRImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("MPR");
-  entry->decoder=(DecoderHandler *) ReadMPRImage;
-  entry->encoder=(EncoderHandler *) WriteMPRImage;
+  entry->decoder=(DecodeImageHandler *) ReadMPRImage;
+  entry->encoder=(EncodeImageHandler *) WriteMPRImage;
   entry->adjoin=MagickFalse;
   entry->stealth=MagickTrue;
   entry->description=ConstantString("Magick Persistent Registry");
   entry->module=ConstantString("MPR");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("MPRI");
-  entry->decoder=(DecoderHandler *) ReadMPRImage;
-  entry->encoder=(EncoderHandler *) WriteMPRImage;
+  entry->decoder=(DecodeImageHandler *) ReadMPRImage;
+  entry->encoder=(EncodeImageHandler *) WriteMPRImage;
   entry->stealth=MagickTrue;
   entry->adjoin=MagickFalse;
   entry->stealth=MagickTrue;
   entry->description=ConstantString("Magick Persistent Registry");
   entry->module=ConstantString("MPRI");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
