@@ -40,6 +40,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
+#include "magick/artifact.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/draw.h"
@@ -50,8 +51,9 @@
 #include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
+#include "magick/module.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 
@@ -205,7 +207,7 @@ static Image *ReadMVGImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if (primitive != (unsigned char *) NULL)
     draw_info->primitive=AcquireString((char *) primitive);
   else
-    draw_info->primitive=FileToString(image->filename,~0,exception);
+    draw_info->primitive=FileToString(image->filename,~0UL,exception);
   if (draw_info->primitive == (char *) NULL)
     return((Image *) NULL);
   (void) DrawImage(image,draw_info);
@@ -234,23 +236,24 @@ static Image *ReadMVGImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterMVGImage method is:
 %
-%      RegisterMVGImage(void)
+%      unsigned long RegisterMVGImage(void)
 %
 */
-ModuleExport void RegisterMVGImage(void)
+ModuleExport unsigned long RegisterMVGImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("MVG");
-  entry->decoder=(DecoderHandler *) ReadMVGImage;
-  entry->encoder=(EncoderHandler *) WriteMVGImage;
-  entry->magick=(MagickHandler *) IsMVG;
+  entry->decoder=(DecodeImageHandler *) ReadMVGImage;
+  entry->encoder=(EncodeImageHandler *) WriteMVGImage;
+  entry->magick=(IsImageFormatHandler *) IsMVG;
   entry->adjoin=MagickFalse;
   entry->seekable_stream=MagickTrue;
   entry->description=ConstantString("Magick Vector Graphics");
   entry->module=ConstantString("MVG");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -318,7 +321,7 @@ static MagickBooleanType WriteMVGImage(const ImageInfo *image_info,Image *image)
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  value=GetImageProperty(image,"[MVG]");
+  value=GetImageArtifact(image,"MVG");
   if (value == (const char *) NULL)
     ThrowWriterException(OptionError,"NoImageVectorGraphics");
   status=OpenBlob(image_info,image,WriteBlobMode,&image->exception);
