@@ -51,9 +51,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -161,6 +162,11 @@ static Image *ReadOTBImage(const ImageInfo *image_info,ExceptionInfo *exception)
       CloseBlob(image);
       return(GetFirstImageInList(image));
     }
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   /*
     Convert bi-level image to pixel packets.
   */
@@ -224,21 +230,22 @@ static Image *ReadOTBImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterOTBImage method is:
 %
-%      RegisterOTBImage(void)
+%      unsigned long RegisterOTBImage(void)
 %
 */
-ModuleExport void RegisterOTBImage(void)
+ModuleExport unsigned long RegisterOTBImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("OTB");
-  entry->decoder=(DecoderHandler *) ReadOTBImage;
-  entry->encoder=(EncoderHandler *) WriteOTBImage;
+  entry->decoder=(DecodeImageHandler *) ReadOTBImage;
+  entry->encoder=(EncodeImageHandler *) WriteOTBImage;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("On-the-air bitmap");
   entry->module=ConstantString("OTB");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
