@@ -57,9 +57,10 @@
 #include "magick/pixel-private.h"
 #include "magick/property.h"
 #include "magick/quantize.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/utility.h"
 
 /*
@@ -491,7 +492,8 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
         if (bits_per_pixel != 16)
           SetMagickPixelPacket(image,image->colormap+(mask-transparentIndex),
             (const IndexPacket *) NULL,&transpix);
-        (void) PaintTransparentImage(image,&transpix,TransparentOpacity);
+        (void) PaintTransparentImage(image,&transpix,(Quantum)
+          TransparentOpacity);
       }
     one_row=(unsigned char *) RelinquishMagickMemory(one_row);
     if (compressionType == PALM_COMPRESSION_SCANLINE)
@@ -561,21 +563,22 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterPALMImage method is:
 %
-%      RegisterPALMImage(void)
+%      unsigned long RegisterPALMImage(void)
 %
 */
-ModuleExport void RegisterPALMImage(void)
+ModuleExport unsigned long RegisterPALMImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("PALM");
-  entry->decoder=(DecoderHandler *) ReadPALMImage;
-  entry->encoder=(EncoderHandler *) WritePALMImage;
+  entry->decoder=(DecodeImageHandler *) ReadPALMImage;
+  entry->encoder=(EncodeImageHandler *) WritePALMImage;
   entry->seekable_stream=MagickTrue;
   entry->description=ConstantString("Palm pixmap");
   entry->module=ConstantString("PALM");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -709,7 +712,7 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,
   transpix.opacity=0;
   do
   {
-    value=GetImageProperty(image, "Comment");
+    value=GetImageProperty(image, "comment");
     if (value != (const char *) NULL)
       if (LocaleCompare("COLORMAP",value) == 0)
         flags|=PALM_HAS_COLORMAP_FLAG;
@@ -824,7 +827,7 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,
               (unsigned long) QuantumRange) << 11) |
               (((63*(unsigned long) p->green)/(unsigned long) QuantumRange) << 5) |
               ((31*(unsigned long) p->blue)/(unsigned long) QuantumRange));
-            if (p->opacity == TransparentOpacity)
+            if (p->opacity == (Quantum) TransparentOpacity)
               {
                 transpix.red=p->red;
                 transpix.green=p->green;
