@@ -49,9 +49,10 @@
 #include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Bricks pattern.
@@ -970,20 +971,21 @@ static Image *ReadPATTERNImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterPATTERNImage method is:
 %
-%      RegisterPATTERNImage(void)
+%      unsigned long RegisterPATTERNImage(void)
 %
 */
-ModuleExport void RegisterPATTERNImage(void)
+ModuleExport unsigned long RegisterPATTERNImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("PATTERN");
-  entry->decoder=(DecoderHandler *) ReadPATTERNImage;
+  entry->decoder=(DecodeImageHandler *) ReadPATTERNImage;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Predefined pattern");
   entry->module=ConstantString("PATTERN");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
