@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -60,9 +60,10 @@
 #include "magick/montage.h"
 #include "magick/resize.h"
 #include "magick/shear.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/transform.h"
 #include "magick/utility.h"
 
@@ -104,8 +105,6 @@ static MagickBooleanType
 %    o chroma2: The address of a character buffer that contains the
 %      chrominance information.
 %
-%
-%
 */
 static MagickBooleanType DecodeImage(Image *image,unsigned char *luma,
   unsigned char *chroma1,unsigned char *chroma2)
@@ -190,7 +189,7 @@ static MagickBooleanType DecodeImage(Image *image,unsigned char *luma,
   assert(luma != (unsigned char *) NULL);
   assert(chroma1 != (unsigned char *) NULL);
   assert(chroma2 != (unsigned char *) NULL);
-  buffer=(unsigned char *) AcquireMagickMemory(0x800);
+  buffer=(unsigned char *) AcquireQuantumMemory(0x800,sizeof(*buffer));
   if (buffer == (unsigned char *) NULL)
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
       image->filename);
@@ -201,7 +200,8 @@ static MagickBooleanType DecodeImage(Image *image,unsigned char *luma,
   {
     PCDGetBits(8);
     length=(sum & 0xff)+1;
-    pcd_table[i]=(PCDTable *) AcquireMagickMemory(length*sizeof(**pcd_table));
+    pcd_table[i]=(PCDTable *) AcquireQuantumMemory(length,
+      sizeof(*pcd_table[i]));
     if (pcd_table[i] == (PCDTable *) NULL)
       {
         buffer=(unsigned char *) RelinquishMagickMemory(buffer);
@@ -396,9 +396,15 @@ static MagickBooleanType IsPCD(const unsigned char *magick,const size_t length)
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 
+static inline size_t MagickMin(const size_t x,const size_t y)
+{
+  if (x < y)
+    return(x);
+  return(y);
+}
+
 static Image *OverviewImage(const ImageInfo *image_info,Image *image,
   ExceptionInfo *exception)
 {
@@ -553,7 +559,7 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Determine if this is a PCD file.
   */
-  header=(unsigned char *) AcquireMagickMemory(3*0x800);
+  header=(unsigned char *) AcquireQuantumMemory(0x800,3UL*sizeof(*header));
   if (header == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   count=ReadBlob(image,3*0x800,header);
@@ -582,7 +588,7 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
       }
     }
   if (image_info->number_scenes != 0)
-    scene=Min(image_info->scene,6);
+    scene=(unsigned long) MagickMin(image_info->scene,6);
   if (overview)
     scene=1;
   /*
@@ -590,7 +596,7 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   */
   width=192;
   height=128;
-  for (i=1; i < (long) Min(scene,3); i++)
+  for (i=1; i < (long) MagickMin(scene,3); i++)
   {
     width<<=1;
     height<<=1;
@@ -606,12 +612,20 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Allocate luma and chroma memory.
   */
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   number_pixels=(MagickSizeType) image->columns*image->rows;
   if (number_pixels != (size_t) number_pixels)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-  chroma1=(unsigned char *) AcquireMagickMemory(image->columns*image->rows+1);
-  chroma2=(unsigned char *) AcquireMagickMemory(image->columns*image->rows+1);
-  luma=(unsigned char *) AcquireMagickMemory(image->columns*image->rows+1);
+  chroma1=(unsigned char *) AcquireQuantumMemory(image->columns+1UL,image->rows*
+    sizeof(*chroma1));
+  chroma2=(unsigned char *) AcquireQuantumMemory(image->columns+1UL,image->rows*
+    sizeof(*chroma2));
+  luma=(unsigned char *) AcquireQuantumMemory(image->columns+1UL,image->rows*
+    sizeof(*luma));
   if ((chroma1 == (unsigned char *) NULL) ||
       (chroma2 == (unsigned char *) NULL) || (luma == (unsigned char *) NULL))
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
@@ -765,7 +779,7 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
           Upsample(768,512,image->columns,chroma2);
           image->rows=2048;
           offset=TellBlob(image)/0x800+12;
-          (void) SeekBlob(image,offset*0x800,SEEK_SET);
+          offset=SeekBlob(image,offset*0x800,SEEK_SET);
           status=DecodeImage(image,luma,chroma1,chroma2);
           if ((scene >= 6) && (status != MagickFalse))
             {
@@ -875,29 +889,30 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterPCDImage method is:
 %
-%      RegisterPCDImage(void)
+%      unsigned long RegisterPCDImage(void)
 %
 */
-ModuleExport void RegisterPCDImage(void)
+ModuleExport unsigned long RegisterPCDImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("PCD");
-  entry->decoder=(DecoderHandler *) ReadPCDImage;
-  entry->encoder=(EncoderHandler *) WritePCDImage;
-  entry->magick=(MagickHandler *) IsPCD;
+  entry->decoder=(DecodeImageHandler *) ReadPCDImage;
+  entry->encoder=(EncodeImageHandler *) WritePCDImage;
+  entry->magick=(IsImageFormatHandler *) IsPCD;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Photo CD");
   entry->module=ConstantString("PCD");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PCDS");
-  entry->decoder=(DecoderHandler *) ReadPCDImage;
-  entry->encoder=(EncoderHandler *) WritePCDImage;
+  entry->decoder=(DecodeImageHandler *) ReadPCDImage;
+  entry->encoder=(EncodeImageHandler *) WritePCDImage;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Photo CD");
   entry->module=ConstantString("PCD");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
