@@ -60,9 +60,10 @@
 #include "magick/monitor.h"
 #include "magick/profile.h"
 #include "magick/resource_.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/token.h"
 #include "magick/transform.h"
 #include "magick/utility.h"
@@ -314,12 +315,12 @@ static Image *ReadPCLImage(const ImageInfo *image_info,ExceptionInfo *exception)
   (void) FormatMagickString(geometry,MaxTextExtent,"%lux%lu",
     page.width,page.height);
   if (image_info->monochrome != MagickFalse)
-    delegate_info=GetDelegateInfo("pcl-mono",(char *) NULL,exception);
+    delegate_info=GetDelegateInfo("pcl:mono",(char *) NULL,exception);
   else
      if (cmyk != MagickFalse)
-       delegate_info=GetDelegateInfo("pcl-cmyk",(char *) NULL,exception);
+       delegate_info=GetDelegateInfo("pcl:cmyk",(char *) NULL,exception);
      else
-       delegate_info=GetDelegateInfo("pcl-color",(char *) NULL,exception);
+       delegate_info=GetDelegateInfo("pcl:color",(char *) NULL,exception);
   if (delegate_info == (const DelegateInfo *) NULL)
     return((Image *) NULL);
   *options='\0';
@@ -399,18 +400,18 @@ static Image *ReadPCLImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterPCLImage method is:
 %
-%      RegisterPCLImage(void)
+%      unsigned long RegisterPCLImage(void)
 %
 */
-ModuleExport void RegisterPCLImage(void)
+ModuleExport unsigned long RegisterPCLImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("PCL");
-  entry->decoder=(DecoderHandler *) ReadPCLImage;
-  entry->encoder=(EncoderHandler *) WritePCLImage;
-  entry->magick=(MagickHandler *) IsPCL;
+  entry->decoder=(DecodeImageHandler *) ReadPCLImage;
+  entry->encoder=(EncodeImageHandler *) WritePCLImage;
+  entry->magick=(IsImageFormatHandler *) IsPCL;
   entry->adjoin=MagickFalse;
   entry->blob_support=MagickFalse;
   entry->seekable_stream=MagickTrue;
@@ -418,6 +419,7 @@ ModuleExport void RegisterPCLImage(void)
   entry->description=ConstantString("Printer Control Language");
   entry->module=ConstantString("PCL");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -593,8 +595,8 @@ static MagickBooleanType WritePCLImage(const ImageInfo *image_info,Image *image)
       /*
         Allocate pixel buffers.
       */
-      pixels=(unsigned char *)
-        AcquireMagickMemory(3*image->columns*sizeof(unsigned char));
+      pixels=(unsigned char *) AcquireQuantumMemory(image->columns,
+        3UL*sizeof(*pixels));
       if (pixels == (unsigned char *) NULL)
         ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
       /*
