@@ -53,9 +53,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Typedef declarations.
@@ -299,8 +300,8 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       magic=ReadBlobLSBLong(image);
       if (magic != 987654321)
         ThrowReaderException(CorruptImageError,"ImproperImageHeader");
-      page_table=(MagickOffsetType *)
-         AcquireMagickMemory(1024*sizeof(*page_table));
+      page_table=(MagickOffsetType *) AcquireQuantumMemory(1024UL,
+        sizeof(*page_table));
       if (page_table == (MagickOffsetType *) NULL)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
       for (id=0; id < 1024; id++)
@@ -349,8 +350,8 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     image->x_resolution=(double) pcx_info.horizontal_resolution;
     image->y_resolution=(double) pcx_info.vertical_resolution;
     image->colors=16;
-    pcx_colormap=(unsigned char *) AcquireMagickMemory(3*256*
-      sizeof(*pcx_colormap));
+    pcx_colormap=(unsigned char *) AcquireQuantumMemory(256UL,
+      3*sizeof(*pcx_colormap));
     if (pcx_colormap == (unsigned char *) NULL)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     count=ReadBlob(image,3*image->colors,pcx_colormap);
@@ -382,12 +383,17 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     /*
       Read image data.
     */
+    if (SetImageExtent(image,0,0) == MagickFalse)
+      {
+        InheritException(exception,&image->exception);
+        return(DestroyImageList(image));
+      }
     pcx_packets=(unsigned long) image->rows*pcx_info.bytes_per_line*
       pcx_info.planes;
-    pcx_pixels=(unsigned char *) AcquireMagickMemory(pcx_packets*
+    pcx_pixels=(unsigned char *) AcquireQuantumMemory(pcx_packets,
       sizeof(*pcx_pixels));
-    scanline=(unsigned char *) AcquireMagickMemory(MagickMax(image->columns,
-      pcx_info.bytes_per_line)*MagickMax(8,pcx_info.planes)*sizeof(*scanline));
+    scanline=(unsigned char *) AcquireQuantumMemory(MagickMax(image->columns,
+      pcx_info.bytes_per_line),MagickMax(8,pcx_info.planes)*sizeof(*scanline));
     if ((pcx_pixels == (unsigned char *) NULL) ||
         (scanline == (unsigned char *) NULL))
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
@@ -447,9 +453,9 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
               image->colormap[0].red=(Quantum) 0;
               image->colormap[0].green=(Quantum) 0;
               image->colormap[0].blue=(Quantum) 0;
-              image->colormap[1].red=QuantumRange;
-              image->colormap[1].green=QuantumRange;
-              image->colormap[1].blue=QuantumRange;
+              image->colormap[1].red=(Quantum) QuantumRange;
+              image->colormap[1].green=(Quantum) QuantumRange;
+              image->colormap[1].blue=(Quantum) QuantumRange;
             }
           else
             if (image->colors > 16)
@@ -696,31 +702,32 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterPCXImage method is:
 %
-%      RegisterPCXImage(void)
+%      unsigned long RegisterPCXImage(void)
 %
 */
-ModuleExport void RegisterPCXImage(void)
+ModuleExport unsigned long RegisterPCXImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("DCX");
-  entry->decoder=(DecoderHandler *) ReadPCXImage;
-  entry->encoder=(EncoderHandler *) WritePCXImage;
+  entry->decoder=(DecodeImageHandler *) ReadPCXImage;
+  entry->encoder=(EncodeImageHandler *) WritePCXImage;
   entry->seekable_stream=MagickTrue;
-  entry->magick=(MagickHandler *) IsDCX;
+  entry->magick=(IsImageFormatHandler *) IsDCX;
   entry->description=ConstantString("ZSoft IBM PC multi-page Paintbrush");
   entry->module=ConstantString("PCX");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PCX");
-  entry->decoder=(DecoderHandler *) ReadPCXImage;
-  entry->encoder=(EncoderHandler *) WritePCXImage;
-  entry->magick=(MagickHandler *) IsPCX;
+  entry->decoder=(DecodeImageHandler *) ReadPCXImage;
+  entry->encoder=(EncodeImageHandler *) WritePCXImage;
+  entry->magick=(IsImageFormatHandler *) IsPCX;
   entry->adjoin=MagickFalse;
   entry->seekable_stream=MagickTrue;
   entry->description=ConstantString("ZSoft IBM PC Paintbrush");
   entry->module=ConstantString("PCX");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -882,8 +889,8 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
         Write the DCX page table.
       */
       (void) WriteBlobLSBLong(image,0x3ADE68B1L);
-      page_table=(MagickOffsetType *)
-        AcquireMagickMemory(1024*sizeof(*page_table));
+      page_table=(MagickOffsetType *) AcquireQuantumMemory(1024UL,
+        sizeof(*page_table));
       if (page_table == (MagickOffsetType *) NULL)
         ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
       for (scene=0; scene < 1024; scene++)
@@ -955,8 +962,8 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
     /*
       Dump colormap to file.
     */
-    pcx_colormap=(unsigned char *)
-      AcquireMagickMemory(3*256*sizeof(*pcx_colormap));
+    pcx_colormap=(unsigned char *) AcquireQuantumMemory(256UL,
+      3*sizeof(*pcx_colormap));
     if (pcx_colormap == (unsigned char *) NULL)
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
     (void) memset(pcx_colormap,0,3*256*sizeof(*pcx_colormap));
@@ -975,9 +982,9 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
     (void) WriteBlobLSBShort(image,pcx_info.palette_info);
     for (i=0; i < 58; i++)
       (void) WriteBlobByte(image,'\0');
-    length=(size_t) pcx_info.bytes_per_line*pcx_info.planes;
-    pcx_pixels=(unsigned char *)
-      AcquireMagickMemory(length*sizeof(*pcx_pixels));
+    length=(size_t) pcx_info.bytes_per_line;
+    pcx_pixels=(unsigned char *) AcquireQuantumMemory(length,
+      pcx_info.planes*sizeof(*pcx_pixels));
     if (pcx_pixels == (unsigned char *) NULL)
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
     q=pcx_pixels;
@@ -1031,7 +1038,7 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
               case 3:
               default:
               {
-                for (x=(long) pcx_info.bytes_per_line; x > 0; x--)
+                for (x=(long) pcx_info.bytes_per_line; x != 0; x--)
                 {
                   *q++=ScaleQuantumToChar((Quantum) (QuantumRange-p->opacity));
                   p++;
@@ -1088,7 +1095,7 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
             Convert PseudoClass image to a PCX monochrome image.
           */
           polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
-            (QuantumRange/2) ? 1 : 0);
+            ((Quantum) QuantumRange/2) ? 1 : 0);
           if (image->colors == 2)
             polarity=(IndexPacket) (
               PixelIntensityToQuantum(&image->colormap[0]) <
