@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -54,10 +54,11 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Typedef declarations.
@@ -390,8 +391,14 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
       CloseBlob(image);
       return(GetFirstImageInList(image));
     }
-  packets=(bits_per_pixel*image->columns/8)*image->rows;
-  pixels=(unsigned char *) AcquireMagickMemory(packets+256);
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
+  packets=bits_per_pixel*image->columns/8;
+  pixels=(unsigned char *) AcquireQuantumMemory(packets+256UL,image->rows*
+    sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   switch (pdb_image.version)
@@ -435,7 +442,7 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
           {
             index=(IndexPacket) (*p & (0x80 >> bit) ? 0x00 : 0x01);
             indexes[x+bit]=index;
-            *q++=image->colormap[index];
+            *q++=image->colormap[(long) index];
           }
           p++;
         }
@@ -467,16 +474,16 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         {
           index=ConstrainColormapIndex(image,3UL-((*p >> 6) & 0x03));
           indexes[x]=index;
-          *q++=image->colormap[index];
+          *q++=image->colormap[(long) index];
           index=ConstrainColormapIndex(image,3UL-((*p >> 4) & 0x03));
           indexes[x+1]=index;
-          *q++=image->colormap[index];
+          *q++=image->colormap[(long) index];
           index=ConstrainColormapIndex(image,3UL-((*p >> 2) & 0x03));
           indexes[x+2]=index;
-          *q++=image->colormap[index];
+          *q++=image->colormap[(long) index];
           index=ConstrainColormapIndex(image,3UL-((*p) & 0x03));
           indexes[x+3]=index;
-          *q++=image->colormap[index];
+          *q++=image->colormap[(long) index];
           p++;
         }
         if (SyncImagePixels(image) == MagickFalse)
@@ -507,10 +514,10 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         {
           index=ConstrainColormapIndex(image,15UL-((*p >> 4) & 0x0f));
           indexes[x]=index;
-          *q++=image->colormap[index];
+          *q++=image->colormap[(long) index];
           index=ConstrainColormapIndex(image,15UL-((*p) & 0x0f));
           indexes[x+1]=index;
-          *q++=image->colormap[index];
+          *q++=image->colormap[(long) index];
           p++;
         }
         if (SyncImagePixels(image) == MagickFalse)
@@ -560,8 +567,8 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
             *p='\0';
             length<<=1;
             length+=MaxTextExtent;
-            comment=(char *) ResizeMagickMemory(comment,
-              (length+MaxTextExtent)*sizeof(*comment));
+            comment=(char *) ResizeQuantumMemory(comment,length+MaxTextExtent,
+              sizeof(*comment));
             if (comment == (char *) NULL)
               break;
             p=comment+strlen(comment);
@@ -572,8 +579,8 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
       *p='\0';
       if (comment == (char *) NULL)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-      (void) SetImageProperty(image,"Comment",comment);
-      comment=(char *) RelinquishMagickMemory(comment);
+      (void) SetImageProperty(image,"comment",comment);
+      comment=DestroyString(comment);
     }
   CloseBlob(image);
   return(GetFirstImageInList(image));
@@ -599,21 +606,22 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterPDBImage method is:
 %
-%      RegisterPDBImage(void)
+%      unsigned long RegisterPDBImage(void)
 %
 */
-ModuleExport void RegisterPDBImage(void)
+ModuleExport unsigned long RegisterPDBImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("PDB");
-  entry->decoder=(DecoderHandler *) ReadPDBImage;
-  entry->encoder=(EncoderHandler *) WritePDBImage;
-  entry->magick=(MagickHandler *) IsPDB;
+  entry->decoder=(DecodeImageHandler *) ReadPDBImage;
+  entry->encoder=(EncodeImageHandler *) WritePDBImage;
+  entry->magick=(IsImageFormatHandler *) IsPDB;
   entry->description=ConstantString("Palm Database ImageViewer Format");
   entry->module=ConstantString("PDB");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -760,7 +768,7 @@ static MagickBooleanType WritePDBImage(const ImageInfo *image_info,Image *image)
   (void) CopyMagickMemory(pdb_info.id,"View",4);
   pdb_info.seed=0;
   pdb_info.next_record=0;
-  comment=GetImageProperty(image,"Comment");
+  comment=GetImageProperty(image,"comment");
   pdb_info.number_records=(comment == (const char *) NULL ? 1 : 2);
   (void) WriteBlob(image,32,(unsigned char *) pdb_info.name);
   (void) WriteBlobMSBShort(image,(unsigned short) pdb_info.attributes);
@@ -796,14 +804,16 @@ static MagickBooleanType WritePDBImage(const ImageInfo *image_info,Image *image)
     pdb_image.width=(short) (16*(image->columns/16+1));
   pdb_image.height=(short) image->rows;
   packets=(bits_per_pixel*image->columns/8)*image->rows;
-  runlength=(unsigned char *) AcquireMagickMemory(2*packets);
+  runlength=(unsigned char *) AcquireQuantumMemory(2UL*packets,
+    sizeof(*runlength));
   if (runlength == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
-  buffer=(unsigned char *) AcquireMagickMemory(256);
+  buffer=(unsigned char *) AcquireQuantumMemory(256UL,sizeof(*buffer));
   if (buffer == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
   packet_size=(size_t) (image->depth > 8 ? 2: 1);
-  scanline=(unsigned char *) AcquireMagickMemory(packet_size*image->columns);
+  scanline=(unsigned char *) AcquireQuantumMemory(image->columns,packet_size*
+    sizeof(*scanline));
   if (scanline == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
     if (image_info->colorspace == UndefinedColorspace)
