@@ -61,14 +61,15 @@
 #include "magick/option.h"
 #include "magick/profile.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/resource_.h"
 #include "magick/resize.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/transform.h"
 #include "magick/utility.h"
-#include "magick/version.h"
+#include "magick/module.h"
 #if defined(HasTIFF)
 #define CCITTParam  "-1"
 #else
@@ -371,6 +372,8 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   (void) ResetMagickMemory(&hires_bounds,0,sizeof(hires_bounds));
   (void) ResetMagickMemory(&page,0,sizeof(page));
   (void) ResetMagickMemory(command,0,sizeof(command));
+  hires_bounds.x2=0.0;
+  hires_bounds.y2=0.0;
   p=command;
   for (c=ReadBlobByte(image); c != EOF; c=ReadBlobByte(image))
   {
@@ -465,7 +468,8 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
     if (count != 4)
       continue;
-    if ((bounds.x2 > hires_bounds.x2) && (bounds.y2 > hires_bounds.y2))
+    if (((bounds.x2 > hires_bounds.x2) && (bounds.y2 > hires_bounds.y2)) ||
+        ((hires_bounds.x2 == 0.0) && (hires_bounds.y2 == 0.0)))
       {
         /*
           Set PDF render geometry.
@@ -530,13 +534,17 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   *read_info->magick='\0';
   if (read_info->number_scenes != 0)
     {
+      char
+        pages[MaxTextExtent];
+
       if (read_info->number_scenes != 1)
-        (void) FormatMagickString(options,MaxTextExtent,"-dLastPage=%lu",
+        (void) FormatMagickString(pages,MaxTextExtent,"-dLastPage=%lu",
           read_info->scene+read_info->number_scenes);
       else
-        (void) FormatMagickString(options,MaxTextExtent,
-          "-dFirstPage=%lu -dLastPage=%lu",read_info->scene+1,read_info->scene+
+        (void) FormatMagickString(pages,MaxTextExtent,"-dFirstPage=%lu "
+          "-dLastPage=%lu",read_info->scene+1,read_info->scene+
           read_info->number_scenes);
+      (void) ConcatenateMagickString(options,pages,MaxTextExtent);
       read_info->number_scenes=0;
       if (read_info->scenes != (char *) NULL)
         *read_info->scenes='\0';
@@ -613,17 +621,17 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterPDFImage method is:
 %
-%      RegisterPDFImage(void)
+%      unsigned long RegisterPDFImage(void)
 %
 */
-ModuleExport void RegisterPDFImage(void)
+ModuleExport unsigned long RegisterPDFImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("EPDF");
-  entry->decoder=(DecoderHandler *) ReadPDFImage;
-  entry->encoder=(EncoderHandler *) WritePDFImage;
+  entry->decoder=(DecodeImageHandler *) ReadPDFImage;
+  entry->encoder=(EncodeImageHandler *) WritePDFImage;
   entry->adjoin=MagickFalse;
   entry->blob_support=MagickFalse;
   entry->seekable_stream=MagickTrue;
@@ -632,15 +640,16 @@ ModuleExport void RegisterPDFImage(void)
   entry->module=ConstantString("PDF");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PDF");
-  entry->decoder=(DecoderHandler *) ReadPDFImage;
-  entry->encoder=(EncoderHandler *) WritePDFImage;
-  entry->magick=(MagickHandler *) IsPDF;
+  entry->decoder=(DecodeImageHandler *) ReadPDFImage;
+  entry->encoder=(EncodeImageHandler *) WritePDFImage;
+  entry->magick=(IsImageFormatHandler *) IsPDF;
   entry->blob_support=MagickFalse;
   entry->seekable_stream=MagickTrue;
   entry->thread_support=EncoderThreadSupport;
   entry->description=ConstantString("Portable Document Format");
   entry->module=ConstantString("PDF");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
