@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -57,9 +57,10 @@
 #include "magick/monitor.h"
 #include "magick/profile.h"
 #include "magick/resource_.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/transform.h"
 #include "magick/utility.h"
 
@@ -82,25 +83,32 @@
   pixmap.plane_bytes=ReadBlobMSBLong(image); \
   pixmap.table=ReadBlobMSBLong(image); \
   pixmap.reserved=ReadBlobMSBLong(image); \
+  if ((pixmap.bits_per_pixel <= 0) || (pixmap.bits_per_pixel > 32) || \
+      (pixmap.component_count <= 0) || (pixmap.component_count > 4) || \
+      (pixmap.component_size <= 0)) \
+    ThrowReaderException(CorruptImageError,"ImproperImageHeader"); \
 }
 
-#define ReadRectangle(rectangle) \
+#define ReadRectangle(image,rectangle) \
 { \
   rectangle.top=(short) ReadBlobMSBShort(image); \
   rectangle.left=(short) ReadBlobMSBShort(image); \
   rectangle.bottom=(short) ReadBlobMSBShort(image); \
   rectangle.right=(short) ReadBlobMSBShort(image); \
+  if ((rectangle.left > rectangle.right) || \
+      (rectangle.top > rectangle.bottom)) \
+    ThrowReaderException(CorruptImageError,"ImproperImageHeader"); \
 }
 
 typedef struct _PICTCode
 {
-  char
+  const char
     *name;
 
   long
     length;
 
-  char
+  const char
     *description;
 } PICTCode;
 
@@ -320,13 +328,14 @@ static MagickBooleanType
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  DecodeImage decompresses an image via Macintosh pack bits
-%  decoding for Macintosh PICT images.
+%  DecodeImage decompresses an image via Macintosh pack bits decoding for
+%  Macintosh PICT images.
 %
 %  The format of the DecodeImage method is:
 %
-%      unsigned char* DecodeImage(const ImageInfo *image_info,Image *blob,
-%        Image *image,unsigned long bytes_per_line,const int bits_per_pixel)
+%      unsigned char *DecodeImage(Image *blob,Image *image,
+%        unsigned long bytes_per_line,const int bits_per_pixel,
+%        unsigned long *extent)
 %
 %  A description of each parameter follows:
 %
@@ -339,6 +348,7 @@ static MagickBooleanType
 %
 %    o bits_per_pixel: The number of bits in a pixel.
 %
+%    o extent: The number of pixels allocated.
 %
 */
 
@@ -410,8 +420,9 @@ static unsigned char *ExpandBuffer(unsigned char *pixels,
   return(scanline);
 }
 
-static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
-  Image *image,unsigned long bytes_per_line,const unsigned int bits_per_pixel)
+static unsigned char *DecodeImage(Image *blob,Image *image,
+  unsigned long bytes_per_line,const unsigned int bits_per_pixel,
+  unsigned long *extent)
 {
   long
     j,
@@ -468,12 +479,13 @@ static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
   /*
     Allocate pixel and scanline buffer.
   */
-  pixels=(unsigned char *) AcquireMagickMemory(row_bytes*image->rows*
+  pixels=(unsigned char *) AcquireQuantumMemory(image->rows,row_bytes*
     sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     return((unsigned char *) NULL);
-  (void) ResetMagickMemory(pixels,0,row_bytes*image->rows);
-  scanline=(unsigned char *) AcquireMagickMemory(row_bytes*sizeof(scanline));
+  *extent=row_bytes*image->rows*sizeof(*pixels);
+  (void) ResetMagickMemory(pixels,0,*extent);
+  scanline=(unsigned char *) AcquireQuantumMemory(row_bytes,sizeof(*scanline));
   if (scanline == (unsigned char *) NULL)
     return((unsigned char *) NULL);
   if (bytes_per_line < 8)
@@ -823,6 +835,9 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
   StringInfo
     *profile;
 
+  unsigned long
+    extent;
+
   /*
     Open image file.
   */
@@ -849,7 +864,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
   for (i=0; i < 512; i++)
     (void) ReadBlobByte(image);  /* skip header */
   (void) ReadBlobMSBShort(image);  /* skip picture size */
-  ReadRectangle(frame);
+  ReadRectangle(image,frame);
   while ((c=ReadBlobByte(image)) == 0);
   if (c != 0x11)
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
@@ -872,6 +887,11 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
   image->x_resolution=DefaultResolution;
   image->y_resolution=DefaultResolution;
   image->units=UndefinedResolution;
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   /*
     Interpret PICT opcodes.
   */
@@ -909,7 +929,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                   (void) ReadBlobByte(image);
                 break;
               }
-            ReadRectangle(frame);
+            ReadRectangle(image,frame);
             if (((frame.left & 0x8000) != 0) || ((frame.top & 0x8000) != 0))
               break;
             image->columns=1UL*(frame.right-frame.left);
@@ -943,7 +963,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
             if (pattern != 1)
               ThrowReaderException(CorruptImageError,"UnknownPatternType");
             length=ReadBlobMSBShort(image);
-            ReadRectangle(frame);
+            ReadRectangle(image,frame);
             ReadPixmap(pixmap);
             image->depth=1UL*pixmap.component_size;
             image->x_resolution=1.0*pixmap.horizontal_resolution;
@@ -1045,7 +1065,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                 (void) ReadBlobMSBShort(image);
                 (void) ReadBlobMSBShort(image);
               }
-            ReadRectangle(frame);
+            ReadRectangle(image,frame);
             /*
               Initialize tile image.
             */
@@ -1115,8 +1135,8 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                     }
                   }
               }
-            ReadRectangle(source);
-            ReadRectangle(destination);
+            ReadRectangle(image,source);
+            ReadRectangle(image,destination);
             (void) ReadBlobMSBShort(image);
             if ((code == 0x91) || (code == 0x99) || (code == 0x9b))
               {
@@ -1129,11 +1149,10 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
               }
             if ((code != 0x9a) && (code != 0x9b) &&
                 (bytes_per_line & 0x8000) == 0)
-              pixels=DecodeImage(image_info,image,tile_image,1UL*
-                bytes_per_line,1);
+              pixels=DecodeImage(image,tile_image,1UL*bytes_per_line,1,&extent);
             else
-              pixels=DecodeImage(image_info,image,tile_image,1UL*bytes_per_line,
-                1U*pixmap.bits_per_pixel);
+              pixels=DecodeImage(image,tile_image,1UL*bytes_per_line,1U*
+                pixmap.bits_per_pixel,&extent);
             if (pixels == (unsigned char *) NULL)
               {
                 tile_image=DestroyImage(tile_image);
@@ -1146,6 +1165,8 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
             p=pixels;
             for (y=0; y < (long) tile_image->rows; y++)
             {
+              if (p > (pixels+extent+image->columns))
+                ThrowReaderException(CorruptImageError,"NotEnoughPixelData");
               q=SetImagePixels(tile_image,0,y,tile_image->columns,1);
               if (q == (PixelPacket *) NULL)
                 break;
@@ -1156,9 +1177,9 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                   {
                     index=ConstrainColormapIndex(tile_image,*p);
                     indexes[x]=index;
-                    q->red=tile_image->colormap[index].red;
-                    q->green=tile_image->colormap[index].green;
-                    q->blue=tile_image->colormap[index].blue;
+                    q->red=tile_image->colormap[(long) index].red;
+                    q->green=tile_image->colormap[(long) index].green;
+                    q->blue=tile_image->colormap[(long) index].blue;
                   }
                 else
                   {
@@ -1176,6 +1197,9 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                     else
                       if (tile_image->matte == MagickFalse)
                         {
+                          if (p > (pixels+extent+2*image->columns))
+                            ThrowReaderException(CorruptImageError,
+                              "NotEnoughPixelData");
                           q->red=ScaleCharToQuantum(*p);
                           q->green=ScaleCharToQuantum(
                             *(p+tile_image->columns));
@@ -1184,6 +1208,9 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                         }
                       else
                         {
+                          if (p > (pixels+extent+3*image->columns))
+                            ThrowReaderException(CorruptImageError,
+                              "NotEnoughPixelData");
                           q->opacity=(Quantum) (QuantumRange-
                             ScaleCharToQuantum(*p));
                           q->red=ScaleCharToQuantum(*(p+tile_image->columns));
@@ -1200,7 +1227,11 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                 break;
               if ((tile_image->storage_class == DirectClass) &&
                   (pixmap.bits_per_pixel != 16))
-                p+=(pixmap.component_count-1)*tile_image->columns;
+                {
+                  p+=(pixmap.component_count-1)*tile_image->columns;
+                  if (p < pixels)
+                    break;
+                }
               if (destination.bottom == (long) image->rows)
                 if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
                     (QuantumTick(y,tile_image->rows) != MagickFalse))
@@ -1246,7 +1277,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
             length-=4;
             if (length == 0)
               break;
-            info=(unsigned char *) AcquireMagickMemory(length);
+            info=(unsigned char *) AcquireQuantumMemory(length,sizeof(*info));
             if (info == (unsigned char *) NULL)
               break;
             count=ReadBlob(image,length,info);
@@ -1345,7 +1376,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
         length=ReadBlobMSBLong(image);
         for (i=0; i < 6; i++)
           (void) ReadBlobMSBLong(image);
-        ReadRectangle(frame);
+        ReadRectangle(image,frame);
         for (i=0; i < 122; i++)
           (void) ReadBlobByte(image);
         for (i=0; i < (long) (length-154); i++)
@@ -1420,30 +1451,31 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterPICTImage method is:
 %
-%      RegisterPICTImage(void)
+%      unsigned long RegisterPICTImage(void)
 %
 */
-ModuleExport void RegisterPICTImage(void)
+ModuleExport unsigned long RegisterPICTImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("PCT");
-  entry->decoder=(DecoderHandler *) ReadPICTImage;
-  entry->encoder=(EncoderHandler *) WritePICTImage;
+  entry->decoder=(DecodeImageHandler *) ReadPICTImage;
+  entry->encoder=(EncodeImageHandler *) WritePICTImage;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Apple Macintosh QuickDraw/PICT");
-  entry->magick=(MagickHandler *) IsPICT;
+  entry->magick=(IsImageFormatHandler *) IsPICT;
   entry->module=ConstantString("PICT");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PICT");
-  entry->decoder=(DecoderHandler *) ReadPICTImage;
-  entry->encoder=(EncoderHandler *) WritePICTImage;
+  entry->decoder=(DecodeImageHandler *) ReadPICTImage;
+  entry->encoder=(EncodeImageHandler *) WritePICTImage;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Apple Macintosh QuickDraw/PICT");
-  entry->magick=(MagickHandler *) IsPICT;
+  entry->magick=(IsImageFormatHandler *) IsPICT;
   entry->module=ConstantString("PICT");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -1630,10 +1662,10 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
   bytes_per_line=image->columns;
   if ((storage_class == DirectClass) || (image->matte != MagickFalse))
     bytes_per_line*=image->matte ? 4 : 3;
-  buffer=(unsigned char *) AcquireMagickMemory(PictInfoSize);
-  packed_scanline=(unsigned char *) AcquireMagickMemory((size_t)
-   (row_bytes+MaxCount));
-  scanline=(unsigned char *) AcquireMagickMemory(row_bytes);
+  buffer=(unsigned char *) AcquireQuantumMemory(PictInfoSize,sizeof(*buffer));
+  packed_scanline=(unsigned char *) AcquireQuantumMemory((size_t)
+   (row_bytes+MaxCount),sizeof(*packed_scanline));
+  scanline=(unsigned char *) AcquireQuantumMemory(row_bytes,sizeof(*scanline));
   if ((buffer == (unsigned char *) NULL) ||
       (packed_scanline == (unsigned char *) NULL) ||
       (scanline == (unsigned char *) NULL))
@@ -1931,7 +1963,7 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
     (void) WriteBlobByte(image,'\0');
   (void) WriteBlobMSBShort(image,PictEndOfPictureOp);
   offset=TellBlob(image);
-  (void) SeekBlob(image,512,SEEK_SET);
+  offset=SeekBlob(image,512,SEEK_SET);
   (void) WriteBlobMSBShort(image,(unsigned short) offset);
   scanline=(unsigned char *) RelinquishMagickMemory(scanline);
   packed_scanline=(unsigned char *) RelinquishMagickMemory(packed_scanline);
