@@ -50,9 +50,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -142,8 +143,8 @@ static Image *ReadPIXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   (void) ReadBlobMSBShort(image);  /* x-offset */
   (void) ReadBlobMSBShort(image);  /* y-offset */
   bits_per_pixel=ReadBlobMSBShort(image);
-  if ((width == (unsigned long) ~0) || (height == (unsigned long) ~0) ||
-      ((bits_per_pixel != 8) && (bits_per_pixel != 24)))
+  if ((width == 0UL) || (height == 0UL) || ((bits_per_pixel != 8) &&
+      (bits_per_pixel != 24)))
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   do
   {
@@ -230,8 +231,7 @@ static Image *ReadPIXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     (void) ReadBlobMSBShort(image);
     (void) ReadBlobMSBShort(image);
     bits_per_pixel=ReadBlobMSBShort(image);
-    status=(width != (unsigned long) ~0) &&
-      (height == (unsigned long) ~0) && ((bits_per_pixel == 8) ||
+    status=(width != 0UL) && (height == 0UL) && ((bits_per_pixel == 8) ||
       (bits_per_pixel == 24)) ? MagickTrue : MagickFalse;
     if (status == MagickTrue)
       {
@@ -278,19 +278,20 @@ static Image *ReadPIXImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterPIXImage method is:
 %
-%      RegisterPIXImage(void)
+%      unsigned long RegisterPIXImage(void)
 %
 */
-ModuleExport void RegisterPIXImage(void)
+ModuleExport unsigned long RegisterPIXImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("PIX");
-  entry->decoder=(DecoderHandler *) ReadPIXImage;
+  entry->decoder=(DecodeImageHandler *) ReadPIXImage;
   entry->description=ConstantString("Alias/Wavefront RLE image format");
   entry->module=ConstantString("PIX");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
