@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -53,9 +53,10 @@
 #include "magick/monitor.h"
 #include "magick/random_.h"
 #include "magick/signature.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -84,6 +85,13 @@
 %
 */
 
+static inline size_t MagickMax(const size_t x,const size_t y)
+{
+  if (x > y)
+    return(x);
+  return(y);
+}
+
 static inline void PlasmaPixel(Image *image,double x,double y)
 {
   register PixelPacket
@@ -93,11 +101,11 @@ static inline void PlasmaPixel(Image *image,double x,double y)
   if (q == (PixelPacket *) NULL)
     return;
   q->red=ScaleAnyToQuantum((unsigned long)
-    (65535.0*GetRandomValue()+0.5),65535UL);
+    (65535.0*GetRandomValue()+0.5),16UL);
   q->green=ScaleAnyToQuantum((unsigned long)
-    (65535.0*GetRandomValue()+0.5),65535UL);
+    (65535.0*GetRandomValue()+0.5),16UL);
   q->blue=ScaleAnyToQuantum((unsigned long)
-    (65535.0*GetRandomValue()+0.5),65535UL);
+    (65535.0*GetRandomValue()+0.5),16UL);
   (void) SyncImagePixels(image);
 }
 
@@ -179,7 +187,7 @@ static Image *ReadPlasmaImage(const ImageInfo *image_info,
       PlasmaPixel(image,segment_info.x2,(segment_info.y1+segment_info.y2)/2);
       PlasmaPixel(image,segment_info.x2,segment_info.y2);
     }
-  i=Max(image->columns,image->rows)/2;
+  i=(unsigned long) MagickMax(image->columns,image->rows)/2;
   for (max_depth=0; i != 0; max_depth++)
     i>>=1;
   for (depth=1; ; depth++)
@@ -219,26 +227,27 @@ static Image *ReadPlasmaImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterPLASMAImage method is:
 %
-%      RegisterPLASMAImage(void)
+%      unsigned long RegisterPLASMAImage(void)
 %
 */
-ModuleExport void RegisterPLASMAImage(void)
+ModuleExport unsigned long RegisterPLASMAImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("PLASMA");
-  entry->decoder=(DecoderHandler *) ReadPlasmaImage;
+  entry->decoder=(DecodeImageHandler *) ReadPlasmaImage;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Plasma fractal image");
   entry->module=ConstantString("PLASMA");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("FRACTAL");
-  entry->decoder=(DecoderHandler *) ReadPlasmaImage;
+  entry->decoder=(DecodeImageHandler *) ReadPlasmaImage;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Plasma fractal image");
   entry->module=ConstantString("PLASMA");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
