@@ -54,10 +54,11 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -183,8 +184,8 @@ static unsigned long PNMInteger(Image *image,const unsigned int base)
           if ((size_t) (p-comment+1) >= length)
             {
               length<<=1;
-              comment=(char *) ResizeMagickMemory(comment,
-                (length+MaxTextExtent)*sizeof(*comment));
+              comment=(char *) ResizeQuantumMemory(comment,length+MaxTextExtent,
+                sizeof(*comment));
               if (comment == (char *) NULL)
                 break;
               p=comment+strlen(comment);
@@ -200,7 +201,7 @@ static unsigned long PNMInteger(Image *image,const unsigned int base)
   } while (isdigit(c) == MagickFalse);
   if (comment != (char *) NULL)
     {
-      (void) SetImageProperty(image,"Comment",comment);
+      (void) SetImageProperty(image,"comment",comment);
       comment=DestroyString(comment);
     }
   if (base == 2)
@@ -220,37 +221,6 @@ static unsigned long PNMInteger(Image *image,const unsigned int base)
   return(value);
 }
 
-static inline unsigned char PushCharPixel(const unsigned char **pixels)
-{
-  unsigned char
-    pixel;
-
-  pixel=(unsigned char) *(*pixels)++;
-  return(pixel);
-}
-
-static inline unsigned long PushLongPixel(const unsigned char **pixels)
-{
-  unsigned long
-    pixel;
-
-  pixel=(unsigned long) (*(*pixels)++ << 24);
-  pixel|=(unsigned long) (*(*pixels)++ << 16);
-  pixel|=(unsigned long) (*(*pixels)++ << 8);
-  pixel|=(unsigned long) (*(*pixels)++);
-  return(pixel);
-}
-
-static inline unsigned short PushShortPixel(const unsigned char **pixels)
-{
-  unsigned short
-    pixel;
-
-  pixel=(unsigned short) (*(*pixels)++ << 8);
-  pixel|=(unsigned short) (*(*pixels)++);
-  return(pixel);
-}
-
 static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
   char
@@ -276,6 +246,9 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
   QuantumInfo
     quantum_info;
 
+  QuantumState
+    quantum_state;
+
   register IndexPacket
     *indexes;
 
@@ -332,6 +305,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
     max_value=1;
     grayscale=MagickFalse;
     GetQuantumInfo(image_info,&quantum_info);
+    InitializeQuantumState(&quantum_info,MSBEndian,&quantum_state);
     format=(char) ReadBlobByte(image);
     if (format != '7')
       {
@@ -454,16 +428,21 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Compute pixel scaling table.
         */
-        scale=(Quantum *) AcquireMagickMemory((size_t) (max_value+1)*
+        scale=(Quantum *) AcquireQuantumMemory((size_t) max_value+1UL,
           sizeof(*scale));
         if (scale == (Quantum *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         for (i=0; i <= (long) max_value; i++)
-          scale[i]=ScaleAnyToQuantum((unsigned long) i,max_value);
+          scale[i]=ScaleAnyToQuantum((QuantumAny) i,image->depth);
       }
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
+    if (SetImageExtent(image,0,0) == MagickFalse)
+      {
+        InheritException(exception,&image->exception);
+        return(DestroyImageList(image));
+      }
     /*
       Convert PNM pixels to runlength-encoded MIFF packets.
     */
@@ -525,7 +504,8 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           {
             intensity=PNMInteger(image,10);
             if (scale != (Quantum *) NULL)
-              intensity=(unsigned long) scale[intensity];
+              intensity=(unsigned long) scale[ConstrainPixel(image,(long)
+                intensity,max_value)];
             index=(long) intensity;
             if ((unsigned long) index >= image->colors)
               {
@@ -649,10 +629,12 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           Convert PGM raw image to pixel packets.
         */
         packet_size=(size_t) (image->depth <= 8 ? 1 : 2);
-        length=packet_size*image->columns;
-        pixels=(unsigned char *) AcquireMagickMemory(length*sizeof(*pixels));
+        length=image->columns;
+        pixels=(unsigned char *) AcquireQuantumMemory(length,packet_size*
+          sizeof(*pixels));
         if (pixels == (unsigned char *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
+        length*=packet_size*sizeof(*pixels);
         for (y=0; y < (long) image->rows; y++)
         {
           count=ReadBlob(image,length,pixels);
@@ -680,7 +662,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           else
             for (x=0; x < (long) image->columns; x++)
             {
-              index=(long) PushShortPixel(&p);
+              index=(long) PushShortPixel(&quantum_state,&p);
               if (index >= (long) image->colors)
                 {
                   (void) ThrowMagickException(&image->exception,
@@ -720,8 +702,8 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         packet_size=(size_t) (image->depth <= 8 ? 3 : 6);
         if (image->colorspace == CMYKColorspace)
           packet_size+=(size_t) (image->depth <= 8 ? 1 : 2);
-        pixels=(unsigned char *) AcquireMagickMemory(packet_size*
-          image->columns*sizeof(*pixels));
+        pixels=(unsigned char *) AcquireQuantumMemory(image->columns,
+          packet_size*sizeof(*pixels));
         if (pixels == (unsigned char *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         (void) ResetMagickMemory(&pixel,0,sizeof(LongPixelPacket));
@@ -757,9 +739,9 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           else
             for (x=0; x < (long) image->columns; x++)
             {
-              pixel.red=(MagickRealType) PushShortPixel(&p);
-              pixel.green=(MagickRealType) PushShortPixel(&p);
-              pixel.blue=(MagickRealType) PushShortPixel(&p);
+              pixel.red=(MagickRealType) PushShortPixel(&quantum_state,&p);
+              pixel.green=(MagickRealType) PushShortPixel(&quantum_state,&p);
+              pixel.blue=(MagickRealType) PushShortPixel(&quantum_state,&p);
               if (scale != (Quantum *) NULL)
                 {
                   pixel.red=(MagickRealType) scale[ConstrainPixel(image,(long)
@@ -812,8 +794,9 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           packet_size++;
         if (image->depth > 8)
           packet_size*=2;
-        length=packet_size*image->columns*sizeof(*pixels);
-        pixels=(unsigned char *) AcquireMagickMemory(length);
+        length=image->columns;
+        pixels=(unsigned char *) AcquireQuantumMemory(length,packet_size*
+          sizeof(*pixels));
         if (pixels == (unsigned char *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         for (y=0; y < (long) image->rows; y++)
@@ -832,41 +815,41 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 for (x=0; x < (long) image->columns; x++)
                 {
                   pixel=PushCharPixel(&p);
-                  q->red=ScaleAnyToQuantum(pixel,(1UL << image->depth)-1);
+                  q->red=ScaleAnyToQuantum(pixel,image->depth);
                   q->green=q->red;
                   q->blue=q->red;
                   if (image->colorspace == CMYKColorspace)
                     {
                       pixel=PushCharPixel(&p);
                       indexes[x]=(IndexPacket) ScaleAnyToQuantum(pixel,
-                        (1UL << image->depth)-1);
+                        image->depth);
                     }
                   if (image->matte != MagickFalse)
                     {
                       pixel=PushCharPixel(&p);
-                      q->opacity=QuantumRange-ScaleAnyToQuantum(pixel,
-                        (1UL << image->depth)-1);
+                      q->opacity=(Quantum) QuantumRange-ScaleAnyToQuantum(pixel,
+                        image->depth);
                     }
                   q++;
                 }
               else
                 for (x=0; x < (long) image->columns; x++)
                 {
-                  pixel=PushShortPixel(&p);
-                  q->red=ScaleAnyToQuantum(pixel,(1UL << image->depth)-1);
+                  pixel=PushShortPixel(&quantum_state,&p);
+                  q->red=ScaleAnyToQuantum(pixel,image->depth);
                   q->green=q->red;
                   q->blue=q->red;
                   if (image->colorspace == CMYKColorspace)
                     {
-                      pixel=PushShortPixel(&p);
+                      pixel=PushShortPixel(&quantum_state,&p);
                       indexes[x]=(IndexPacket) ScaleAnyToQuantum(pixel,
-                        (1UL << image->depth)-1);
+                        image->depth);
                     }
                   if (image->matte != MagickFalse)
                     {
-                      pixel=PushShortPixel(&p);
-                      q->opacity=QuantumRange-ScaleAnyToQuantum(pixel,
-                        (1UL << image->depth)-1);
+                      pixel=PushShortPixel(&quantum_state,&p);
+                      q->opacity=(Quantum) QuantumRange-ScaleAnyToQuantum(pixel,
+                        image->depth);
                     }
                   q++;
                 }
@@ -876,45 +859,45 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
               for (x=0; x < (long) image->columns; x++)
               {
                 pixel=PushCharPixel(&p);
-                q->red=ScaleAnyToQuantum(pixel,(1UL << image->depth)-1);
+                q->red=ScaleAnyToQuantum(pixel,image->depth);
                 pixel=PushCharPixel(&p);
-                q->green=ScaleAnyToQuantum(pixel,(1UL << image->depth)-1);
+                q->green=ScaleAnyToQuantum(pixel,image->depth);
                 pixel=PushCharPixel(&p);
-                q->blue=ScaleAnyToQuantum(pixel,(1UL << image->depth)-1);
+                q->blue=ScaleAnyToQuantum(pixel,image->depth);
                 if (image->colorspace == CMYKColorspace)
                   {
                     pixel=PushCharPixel(&p);
                     indexes[x]=(IndexPacket) ScaleAnyToQuantum(pixel,
-                      (1UL << image->depth)-1);
+                      image->depth);
                   }
                 if (image->matte != MagickFalse)
                   {
                     pixel=PushCharPixel(&p);
-                    q->opacity=QuantumRange-ScaleAnyToQuantum(pixel,
-                      (1UL << image->depth)-1);
+                    q->opacity=(Quantum) QuantumRange-ScaleAnyToQuantum(pixel,
+                      image->depth);
                   }
                 q++;
               }
             else
               for (x=0; x < (long) image->columns; x++)
               {
-                pixel=PushShortPixel(&p);
-                q->red=ScaleAnyToQuantum(pixel,(1UL << image->depth)-1);
-                pixel=PushShortPixel(&p);
-                q->green=ScaleAnyToQuantum(pixel,(1UL << image->depth)-1);
-                pixel=PushShortPixel(&p);
-                q->blue=ScaleAnyToQuantum(pixel,(1UL << image->depth)-1);
+                pixel=PushShortPixel(&quantum_state,&p);
+                q->red=ScaleAnyToQuantum(pixel,image->depth);
+                pixel=PushShortPixel(&quantum_state,&p);
+                q->green=ScaleAnyToQuantum(pixel,image->depth);
+                pixel=PushShortPixel(&quantum_state,&p);
+                q->blue=ScaleAnyToQuantum(pixel,image->depth);
                 if (image->colorspace == CMYKColorspace)
                   {
-                    pixel=PushShortPixel(&p);
+                    pixel=PushShortPixel(&quantum_state,&p);
                     indexes[x]=(IndexPacket) ScaleAnyToQuantum(pixel,
-                      (1UL << image->depth)-1);
+                      image->depth);
                   }
                 if (image->matte != MagickFalse)
                   {
-                    pixel=PushShortPixel(&p);
-                    q->opacity=QuantumRange-ScaleAnyToQuantum(pixel,
-                      (1UL << image->depth)-1);
+                    pixel=PushShortPixel(&quantum_state,&p);
+                    q->opacity=(Quantum) QuantumRange-ScaleAnyToQuantum(pixel,
+                      image->depth);
                   }
                 q++;
               }
@@ -950,7 +933,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         quantum_info.scale=QuantumRange;
         quantum_type=format == 'f' ? GrayQuantum : RGBQuantum;
         length=(format == 'f' ? 1 : 3)*image->columns*sizeof(float);
-        pixels=(unsigned char *) AcquireMagickMemory(length);
+        pixels=(unsigned char *) AcquireQuantumMemory(length,sizeof(pixels));
         if (pixels == (unsigned char *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         for (y=(long) image->rows-1; y >= 0; y--)
@@ -1049,51 +1032,52 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterPNMImage method is:
 %
-%      RegisterPNMImage(void)
+%      unsigned long RegisterPNMImage(void)
 %
 */
-ModuleExport void RegisterPNMImage(void)
+ModuleExport unsigned long RegisterPNMImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("PAM");
-  entry->decoder=(DecoderHandler *) ReadPNMImage;
-  entry->encoder=(EncoderHandler *) WritePNMImage;
+  entry->decoder=(DecodeImageHandler *) ReadPNMImage;
+  entry->encoder=(EncodeImageHandler *) WritePNMImage;
   entry->description=ConstantString("Common 2-dimensional bitmap format");
   entry->module=ConstantString("PNM");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PBM");
-  entry->decoder=(DecoderHandler *) ReadPNMImage;
-  entry->encoder=(EncoderHandler *) WritePNMImage;
+  entry->decoder=(DecodeImageHandler *) ReadPNMImage;
+  entry->encoder=(EncodeImageHandler *) WritePNMImage;
   entry->description=ConstantString("Portable bitmap format (black and white)");
   entry->module=ConstantString("PNM");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PFM");
-  entry->decoder=(DecoderHandler *) ReadPNMImage;
-  entry->encoder=(EncoderHandler *) WritePNMImage;
+  entry->decoder=(DecodeImageHandler *) ReadPNMImage;
+  entry->encoder=(EncodeImageHandler *) WritePNMImage;
   entry->description=ConstantString("Portable float format");
   entry->module=ConstantString("PFM");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PGM");
-  entry->decoder=(DecoderHandler *) ReadPNMImage;
-  entry->encoder=(EncoderHandler *) WritePNMImage;
+  entry->decoder=(DecodeImageHandler *) ReadPNMImage;
+  entry->encoder=(EncodeImageHandler *) WritePNMImage;
   entry->description=ConstantString("Portable graymap format (gray scale)");
   entry->module=ConstantString("PNM");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PNM");
-  entry->decoder=(DecoderHandler *) ReadPNMImage;
-  entry->encoder=(EncoderHandler *) WritePNMImage;
-  entry->magick=(MagickHandler *) IsPNM;
+  entry->decoder=(DecodeImageHandler *) ReadPNMImage;
+  entry->encoder=(EncodeImageHandler *) WritePNMImage;
+  entry->magick=(IsImageFormatHandler *) IsPNM;
   entry->description=ConstantString("Portable anymap");
   entry->module=ConstantString("PNM");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PPM");
-  entry->decoder=(DecoderHandler *) ReadPNMImage;
-  entry->encoder=(EncoderHandler *) WritePNMImage;
+  entry->decoder=(DecodeImageHandler *) ReadPNMImage;
+  entry->encoder=(EncodeImageHandler *) WritePNMImage;
   entry->description=ConstantString("Portable pixmap format (color)");
   entry->module=ConstantString("PNM");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -1149,29 +1133,6 @@ ModuleExport void UnregisterPNMImage(void)
 %    o image:  The image.
 %
 */
-
-static inline void PopCharPixel(const unsigned char pixel,
-  unsigned char **pixels)
-{
-  *(*pixels)++=(unsigned char) (pixel);
-}
-
-static inline void PopShortPixel(const unsigned short pixel,
-  unsigned char **pixels)
-{
-  *(*pixels)++=(unsigned char) ((pixel) >> 8);
-  *(*pixels)++=(unsigned char) (pixel);
-}
-
-static inline void PopLongPixel(const unsigned long pixel,
-  unsigned char **pixels)
-{
-  *(*pixels)++=(unsigned char) ((pixel) >> 24);
-  *(*pixels)++=(unsigned char) ((pixel) >> 16);
-  *(*pixels)++=(unsigned char) ((pixel) >> 8);
-  *(*pixels)++=(unsigned char) (pixel);
-}
-
 static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
 {
   char
@@ -1198,6 +1159,9 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
   QuantumInfo
     quantum_info;
 
+  QuantumState
+    quantum_state;
+
   register const PixelPacket
     *p;
 
@@ -1238,6 +1202,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
       Write PNM file header.
     */
     GetQuantumInfo(image_info,&quantum_info);
+    InitializeQuantumState(&quantum_info,MSBEndian,&quantum_state);
     if (image_info->colorspace == UndefinedColorspace)
       (void) SetImageColorspace(image,RGBColorspace);
     grayscale=IsGrayImage(image,&image->exception);
@@ -1301,7 +1266,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
     }
     (void) FormatMagickString(buffer,MaxTextExtent,"P%c\n",format);
     (void) WriteBlobString(image,buffer);
-    value=GetImageProperty(image,"Comment");
+    value=GetImageProperty(image,"comment");
     if (value != (const char *) NULL)
       {
         register const char
@@ -1598,8 +1563,9 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
           Allocate memory for pixels.
         */
         packet_size=(size_t) (image->depth <= 8 ? 3 : 6);
-        length=packet_size*image->columns*sizeof(*pixels);
-        pixels=(unsigned char *) AcquireMagickMemory(length);
+        length=image->columns;
+        pixels=(unsigned char *) AcquireQuantumMemory(length,packet_size*
+          sizeof(*pixels));
         if (pixels == (unsigned char *) NULL)
           ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
         /*
@@ -1660,8 +1626,9 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
           packet_size++;
         if (depth > 8)
           packet_size*=2;
-        length=packet_size*image->columns*sizeof(*pixels);
-        pixels=(unsigned char *) AcquireMagickMemory(length);
+        length=image->columns;
+        pixels=(unsigned char *) AcquireQuantumMemory(length,packet_size*
+          sizeof(*pixels));
         if (pixels == (unsigned char *) NULL)
           ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
         for (y=0; y < (long) image->rows; y++)
@@ -1679,12 +1646,12 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                     pixel;
 
                   pixel=(unsigned char) ScaleQuantumToAny(
-                    PixelIntensityToQuantum(p),(1UL << depth)-1);
+                    PixelIntensityToQuantum(p),depth);
                   PopCharPixel(pixel,&q);
                   if (image->matte != MagickFalse)
                     {
                       pixel=(unsigned char) ScaleQuantumToAny((Quantum)
-                        (QuantumRange-p->opacity),(1UL << depth)-1UL);
+                        (QuantumRange-p->opacity),depth);
                       PopCharPixel(pixel,&q);
                     }
                   p++;
@@ -1696,13 +1663,13 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                     pixel;
 
                   pixel=(unsigned short) ScaleQuantumToAny(
-                    PixelIntensityToQuantum(p),(1UL << depth)-1);
-                  PopShortPixel(pixel,&q);
+                    PixelIntensityToQuantum(p),depth);
+                  PopShortPixel(&quantum_state,pixel,&q);
                   if (image->matte != MagickFalse)
                     {
                       pixel=(unsigned short) ScaleQuantumToAny((Quantum)
-                        (QuantumRange-p->opacity),(1UL << depth)-1UL);
-                      PopShortPixel(pixel,&q);
+                        (QuantumRange-p->opacity),depth);
+                      PopShortPixel(&quantum_state,pixel,&q);
                     }
                   p++;
                 }
@@ -1714,19 +1681,16 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                 unsigned char
                   pixel;
 
-                pixel=(unsigned char) ScaleQuantumToAny(p->red,
-                  (1UL << depth)-1);
+                pixel=(unsigned char) ScaleQuantumToAny(p->red,depth);
                 PopCharPixel(pixel,&q);
-                pixel=(unsigned char) ScaleQuantumToAny(p->green,
-                  (1UL << depth)-1);
+                pixel=(unsigned char) ScaleQuantumToAny(p->green,depth);
                 PopCharPixel(pixel,&q);
-                pixel=(unsigned char) ScaleQuantumToAny(p->blue,
-                  (1UL << depth)-1);
+                pixel=(unsigned char) ScaleQuantumToAny(p->blue,depth);
                 PopCharPixel(pixel,&q);
                 if (image->matte != MagickFalse)
                   {
                     pixel=(unsigned char) ScaleQuantumToAny((Quantum)
-                      (QuantumRange-p->opacity),(1UL << depth)-1UL);
+                      (QuantumRange-p->opacity),depth);
                     PopCharPixel(pixel,&q);
                   }
                 p++;
@@ -1737,20 +1701,17 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                 unsigned short
                   pixel;
 
-                pixel=(unsigned short) ScaleQuantumToAny(p->red,
-                  (1UL << depth)-1);
-                PopShortPixel(pixel,&q);
-                pixel=(unsigned short) ScaleQuantumToAny(p->green,
-                  (1UL << depth)-1);
-                PopShortPixel(pixel,&q);
-                pixel=(unsigned short) ScaleQuantumToAny(p->blue,
-                  (1UL << depth)-1);
-                PopShortPixel(pixel,&q);
+                pixel=(unsigned short) ScaleQuantumToAny(p->red,depth);
+                PopShortPixel(&quantum_state,pixel,&q);
+                pixel=(unsigned short) ScaleQuantumToAny(p->green,depth);
+                PopShortPixel(&quantum_state,pixel,&q);
+                pixel=(unsigned short) ScaleQuantumToAny(p->blue,depth);
+                PopShortPixel(&quantum_state,pixel,&q);
                 if (image->matte != MagickFalse)
                   {
                     pixel=(unsigned short) ScaleQuantumToAny((Quantum)
-                      (QuantumRange-p->opacity),(1UL << depth)-1UL);
-                    PopShortPixel(pixel,&q);
+                      (QuantumRange-p->opacity),depth);
+                    PopShortPixel(&quantum_state,pixel,&q);
                   }
                 p++;
               }
@@ -1781,7 +1742,8 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
         quantum_info.scale=1.0/QuantumRange;
         quantum_type=format == 'f' ? GrayQuantum : RGBQuantum;
         length=(format == 'f' ? 1 : 3)*image->columns*sizeof(float);
-        pixels=(unsigned char *) AcquireMagickMemory(length);
+        pixels=(unsigned char *) AcquireQuantumMemory(length,
+          sizeof(*pixels));
         if (pixels == (unsigned char *) NULL)
           ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
         for (y=(long) image->rows-1; y >= 0; y--)
