@@ -61,9 +61,10 @@
 #include "magick/profile.h"
 #include "magick/resource_.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/token.h"
 #include "magick/transform.h"
 #include "magick/utility.h"
@@ -130,11 +131,11 @@ static MagickBooleanType InvokePostscriptDelegate(
     gs_func_struct;
 
   gs_func=(&gs_func_struct);
-  gs_func_struct.exit=gsapi_exit;
-  gs_func_struct.init_with_args=gsapi_init_with_args;
-  gs_func_struct.new_instance=gsapi_new_instance;
-  gs_func_struct.run_string=gsapi_run_string;
-  gs_func_struct.delete_instance=gsapi_delete_instance;
+  gs_func_struct.exit=(int (*)(gs_main_instance *)) gsapi_exit;
+  gs_func_struct.init_with_args=(int (*)(gs_main_instance *,int,char **)) gsapi_init_with_args;
+  gs_func_struct.new_instance=(int (*)(gs_main_instance **,void *)) gsapi_new_instance;
+  gs_func_struct.run_string=(int (*)(gs_main_instance *,const char *,int,int *)) gsapi_run_string;
+  gs_func_struct.delete_instance=(void (*)(gs_main_instance *)) gsapi_delete_instance;
 #endif
   if (gs_func == (GhostscriptVectors *) NULL)
     return(SystemCommand(verbose,command) == 0 ? MagickFalse : MagickTrue);
@@ -436,6 +437,8 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
   (void) ResetMagickMemory(&hires_bounds,0,sizeof(hires_bounds));
   (void) ResetMagickMemory(&page,0,sizeof(page));
   (void) ResetMagickMemory(command,0,sizeof(command));
+  hires_bounds.x2=0.0;
+  hires_bounds.y2=0.0;
   columns=0;
   rows=0;
   extent=0;
@@ -534,7 +537,7 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
         p=GetStringInfoDatum(profile);
         for (i=0; i < (long) length; i++)
           *p++=(unsigned char) ReadBlobByte(image);
-        (void) SetImageProfile(image,"XML",profile);
+        (void) SetImageProfile(image,"xml",profile);
         profile=DestroyStringInfo(profile);
         continue;
       }
@@ -595,8 +598,8 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
         &bounds.y2)+2;
     if (count != 4)
       continue;
-    if (((unsigned long) (bounds.x2-bounds.x1+0.5) > page.width) ||
-        ((unsigned long) (bounds.y2-bounds.y1+0.5) > page.height))
+    if (((bounds.x2 > hires_bounds.x2) && (bounds.y2 > hires_bounds.y2)) ||
+        ((hires_bounds.x2 == 0.0) && (hires_bounds.y2 == 0.0)))
       {
         /*
           Set Postscript render geometry.
@@ -663,13 +666,17 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
   *read_info->magick='\0';
   if (read_info->number_scenes != 0)
     {
+      char
+        pages[MaxTextExtent];
+
       if (read_info->number_scenes != 1)
-        (void) FormatMagickString(options,MaxTextExtent,"-dLastPage=%lu",
+        (void) FormatMagickString(pages,MaxTextExtent,"-dLastPage=%lu",
           read_info->scene+read_info->number_scenes);
       else
-        (void) FormatMagickString(options,MaxTextExtent,
-          "-dFirstPage=%lu -dLastPage=%lu",read_info->scene+1,
-          read_info->scene+read_info->number_scenes);
+        (void) FormatMagickString(pages,MaxTextExtent,"-dFirstPage=%lu "
+          "-dLastPage=%lu",read_info->scene+1,read_info->scene+
+          read_info->number_scenes);
+      (void) ConcatenateMagickString(options,pages,MaxTextExtent);
       read_info->number_scenes=0;
       if (read_info->scenes != (char *) NULL)
         *read_info->scenes='\0';
@@ -685,36 +692,24 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     read_info->antialias != MagickFalse ? 4 : 1,geometry,density,options,
     read_info->filename,postscript_filename,input_filename);
   status=InvokePostscriptDelegate(read_info->verbose,command);
-  postscript_image=ReadImage(read_info,exception);
-  if (postscript_image == (Image *) NULL)
+  if (status != MagickFalse)
     {
       (void) ConcatenateMagickString(command," -c showpage",MaxTextExtent);
       status=InvokePostscriptDelegate(read_info->verbose,command);
-      *read_info->magick='\0';
-      postscript_image=ReadImage(read_info,exception);
     }
+  postscript_image=(Image *) NULL;
+  if (status == MagickFalse)
+    postscript_image=ReadImage(read_info,exception);
   (void) RelinquishUniqueFileResource(postscript_filename);
   (void) RelinquishUniqueFileResource(read_info->filename);
   (void) RelinquishUniqueFileResource(input_filename);
-  if (postscript_image == (Image *) NULL)
-    {
-      /*
-        Ghostscript has failed-- try the Display Postscript Extension.
-      */
-      image=DestroyImageList(image);
-      (void) FormatMagickString(read_info->filename,MaxTextExtent,"dps:%s",
-        filename);
-      postscript_image=ReadImage(read_info,exception);
-      read_info=DestroyImageInfo(read_info);
-      if (postscript_image != (Image *) NULL)
-        return(GetFirstImageInList(postscript_image));
-      ThrowReaderException(DelegateError,"PostscriptDelegateFailed");
-    }
   read_info=DestroyImageInfo(read_info);
   if (postscript_image == (Image *) NULL)
     {
       image=DestroyImageList(image);
-      ThrowReaderException(DelegateError,"PostscriptDelegateFailed");
+      ThrowFileException(exception,DelegateError,"PostscriptDelegateFailed",
+        image_info->filename);
+      return((Image *) NULL);
     }
   if (LocaleCompare(postscript_image->magick,"BMP") == 0)
     {
@@ -768,18 +763,18 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterPSImage method is:
 %
-%      RegisterPSImage(void)
+%      unsigned long RegisterPSImage(void)
 %
 */
-ModuleExport void RegisterPSImage(void)
+ModuleExport unsigned long RegisterPSImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("EPI");
-  entry->decoder=(DecoderHandler *) ReadPSImage;
-  entry->encoder=(EncoderHandler *) WritePSImage;
-  entry->magick=(MagickHandler *) IsPS;
+  entry->decoder=(DecodeImageHandler *) ReadPSImage;
+  entry->encoder=(EncodeImageHandler *) WritePSImage;
+  entry->magick=(IsImageFormatHandler *) IsPS;
   entry->adjoin=MagickFalse;
   entry->blob_support=MagickFalse;
   entry->seekable_stream=MagickTrue;
@@ -789,9 +784,9 @@ ModuleExport void RegisterPSImage(void)
   entry->module=ConstantString("PS");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("EPS");
-  entry->decoder=(DecoderHandler *) ReadPSImage;
-  entry->encoder=(EncoderHandler *) WritePSImage;
-  entry->magick=(MagickHandler *) IsPS;
+  entry->decoder=(DecodeImageHandler *) ReadPSImage;
+  entry->encoder=(EncodeImageHandler *) WritePSImage;
+  entry->magick=(IsImageFormatHandler *) IsPS;
   entry->adjoin=MagickFalse;
   entry->blob_support=MagickFalse;
   entry->seekable_stream=MagickTrue;
@@ -800,9 +795,9 @@ ModuleExport void RegisterPSImage(void)
   entry->module=ConstantString("PS");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("EPSF");
-  entry->decoder=(DecoderHandler *) ReadPSImage;
-  entry->encoder=(EncoderHandler *) WritePSImage;
-  entry->magick=(MagickHandler *) IsPS;
+  entry->decoder=(DecodeImageHandler *) ReadPSImage;
+  entry->encoder=(EncodeImageHandler *) WritePSImage;
+  entry->magick=(IsImageFormatHandler *) IsPS;
   entry->adjoin=MagickFalse;
   entry->blob_support=MagickFalse;
   entry->seekable_stream=MagickTrue;
@@ -810,9 +805,9 @@ ModuleExport void RegisterPSImage(void)
   entry->module=ConstantString("PS");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("EPSI");
-  entry->decoder=(DecoderHandler *) ReadPSImage;
-  entry->encoder=(EncoderHandler *) WritePSImage;
-  entry->magick=(MagickHandler *) IsPS;
+  entry->decoder=(DecodeImageHandler *) ReadPSImage;
+  entry->encoder=(EncodeImageHandler *) WritePSImage;
+  entry->magick=(IsImageFormatHandler *) IsPS;
   entry->adjoin=MagickFalse;
   entry->blob_support=MagickFalse;
   entry->seekable_stream=MagickTrue;
@@ -822,15 +817,16 @@ ModuleExport void RegisterPSImage(void)
   entry->module=ConstantString("PS");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PS");
-  entry->decoder=(DecoderHandler *) ReadPSImage;
-  entry->encoder=(EncoderHandler *) WritePSImage;
-  entry->magick=(MagickHandler *) IsPS;
+  entry->decoder=(DecodeImageHandler *) ReadPSImage;
+  entry->encoder=(EncodeImageHandler *) WritePSImage;
+  entry->magick=(IsImageFormatHandler *) IsPS;
   entry->module=ConstantString("PS");
   entry->blob_support=MagickFalse;
   entry->seekable_stream=MagickTrue;
   entry->thread_support=EncoderThreadSupport;
   entry->description=ConstantString("PostScript");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -900,7 +896,8 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
 {
 #define WriteRunlengthPacket(image,pixel,length,p) \
 { \
-  if ((image->matte != MagickFalse) && (p->opacity == TransparentOpacity)) \
+  if ((image->matte != MagickFalse) && \
+      (p->opacity == (Quantum) TransparentOpacity)) \
     (void) FormatMagickString(buffer,MaxTextExtent,"ffffff%02lX", \
       (unsigned long) MagickMin(length,0xff)); \
   else \
@@ -1324,7 +1321,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
     if (image_info->pointsize != 0.0)
       pointsize=image_info->pointsize;
     text_size=0;
-    value=GetImageProperty(image,"Label");
+    value=GetImageProperty(image,"label");
     if (value != (const char *) NULL)
       text_size=(unsigned long) (MultilineCensus(value)*pointsize+12);
     count=0;
@@ -1404,7 +1401,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
               (void) WriteBlobByte(image,GetStringInfoDatum(profile)[i]);
             (void) WriteBlobString(image,"\n%end_xml_packet\n");
           }
-        value=GetImageProperty(image,"Label");
+        value=GetImageProperty(image,"label");
         if (value != (const char *) NULL)
           (void) WriteBlobString(image,
             "%%DocumentNeededResources: font Times-Roman\n");
@@ -1510,7 +1507,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
           (void) FormatMagickString(buffer,MaxTextExtent,"%s\n",*q);
           (void) WriteBlobString(image,buffer);
         }
-        value=GetImageProperty(image,"Label");
+        value=GetImageProperty(image,"label");
         if (value != (const char *) NULL)
           for (j=(long) MultilineCensus(value)-1; j >= 0; j--)
           {
@@ -1545,7 +1542,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
       bounds.x2=(double) geometry.x+geometry.width-1;
     if ((double) (geometry.y+(geometry.height+text_size)-1) > bounds.y2)
       bounds.y2=(double) geometry.y+(geometry.height+text_size)-1;
-    value=GetImageProperty(image,"Label");
+    value=GetImageProperty(image,"label");
     if (value != (const char *) NULL)
       (void) WriteBlobString(image,"%%%%PageResources: font Times-Roman\n");
     if (LocaleCompare(image_info->magick,"PS") != 0)
@@ -1558,7 +1555,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
       geometry.x,geometry.y,scale.x,scale.y,pointsize);
     (void) WriteBlobString(image,buffer);
     labels=(char **) NULL;
-    value=GetImageProperty(image,"Label");
+    value=GetImageProperty(image,"label");
     if (value != (const char *) NULL)
       labels=StringToList(value);
     if (labels != (char **) NULL)
@@ -1573,7 +1570,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
         labels=(char **) RelinquishMagickMemory(labels);
       }
     (void) ResetMagickMemory(&pixel,0,sizeof(pixel));
-    pixel.opacity=TransparentOpacity;
+    pixel.opacity=(Quantum) TransparentOpacity;
     i=0;
     index=(IndexPacket) 0;
     x=0;
@@ -1768,7 +1765,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
                 for (x=0; x < (long) image->columns; x++)
                 {
                   if ((image->matte != MagickFalse) &&
-                      (p->opacity == TransparentOpacity))
+                      (p->opacity == (Quantum) TransparentOpacity))
                     (void) CopyMagickString(buffer,"ffffff",MaxTextExtent);
                   else
                     (void) FormatMagickString(buffer,MaxTextExtent,
