@@ -58,9 +58,10 @@
 #include "magick/monitor.h"
 #include "magick/resource_.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/utility.h"
 #if defined(HasTIFF)
 #define CCITTParam  "-1"
@@ -94,27 +95,28 @@ static MagickBooleanType
 %
 %  The format of the RegisterPS2Image method is:
 %
-%      RegisterPS2Image(void)
+%      unsigned long RegisterPS2Image(void)
 %
 */
-ModuleExport void RegisterPS2Image(void)
+ModuleExport unsigned long RegisterPS2Image(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("EPS2");
-  entry->encoder=(EncoderHandler *) WritePS2Image;
+  entry->encoder=(EncodeImageHandler *) WritePS2Image;
   entry->adjoin=MagickFalse;
   entry->seekable_stream=MagickTrue;
   entry->description=ConstantString("Level II Encapsulated PostScript");
   entry->module=ConstantString("PS2");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PS2");
-  entry->encoder=(EncoderHandler *) WritePS2Image;
+  entry->encoder=(EncodeImageHandler *) WritePS2Image;
   entry->seekable_stream=MagickTrue;
   entry->description=ConstantString("Level II PostScript");
   entry->module=ConstantString("PS2");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -168,7 +170,6 @@ ModuleExport void UnregisterPS2Image(void)
 %
 %    o image: The image.
 %
-%
 */
 static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
 {
@@ -495,7 +496,7 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
     if (image_info->pointsize != 0.0)
       pointsize=image_info->pointsize;
     text_size=0;
-    value=GetImageProperty(image,"Label");
+    value=GetImageProperty(image,"label");
     if (value != (const char *) NULL)
       text_size=(unsigned long) (MultilineCensus(value)*pointsize+12);
     if (page == 1)
@@ -540,7 +541,7 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
               bounds.x2,bounds.y2);
           }
         (void) WriteBlobString(image,buffer);
-        value=GetImageProperty(image,"Label");
+        value=GetImageProperty(image,"label");
         if (value != (const char *) NULL)
           (void) WriteBlobString(image,
             "%%DocumentNeededResources: font Helvetica\n");
@@ -601,7 +602,7 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
           (void) WriteBlobString(image,buffer);
           (void) WriteBlobByte(image,'\n');
         }
-        value=GetImageProperty(image,"Label");
+        value=GetImageProperty(image,"label");
         if (value != (const char *) NULL)
           for (j=(long) MultilineCensus(value)-1; j >= 0; j--)
           {
@@ -636,7 +637,7 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
       bounds.x2=(double) geometry.x+geometry.width-1;
     if ((double) (geometry.y+(geometry.height+text_size)-1) > bounds.y2)
       bounds.y2=(double) geometry.y+(geometry.height+text_size)-1;
-    value=GetImageProperty(image,"Label");
+    value=GetImageProperty(image,"label");
     if (value != (const char *) NULL)
       (void) WriteBlobString(image,"%%PageResources: font Times-Roman\n");
     if (LocaleCompare(image_info->magick,"PS2") != 0)
@@ -655,7 +656,7 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
       geometry.x,geometry.y,scale.x,scale.y,pointsize);
     (void) WriteBlobString(image,buffer);
     labels=(char **) NULL;
-    value=GetImageProperty(image,"Label");
+    value=GetImageProperty(image,"label");
     if (value != (const char *) NULL)
       labels=StringToList(value);
     if (labels != (char **) NULL)
@@ -721,7 +722,8 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
               Allocate pixel array.
             */
             length=(size_t) number_pixels;
-            pixels=(unsigned char *) AcquireMagickMemory(length);
+            pixels=(unsigned char *) AcquireQuantumMemory(length,
+              sizeof(*pixels));
             if (pixels == (unsigned char *) NULL)
               ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
             /*
@@ -823,9 +825,9 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
               /*
                 Allocate pixel array.
               */
-              length=(size_t) ((image->colorspace == CMYKColorspace ? 4 : 3)*
-                number_pixels);
-              pixels=(unsigned char *) AcquireMagickMemory(length);
+              length=(size_t) number_pixels;
+              pixels=(unsigned char *) AcquireQuantumMemory(length,
+                4*sizeof(*pixels));
               if (pixels == (unsigned char *) NULL)
                 ThrowWriterException(ResourceLimitError,
                   "MemoryAllocationFailed");
@@ -843,7 +845,7 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
                 for (x=0; x < (long) image->columns; x++)
                 {
                   if ((image->matte != MagickFalse) &&
-                      (p->opacity == TransparentOpacity))
+                      (p->opacity == (Quantum) TransparentOpacity))
                     {
                       *q++=ScaleQuantumToChar((Quantum) QuantumRange);
                       *q++=ScaleQuantumToChar((Quantum) QuantumRange);
@@ -903,7 +905,7 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
                 for (x=0; x < (long) image->columns; x++)
                 {
                   if ((image->matte != MagickFalse) &&
-                      (p->opacity == TransparentOpacity))
+                      (p->opacity == (Quantum) TransparentOpacity))
                     {
                       Ascii85Encode(image,ScaleQuantumToChar((Quantum)
                         QuantumRange));
@@ -977,7 +979,8 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
                 Allocate pixel array.
               */
               length=(size_t) number_pixels;
-              pixels=(unsigned char *) AcquireMagickMemory(length);
+              pixels=(unsigned char *) AcquireQuantumMemory(length,
+                sizeof(*pixels));
               if (pixels == (unsigned char *) NULL)
                 ThrowWriterException(ResourceLimitError,
                   "MemoryAllocationFailed");
@@ -995,15 +998,15 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
                 for (x=0; x < (long) image->columns; x++)
                   *q++=(unsigned char) indexes[x];
                 if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(y,image->rows) != MagickFalse))
-                  {
-                    status=image->progress_monitor(SaveImageTag,y,image->rows,
-                      image->client_data);
-                    if (status == MagickFalse)
-                      break;
-                  }
-              }
+                  if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+                      (QuantumTick(y,image->rows) != MagickFalse))
+                    {
+                      status=image->progress_monitor(SaveImageTag,y,image->rows,
+                        image->client_data);
+                      if (status == MagickFalse)
+                        break;
+                    }
+                }
               if (compression == LZWCompression)
                 status=LZWEncodeImage(image,length,pixels);
               else
