@@ -59,13 +59,14 @@
 #include "magick/monitor.h"
 #include "magick/option.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/resource_.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/token.h"
 #include "magick/utility.h"
-#include "magick/version.h"
+#include "magick/module.h"
 #if defined(HasTIFF)
 #define CCITTParam  "-1"
 #else
@@ -113,24 +114,25 @@ static MagickBooleanType
 %
 %  The format of the RegisterPS3Image method is:
 %
-%      RegisterPS3Image(void)
+%      unsigned long RegisterPS3Image(void)
 %
 */
-ModuleExport void RegisterPS3Image(void)
+ModuleExport unsigned long RegisterPS3Image(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("EPS3");
-  entry->encoder=(EncoderHandler *) WritePS3Image;
+  entry->encoder=(EncodeImageHandler *) WritePS3Image;
   entry->description=ConstantString("Level III Encapsulated PostScript");
   entry->module=ConstantString("PS3");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PS3");
-  entry->encoder=(EncoderHandler *) WritePS3Image;
+  entry->encoder=(EncodeImageHandler *) WritePS3Image;
   entry->description=ConstantString("Level III PostScript");
   entry->module=ConstantString("PS3");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -314,7 +316,7 @@ static MagickBooleanType SerializeImageChannel(const ImageInfo *image_info,
           bit=(unsigned char) 0x00;
           if (x < (long) image->columns)
             bit=(unsigned char) (PixelIntensityToQuantum(p) ==
-              TransparentOpacity ? 0x01 : 0x00);
+              (Quantum) TransparentOpacity ? 0x01 : 0x00);
           code=(code << 1)+bit;
           if (((x+1) % pack) == 0)
             {
@@ -945,7 +947,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
     if (image_info->pointsize != 0.0)
       pointsize=image_info->pointsize;
     text_size=0;
-    value=GetImageProperty(image,"Label");
+    value=GetImageProperty(image,"label");
     if (value != (const char *) NULL)
       text_size=(unsigned long) (MultilineCensus(value)*pointsize+12);
     page++;
@@ -1004,7 +1006,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
         /*
           Font resources
         */
-        value=GetImageProperty(image,"Label");
+        value=GetImageProperty(image,"label");
         if (value != (const char *) NULL)
           (void) WriteBlobString(image,
             "%%DocumentNeededResources: font Helvetica\n");
@@ -1038,7 +1040,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
         /*
           One label line for each line in label string.
         */
-        value=GetImageProperty(image,"Label");
+        value=GetImageProperty(image,"label");
         if (value != (const char *) NULL)
           {
               (void) WriteBlobString(image,"\n  %% Labels.\n  /Helvetica "
@@ -1094,7 +1096,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
     /*
       Page font resource if there's a label.
     */
-    value=GetImageProperty(image,"Label");
+    value=GetImageProperty(image,"label");
     if (value != (const char *) NULL)
       (void) WriteBlobString(image,"%%PageResources: font Helvetica\n");
     /*
@@ -1148,7 +1150,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
       Output labels.
     */
     labels=(char **) NULL;
-    value=GetImageProperty(image,"Label");
+    value=GetImageProperty(image,"label");
     if (value != (const char *) NULL)
       labels=StringToList(value);
     if (labels != (char **) NULL)
