@@ -41,6 +41,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
+#include "magick/artifact.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/colorspace.h"
@@ -54,9 +55,10 @@
 #include "magick/log.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
+#include "magick/module.h"
 #include "magick/profile.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 
@@ -423,7 +425,7 @@ typedef enum
   LabMode = 9
 } PSDImageType;
 
-static char *ModeToString( PSDImageType inType )
+static const char *ModeToString( PSDImageType inType )
 {
   switch ( inType )
   {
@@ -439,43 +441,18 @@ static char *ModeToString( PSDImageType inType )
   }
 }
 
-static inline unsigned char PushCharPixel(const unsigned char **pixels)
-{
-  unsigned char
-    pixel;
-
-  pixel=(unsigned char) *(*pixels)++;
-  return(pixel);
-}
-
-static inline unsigned long PushLongPixel(const unsigned char **pixels)
-{
-  unsigned long
-    pixel;
-
-  pixel=(unsigned long) (*(*pixels)++ << 24);
-  pixel|=(unsigned long) (*(*pixels)++ << 16);
-  pixel|=(unsigned long) (*(*pixels)++ << 8);
-  pixel|=(unsigned long) (*(*pixels)++);
-  return(pixel);
-}
-
-static inline unsigned short PushShortPixel(const unsigned char **pixels)
-{
-  unsigned short
-    pixel;
-
-  pixel=(unsigned short) (*(*pixels)++ << 8);
-  pixel|=(unsigned short) (*(*pixels)++);
-  return(pixel);
-}
-
-static MagickBooleanType ParseImageResourceBlocks(Image *image,
-  const unsigned char *blocks,size_t length)
+static MagickBooleanType ParseImageResourceBlocks(const ImageInfo *image_info,
+  Image *image,const unsigned char *blocks,size_t length)
 {
   const unsigned char
     *p;
 
+  QuantumInfo
+    quantum_info;
+
+  QuantumState
+    quantum_state;
+
   StringInfo
     *profile;
 
@@ -486,6 +463,8 @@ static MagickBooleanType ParseImageResourceBlocks(Image *image,
 
   if (length < 16)
     return(MagickFalse);
+  GetQuantumInfo(image_info,&quantum_info);
+  InitializeQuantumState(&quantum_info,LSBEndian,&quantum_state);
   profile=AcquireStringInfo(length);
   SetStringInfoDatum(profile,blocks);
   (void) SetImageProfile(image,"iptc",profile);
@@ -494,10 +473,10 @@ static MagickBooleanType ParseImageResourceBlocks(Image *image,
   {
     if (LocaleNCompare((char *) p,"8BIM",4) != 0)
       break;
-    sans=PushLongPixel(&p);
-    id=PushShortPixel(&p);
-    sans=PushShortPixel(&p);
-    count=PushLongPixel(&p);
+    sans=PushLongPixel(&quantum_state,&p);
+    id=PushShortPixel(&quantum_state,&p);
+    sans=PushShortPixel(&quantum_state,&p);
+    count=PushLongPixel(&quantum_state,&p);
     switch (id)
     {
       case 0x03ed:
@@ -508,16 +487,16 @@ static MagickBooleanType ParseImageResourceBlocks(Image *image,
         /*
           Resolution info.
         */
-        resolution=PushShortPixel(&p);
+        resolution=PushShortPixel(&quantum_state,&p);
         image->x_resolution=(double) resolution;
-        sans=PushShortPixel(&p);
-        sans=PushShortPixel(&p);
-        sans=PushShortPixel(&p);
-        resolution=PushShortPixel(&p);
+        sans=PushShortPixel(&quantum_state,&p);
+        sans=PushShortPixel(&quantum_state,&p);
+        sans=PushShortPixel(&quantum_state,&p);
+        resolution=PushShortPixel(&quantum_state,&p);
         image->y_resolution=(double) resolution;
-        sans=PushShortPixel(&p);
-        sans=PushShortPixel(&p);
-        sans=PushShortPixel(&p);
+        sans=PushShortPixel(&quantum_state,&p);
+        sans=PushShortPixel(&quantum_state,&p);
+        sans=PushShortPixel(&quantum_state,&p);
         break;
       }
       default:
@@ -785,7 +764,7 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
           blocks=(unsigned char *) RelinquishMagickMemory(blocks);
           ThrowReaderException(CorruptImageError,"ImproperImageHeader");
         }
-      (void) ParseImageResourceBlocks(image,blocks,length);
+      (void) ParseImageResourceBlocks(image_info,image,blocks,length);
       blocks=(unsigned char *) RelinquishMagickMemory(blocks);
     }
   /*
@@ -1072,13 +1051,13 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
             */
             (void) FormatMagickString(s,MaxTextExtent,"%ld",
               layer_info[i].page.x );
-            (void) SetImageProperty(layer_info[i].image,"[layer-xpos]",s);
+            (void) SetImageArtifact(layer_info[i].image,"layer-xpos",s);
             (void) FormatMagickString(s,MaxTextExtent,"%ld",
               layer_info[i].page.y);
-            (void) SetImageProperty(layer_info[i].image,"[layer-ypos]",s);
+            (void) SetImageArtifact(layer_info[i].image,"layer-ypos",s);
             (void) FormatMagickString(s,MaxTextExtent,"%lu",(unsigned long)
               layer_info[i].opacity );
-            (void) SetImageProperty(layer_info[i].image,"[layer-opacity]",s);
+            (void) SetImageArtifact(layer_info[i].image,"layer-opacity",s);
             (void) SetImageProperty(layer_info[i].image,"label",(char *)
               layer_info[i].name);
           }
@@ -1446,21 +1425,22 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterPSDImage method is:
 %
-%      RegisterPSDImage(void)
+%      unsigned long RegisterPSDImage(void)
 %
 */
-ModuleExport void RegisterPSDImage(void)
+ModuleExport unsigned long RegisterPSDImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("PSD");
-  entry->decoder=(DecoderHandler *) ReadPSDImage;
-  entry->encoder=(EncoderHandler *) WritePSDImage;
-  entry->magick=(MagickHandler *) IsPSD;
+  entry->decoder=(DecodeImageHandler *) ReadPSDImage;
+  entry->encoder=(EncodeImageHandler *) WritePSDImage;
+  entry->magick=(IsImageFormatHandler *) IsPSD;
   entry->description=ConstantString("Adobe Photoshop bitmap");
   entry->module=ConstantString("PSD");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
