@@ -52,9 +52,10 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/resource_.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -277,20 +278,21 @@ static Image *ReadPWPImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterPWPImage method is:
 %
-%      RegisterPWPImage(void)
+%      unsigned long RegisterPWPImage(void)
 %
 */
-ModuleExport void RegisterPWPImage(void)
+ModuleExport unsigned long RegisterPWPImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("PWP");
-  entry->decoder=(DecoderHandler *) ReadPWPImage;
-  entry->magick=(MagickHandler *) IsPWP;
+  entry->decoder=(DecodeImageHandler *) ReadPWPImage;
+  entry->magick=(IsImageFormatHandler *) IsPWP;
   entry->description=ConstantString("Seattle Film Works");
   entry->module=ConstantString("PWP");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
