@@ -52,11 +52,12 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -89,7 +90,6 @@ static MagickBooleanType
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadRAWImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
@@ -166,9 +166,9 @@ static Image *ReadRAWImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Allocate memory for a pixels.
   */
-  packet_size=(size_t) ((image->depth+7)/8);
-  pixels=(unsigned char *) AcquireMagickMemory(packet_size*
-    image->extract_info.width*sizeof(*pixels));
+  packet_size=(size_t) (image->depth+7)/8;
+  pixels=(unsigned char *) AcquireQuantumMemory(image->extract_info.width,
+    packet_size*sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   if (image_info->number_scenes != 0)
@@ -191,6 +191,11 @@ static Image *ReadRAWImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
+      if (SetImageExtent(image,0,0) == MagickFalse)
+        {
+          InheritException(exception,&image->exception);
+          return(DestroyImageList(image));
+        }
     for (y=0; y < image->extract_info.y; y++)
       count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
     for (y=0; y < (long) image->rows; y++)
@@ -276,86 +281,87 @@ static Image *ReadRAWImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterRAWImage method is:
 %
-%      RegisterRAWImage(void)
+%      unsigned long RegisterRAWImage(void)
 %
 */
-ModuleExport void RegisterRAWImage(void)
+ModuleExport unsigned long RegisterRAWImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("R");
-  entry->decoder=(DecoderHandler *) ReadRAWImage;
-  entry->encoder=(EncoderHandler *) WriteRAWImage;
+  entry->decoder=(DecodeImageHandler *) ReadRAWImage;
+  entry->encoder=(EncodeImageHandler *) WriteRAWImage;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->description=ConstantString("Raw red samples");
   entry->module=ConstantString("RAW");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("C");
-  entry->decoder=(DecoderHandler *) ReadRAWImage;
-  entry->encoder=(EncoderHandler *) WriteRAWImage;
+  entry->decoder=(DecodeImageHandler *) ReadRAWImage;
+  entry->encoder=(EncodeImageHandler *) WriteRAWImage;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->description=ConstantString("Raw cyan samples");
   entry->module=ConstantString("RAW");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("G");
-  entry->decoder=(DecoderHandler *) ReadRAWImage;
-  entry->encoder=(EncoderHandler *) WriteRAWImage;
+  entry->decoder=(DecodeImageHandler *) ReadRAWImage;
+  entry->encoder=(EncodeImageHandler *) WriteRAWImage;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->description=ConstantString("Raw green samples");
   entry->module=ConstantString("RAW");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("M");
-  entry->decoder=(DecoderHandler *) ReadRAWImage;
-  entry->encoder=(EncoderHandler *) WriteRAWImage;
+  entry->decoder=(DecodeImageHandler *) ReadRAWImage;
+  entry->encoder=(EncodeImageHandler *) WriteRAWImage;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->description=ConstantString("Raw magenta samples");
   entry->module=ConstantString("RAW");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("B");
-  entry->decoder=(DecoderHandler *) ReadRAWImage;
-  entry->encoder=(EncoderHandler *) WriteRAWImage;
+  entry->decoder=(DecodeImageHandler *) ReadRAWImage;
+  entry->encoder=(EncodeImageHandler *) WriteRAWImage;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->description=ConstantString("Raw blue samples");
   entry->module=ConstantString("RAW");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("Y");
-  entry->decoder=(DecoderHandler *) ReadRAWImage;
-  entry->encoder=(EncoderHandler *) WriteRAWImage;
+  entry->decoder=(DecodeImageHandler *) ReadRAWImage;
+  entry->encoder=(EncodeImageHandler *) WriteRAWImage;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->description=ConstantString("Raw yellow samples");
   entry->module=ConstantString("RAW");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("A");
-  entry->decoder=(DecoderHandler *) ReadRAWImage;
-  entry->encoder=(EncoderHandler *) WriteRAWImage;
+  entry->decoder=(DecodeImageHandler *) ReadRAWImage;
+  entry->encoder=(EncodeImageHandler *) WriteRAWImage;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->description=ConstantString("Raw alpha samples");
   entry->module=ConstantString("RAW");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("O");
-  entry->decoder=(DecoderHandler *) ReadRAWImage;
-  entry->encoder=(EncoderHandler *) WriteRAWImage;
+  entry->decoder=(DecodeImageHandler *) ReadRAWImage;
+  entry->encoder=(EncodeImageHandler *) WriteRAWImage;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->description=ConstantString("Raw opacity samples");
   entry->module=ConstantString("RAW");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("K");
-  entry->decoder=(DecoderHandler *) ReadRAWImage;
-  entry->encoder=(EncoderHandler *) WriteRAWImage;
+  entry->decoder=(DecodeImageHandler *) ReadRAWImage;
+  entry->encoder=(EncodeImageHandler *) WriteRAWImage;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->description=ConstantString("Raw black samples");
   entry->module=ConstantString("RAW");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -536,8 +542,8 @@ static MagickBooleanType WriteRAWImage(const ImageInfo *image_info,Image *image)
       Allocate memory for pixels.
     */
     GetQuantumInfo(image_info,&quantum_info);
-    packet_size=(size_t) ((image->depth+7)/8);
-    pixels=(unsigned char *) AcquireMagickMemory(packet_size*image->columns*
+    packet_size=(size_t) (image->depth+7)/8;
+    pixels=(unsigned char *) AcquireQuantumMemory(image->columns,packet_size*
       sizeof(*pixels));
     if (pixels == (unsigned char *) NULL)
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
