@@ -52,11 +52,12 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/utility.h"
 
 /*
@@ -608,38 +609,39 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterRGBImage method is:
 %
-%      RegisterRGBImage(void)
+%      unsigned long RegisterRGBImage(void)
 %
 */
-ModuleExport void RegisterRGBImage(void)
+ModuleExport unsigned long RegisterRGBImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("RGB");
-  entry->decoder=(DecoderHandler *) ReadRGBImage;
-  entry->encoder=(EncoderHandler *) WriteRGBImage;
+  entry->decoder=(DecodeImageHandler *) ReadRGBImage;
+  entry->encoder=(EncodeImageHandler *) WriteRGBImage;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->description=ConstantString("Raw red, green, and blue samples");
   entry->module=ConstantString("RGB");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("RGBA");
-  entry->decoder=(DecoderHandler *) ReadRGBImage;
-  entry->encoder=(EncoderHandler *) WriteRGBImage;
+  entry->decoder=(DecodeImageHandler *) ReadRGBImage;
+  entry->encoder=(EncodeImageHandler *) WriteRGBImage;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->description=ConstantString("Raw red, green, blue, and alpha samples");
   entry->module=ConstantString("RGB");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("RGBO");
-  entry->decoder=(DecoderHandler *) ReadRGBImage;
-  entry->encoder=(EncoderHandler *) WriteRGBImage;
+  entry->decoder=(DecodeImageHandler *) ReadRGBImage;
+  entry->encoder=(EncodeImageHandler *) WriteRGBImage;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->description=ConstantString("Raw red, green, blue, and opacity samples");
   entry->module=ConstantString("RGB");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
