@@ -51,9 +51,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -259,11 +260,16 @@ static Image *ReadRLAImage(const ImageInfo *image_info,ExceptionInfo *exception)
       CloseBlob(image);
       return(GetFirstImageInList(image));
     }
-  scanlines=(long *) AcquireMagickMemory(image->rows*sizeof(long));
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
+  scanlines=(long *) AcquireQuantumMemory(image->rows,sizeof(*scanlines));
   if (scanlines == (long *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   if (*rla_info.description != '\0')
-    (void) SetImageProperty(image,"Comment",rla_info.description);
+    (void) SetImageProperty(image,"comment",rla_info.description);
   /*
     Read offsets to each scanline data.
   */
@@ -409,20 +415,21 @@ static Image *ReadRLAImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterRLAImage method is:
 %
-%      RegisterRLAImage(void)
+%      unsigned long RegisterRLAImage(void)
 %
 */
-ModuleExport void RegisterRLAImage(void)
+ModuleExport unsigned long RegisterRLAImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("RLA");
-  entry->decoder=(DecoderHandler *) ReadRLAImage;
+  entry->decoder=(DecodeImageHandler *) ReadRLAImage;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Alias/Wavefront image");
   entry->module=ConstantString("RLA");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
