@@ -50,9 +50,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -273,9 +274,9 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
         indexes=GetIndexes(image);
         for (x=0; x < (long) image->columns; x++)
         {
-          q->red=QuantumRange-q->red;
-          q->green=QuantumRange-q->green;
-          q->blue=QuantumRange-q->blue;
+          q->red=(Quantum) QuantumRange-q->red;
+          q->green=(Quantum) QuantumRange-q->green;
+          q->blue=(Quantum) QuantumRange-q->blue;
           indexes[x]=(IndexPacket) (QuantumRange-ScaleCharToQuantum(
             (unsigned char) ReadBlobByte(image)));
           q++;
@@ -321,21 +322,22 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterSCTImage method is:
 %
-%      RegisterSCTImage(void)
+%      unsigned long RegisterSCTImage(void)
 %
 */
-ModuleExport void RegisterSCTImage(void)
+ModuleExport unsigned long RegisterSCTImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("SCT");
-  entry->decoder=(DecoderHandler *) ReadSCTImage;
-  entry->magick=(MagickHandler *) IsSCT;
+  entry->decoder=(DecodeImageHandler *) ReadSCTImage;
+  entry->magick=(IsImageFormatHandler *) IsSCT;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Scitex HandShake");
   entry->module=ConstantString("SCT");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
