@@ -54,9 +54,10 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Typedef declaractions.
@@ -369,6 +370,11 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((image_info->ping != MagickFalse)  && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
+    if (SetImageExtent(image,0,0) == MagickFalse)
+      {
+        InheritException(exception,&image->exception);
+        return(DestroyImageList(image));
+      }
     /*
       Allocate SGI pixels.
     */
@@ -377,8 +383,8 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((4*bytes_per_pixel*number_pixels) != ((MagickSizeType) (size_t)
         (4*bytes_per_pixel*number_pixels)))
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-    iris_pixels=(unsigned char *) AcquireMagickMemory(4*bytes_per_pixel*
-      iris_info.columns*iris_info.rows);
+    iris_pixels=(unsigned char *) AcquireQuantumMemory(iris_info.columns,
+      iris_info.rows*4*bytes_per_pixel*sizeof(*iris_pixels));
     if (iris_pixels == (unsigned char *) NULL)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     if ((int) iris_info.storage != 0x01)
@@ -389,8 +395,8 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Read standard image format.
         */
-        scanline=(unsigned char *) AcquireMagickMemory(bytes_per_pixel*
-          iris_info.columns*sizeof(*scanline));
+        scanline=(unsigned char *) AcquireQuantumMemory(iris_info.columns,
+          bytes_per_pixel*sizeof(*scanline));
         if (scanline == (unsigned char *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         for (z=0; z < (long) iris_info.depth; z++)
@@ -436,11 +442,11 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Read runlength-encoded image format.
         */
-        offsets=(ssize_t *) AcquireMagickMemory((size_t) iris_info.rows*
+        offsets=(ssize_t *) AcquireQuantumMemory((size_t) iris_info.rows,
           iris_info.depth*sizeof(*offsets));
-        packets=(unsigned char *) AcquireMagickMemory(4*(size_t)
-          iris_info.columns+10);
-        runlength=(unsigned long *) AcquireMagickMemory(iris_info.rows*
+        packets=(unsigned char *) AcquireQuantumMemory((size_t)
+          iris_info.columns+10UL,4UL*sizeof(*packets));
+        runlength=(unsigned long *) AcquireQuantumMemory(iris_info.rows,
           iris_info.depth*sizeof(*runlength));
         if ((offsets == (ssize_t *) NULL) ||
             (packets == (unsigned char *) NULL) ||
@@ -736,22 +742,23 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterSGIImage method is:
 %
-%      RegisterSGIImage(void)
+%      unsigned long RegisterSGIImage(void)
 %
 */
-ModuleExport void RegisterSGIImage(void)
+ModuleExport unsigned long RegisterSGIImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("SGI");
-  entry->decoder=(DecoderHandler *) ReadSGIImage;
-  entry->encoder=(EncoderHandler *) WriteSGIImage;
-  entry->magick=(MagickHandler *) IsSGI;
+  entry->decoder=(DecodeImageHandler *) ReadSGIImage;
+  entry->encoder=(EncodeImageHandler *) WriteSGIImage;
+  entry->magick=(IsImageFormatHandler *) IsSGI;
   entry->description=ConstantString("Irix RGB image");
   entry->module=ConstantString("SGI");
   entry->seekable_stream=MagickTrue;
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -969,8 +976,8 @@ static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
     if ((4*iris_info.bytes_per_pixel*number_pixels) !=
         ((MagickSizeType) (size_t) (4*iris_info.bytes_per_pixel*number_pixels)))
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
-    iris_pixels=(unsigned char *) AcquireMagickMemory((size_t)
-      (4*iris_info.bytes_per_pixel*number_pixels*sizeof(*iris_pixels)));
+    iris_pixels=(unsigned char *) AcquireQuantumMemory((size_t) number_pixels,
+      4*iris_info.bytes_per_pixel*sizeof(*iris_pixels));
     if (iris_pixels == (unsigned char *) NULL)
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
     /*
@@ -1070,11 +1077,11 @@ static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
         /*
           Convert SGI uncompressed pixels.
         */
-        offsets=(ssize_t *) AcquireMagickMemory(iris_info.rows*iris_info.depth*
+        offsets=(ssize_t *) AcquireQuantumMemory(iris_info.rows*iris_info.depth,
           sizeof(*offsets));
-        packets=(unsigned char *) AcquireMagickMemory(4*(2*(size_t)
-          iris_info.columns+10)*image->rows*sizeof(*packets));
-        runlength=(unsigned long *) AcquireMagickMemory(iris_info.rows*
+        packets=(unsigned char *) AcquireQuantumMemory((2*(size_t)
+          iris_info.columns+10)*image->rows,4*sizeof(*packets));
+        runlength=(unsigned long *) AcquireQuantumMemory(iris_info.rows,
           iris_info.depth*sizeof(*runlength));
         if ((offsets == (ssize_t *) NULL) ||
             (packets == (unsigned char *) NULL) ||
