@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -51,9 +51,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -81,14 +82,15 @@
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadSTEGANOImage(const ImageInfo *image_info,
   ExceptionInfo *exception)
 {
-#define GetBit(alpha,i) (((alpha) >> (unsigned long) (i)) & 0x01)
-#define SetBit(alpha,i,set) (alpha)=(Quantum) ((set) != 0 ? (alpha) | \
-  (1UL << (unsigned long) (i)) : (alpha) & ~(1UL << (unsigned long) (i)))
+#define GetBit(alpha,i) (((unsigned long) (alpha) >> (unsigned long) \
+  (i)) & 0x01)
+#define SetBit(alpha,i,set) (alpha)=(Quantum) ((set) != 0 ? (unsigned long) \
+  (alpha) | (1UL << (unsigned long) (i)) : (unsigned long) (alpha) & \
+  ~(1UL << (unsigned long) (i)))
 
   Image
     *image,
@@ -184,7 +186,8 @@ static Image *ReadSTEGANOImage(const ImageInfo *image_info,
             break;
           }
         }
-        (void) SyncImage(image);
+        if (SyncImagePixels(image) == MagickFalse)
+          break;
         c++;
         if (c == 3)
           c=0;
@@ -229,19 +232,20 @@ static Image *ReadSTEGANOImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterSTEGANOImage method is:
 %
-%      RegisterSTEGANOImage(void)
+%      unsigned long RegisterSTEGANOImage(void)
 %
 */
-ModuleExport void RegisterSTEGANOImage(void)
+ModuleExport unsigned long RegisterSTEGANOImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("STEGANO");
-  entry->decoder=(DecoderHandler *) ReadSTEGANOImage;
+  entry->decoder=(DecodeImageHandler *) ReadSTEGANOImage;
   entry->description=ConstantString("Steganographic image");
   entry->module=ConstantString("STEGANO");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
