@@ -53,9 +53,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -309,7 +310,7 @@ static Image *ReadSUNImage(const ImageInfo *image_info,ExceptionInfo *exception)
     image->rows=sun_info.height;
     if ((sun_info.depth == 0) || (sun_info.depth > 32))
       ThrowReaderException(CorruptImageError,"ImproperImageHeader");
-    image->depth=sun_info.depth <= 8 ? 8UL : QuantumDepth;
+    image->depth=sun_info.depth <= 8 ? sun_info.depth : QuantumDepth;
     if (sun_info.depth < 24)
       {
         image->storage_class=PseudoClass;
@@ -615,27 +616,28 @@ static Image *ReadSUNImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterSUNImage method is:
 %
-%      RegisterSUNImage(void)
+%      unsigned long RegisterSUNImage(void)
 %
 */
-ModuleExport void RegisterSUNImage(void)
+ModuleExport unsigned long RegisterSUNImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("RAS");
-  entry->decoder=(DecoderHandler *) ReadSUNImage;
-  entry->encoder=(EncoderHandler *) WriteSUNImage;
-  entry->magick=(MagickHandler *) IsSUN;
+  entry->decoder=(DecodeImageHandler *) ReadSUNImage;
+  entry->encoder=(EncodeImageHandler *) WriteSUNImage;
+  entry->magick=(IsImageFormatHandler *) IsSUN;
   entry->description=ConstantString("SUN Rasterfile");
   entry->module=ConstantString("SUN");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("SUN");
-  entry->decoder=(DecoderHandler *) ReadSUNImage;
-  entry->encoder=(EncoderHandler *) WriteSUNImage;
+  entry->decoder=(DecodeImageHandler *) ReadSUNImage;
+  entry->encoder=(EncodeImageHandler *) WriteSUNImage;
   entry->description=ConstantString("SUN Rasterfile");
   entry->module=ConstantString("SUN");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
