@@ -53,9 +53,10 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -289,7 +290,7 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
         char
           *comment;
 
-        unsigned long
+        size_t
           length;
 
         /*
@@ -304,11 +305,11 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         count=ReadBlob(image,tga_info.id_length,(unsigned char *) comment);
         comment[tga_info.id_length]='\0';
-        (void) SetImageProperty(image,"Comment",comment);
+        (void) SetImageProperty(image,"comment",comment);
         comment=DestroyString(comment);
       }
     (void) ResetMagickMemory(&pixel,0,sizeof(pixel));
-    pixel.opacity=TransparentOpacity;
+    pixel.opacity=(Quantum) TransparentOpacity;
     if (tga_info.colormap_type != 0)
       {
         /*
@@ -447,8 +448,8 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 (1UL*(j & 0xe0) >> 5),5);
               pixel.blue=ScaleAnyToQuantum(1UL*(j & 0x1f),5);
               if (image->matte != MagickFalse)
-                pixel.opacity=(k & 0x80) != 0? OpaqueOpacity :
-                  TransparentOpacity; 
+                pixel.opacity=(k & 0x80) != 0 ? (Quantum) OpaqueOpacity :
+                  (Quantum) TransparentOpacity; 
               if (image->storage_class == PseudoClass)
                 index=ConstrainColormapIndex(image,((unsigned long) k << 8)+j);
               break;
@@ -571,42 +572,43 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterTGAImage method is:
 %
-%      RegisterTGAImage(void)
+%      unsigned long RegisterTGAImage(void)
 %
 */
-ModuleExport void RegisterTGAImage(void)
+ModuleExport unsigned long RegisterTGAImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("ICB");
-  entry->decoder=(DecoderHandler *) ReadTGAImage;
-  entry->encoder=(EncoderHandler *) WriteTGAImage;
-  entry->magick=(MagickHandler *) IsTGA;
+  entry->decoder=(DecodeImageHandler *) ReadTGAImage;
+  entry->encoder=(EncodeImageHandler *) WriteTGAImage;
+  entry->magick=(IsImageFormatHandler *) IsTGA;
   entry->description=ConstantString("Truevision Targa image");
   entry->module=ConstantString("TGA");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("TGA");
-  entry->decoder=(DecoderHandler *) ReadTGAImage;
-  entry->encoder=(EncoderHandler *) WriteTGAImage;
-  entry->magick=(MagickHandler *) IsTGA;
+  entry->decoder=(DecodeImageHandler *) ReadTGAImage;
+  entry->encoder=(EncodeImageHandler *) WriteTGAImage;
+  entry->magick=(IsImageFormatHandler *) IsTGA;
   entry->description=ConstantString("Truevision Targa image");
   entry->module=ConstantString("TGA");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("VDA");
-  entry->decoder=(DecoderHandler *) ReadTGAImage;
-  entry->encoder=(EncoderHandler *) WriteTGAImage;
-  entry->magick=(MagickHandler *) IsTGA;
+  entry->decoder=(DecodeImageHandler *) ReadTGAImage;
+  entry->encoder=(EncodeImageHandler *) WriteTGAImage;
+  entry->magick=(IsImageFormatHandler *) IsTGA;
   entry->description=ConstantString("Truevision Targa image");
   entry->module=ConstantString("TGA");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("VST");
-  entry->decoder=(DecoderHandler *) ReadTGAImage;
-  entry->encoder=(EncoderHandler *) WriteTGAImage;
-  entry->magick=(MagickHandler *) IsTGA;
+  entry->decoder=(DecodeImageHandler *) ReadTGAImage;
+  entry->encoder=(EncodeImageHandler *) WriteTGAImage;
+  entry->magick=(IsImageFormatHandler *) IsTGA;
   entry->description=ConstantString("Truevision Targa image");
   entry->module=ConstantString("TGA");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -762,7 +764,7 @@ static MagickBooleanType WriteTGAImage(const ImageInfo *image_info,Image *image)
     if (image_info->colorspace == UndefinedColorspace)
       (void) SetImageColorspace(image,RGBColorspace);
     targa_info.id_length=0;
-    value=GetImageProperty(image,"Comment");
+    value=GetImageProperty(image,"comment");
     if (value != (const char *) NULL)
       targa_info.id_length=(unsigned char) MagickMin(strlen(value),255);
     targa_info.colormap_type=0;
