@@ -50,9 +50,10 @@
 #include "magick/monitor.h"
 #include "magick/profile.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -80,19 +81,20 @@ static MagickBooleanType
 %
 %  The format of the RegisterTHUMBNAILImage method is:
 %
-%      RegisterTHUMBNAILImage(void)
+%      unsigned long RegisterTHUMBNAILImage(void)
 %
 */
-ModuleExport void RegisterTHUMBNAILImage(void)
+ModuleExport unsigned long RegisterTHUMBNAILImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("THUMBNAIL");
-  entry->encoder=(EncoderHandler *) WriteTHUMBNAILImage;
+  entry->encoder=(EncodeImageHandler *) WriteTHUMBNAILImage;
   entry->description=ConstantString("EXIF Profile Thumbnail");
   entry->module=ConstantString("THUMBNAIL");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
