@@ -59,15 +59,16 @@
 #include "magick/monitor.h"
 #include "magick/option.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/profile.h"
 #include "magick/resize.h"
 #include "magick/splay-tree.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/utility.h"
-#include "magick/version.h"
+#include "magick/module.h"
 #if defined(HasTIFF)
 # if defined(HAVE_TIFFCONF_H)
 #  include "tiffconf.h"
@@ -104,8 +105,8 @@ static MagickBooleanType
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  IsTIFF() returns MagickTrue if the image format type, identified by the magick
-%  string, is TIFF.
+%  IsTIFF() returns MagickTrue if the image format type, identified by the
+%  magick string, is TIFF.
 %
 %  The format of the IsTIFF method is:
 %
@@ -118,7 +119,6 @@ static MagickBooleanType
 %
 %    o length: Specifies the length of the magick string.
 %
-%
 */
 static MagickBooleanType IsTIFF(const unsigned char *magick,const size_t length)
 {
@@ -813,11 +813,11 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
                 }
             for (i=0; i < (long) image->colors; i++)
             {
-              image->colormap[i].red=
+              image->colormap[i].red=(Quantum) 
                 (((double) QuantumRange*red_colormap[i])/range+0.5);
-              image->colormap[i].green=
+              image->colormap[i].green=(Quantum) 
                 (((double) QuantumRange*green_colormap[i])/range+0.5);
-              image->colormap[i].blue=
+              image->colormap[i].blue=(Quantum) 
                 (((double) QuantumRange*blue_colormap[i])/range+0.5);
             }
           }
@@ -1304,10 +1304,10 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterTIFFImage method is:
 %
-%      RegisterTIFFImage(void)
+%      unsigned long RegisterTIFFImage(void)
 %
 */
-ModuleExport void RegisterTIFFImage(void)
+ModuleExport unsigned long RegisterTIFFImage(void)
 {
 #define TIFFDescription  "Tagged Image File Format"
 
@@ -1338,8 +1338,8 @@ ModuleExport void RegisterTIFFImage(void)
 
   entry=SetMagickInfo("PTIF");
 #if defined(HasTIFF)
-  entry->decoder=(DecoderHandler *) ReadTIFFImage;
-  entry->encoder=(EncoderHandler *) WritePTIFImage;
+  entry->decoder=(DecodeImageHandler *) ReadTIFFImage;
+  entry->encoder=(EncodeImageHandler *) WritePTIFImage;
 #endif
   entry->adjoin=MagickFalse;
   entry->endian_support=MagickTrue;
@@ -1350,8 +1350,8 @@ ModuleExport void RegisterTIFFImage(void)
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("TIF");
 #if defined(HasTIFF)
-  entry->decoder=(DecoderHandler *) ReadTIFFImage;
-  entry->encoder=(EncoderHandler *) WriteTIFFImage;
+  entry->decoder=(DecodeImageHandler *) ReadTIFFImage;
+  entry->encoder=(EncodeImageHandler *) WriteTIFFImage;
 #endif
   entry->endian_support=MagickTrue;
   entry->seekable_stream=MagickTrue;
@@ -1364,10 +1364,10 @@ ModuleExport void RegisterTIFFImage(void)
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("TIFF");
 #if defined(HasTIFF)
-  entry->decoder=(DecoderHandler *) ReadTIFFImage;
-  entry->encoder=(EncoderHandler *) WriteTIFFImage;
+  entry->decoder=(DecodeImageHandler *) ReadTIFFImage;
+  entry->encoder=(EncodeImageHandler *) WriteTIFFImage;
 #endif
-  entry->magick=(MagickHandler *) IsTIFF;
+  entry->magick=(IsImageFormatHandler *) IsTIFF;
   entry->endian_support=MagickTrue;
   entry->seekable_stream=MagickTrue;
   entry->thread_support=NoThreadSupport;
@@ -1378,8 +1378,8 @@ ModuleExport void RegisterTIFFImage(void)
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("TIFF64");
 #if defined(TIFF_VERSION_BIG)
-  entry->decoder=(DecoderHandler *) ReadTIFFImage;
-  entry->encoder=(EncoderHandler *) WritePTIFImage;
+  entry->decoder=(DecodeImageHandler *) ReadTIFFImage;
+  entry->encoder=(EncodeImageHandler *) WritePTIFImage;
 #endif
   entry->adjoin=MagickFalse;
   entry->endian_support=MagickTrue;
@@ -1390,6 +1390,7 @@ ModuleExport void RegisterTIFFImage(void)
     entry->version=ConstantString(version);
   entry->module=ConstantString("TIFF");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -2191,10 +2192,10 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
     value=GetImageProperty(image,"tiff:copyright");
     if (value != (const char *) NULL)
       (void) TIFFSetField(tiff,33432,value);
-    value=GetImageProperty(image,"Kodak-33423");
+    value=GetImageProperty(image,"kodak-33423");
     if (value != (const char *) NULL)
       (void) TIFFSetField(tiff,33423,value);
-    value=GetImageProperty(image,"Kodak-36867");
+    value=GetImageProperty(image,"kodak-36867");
     if (value != (const char *) NULL)
       (void) TIFFSetField(tiff,36867,value);
     value=GetImageProperty(image,"label");
