@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -51,8 +51,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -79,7 +81,6 @@
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadTILEImage(const ImageInfo *image_info,
   ExceptionInfo *exception)
@@ -97,7 +98,8 @@ static Image *ReadTILEImage(const ImageInfo *image_info,
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   read_info=CloneImageInfo(image_info);
@@ -112,9 +114,14 @@ static Image *ReadTILEImage(const ImageInfo *image_info,
     ThrowReaderException(OptionError,"MustSpecifyImageSize");
   if (*image_info->filename == '\0')
     ThrowReaderException(OptionError,"MustSpecifyAnImageName");
-  SetImageBackgroundColor(image);
+  (void) SetImageBackgroundColor(image);
   image->matte=tile_image->matte;
   (void) CopyMagickString(image->filename,image_info->filename,MaxTextExtent);
+  if (LocaleCompare(tile_image->magick,"PATTERN") == 0)
+    {
+      tile_image->tile_offset.x=0;
+      tile_image->tile_offset.y=0;
+    }
   (void) TextureImage(image,tile_image);
   tile_image=DestroyImage(tile_image);
   return(GetFirstImageInList(image));
@@ -140,21 +147,22 @@ static Image *ReadTILEImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterTILEImage method is:
 %
-%      RegisterTILEImage(void)
+%      unsigned long RegisterTILEImage(void)
 %
 */
-ModuleExport void RegisterTILEImage(void)
+ModuleExport unsigned long RegisterTILEImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("TILE");
-  entry->decoder=(DecoderHandler *) ReadTILEImage;
+  entry->decoder=(DecodeImageHandler *) ReadTILEImage;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
-  entry->description=AcquireString("Tile image with a texture");
-  entry->module=AcquireString("TILE");
+  entry->description=ConstantString("Tile image with a texture");
+  entry->module=ConstantString("TILE");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
