@@ -50,9 +50,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -81,7 +82,6 @@
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
@@ -196,7 +196,8 @@ static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         image->rows=height;
         if (AllocateImageColormap(image,pixel_mode == 1 ? 256UL : 16UL) == MagickFalse)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-        tim_colormap=(unsigned char *) AcquireMagickMemory(image->colors*2);
+        tim_colormap=(unsigned char *) AcquireQuantumMemory(image->colors,
+          2UL*sizeof(*tim_colormap));
         if (tim_colormap == (unsigned char *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         count=ReadBlob(image,2*image->colors,tim_colormap);
@@ -219,6 +220,11 @@ static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
+    if (SetImageExtent(image,0,0) == MagickFalse)
+      {
+        InheritException(exception,&image->exception);
+        return(DestroyImageList(image));
+      }
     /*
       Read image data.
     */
@@ -230,7 +236,8 @@ static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
     image_size=2*width*height;
     bytes_per_line=width*2;
     width=(width*16)/bits_per_pixel;
-    tim_data=(unsigned char *) AcquireMagickMemory(image_size);
+    tim_data=(unsigned char *) AcquireQuantumMemory(image_size,
+      sizeof(*tim_data));
     if (tim_data == (unsigned char *) NULL)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     count=ReadBlob(image,image_size,tim_data);
@@ -435,19 +442,20 @@ static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterTIMImage method is:
 %
-%      RegisterTIMImage(void)
+%      unsigned long RegisterTIMImage(void)
 %
 */
-ModuleExport void RegisterTIMImage(void)
+ModuleExport unsigned long RegisterTIMImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("TIM");
-  entry->decoder=(DecoderHandler *) ReadTIMImage;
+  entry->decoder=(DecodeImageHandler *) ReadTIMImage;
   entry->description=ConstantString("PSX TIM");
   entry->module=ConstantString("TIM");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
