@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -50,9 +50,10 @@
 #include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/type.h"
 #include "wand/MagickWand.h"
 #if defined(HasFREETYPE)
@@ -166,7 +167,6 @@ static MagickBooleanType IsTTF(const unsigned char *magick,const size_t length)
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadTTFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
@@ -231,6 +231,11 @@ static Image *ReadTTFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Color canvas with background color
   */
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   background_color=image_info->background_color;
   for (y=0; y < (long) image->rows; y++)
   {
@@ -306,10 +311,10 @@ static Image *ReadTTFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterTTFImage method is:
 %
-%      RegisterTTFImage(void)
+%      unsigned long RegisterTTFImage(void)
 %
 */
-ModuleExport void RegisterTTFImage(void)
+ModuleExport unsigned long RegisterTTFImage(void)
 {
   char
     version[MaxTextExtent];
@@ -324,9 +329,9 @@ ModuleExport void RegisterTTFImage(void)
 #endif
   entry=SetMagickInfo("DFONT");
 #if defined(HasFREETYPE)
-  entry->decoder=(DecoderHandler *) ReadTTFImage;
+  entry->decoder=(DecodeImageHandler *) ReadTTFImage;
 #endif
-  entry->magick=(MagickHandler *) IsTTF;
+  entry->magick=(IsImageFormatHandler *) IsTTF;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Multi-face font package");
   if (*version != '\0')
@@ -335,9 +340,9 @@ ModuleExport void RegisterTTFImage(void)
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PFA");
 #if defined(HasFREETYPE)
-  entry->decoder=(DecoderHandler *) ReadTTFImage;
+  entry->decoder=(DecodeImageHandler *) ReadTTFImage;
 #endif
-  entry->magick=(MagickHandler *) IsPFA;
+  entry->magick=(IsImageFormatHandler *) IsPFA;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Postscript Type 1 font (ASCII)");
   if (*version != '\0')
@@ -346,9 +351,9 @@ ModuleExport void RegisterTTFImage(void)
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PFB");
 #if defined(HasFREETYPE)
-  entry->decoder=(DecoderHandler *) ReadTTFImage;
+  entry->decoder=(DecodeImageHandler *) ReadTTFImage;
 #endif
-  entry->magick=(MagickHandler *) IsPFA;
+  entry->magick=(IsImageFormatHandler *) IsPFA;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Postscript Type 1 font (binary)");
   if (*version != '\0')
@@ -357,9 +362,9 @@ ModuleExport void RegisterTTFImage(void)
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("OTF");
 #if defined(HasFREETYPE)
-  entry->decoder=(DecoderHandler *) ReadTTFImage;
+  entry->decoder=(DecodeImageHandler *) ReadTTFImage;
 #endif
-  entry->magick=(MagickHandler *) IsTTF;
+  entry->magick=(IsImageFormatHandler *) IsTTF;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Open Type font");
   if (*version != '\0')
@@ -368,9 +373,9 @@ ModuleExport void RegisterTTFImage(void)
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("TTC");
 #if defined(HasFREETYPE)
-  entry->decoder=(DecoderHandler *) ReadTTFImage;
+  entry->decoder=(DecodeImageHandler *) ReadTTFImage;
 #endif
-  entry->magick=(MagickHandler *) IsTTF;
+  entry->magick=(IsImageFormatHandler *) IsTTF;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("TrueType font collection");
   if (*version != '\0')
@@ -379,15 +384,16 @@ ModuleExport void RegisterTTFImage(void)
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("TTF");
 #if defined(HasFREETYPE)
-  entry->decoder=(DecoderHandler *) ReadTTFImage;
+  entry->decoder=(DecodeImageHandler *) ReadTTFImage;
 #endif
-  entry->magick=(MagickHandler *) IsTTF;
+  entry->magick=(IsImageFormatHandler *) IsTTF;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("TrueType font");
   if (*version != '\0')
     entry->version=ConstantString(version);
   entry->module=ConstantString("TTF");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
