@@ -59,10 +59,11 @@
 #include "magick/monitor.h"
 #include "magick/option.h"
 #include "magick/pixel-private.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -84,7 +85,7 @@ static MagickBooleanType
 %  IsTXT() returns MagickTrue if the image format type, identified by the magick
 %  string, is TXT.
 %
-%  The format of the IsTXT method is:
+%  The colorspace of the IsTXT method is:
 %
 %      MagickBooleanType IsTXT(const unsigned char *magick,const size_t length)
 %
@@ -102,14 +103,14 @@ static MagickBooleanType IsTXT(const unsigned char *magick,const size_t length)
 #define MagickID  "# ImageMagick pixel enumeration:"
 
   char
-    format[MaxTextExtent];
+    colorspace[MaxTextExtent];
 
   ssize_t
     count;
 
   unsigned long
     columns,
-    max_value,
+    depth,
     rows;
 
   if (length < 40)
@@ -117,7 +118,7 @@ static MagickBooleanType IsTXT(const unsigned char *magick,const size_t length)
   if (LocaleNCompare((char *) magick,MagickID,strlen(MagickID)) != 0)
     return(MagickFalse);
   count=(ssize_t) sscanf((char *) magick+32,"%lu,%lu,%lu,%s",&columns,&rows,
-    &max_value,format);
+    &depth,colorspace);
   if (count != 4)
     return(MagickFalse);
   return(MagickTrue);
@@ -138,7 +139,7 @@ static MagickBooleanType IsTXT(const unsigned char *magick,const size_t length)
 %  allocates the memory necessary for the new Image structure and returns a
 %  pointer to the new image.
 %
-%  The format of the ReadTEXTImage method is:
+%  The colorspace of the ReadTEXTImage method is:
 %
 %      Image *ReadTEXTImage(const ImageInfo *image_info,
 %        ExceptionInfo *exception)
@@ -232,6 +233,11 @@ static Image *ReadTEXTImage(const ImageInfo *image_info,
   image->rows=(unsigned long) (((page.height*image->y_resolution)/delta.y)+0.5);
   image->page.x=0;
   image->page.y=0;
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   texture=(Image *) NULL;
   if (image_info->texture != (char *) NULL)
     {
@@ -354,7 +360,7 @@ static Image *ReadTEXTImage(const ImageInfo *image_info,
 %  the memory necessary for the new Image structure and returns a pointer to
 %  the new image.
 %
-%  The format of the ReadTXTImage method is:
+%  The colorspace of the ReadTXTImage method is:
 %
 %      Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
@@ -364,12 +370,11 @@ static Image *ReadTEXTImage(const ImageInfo *image_info,
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
   char
-    format[MaxTextExtent],
+    colorspace[MaxTextExtent],
     text[MaxTextExtent];
 
   Image
@@ -379,6 +384,7 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
     *indexes;
 
   long
+    type,
     x,
     y;
 
@@ -388,6 +394,9 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   MagickBooleanType
     status;
 
+  register long
+    i;
+
   register PixelPacket
     *q;
 
@@ -417,23 +426,40 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   (void) ReadBlobString(image,text);
   if (LocaleNCompare((char *) text,MagickID,strlen(MagickID)) != 0)
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
+  *colorspace='\0';
   count=(ssize_t) sscanf(text+32,"%lu,%lu,%lu,%s",&image->columns,
-    &image->rows,&max_value,format);
+    &image->rows,&max_value,colorspace);
   if (count != 4)
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
-  if (LocaleNCompare(format,"CMYK",4) == 0)
-    image->colorspace=CMYKColorspace;
-  image->matte=strchr(format,'A') != (char *) NULL ? MagickTrue : MagickFalse;
+  if (max_value == 4294967295UL)
+    image->depth=32;
+  else
+    for (image->depth=1; (1UL << image->depth)-1 < max_value; image->depth++);
+  LocaleLower(colorspace);
+  i=(long) strlen(colorspace)-1;
+  image->matte=MagickFalse;
+  if ((i > 0) && (colorspace[i] == 'a'))
+    {
+      colorspace[i]='\0';
+      image->matte=MagickTrue;
+    }
+  type=ParseMagickOption(MagickColorspaceOptions,MagickFalse,colorspace);
+  if (type < 0)
+    ThrowReaderException(CorruptImageError,"ImproperImageHeader");
+  image->colorspace=(ColorspaceType) type;
+  (void) ResetMagickMemory(&pixel,0,sizeof(pixel));
+  (void) SetImageBackgroundColor(image);
   while (ReadBlobString(image,text) != (char *) NULL)
   {
-    pixel.red=0;
-    pixel.green=0;
-    pixel.blue=0;
-    pixel.index=0;
-    pixel.opacity=OpaqueOpacity;
-    if ((image->colorspace == CMYKColorspace) && (image->matte != MagickFalse))
-      count=(ssize_t) sscanf(text,"%ld,%ld: (%lu,%lu,%lu,%lu,%lu",&x,&y,
-        &pixel.red,&pixel.green,&pixel.blue,&pixel.index,&pixel.opacity);
+    if (image->colorspace == CMYKColorspace)
+      {
+        if (image->matte != MagickFalse)
+          count=(ssize_t) sscanf(text,"%ld,%ld: (%lu,%lu,%lu,%lu,%lu",&x,&y,
+            &pixel.red,&pixel.green,&pixel.blue,&pixel.index,&pixel.opacity);
+        else
+          count=(ssize_t) sscanf(text,"%ld,%ld: (%lu,%lu,%lu,%lu",&x,&y,
+            &pixel.red,&pixel.green,&pixel.blue,&pixel.index);
+      }
     else
       if (image->matte != MagickFalse)
         count=(ssize_t) sscanf(text,"%ld,%ld: (%lu,%lu,%lu,%lu",&x,&y,
@@ -443,21 +469,21 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
           &pixel.red,&pixel.green,&pixel.blue);
     if (count < 5)
       continue;
-    q=SetImagePixels(image,x,y,1,1);
+    q=GetImagePixels(image,x,y,1,1);
     if (q == (PixelPacket *) NULL)
       continue;
-    q->red=ScaleAnyToQuantum(pixel.red,max_value);
-    q->green=ScaleAnyToQuantum(pixel.green,max_value);
-    q->blue=ScaleAnyToQuantum(pixel.blue,max_value);
+    q->red=ScaleAnyToQuantum(pixel.red,image->depth);
+    q->green=ScaleAnyToQuantum(pixel.green,image->depth);
+    q->blue=ScaleAnyToQuantum(pixel.blue,image->depth);
     if (image->colorspace == CMYKColorspace)
       {
         indexes=GetIndexes(image);
-        *indexes=ScaleAnyToQuantum(pixel.index,max_value);
+        *indexes=ScaleAnyToQuantum(pixel.index,image->depth);
       }
     if (image->matte != MagickFalse)
-      q->opacity=QuantumRange-
-        ScaleAnyToQuantum(pixel.opacity,max_value);
-    (void) SyncImagePixels(image);
+      q->opacity=(Quantum) ScaleAnyToQuantum(pixel.opacity,image->depth);
+    if (SyncImagePixels(image) == MagickFalse)
+      break;
   }
   return(GetFirstImageInList(image));
 }
@@ -473,38 +499,39 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RegisterTXTImage() adds attributes for the TXT image format to
-%  the list of supported formats.  The attributes include the image format
-%  tag, a method to read and/or write the format, whether the format
+%  RegisterTXTImage() adds attributes for the TXT image format to the
+%  list of supported formats.  The attributes include the image format
+%  tag, a method to read and/or write the colorspace, whether the format
 %  supports the saving of more than one frame to the same file or blob,
 %  whether the format supports native in-memory I/O, and a brief
 %  description of the format.
 %
-%  The format of the RegisterTXTImage method is:
+%  The colorspace of the RegisterTXTImage method is:
 %
-%      RegisterTXTImage(void)
+%      unsigned long RegisterTXTImage(void)
 %
 */
-ModuleExport void RegisterTXTImage(void)
+ModuleExport unsigned long RegisterTXTImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("TEXT");
-  entry->decoder=(DecoderHandler *) ReadTEXTImage;
-  entry->encoder=(EncoderHandler *) WriteTXTImage;
+  entry->decoder=(DecodeImageHandler *) ReadTEXTImage;
+  entry->encoder=(EncodeImageHandler *) WriteTXTImage;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->description=ConstantString("Text");
   entry->module=ConstantString("TXT");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("TXT");
-  entry->decoder=(DecoderHandler *) ReadTXTImage;
-  entry->encoder=(EncoderHandler *) WriteTXTImage;
+  entry->decoder=(DecodeImageHandler *) ReadTXTImage;
+  entry->encoder=(EncodeImageHandler *) WriteTXTImage;
   entry->description=ConstantString("Text");
-  entry->magick=(MagickHandler *) IsTXT;
+  entry->magick=(IsImageFormatHandler *) IsTXT;
   entry->module=ConstantString("TXT");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -518,10 +545,10 @@ ModuleExport void RegisterTXTImage(void)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  UnregisterTXTImage() removes format registrations made by the
-%  TXT module from the list of supported formats.
+%  UnregisterTXTImage() removes colorspace registrations made by the
+%  TXT module from the list of supported colorspaces.
 %
-%  The format of the UnregisterTXTImage method is:
+%  The colorspace of the UnregisterTXTImage method is:
 %
 %      UnregisterTXTImage(void)
 %
@@ -545,7 +572,7 @@ ModuleExport void UnregisterTXTImage(void)
 %
 %  WriteTXTImage writes the pixel values as text numbers.
 %
-%  The format of the WriteTXTImage method is:
+%  The colorspace of the WriteTXTImage method is:
 %
 %      MagickBooleanType WriteTXTImage(const ImageInfo *image_info,Image *image)
 %
@@ -555,52 +582,12 @@ ModuleExport void UnregisterTXTImage(void)
 %
 %    o image:  The image.
 %
-%
 */
-
-static inline void ConcatenateColorComponent(const MagickPixelPacket *pixel,
-  const ChannelType channel,char *tuple)
-{
-  char
-    component[MaxTextExtent];
-
-  MagickRealType
-    color;
-
-  color=0.0;
-  switch (channel)
-  {
-    case RedChannel: color=pixel->red; break;
-    case GreenChannel: color=pixel->green; break;
-    case BlueChannel: color=pixel->blue; break;
-    case OpacityChannel: color=(MagickRealType) QuantumRange-pixel->opacity; break;
-    case IndexChannel: color=pixel->index; break;
-    default: break;
-  }
-  if (pixel->depth > 16)
-    {
-      (void) FormatMagickString(component,MaxTextExtent,"%10lu",
-        (unsigned long) ScaleQuantumToLong(RoundToQuantum(color)));
-      (void) ConcatenateMagickString(tuple,component,MaxTextExtent);
-      return;
-    }
-  if (pixel->depth > 8)
-    {
-      (void) FormatMagickString(component,MaxTextExtent,"%5d",
-        ScaleQuantumToShort(RoundToQuantum(color)));
-      (void) ConcatenateMagickString(tuple,component,MaxTextExtent);
-      return;
-    }
-  (void) FormatMagickString(component,MaxTextExtent,"%3d",
-    ScaleQuantumToChar(RoundToQuantum(color)));
-  (void) ConcatenateMagickString(tuple,component,MaxTextExtent);
-}
-
 static MagickBooleanType WriteTXTImage(const ImageInfo *image_info,Image *image)
 {
   char
     buffer[MaxTextExtent],
-    format[MaxTextExtent],
+    colorspace[MaxTextExtent],
     tuple[MaxTextExtent];
 
   long
@@ -624,9 +611,6 @@ static MagickBooleanType WriteTXTImage(const ImageInfo *image_info,Image *image)
   register long
     x;
 
-  unsigned long
-    quantum_range;
-
   /*
     Open output image file.
   */
@@ -639,19 +623,16 @@ static MagickBooleanType WriteTXTImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  if (image->colorspace != CMYKColorspace)
-    (void) CopyMagickString(format,"RGB",MaxTextExtent);
-  else
-    (void) CopyMagickString(format,"CMYK",MaxTextExtent);
-  if (image->matte != MagickFalse)
-    (void) ConcatenateMagickString(format,"A",MaxTextExtent);
+  (void) CopyMagickString(colorspace,MagickOptionToMnemonic(
+    MagickColorspaceOptions,(long) image->colorspace),MaxTextExtent);
   image->depth=GetImageQuantumDepth(image,MagickTrue);
-  quantum_range=(1UL << image->depth)-1;
-  if (image->depth == 32)
-     quantum_range=4294967295UL;
+  if (image->matte != MagickFalse)
+    (void) ConcatenateMagickString(colorspace,"a",MaxTextExtent);
+  LocaleLower(colorspace);
   (void) FormatMagickString(buffer,MaxTextExtent,
     "# ImageMagick pixel enumeration: %lu,%lu,%lu,%s\n",image->columns,
-    image->rows,quantum_range,format);
+    image->rows,image->depth == 32 ? 4294967295UL : (1UL << image->depth)-1,
+    colorspace);
   (void) WriteBlobString(image,buffer);
   scene=0;
   do
@@ -672,20 +653,21 @@ static MagickBooleanType WriteTXTImage(const ImageInfo *image_info,Image *image)
         (void) WriteBlobString(image,buffer);
         SetMagickPixelPacket(image,p,indexes+x,&pixel);
         (void) CopyMagickString(tuple,"(",MaxTextExtent);
-        ConcatenateColorComponent(&pixel,RedChannel,tuple);
+        ConcatenateColorComponent(&pixel,RedChannel,X11Compliance,tuple);
         (void) ConcatenateMagickString(tuple,",",MaxTextExtent);
-        ConcatenateColorComponent(&pixel,GreenChannel,tuple);
+        ConcatenateColorComponent(&pixel,GreenChannel,X11Compliance,tuple);
         (void) ConcatenateMagickString(tuple,",",MaxTextExtent);
-        ConcatenateColorComponent(&pixel,BlueChannel,tuple);
+        ConcatenateColorComponent(&pixel,BlueChannel,X11Compliance,tuple);
         if (pixel.colorspace == CMYKColorspace)
           {
             (void) ConcatenateMagickString(tuple,",",MaxTextExtent);
-            ConcatenateColorComponent(&pixel,IndexChannel,tuple);
+            ConcatenateColorComponent(&pixel,IndexChannel,X11Compliance,tuple);
           }
         if (pixel.matte != MagickFalse)
           {
             (void) ConcatenateMagickString(tuple,",",MaxTextExtent);
-            ConcatenateColorComponent(&pixel,OpacityChannel,tuple);
+            ConcatenateColorComponent(&pixel,OpacityChannel,X11Compliance,
+              tuple);
           }
         (void) ConcatenateMagickString(tuple,")",MaxTextExtent);
         (void) WriteBlobString(image,tuple);
