@@ -52,9 +52,10 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/pixel-private.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/utility.h"
 
 /*
@@ -83,20 +84,21 @@ static MagickBooleanType
 %
 %  The format of the RegisterUILImage method is:
 %
-%      RegisterUILImage(void)
+%      unsigned long RegisterUILImage(void)
 %
 */
-ModuleExport void RegisterUILImage(void)
+ModuleExport unsigned long RegisterUILImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("UIL");
-  entry->encoder=(EncoderHandler *) WriteUILImage;
+  entry->encoder=(EncodeImageHandler *) WriteUILImage;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("X-Motif UIL table");
   entry->module=ConstantString("UIL");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -230,8 +232,8 @@ static MagickBooleanType WriteUILImage(const ImageInfo *image_info,Image *image)
           number_pixels=(MagickSizeType) image->columns*image->rows;
           if (number_pixels != ((MagickSizeType) (size_t) number_pixels))
             ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
-          matte_image=(unsigned char *)
-            AcquireMagickMemory(image->columns*image->rows);
+          matte_image=(unsigned char *) AcquireQuantumMemory(image->columns,
+            image->rows*sizeof(*matte_image));
           if (matte_image == (unsigned char *) NULL)
             ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
           for (y=0; y < (long) image->rows; y++)
@@ -241,8 +243,9 @@ static MagickBooleanType WriteUILImage(const ImageInfo *image_info,Image *image)
               break;
             for (x=0; x < (long) image->columns; x++)
             {
-              matte_image[i]=(unsigned char) (p->opacity == TransparentOpacity);
-              if (matte_image[i])
+              matte_image[i]=(unsigned char)
+              (p->opacity == (Quantum) TransparentOpacity ? 1 : 0);
+              if (matte_image[i] != 0)
                 transparent=MagickTrue;
               i++;
               p++;
