@@ -18,7 +18,7 @@
 %                                March 2000                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -51,9 +51,11 @@
 #include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/resource_.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #if defined(HasXML)
 #  if defined(__WINDOWS__)
 #    if defined(__MINGW32__)
@@ -67,7 +69,6 @@
 #  include <libxml/nanohttp.h>
 #endif
 
-#if defined(HasXML) && defined(LIBXML_HTTP_ENABLED) && defined(LIBXML_FTP_ENABLED)
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -122,7 +123,6 @@ static Image *ReadURLImage(const ImageInfo *image_info,ExceptionInfo *exception)
 #define MaxBufferExtent  8192
 
   char
-    buffer[MaxBufferExtent],
     filename[MaxTextExtent];
 
   FILE
@@ -137,9 +137,6 @@ static Image *ReadURLImage(const ImageInfo *image_info,ExceptionInfo *exception)
   int
     unique_file;
 
-  void
-    *context;
-
   image=(Image *) NULL;
   read_info=CloneImageInfo(image_info);
   SetImageInfoBlob(read_info,(void *) NULL,0);
@@ -161,14 +158,43 @@ static Image *ReadURLImage(const ImageInfo *image_info,ExceptionInfo *exception)
   (void) ConcatenateMagickString(filename,":",MaxTextExtent);
   LocaleLower(filename);
   (void) ConcatenateMagickString(filename,image_info->filename,MaxTextExtent);
-  if (LocaleCompare(read_info->magick,"ftp") != 0)
+  if (LocaleCompare(read_info->magick,"file") == 0)
+    {
+      (void) RelinquishUniqueFileResource(read_info->filename);
+      unique_file=(-1);
+      (void) CopyMagickString(read_info->filename,image_info->filename+2,
+        MaxTextExtent);
+    }
+#if defined(HasXML) && defined(LIBXML_FTP_ENABLED)
+  if (LocaleCompare(read_info->magick,"ftp") == 0)
+    {
+      void
+        *context;
+
+      xmlNanoFTPInit();
+      context=xmlNanoFTPNewCtxt(filename);
+      if (context != (void *) NULL)
+        {
+          if (xmlNanoFTPConnect(context) >= 0)
+            (void) xmlNanoFTPGet(context,GetFTPData,(void *) file,
+              (char *) NULL);
+          (void) xmlNanoFTPClose(context);
+        }
+    }
+#endif
+#if defined(HasXML) && defined(LIBXML_HTTP_ENABLED)
+  if (LocaleCompare(read_info->magick,"http") == 0)
     {
       char
+        buffer[MaxBufferExtent],
         *type;
 
       int
         bytes;
 
+      void
+        *context;
+
       type=(char *) NULL;
       context=xmlNanoHTTPMethod(filename,(const char *) NULL,
         (const char *) NULL,&type,(const char *) NULL,0);
@@ -181,29 +207,18 @@ static Image *ReadURLImage(const ImageInfo *image_info,ExceptionInfo *exception)
           xmlNanoHTTPCleanup();
         }
     }
-  else
-    {
-      xmlNanoFTPInit();
-      context=xmlNanoFTPNewCtxt(filename);
-      if (context != (void *) NULL)
-        {
-          if (xmlNanoFTPConnect(context) >= 0)
-            (void) xmlNanoFTPGet(context,GetFTPData,(void *) file,
-              (char *) NULL);
-          (void) xmlNanoFTPClose(context);
-        }
-    }
+#endif
   (void) fclose(file);
   *read_info->magick='\0';
   image=ReadImage(read_info,exception);
-  (void) RelinquishUniqueFileResource(read_info->filename);
+  if (unique_file != -1)
+    (void) RelinquishUniqueFileResource(read_info->filename);
   read_info=DestroyImageInfo(read_info);
   if (image == (Image *) NULL)
     (void) ThrowMagickException(exception,GetMagickModule(),CoderError,
       "NoDataReturned","`%s'",filename);
   return(GetFirstImageInList(image));
 }
-#endif
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -225,38 +240,37 @@ static Image *ReadURLImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterURLImage method is:
 %
-%      RegisterURLImage(void)
+%      unsigned long RegisterURLImage(void)
 %
 */
-ModuleExport void RegisterURLImage(void)
+ModuleExport unsigned long RegisterURLImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("HTTP");
-#if defined(HasXML) && defined(LIBXML_HTTP_ENABLED) && defined(LIBXML_FTP_ENABLED)
-  entry->decoder=(DecoderHandler *) ReadURLImage;
+#if defined(HasXML) && defined(LIBXML_HTTP_ENABLED)
+  entry->decoder=(DecodeImageHandler *) ReadURLImage;
 #endif
-  entry->description=AcquireString("Uniform Resource Locator (http://)");
-  entry->module=AcquireString("URL");
+  entry->description=ConstantString("Uniform Resource Locator (http://)");
+  entry->module=ConstantString("URL");
   entry->stealth=MagickTrue;
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("FTP");
-#if defined(HasXML) && defined(LIBXML_HTTP_ENABLED) && defined(LIBXML_FTP_ENABLED)
-  entry->decoder=(DecoderHandler *) ReadURLImage;
+#if defined(HasXML) && defined(LIBXML_FTP_ENABLED)
+  entry->decoder=(DecodeImageHandler *) ReadURLImage;
 #endif
-  entry->description=AcquireString("Uniform Resource Locator (ftp://)");
-  entry->module=AcquireString("URL");
+  entry->description=ConstantString("Uniform Resource Locator (ftp://)");
+  entry->module=ConstantString("URL");
   entry->stealth=MagickTrue;
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("FILE");
-#if defined(HasXML) && defined(LIBXML_HTTP_ENABLED) && defined(LIBXML_FTP_ENABLED)
-  entry->decoder=(DecoderHandler *) ReadURLImage;
-#endif
-  entry->description=AcquireString("Uniform Resource Locator (file://)");
-  entry->module=AcquireString("URL");
+  entry->decoder=(DecodeImageHandler *) ReadURLImage;
+  entry->description=ConstantString("Uniform Resource Locator (file://)");
+  entry->module=ConstantString("URL");
   entry->stealth=MagickTrue;
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
