@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -52,9 +52,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -137,13 +138,23 @@ static Image *ReadUYVYImage(const ImageInfo *image_info,
   if (status == MagickFalse)
     return((Image *) NULL);
   for (i=0; i < image->offset; i++)
-    (void) ReadBlobByte(image);
+    if (ReadBlobByte(image) == EOF)
+      {
+        ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
+          image->filename);
+        break;
+      }
   image->depth=8;
   if (image_info->ping != MagickFalse)
     {
       CloseBlob(image);
       return(GetFirstImageInList(image));
     }
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   /*
     Accumulate UYVY, then unpack into two pixels.
   */
@@ -208,17 +219,17 @@ static Image *ReadUYVYImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterUYVYImage method is:
 %
-%      RegisterUYVYImage(void)
+%      unsigned long RegisterUYVYImage(void)
 %
 */
-ModuleExport void RegisterUYVYImage(void)
+ModuleExport unsigned long RegisterUYVYImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("PAL");
-  entry->decoder=(DecoderHandler *) ReadUYVYImage;
-  entry->encoder=(EncoderHandler *) WriteUYVYImage;
+  entry->decoder=(DecodeImageHandler *) ReadUYVYImage;
+  entry->encoder=(EncodeImageHandler *) WriteUYVYImage;
   entry->adjoin=MagickFalse;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
@@ -226,14 +237,15 @@ ModuleExport void RegisterUYVYImage(void)
   entry->module=ConstantString("UYVY");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("UYVY");
-  entry->decoder=(DecoderHandler *) ReadUYVYImage;
-  entry->encoder=(EncoderHandler *) WriteUYVYImage;
+  entry->decoder=(DecodeImageHandler *) ReadUYVYImage;
+  entry->encoder=(EncodeImageHandler *) WriteUYVYImage;
   entry->adjoin=MagickFalse;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->description=ConstantString("16bit/pixel interleaved YUV");
   entry->module=ConstantString("UYVY");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
