@@ -52,10 +52,11 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -341,22 +342,23 @@ static Image *ReadVICARImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterVICARImage method is:
 %
-%      RegisterVICARImage(void)
+%      unsigned long RegisterVICARImage(void)
 %
 */
-ModuleExport void RegisterVICARImage(void)
+ModuleExport unsigned long RegisterVICARImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("VICAR");
-  entry->decoder=(DecoderHandler *) ReadVICARImage;
-  entry->encoder=(EncoderHandler *) WriteVICARImage;
-  entry->magick=(MagickHandler *) IsVICAR;
+  entry->decoder=(DecodeImageHandler *) ReadVICARImage;
+  entry->encoder=(EncodeImageHandler *) WriteVICARImage;
+  entry->magick=(IsImageFormatHandler *) IsVICAR;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("VICAR rasterfile format");
   entry->module=ConstantString("VICAR");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
