@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -55,10 +55,11 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/montage.h"
+#include "magick/quantum-private.h"
 #include "magick/resize.h"
-#include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/utility.h"
 
 /*
@@ -92,14 +93,14 @@ static MagickBooleanType
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadVIDImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
 #define ClientName  "montage"
 
   char
-    **filelist;
+    **filelist,
+    *label;
 
   Image
     *image,
@@ -137,7 +138,7 @@ static Image *ReadVIDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
-  filelist=(char **) AcquireMagickMemory(sizeof(filelist));
+  filelist=(char **) AcquireMagickMemory(sizeof(*filelist));
   if (filelist == (char **) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   filelist[0]=(char *) image_info->filename;
@@ -162,13 +163,15 @@ static Image *ReadVIDImage(const ImageInfo *image_info,ExceptionInfo *exception)
       (void) LogMagickEvent(CoderEvent,GetMagickModule(),"name: %s",
         filelist[i]);
     (void) CopyMagickString(read_info->filename,filelist[i],MaxTextExtent);
-    filelist[i]=(char *) RelinquishMagickMemory(filelist[i]);
+    filelist[i]=DestroyString(filelist[i]);
     *read_info->magick='\0';
     next_image=ReadImage(read_info,exception);
     CatchException(exception);
     if (next_image == (Image *) NULL)
       break;
-    (void) SetImageProperty(next_image,"Label",DefaultTileLabel);
+    label=InterpretImageProperties(image_info,next_image,DefaultTileLabel);
+    (void) SetImageProperty(next_image,"label",label);
+    label=DestroyString(label);
     if (image_info->debug != MagickFalse)
       (void) LogMagickEvent(CoderEvent,GetMagickModule(),"geometry: %ldx%ld",
         next_image->columns,next_image->rows);
@@ -232,20 +235,21 @@ static Image *ReadVIDImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterVIDImage method is:
 %
-%      RegisterVIDImage(void)
+%      unsigned long RegisterVIDImage(void)
 %
 */
-ModuleExport void RegisterVIDImage(void)
+ModuleExport unsigned long RegisterVIDImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("VID");
-  entry->decoder=(DecoderHandler *) ReadVIDImage;
-  entry->encoder=(EncoderHandler *) WriteVIDImage;
+  entry->decoder=(DecodeImageHandler *) ReadVIDImage;
+  entry->encoder=(EncodeImageHandler *) WriteVIDImage;
   entry->description=ConstantString("Visual Image Directory");
   entry->module=ConstantString("VID");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -318,7 +322,7 @@ static MagickBooleanType WriteVIDImage(const ImageInfo *image_info,Image *image)
     Create the visual image directory.
   */
   for (p=image; p != (Image *) NULL; p=GetNextImageInList(p))
-    (void) SetImageProperty(p,"Label",DefaultTileLabel);
+    (void) SetImageProperty(p,"label",DefaultTileLabel);
   montage_info=CloneMontageInfo(image_info,(MontageInfo *) NULL);
   montage_image=MontageImageList(image_info,montage_info,image,
     &image->exception);
