@@ -54,9 +54,10 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -291,7 +292,7 @@ static Image *ReadVIFFImage(const ImageInfo *image_info,
     count=ReadBlob(image,512,(unsigned char *) viff_info.comment);
     viff_info.comment[511]='\0';
     if (strlen(viff_info.comment) > 4)
-      (void) SetImageProperty(image,"Comment",viff_info.comment);
+      (void) SetImageProperty(image,"comment",viff_info.comment);
     if ((viff_info.machine_dependency == VFF_DEP_DECORDER) ||
         (viff_info.machine_dependency == VFF_DEP_NSORDER))
       {
@@ -786,27 +787,28 @@ static Image *ReadVIFFImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterVIFFImage method is:
 %
-%      RegisterVIFFImage(void)
+%      unsigned long RegisterVIFFImage(void)
 %
 */
-ModuleExport void RegisterVIFFImage(void)
+ModuleExport unsigned long RegisterVIFFImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("VIFF");
-  entry->decoder=(DecoderHandler *) ReadVIFFImage;
-  entry->encoder=(EncoderHandler *) WriteVIFFImage;
-  entry->magick=(MagickHandler *) IsVIFF;
+  entry->decoder=(DecodeImageHandler *) ReadVIFFImage;
+  entry->encoder=(EncodeImageHandler *) WriteVIFFImage;
+  entry->magick=(IsImageFormatHandler *) IsVIFF;
   entry->description=ConstantString("Khoros Visualization image");
   entry->module=ConstantString("VIFF");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("XV");
-  entry->decoder=(DecoderHandler *) ReadVIFFImage;
-  entry->encoder=(EncoderHandler *) WriteVIFFImage;
+  entry->decoder=(DecodeImageHandler *) ReadVIFFImage;
+  entry->encoder=(EncodeImageHandler *) WriteVIFFImage;
   entry->description=ConstantString("Khoros Visualization image");
   entry->module=ConstantString("VIFF");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -990,7 +992,7 @@ static MagickBooleanType WriteVIFFImage(const ImageInfo *image_info,
     viff_info.version=3;
     viff_info.machine_dependency=VFF_DEP_IEEEORDER;  /* IEEE byte ordering */
     *viff_info.comment='\0';
-    value=GetImageProperty(image,"Comment");
+    value=GetImageProperty(image,"comment");
     if (value != (const char *) NULL)
       (void) CopyMagickString(viff_info.comment,value,MagickMin(strlen(value),511)+1);
     viff_info.rows=image->columns;
