@@ -17,7 +17,7 @@
 %                               January 2000                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -51,9 +51,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -89,7 +90,6 @@ static MagickBooleanType
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 
 static MagickBooleanType WBMPReadInteger(Image *image,unsigned long *value)
@@ -173,7 +173,12 @@ static Image *ReadWBMPImage(const ImageInfo *image_info,
   if ((image->columns == 0) || (image->rows == 0))
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   for (i=0; i < image->offset; i++)
-    (void) ReadBlobByte(image);
+    if (ReadBlobByte(image) == EOF)
+      {
+        ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
+          image->filename);
+        break;
+      }
   if (AllocateImageColormap(image,2) == MagickFalse)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   if (image_info->ping != MagickFalse)
@@ -181,6 +186,11 @@ static Image *ReadWBMPImage(const ImageInfo *image_info,
       CloseBlob(image);
       return(GetFirstImageInList(image));
     }
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   /*
     Convert bi-level image to pixel packets.
   */
@@ -244,21 +254,22 @@ static Image *ReadWBMPImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterWBMPImage method is:
 %
-%      RegisterWBMPImage(void)
+%      unsigned long RegisterWBMPImage(void)
 %
 */
-ModuleExport void RegisterWBMPImage(void)
+ModuleExport unsigned long RegisterWBMPImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("WBMP");
-  entry->decoder=(DecoderHandler *) ReadWBMPImage;
-  entry->encoder=(EncoderHandler *) WriteWBMPImage;
+  entry->decoder=(DecodeImageHandler *) ReadWBMPImage;
+  entry->encoder=(EncodeImageHandler *) WriteWBMPImage;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Wireless Bitmap (level 0) image");
   entry->module=ConstantString("WBMP");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -399,7 +410,7 @@ static MagickBooleanType WriteWBMPImage(const ImageInfo *image_info,
     byte=0;
     for (x=0; x < (long) image->columns; x++)
     {
-      if (PixelIntensity(p) >= (QuantumRange/2.0))
+      if (PixelIntensity(p) >= ((MagickRealType) QuantumRange/2.0))
         byte|=0x1 << (7-bit);
       bit++;
       if (bit == 8)
@@ -408,6 +419,7 @@ static MagickBooleanType WriteWBMPImage(const ImageInfo *image_info,
           bit=0;
           byte=0;
         }
+      p++;
     }
     if (bit != 0)
       (void) WriteBlobByte(image,byte);
