@@ -59,11 +59,12 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/paint.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/type.h"
-#include "magick/version.h"
+#include "magick/module.h"
 #include "wand/MagickWand.h"
 
 #if defined(HasWMF) || defined(HasWMFlite)
@@ -2161,28 +2162,28 @@ static float lite_font_stringwidth( wmfAPI* API, wmfFont* font, char* str)
 
 /* Mappings to Postscript fonts: family, normal, italic, bold, bolditalic */
 static wmfFontMap WMFFontMap[] = {
-  { "Courier",            "Courier",     "Courier-Oblique",   "Courier-Bold", "Courier-BoldOblique"   },   { "Helvetica",          "Helvetica",   "Helvetica-Oblique", "Helvetica-Bold", "Helvetica-BoldOblique" },   { "Modern",             "Courier",     "Courier-Oblique",   "Courier-Bold", "Courier-BoldOblique"   },   { "Monotype Corsiva",   "Courier",     "Courier-Oblique",   "Courier-Bold", "Courier-BoldOblique"   },
-  { "News Gothic",        "Helvetica",   "Helvetica-Oblique", "Helvetica-Bold", "Helvetica-BoldOblique" },
-  { "Symbol",             "Symbol",      "Symbol",            "Symbol", "Symbol"                },
-  { "System",             "Courier",     "Courier-Oblique",   "Courier-Bold", "Courier-BoldOblique"   },
-  { "Times",              "Times-Roman", "Times-Italic",      "Times-Bold", "Times-BoldItalic"      },
-  {  NULL,                NULL,           NULL,               NULL,  NULL                   }
+  { (char *) "Courier",            (char *) "Courier",     (char *) "Courier-Oblique",   (char *) "Courier-Bold", (char *) "Courier-BoldOblique"   },   { (char *) "Helvetica",          (char *) "Helvetica",   (char *) "Helvetica-Oblique", (char *) "Helvetica-Bold", (char *) "Helvetica-BoldOblique" },   { (char *) "Modern",             (char *) "Courier",     (char *) "Courier-Oblique",   (char *) "Courier-Bold", (char *) "Courier-BoldOblique"   },   { (char *) "Monotype Corsiva",   (char *) "Courier",     (char *) "Courier-Oblique",   (char *) "Courier-Bold", (char *) "Courier-BoldOblique"   },
+  { (char *) "News Gothic",        (char *) "Helvetica",   (char *) "Helvetica-Oblique", (char *) "Helvetica-Bold", (char *) "Helvetica-BoldOblique" },
+  { (char *) "Symbol",             (char *) "Symbol",      (char *) "Symbol",            (char *) "Symbol", (char *) "Symbol"                },
+  { (char *) "System",             (char *) "Courier",     (char *) "Courier-Oblique",   (char *) "Courier-Bold", (char *) "Courier-BoldOblique"   },
+  { (char *) "Times",              (char *) "Times-Roman", (char *) "Times-Italic",      (char *) "Times-Bold", (char *) "Times-BoldItalic"      },
+  {  (char *) NULL,                (char *) NULL,           (char *) NULL,               (char *) NULL,  (char *) NULL                   }
 };
 
 
 /* Mapping between base name and Ghostscript family name */
 static wmfMapping SubFontMap[] =
 {
-  { "Arial", "Helvetica", FT_ENCODING_NONE },
-  { "Courier", "Courier", FT_ENCODING_NONE },
-  { "Fixed", "Courier", FT_ENCODING_NONE },
-  { "Helvetica", "Helvetica", FT_ENCODING_NONE },
-  { "Sans", "Helvetica", FT_ENCODING_NONE },
-  { "Sym", "Symbol", FT_ENCODING_NONE },
-  { "Terminal", "Courier", FT_ENCODING_NONE },
-  { "Times", "Times", FT_ENCODING_NONE },
-  { "Wingdings", "Symbol", FT_ENCODING_NONE },
-  {  NULL, NULL, FT_ENCODING_NONE }
+  { (char *) "Arial", (char *) "Helvetica", FT_ENCODING_NONE },
+  { (char *) "Courier", (char *) "Courier", FT_ENCODING_NONE },
+  { (char *) "Fixed", (char *) "Courier", FT_ENCODING_NONE },
+  { (char *) "Helvetica", (char *) "Helvetica", FT_ENCODING_NONE },
+  { (char *) "Sans", (char *) "Helvetica", FT_ENCODING_NONE },
+  { (char *) "Sym", (char *) "Symbol", FT_ENCODING_NONE },
+  { (char *) "Terminal", (char *) "Courier", FT_ENCODING_NONE },
+  { (char *) "Times", (char *) "Times", FT_ENCODING_NONE },
+  { (char *) "Wingdings", (char *) "Symbol", FT_ENCODING_NONE },
+  { (char *)  NULL, (char *) NULL, FT_ENCODING_NONE }
 };
 
 static void lite_font_map( wmfAPI* API, wmfFont* font)
@@ -2776,10 +2777,10 @@ static Image *ReadWMFImage(const ImageInfo * image_info, ExceptionInfo * excepti
 %
 %  The format of the RegisterWMFImage method is:
 %
-%      RegisterWMFImage(void)
+%      unsigned long RegisterWMFImage(void)
 %
 */
-ModuleExport void RegisterWMFImage(void)
+ModuleExport unsigned long RegisterWMFImage(void)
 {
   MagickInfo
     *entry;
@@ -2802,6 +2803,7 @@ ModuleExport void RegisterWMFImage(void)
   entry->seekable_stream=MagickTrue;
   entry->module=ConstantString("WMF");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
