@@ -53,10 +53,11 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/resource_.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/shear.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/transform.h"
 #include "magick/utility.h"
 
@@ -1382,7 +1383,7 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
       Fix scene numbers.
     */
     for (p=image; p != (Image *) NULL; p=p->next)
-      p->scene=scene++;
+      p->scene=(unsigned long) scene++;
   }
   return(image);       
 }
@@ -1407,21 +1408,22 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterWPGImage method is:
 %
-%      RegisterWPGImage(void)
+%      unsigned long RegisterWPGImage(void)
 %
 */
-ModuleExport void RegisterWPGImage(void)
+ModuleExport unsigned long RegisterWPGImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("WPG");
-  entry->decoder=(DecoderHandler *) ReadWPGImage;
-  entry->magick=(MagickHandler *) IsWPG;
+  entry->decoder=(DecodeImageHandler *) ReadWPGImage;
+  entry->magick=(IsImageFormatHandler *) IsWPG;
   entry->description=AcquireString("Word Perfect Graphics");
   entry->module=ConstantString("WPG");
   entry->seekable_stream=MagickTrue;
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
