@@ -52,9 +52,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/option.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/utility.h"
 #include "magick/xwindow.h"
 #include "magick/xwindow-private.h"
@@ -101,6 +102,7 @@ static Image *ReadXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   XImportInfo
     ximage_info;
 
+  (void) exception;
   XGetImportInfo(&ximage_info);
   option=GetImageOption(image_info,"x:screen");
   if (option != (const char *) NULL)
@@ -129,22 +131,23 @@ static Image *ReadXImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterXImage method is:
 %
-%      RegisterXImage(void)
+%      unsigned long RegisterXImage(void)
 %
 */
-ModuleExport void RegisterXImage(void)
+ModuleExport unsigned long RegisterXImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("X");
 #if defined(HasX11)
-  entry->decoder=(DecoderHandler *) ReadXImage;
-  entry->encoder=(EncoderHandler *) WriteXImage;
+  entry->decoder=(DecodeImageHandler *) ReadXImage;
+  entry->encoder=(EncodeImageHandler *) WriteXImage;
 #endif
   entry->description=ConstantString("X Image");
   entry->module=ConstantString("X");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
