@@ -52,9 +52,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/utility.h"
 
 /*
@@ -268,9 +269,9 @@ static Image *ReadXBMImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Initialize colormap.
   */
-  image->colormap[0].red=QuantumRange;
-  image->colormap[0].green=QuantumRange;
-  image->colormap[0].blue=QuantumRange;
+  image->colormap[0].red=(Quantum) QuantumRange;
+  image->colormap[0].green=(Quantum) QuantumRange;
+  image->colormap[0].blue=(Quantum) QuantumRange;
   image->colormap[1].red=(Quantum) 0;
   image->colormap[1].green=(Quantum) 0;
   image->colormap[1].blue=(Quantum) 0;
@@ -403,23 +404,24 @@ static Image *ReadXBMImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterXBMImage method is:
 %
-%      RegisterXBMImage(void)
+%      unsigned long RegisterXBMImage(void)
 %
 */
-ModuleExport void RegisterXBMImage(void)
+ModuleExport unsigned long RegisterXBMImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("XBM");
-  entry->decoder=(DecoderHandler *) ReadXBMImage;
-  entry->encoder=(EncoderHandler *) WriteXBMImage;
-  entry->magick=(MagickHandler *) IsXBM;
+  entry->decoder=(DecodeImageHandler *) ReadXBMImage;
+  entry->encoder=(EncodeImageHandler *) WriteXBMImage;
+  entry->magick=(IsImageFormatHandler *) IsXBM;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString(
     "X Windows system bitmap (black and white)");
   entry->module=ConstantString("XBM");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
