@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -51,9 +51,10 @@
 #include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -77,9 +78,7 @@
 %
 %  A description of each parameter follows:
 %
-%    o image:  Method ReadXCImage returns a pointer to the image after
-%      creating it. A null image is returned if there is a memory shortage
-%      or if the image cannot be read.
+%    o image:  The image.
 %
 %    o image_info: The image info.
 %
@@ -142,6 +141,11 @@ static Image *ReadXCImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image->colormap[0]=image->background_color;
       color.index=0.0;
     }
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   for (y=0; y < (long) image->rows; y++)
   {
     q=GetImagePixels(image,0,y,image->columns,1);
@@ -186,22 +190,23 @@ static Image *ReadXCImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterXCImage method is:
 %
-%      RegisterXCImage(void)
+%      unsigned long RegisterXCImage(void)
 %
 */
-ModuleExport void RegisterXCImage(void)
+ModuleExport unsigned long RegisterXCImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("XC");
-  entry->decoder=(DecoderHandler *) ReadXCImage;
+  entry->decoder=(DecodeImageHandler *) ReadXCImage;
   entry->adjoin=MagickFalse;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->description=ConstantString("Constant image uniform color");
   entry->module=ConstantString("XC");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
