@@ -52,9 +52,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/quantize.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Typedef declarations.
@@ -307,7 +308,7 @@ static char *ReadBlobStringWithLongSize(Image *image,char *string,size_t max)
   offset=SeekBlob(image,(MagickOffsetType) (length-i),SEEK_CUR);
   if (offset < 0)
     (void) ThrowMagickException(&image->exception,GetMagickModule(),
-      CorruptImageError,"InvalidImageHeader","`%s'",image->filename);
+      CorruptImageError,"ImproperImageHeader","`%s'",image->filename);
   return(string);
 }
 
@@ -321,7 +322,8 @@ static int load_tile (Image* image, Image* tile_image, XCFDocInfo* inDocInfo,
   XCFPixelPacket *xcfdata, *xcfodata;
   unsigned char  *graydata;
 
-  xcfdata = xcfodata = (XCFPixelPacket *) AcquireMagickMemory(data_length);
+  xcfdata = xcfodata = (XCFPixelPacket *) AcquireQuantumMemory(data_length,
+    sizeof(*xcfdata));
   graydata = (unsigned char *)xcfdata;  /* used by gray and indexed */
   nmemb_read_successfully = ReadBlob(image, data_length, (unsigned char *) xcfdata);
   if (nmemb_read_successfully > (ssize_t) (tile_image->columns*tile_image->rows))
@@ -370,8 +372,8 @@ static int load_tile_rle (Image* image, Image* tile_image, XCFDocInfo* inDocInfo
 
   bpp = (int) inDocInfo->bpp;
 
-  xcfdata = xcfodata = (unsigned char *)
-    AcquireMagickMemory((size_t) data_length);
+  xcfdata = xcfodata = (unsigned char *) AcquireQuantumMemory((size_t)
+    data_length,sizeof(*xcfdata));
 
   nmemb_read_successfully = ReadBlob(image, (size_t) data_length, xcfdata);
 
@@ -600,10 +602,10 @@ static int load_level (Image* image, XCFDocInfo* inDocInfo, XCFLayerInfo*
             fail = MagickTrue;
           break;
         case COMPRESS_ZLIB:
-          ThrowBinaryException(CoderError,"ZipCompressionNotSupported",
+          ThrowBinaryException(CoderError,"ZipCompressNotSupported",
             image->filename)
         case COMPRESS_FRACTAL:
-          ThrowBinaryException(CoderError,"FractalCompressionNotSupported",
+          ThrowBinaryException(CoderError,"FractalCompressNotSupported",
             image->filename)
       }
 
@@ -923,12 +925,15 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   register long
     i;
 
-  unsigned long
-    image_type;
+  size_t
+    length;
 
   ssize_t
     count;
 
+  unsigned long
+    image_type;
+
   XCFDocInfo
     doc_info;
 
@@ -974,8 +979,13 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if (image_type == GIMP_GRAY)
       image->colorspace=GRAYColorspace;
     else
-      if ( image_type == GIMP_INDEXED )
+      if (image_type == GIMP_INDEXED)
         ThrowReaderException(CoderError,"ColormapTypeNotSupported");
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   (void) SetImageBackgroundColor(image);
   /*
     Read properties.
@@ -1040,7 +1050,7 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
         (doc_info.compression != COMPRESS_RLE) &&
         (doc_info.compression != COMPRESS_ZLIB) &&
         (doc_info.compression != COMPRESS_FRACTAL))
-          ThrowReaderException(CorruptImageError,"CompressionNotValid");
+          ThrowReaderException(CorruptImageError,"UnrecognizedImageCompression");
       }
       break;
 
@@ -1069,9 +1079,9 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
 
         /* BOGUS: we don't write these yet because we aren't
-        //      reading them properly yet :(
-        //image->x_resolution = xres;
-        //image->y_resolution = yres;
+              reading them properly yet :(
+              image->x_resolution = xres;
+              image->y_resolution = yres;
         */
       }
       break;
@@ -1181,6 +1191,12 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
         foundAllLayers = MagickTrue;
       else
         number_layers++;
+      if (EOFBlob(image) != MagickFalse)
+        {
+          ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
+            image->filename);
+          break;
+        }
     } while (foundAllLayers  == MagickFalse);
     offset=SeekBlob(image, oldPos, SEEK_SET); /* restore the position! */
     if (offset < 0)
@@ -1188,8 +1204,9 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
 
     /* allocate our array of layer info blocks */
-    layer_info=(XCFLayerInfo *)
-      AcquireMagickMemory(number_layers*sizeof(XCFLayerInfo));
+    length=(size_t) number_layers;
+    layer_info=(XCFLayerInfo *) AcquireQuantumMemory(length,
+      sizeof(*layer_info));
     if (layer_info == (XCFLayerInfo *) NULL)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     (void) ResetMagickMemory(layer_info,0,number_layers*sizeof(XCFLayerInfo));
@@ -1391,21 +1408,22 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterXCFImage method is:
 %
-%      RegisterXCFImage(void)
+%      unsigned long RegisterXCFImage(void)
 %
 */
-ModuleExport void RegisterXCFImage(void)
+ModuleExport unsigned long RegisterXCFImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("XCF");
-  entry->decoder=(DecoderHandler *) ReadXCFImage;
-  entry->magick=(MagickHandler *) IsXCF;
+  entry->decoder=(DecodeImageHandler *) ReadXCFImage;
+  entry->magick=(IsImageFormatHandler *) IsXCF;
   entry->description=ConstantString("GIMP image");
   entry->module=ConstantString("XCF");
   entry->seekable_stream=MagickTrue;
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
