@@ -56,12 +56,13 @@
 #include "magick/monitor.h"
 #include "magick/pixel-private.h"
 #include "magick/quantize.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/resize.h"
 #include "magick/resource_.h"
 #include "magick/splay-tree.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/threshold.h"
 #include "magick/utility.h"
 
@@ -444,37 +445,38 @@ static Image *ReadXPMImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterXPMImage method is:
 %
-%      RegisterXPMImage(void)
+%      unsigned long RegisterXPMImage(void)
 %
 */
-ModuleExport void RegisterXPMImage(void)
+ModuleExport unsigned long RegisterXPMImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("PICON");
-  entry->decoder=(DecoderHandler *) ReadXPMImage;
-  entry->encoder=(EncoderHandler *) WritePICONImage;
+  entry->decoder=(DecodeImageHandler *) ReadXPMImage;
+  entry->encoder=(EncodeImageHandler *) WritePICONImage;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Personal Icon");
   entry->module=ConstantString("XPM");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PM");
-  entry->decoder=(DecoderHandler *) ReadXPMImage;
-  entry->encoder=(EncoderHandler *) WriteXPMImage;
+  entry->decoder=(DecodeImageHandler *) ReadXPMImage;
+  entry->encoder=(EncodeImageHandler *) WriteXPMImage;
   entry->adjoin=MagickFalse;
   entry->stealth=MagickTrue;
   entry->description=ConstantString("X Windows system pixmap (color)");
   entry->module=ConstantString("XPM");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("XPM");
-  entry->decoder=(DecoderHandler *) ReadXPMImage;
-  entry->encoder=(EncoderHandler *) WriteXPMImage;
-  entry->magick=(MagickHandler *) IsXPM;
+  entry->decoder=(DecodeImageHandler *) ReadXPMImage;
+  entry->encoder=(EncodeImageHandler *) WriteXPMImage;
+  entry->magick=(IsImageFormatHandler *) IsXPM;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("X Windows system pixmap (color)");
   entry->module=ConstantString("XPM");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -672,7 +674,7 @@ static MagickBooleanType WritePICONImage(const ImageInfo *image_info,
               break;
             for (x=0; x < (long) picon->columns; x++)
             {
-              if (q->opacity == TransparentOpacity)
+              if (q->opacity == (Quantum) TransparentOpacity)
                 transparent=MagickTrue;
               else
                 q->opacity=OpaqueOpacity;
@@ -700,7 +702,7 @@ static MagickBooleanType WritePICONImage(const ImageInfo *image_info,
         indexes=GetIndexes(picon);
         for (x=0; x < (long) picon->columns; x++)
         {
-          if (q->opacity == TransparentOpacity)
+          if (q->opacity == (Quantum) TransparentOpacity)
             indexes[x]=(IndexPacket) picon->colors;
           q++;
         }
@@ -907,9 +909,9 @@ static MagickBooleanType WriteXPMImage(const ImageInfo *image_info,Image *image)
                 opacity=i;
                 continue;
               }
-            alpha=TransparentOpacity-(MagickRealType)
+            alpha=(Quantum) TransparentOpacity-(MagickRealType)
               image->colormap[i].opacity;
-            beta=TransparentOpacity-(MagickRealType)
+            beta=(Quantum) TransparentOpacity-(MagickRealType)
               image->colormap[opacity].opacity;
             if (alpha < beta)
               opacity=i;
@@ -925,9 +927,9 @@ static MagickBooleanType WriteXPMImage(const ImageInfo *image_info,Image *image)
                     opacity=i;
                     continue;
                   }
-                alpha=TransparentOpacity-(MagickRealType)
+                alpha=(Quantum) TransparentOpacity-(MagickRealType)
                   image->colormap[i].opacity;
-                beta=TransparentOpacity-(MagickRealType)
+                beta=(Quantum) TransparentOpacity-(MagickRealType)
                   image->colormap[opacity].opacity;
                 if (alpha < beta)
                   opacity=i;
