@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -53,9 +53,10 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #if defined(HasX11)
 #include "magick/xwindow-private.h"
 #if !defined(vms)
@@ -140,10 +141,13 @@ static MagickBooleanType IsXWD(const unsigned char *magick,const size_t length)
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
+
 static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
+#define CheckOverflowException(length,width,height) \
+   (((height) != 0) && ((length)/((size_t) height) != ((size_t) width)))
+
   char
     *comment;
 
@@ -235,16 +239,15 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if (header.header_size < sz_XWDheader)
     ThrowReaderException(CorruptImageError,"CorruptImage");
   length=(size_t) header.header_size-sz_XWDheader;
-  comment=(char *) AcquireMagickMemory(length+MaxTextExtent);
+  comment=(char *) AcquireQuantumMemory(length+1,sizeof(*comment));
   if (comment == (char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   count=ReadBlob(image,length,(unsigned char *) comment);
   comment[length]='\0';
-  (void) SetImageProperty(image,"Comment",comment);
-  comment=(char *) RelinquishMagickMemory(comment);
+  (void) SetImageProperty(image,"comment",comment);
+  comment=DestroyString(comment);
   if (count == 0)
-    ThrowReaderException(CorruptImageError,
-      "UnableToReadWindowNameFromDumpFile");
+    ThrowReaderException(CorruptImageError,"UnexpectedEndOfFile");
   /*
     Initialize the X image.
   */
@@ -266,9 +269,14 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   ximage->red_mask=header.red_mask;
   ximage->green_mask=header.green_mask;
   ximage->blue_mask=header.blue_mask;
+  if ((ximage->depth < 0) || (ximage->width < 0) || (ximage->height < 0) ||
+      (ximage->bitmap_pad < 0) || (ximage->bytes_per_line < 0))
+    ThrowReaderException(CorruptImageError,"ImproperImageHeader");
+  if ((ximage->bits_per_pixel > 32) || (ximage->bitmap_unit > 32))
+    ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   x_status=XInitImage(ximage);
   if (x_status == 0)
-    ThrowReaderException(CorruptImageError,"UnableToReadImageHeader");
+    ThrowReaderException(CorruptImageError,"UnexpectedEndOfFile");
   /*
     Read colormap.
   */
@@ -278,16 +286,15 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
       XWDColor
         color;
 
-      colors=(XColor *)
-        AcquireMagickMemory((size_t) header.ncolors*sizeof(*colors));
+      length=(size_t) header.ncolors;
+      colors=(XColor *) AcquireQuantumMemory(length,sizeof(*colors));
       if (colors == (XColor *) NULL)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
       for (i=0; i < (long) header.ncolors; i++)
       {
         count=ReadBlob(image,sz_XWDColor,(unsigned char *) &color);
         if (count == 0)
-          ThrowReaderException(CorruptImageError,
-            "UnableToReadColormapFromDumpFile");
+          ThrowReaderException(CorruptImageError,"UnexpectedEndOfFile");
         colors[i].pixel=color.pixel;
         colors[i].red=color.red;
         colors[i].green=color.green;
@@ -303,23 +310,32 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
         {
           MSBOrderLong((unsigned char *) &colors[i].pixel,
             sizeof(colors[i].pixel));
-          MSBOrderShort((unsigned char *) &colors[i].red,
-            3*sizeof(colors[i].red));
+          MSBOrderShort((unsigned char *) &colors[i].red,3*
+            sizeof(colors[i].red));
         }
     }
   /*
     Allocate the pixel buffer.
   */
-  if (ximage->format == ZPixmap)
-    length=(size_t) ximage->bytes_per_line*ximage->height;
-  else
-    length=(size_t) ximage->bytes_per_line*ximage->height*ximage->depth;
-  ximage->data=(char *) AcquireMagickMemory(length);
+  length=(size_t) ximage->bytes_per_line*ximage->height;
+  if (CheckOverflowException(length,ximage->bytes_per_line,ximage->height))
+    ThrowReaderException(CorruptImageError,"ImproperImageHeader");
+  if (ximage->format != ZPixmap)
+    {
+      size_t
+        extent;
+
+      extent=length;
+      length*=ximage->depth;
+      if (CheckOverflowException(length,extent,ximage->depth))
+        ThrowReaderException(CorruptImageError,"ImproperImageHeader");
+    }
+  ximage->data=(char *) AcquireQuantumMemory(length,sizeof(*ximage->data));
   if (ximage->data == (char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   count=ReadBlob(image,length,(unsigned char *) ximage->data);
   if (count == 0)
-    ThrowReaderException(CorruptImageError,"UnableToReadPixmapFromDumpFile");
+    ThrowReaderException(CorruptImageError,"UnexpectedEndOfFile");
   /*
     Convert image to MIFF format.
   */
@@ -330,6 +346,11 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
     image->storage_class=DirectClass;
   else
     image->storage_class=PseudoClass;
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   image->colors=header.ncolors;
   if (image_info->ping == MagickFalse)
     switch (image->storage_class)
@@ -385,11 +406,11 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
             {
               pixel=XGetPixel(ximage,(int) x,(int) y);
               index=(IndexPacket) ((pixel >> red_shift) & red_mask);
-              q->red=ScaleShortToQuantum(colors[index].red);
+              q->red=ScaleShortToQuantum(colors[(long) index].red);
               index=(IndexPacket) ((pixel >> green_shift) & green_mask);
-              q->green=ScaleShortToQuantum(colors[index].green);
+              q->green=ScaleShortToQuantum(colors[(long) index].green);
               index=(IndexPacket) ((pixel >> blue_shift) & blue_mask);
-              q->blue=ScaleShortToQuantum(colors[index].blue);
+              q->blue=ScaleShortToQuantum(colors[(long) index].blue);
               q++;
             }
             if (SyncImagePixels(image) == MagickFalse)
@@ -462,7 +483,7 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
             index=ConstrainColormapIndex(image,XGetPixel(ximage,(int) x,
               (int) y));
             indexes[x]=index;
-            *q++=image->colormap[index];
+            *q++=image->colormap[(long) index];
           }
           if (SyncImagePixels(image) == MagickFalse)
             break;
@@ -484,7 +505,7 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   */
   if (header.ncolors != 0)
     colors=(XColor *) RelinquishMagickMemory(colors);
-  ximage->data=(char *) RelinquishMagickMemory(ximage->data);
+  ximage->data=DestroyString(ximage->data);
   ximage=(XImage *) RelinquishMagickMemory(ximage);
   if (EOFBlob(image) != MagickFalse)
     ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
@@ -514,24 +535,25 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterXWDImage method is:
 %
-%      RegisterXWDImage(void)
+%      unsigned long RegisterXWDImage(void)
 %
 */
-ModuleExport void RegisterXWDImage(void)
+ModuleExport unsigned long RegisterXWDImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("XWD");
 #if defined(HasX11)
-  entry->decoder=(DecoderHandler *) ReadXWDImage;
-  entry->encoder=(EncoderHandler *) WriteXWDImage;
+  entry->decoder=(DecodeImageHandler *) ReadXWDImage;
+  entry->encoder=(EncodeImageHandler *) WriteXWDImage;
 #endif
-  entry->magick=(MagickHandler *) IsXWD;
+  entry->magick=(IsImageFormatHandler *) IsXWD;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("X Windows system window dump (color)");
   entry->module=ConstantString("XWD");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -583,7 +605,6 @@ ModuleExport void UnregisterXWDImage(void)
 %
 %    o image:  The image.
 %
-%
 */
 static MagickBooleanType WriteXWDImage(const ImageInfo *image_info,Image *image)
 {
@@ -644,7 +665,7 @@ static MagickBooleanType WriteXWDImage(const ImageInfo *image_info,Image *image)
     Initialize XWD file header.
   */
   xwd_info.header_size=(CARD32) sz_XWDheader;
-  value=GetImageProperty(image,"Comment");
+  value=GetImageProperty(image,"comment");
   if (value != (const char *) NULL)
     xwd_info.header_size+=(CARD32) strlen(value);
   xwd_info.header_size++;
@@ -702,8 +723,8 @@ static MagickBooleanType WriteXWDImage(const ImageInfo *image_info,Image *image)
       /*
         Dump colormap to file.
       */
-      colors=(XColor *)
-        AcquireMagickMemory((size_t) image->colors*sizeof(*colors));
+      colors=(XColor *) AcquireQuantumMemory((size_t) image->colors,
+        sizeof(*colors));
       if (colors == (XColor *) NULL)
         ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
       for (i=0; i < (long) image->colors; i++)
@@ -739,7 +760,7 @@ static MagickBooleanType WriteXWDImage(const ImageInfo *image_info,Image *image)
   length=3*bytes_per_line;
   if (image->storage_class == PseudoClass)
     length=bytes_per_line;
-  pixels=(unsigned char *) AcquireMagickMemory(length);
+  pixels=(unsigned char *) AcquireQuantumMemory(length,sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
   (void) ResetMagickMemory(pixels,0,length);
