@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -52,11 +52,12 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/utility.h"
 
 /*
@@ -127,7 +128,6 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
     *pixels;
 
   unsigned long
-    depth,
     width;
 
   assert(image_info != (const ImageInfo *) NULL);
@@ -157,15 +157,14 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
   /*
     Allocate memory for a pixels.
   */
-  depth=GetImageQuantumDepth(image,MagickTrue);
-  packet_size=(size_t) (3*depth/8);
+  packet_size=(size_t) ((3*image->depth+7)/8);
   if (LocaleCompare(image_info->magick,"YCbCrA") == 0)
     {
-      packet_size+=depth/8;
+      packet_size+=(image->depth+7)/8;
       image->matte=MagickTrue;
     }
-  pixels=(unsigned char *)
-    AcquireMagickMemory(packet_size*image->extract_info.width);
+  pixels=(unsigned char *) AcquireQuantumMemory(image->extract_info.width,
+    packet_size*sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   if (image_info->number_scenes != 0)
@@ -189,6 +188,11 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
+    if (SetImageExtent(image,0,0) == MagickFalse)
+      {
+        InheritException(exception,&image->exception);
+        return(DestroyImageList(image));
+      }
     switch (image_info->interlace)
     {
       case NoInterlace:
@@ -235,7 +239,7 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
         /*
           Line interlacing:  YYY...CbCbCb...CrCrCr...YYY...CbCbCb...CrCrCr...
         */
-        packet_size=(size_t) (image->depth > 8 ? 2 : 1);
+        packet_size=(size_t) ((image->depth+7)/8);
         for (y=0; y < image->extract_info.y; y++)
           count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
         for (y=0; y < (long) image->rows; y++)
@@ -297,7 +301,7 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
                 return((Image *) NULL);
               }
           }
-        packet_size=(size_t) (image->depth > 8 ? 2 : 1);
+        packet_size=(size_t) ((image->depth+7)/8);
         for (y=0; y < image->extract_info.y; y++)
           count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
         i=0;
@@ -515,28 +519,29 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterYCBCRImage method is:
 %
-%      RegisterYCBCRImage(void)
+%      unsigned long RegisterYCBCRImage(void)
 %
 */
-ModuleExport void RegisterYCBCRImage(void)
+ModuleExport unsigned long RegisterYCBCRImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("YCbCr");
-  entry->decoder=(DecoderHandler *) ReadYCBCRImage;
-  entry->encoder=(EncoderHandler *) WriteYCBCRImage;
+  entry->decoder=(DecodeImageHandler *) ReadYCBCRImage;
+  entry->encoder=(EncodeImageHandler *) WriteYCBCRImage;
   entry->raw=MagickTrue;
   entry->description=ConstantString("Raw Y, Cb, and Cr samples");
   entry->module=ConstantString("YCbCr");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("YCbCrA");
-  entry->decoder=(DecoderHandler *) ReadYCBCRImage;
-  entry->encoder=(EncoderHandler *) WriteYCBCRImage;
+  entry->decoder=(DecodeImageHandler *) ReadYCBCRImage;
+  entry->encoder=(EncodeImageHandler *) WriteYCBCRImage;
   entry->raw=MagickTrue;
   entry->description=ConstantString("Raw Y, Cb, Cr, and opacity samples");
   entry->module=ConstantString("YCbCr");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -615,9 +620,6 @@ static MagickBooleanType WriteYCBCRImage(const ImageInfo *image_info,
   unsigned char
     *pixels;
 
-  unsigned long
-    depth;
-
   /*
     Allocate memory for pixels.
   */
@@ -627,11 +629,10 @@ static MagickBooleanType WriteYCBCRImage(const ImageInfo *image_info,
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  depth=GetImageQuantumDepth(image,MagickTrue);
-  packet_size=(size_t) (3*depth/8);
+  packet_size=(size_t) ((3*image->depth+7)/8);
   if (LocaleCompare(image_info->magick,"YCbCrA") == 0)
-    packet_size+=depth/8;
-  pixels=(unsigned char *) AcquireMagickMemory(packet_size*image->columns*
+    packet_size+=(image->depth+7)/8;
+  pixels=(unsigned char *) AcquireQuantumMemory(image->columns,packet_size*
     sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
@@ -697,7 +698,7 @@ static MagickBooleanType WriteYCBCRImage(const ImageInfo *image_info,
         /*
           Line interlacing:  YYY...CbCbCb...CrCrCr...YYY...CbCbCb...CrCrCr...
         */
-        packet_size=depth/8;
+        packet_size=(image->depth+7)/8;
         for (y=0; y < (long) image->rows; y++)
         {
           p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
@@ -732,7 +733,7 @@ static MagickBooleanType WriteYCBCRImage(const ImageInfo *image_info,
         /*
           Plane interlacing:  YYYYYY...CbCbCbCbCbCb...CrCrCrCrCrCr...
         */
-        packet_size=depth/8;
+        packet_size=(image->depth+7)/8;
         if (image_info->interlace == PartitionInterlace)
           {
             AppendImageFormat("Y",image->filename);
