@@ -54,9 +54,10 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/resize.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/utility.h"
 
 /*
@@ -444,22 +445,23 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterYUVImage method is:
 %
-%      RegisterYUVImage(void)
+%      unsigned long RegisterYUVImage(void)
 %
 */
-ModuleExport void RegisterYUVImage(void)
+ModuleExport unsigned long RegisterYUVImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("YUV");
-  entry->decoder=(DecoderHandler *) ReadYUVImage;
-  entry->encoder=(EncoderHandler *) WriteYUVImage;
+  entry->decoder=(DecodeImageHandler *) ReadYUVImage;
+  entry->encoder=(EncodeImageHandler *) WriteYUVImage;
   entry->adjoin=MagickFalse;
   entry->raw=MagickTrue;
   entry->description=ConstantString("CCIR 601 4:1:1 or 4:2:2");
   entry->module=ConstantString("YUV");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
