@@ -60,6 +60,7 @@
 #include "magick/image-private.h"
 #include "magick/log.h"
 #include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/property.h"
 #include "magick/resource_.h"
 #include "magick/statistic.h"
@@ -498,8 +499,7 @@ static int GetOneCharacter(const unsigned char *text,size_t *length)
   return((int) c);
 }
 
-static unsigned long *EncodeSJIS(const Image *image,const char *text,
-  size_t *count)
+static unsigned long *EncodeSJIS(const char *text,size_t *count)
 {
   int
     c;
@@ -519,11 +519,13 @@ static unsigned long *EncodeSJIS(const Image *image,const char *text,
   *count=0;
   if ((text == (char *) NULL) || (*text == '\0'))
     return((unsigned long *) NULL);
-  length=strlen(text)+MaxTextExtent;
-  encoding=(unsigned long *) AcquireMagickMemory(length*sizeof(*encoding));
+  length=strlen(text);
+  if (~length < MaxTextExtent)
+    return((unsigned long *) NULL);
+  length+=MaxTextExtent;
+  encoding=(unsigned long *) AcquireQuantumMemory(length,sizeof(*encoding));
   if (encoding == (unsigned long *) NULL)
-    ThrowMagickFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
-      image->filename);
+    return((unsigned long *) NULL);
   q=encoding;
   for (p=text; *p != '\0'; p+=length)
   {
@@ -561,19 +563,16 @@ static unsigned long *EncodeSJIS(const Image *image,const char *text,
 %
 %  The format of the EncodeText function is:
 %
-%      encoding=EncodeText(const Image *image,const char *text,size_t count)
+%      encoding=EncodeText(const char *text,size_t count)
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
-%
 %    o text: The text.
 %
 %    o count: return the number of characters generated by the encoding.
 %
 */
-static unsigned long *EncodeText(const Image *image,const char *text,
-  size_t *count)
+static unsigned long *EncodeText(const char *text,size_t *count)
 {
   register const char
     *p;
@@ -581,17 +580,22 @@ static unsigned long *EncodeText(const Image *image,const char *text,
   register unsigned long
     *q;
 
+  size_t
+    length;
+
   unsigned long
     *encoding;
 
   *count=0;
   if ((text == (char *) NULL) || (*text == '\0'))
     return((unsigned long *) NULL);
-  encoding=(unsigned long *)
-    AcquireMagickMemory((strlen(text)+MaxTextExtent)*sizeof(*encoding));
+  length=strlen(text);
+  if (~length < MaxTextExtent)
+    return((unsigned long *) NULL);
+  length+=MaxTextExtent;
+  encoding=(unsigned long *) AcquireQuantumMemory(length,sizeof(*encoding));
   if (encoding == (unsigned long *) NULL)
-    ThrowMagickFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
-      image->filename);
+    return((unsigned long *) NULL);
   q=encoding;
   for (p=text; *p != '\0'; p++)
     *q++=(unsigned char) *p;
@@ -618,8 +622,7 @@ static unsigned long *EncodeText(const Image *image,const char *text,
 %
 %  The format of the EncodeUnicode function is:
 %
-%      unsigned short *EncodeUnicode(const Image *image,
-%        const unsigned char *text,size_t count)
+%      unsigned short *EncodeUnicode(const unsigned char *text,size_t count)
 %
 %  A description of each parameter follows:
 %
@@ -683,8 +686,7 @@ static long GetUnicodeCharacter(const unsigned char *text,size_t *length)
   return((long) c);
 }
 
-static unsigned long *EncodeUnicode(const Image *image,const char *text,
-  size_t *count)
+static unsigned long *EncodeUnicode(const char *text,size_t *count)
 {
   long
     c;
@@ -704,11 +706,13 @@ static unsigned long *EncodeUnicode(const Image *image,const char *text,
   *count=0;
   if ((text == (char *) NULL) || (*text == '\0'))
     return((unsigned long *) NULL);
-  length=strlen(text)+MaxTextExtent;
-  unicode=(unsigned long *) AcquireMagickMemory(length*sizeof(*unicode));
+  length=strlen(text);
+  if (~length < MaxTextExtent)
+    return((unsigned long *) NULL);
+  length+=MaxTextExtent;
+  unicode=(unsigned long *) AcquireQuantumMemory(length,sizeof(*unicode));
   if (unicode == (unsigned long *) NULL)
-    ThrowMagickFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
-      image->filename);
+    return((unsigned long *) NULL);
   q=unicode;
   for (p=text; *p != '\0'; p+=length)
   {
@@ -1282,7 +1286,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
       image->filename);
   args.flags=FT_OPEN_PATHNAME;
   if (draw_info->font == (char *) NULL)
-    args.pathname="helvetica";
+    args.pathname=(char *) "helvetica";
   else
     if (*draw_info->font != '@')
       args.pathname=draw_info->font;
@@ -1293,7 +1297,9 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
   if (status != 0)
     {
       (void) FT_Done_FreeType(library);
-      ThrowBinaryException(TypeError,"UnableToReadFont",draw_info->font);
+      (void) ThrowMagickException(&image->exception,GetMagickModule(),
+        TypeError,"UnableToReadFont","`%s'",draw_info->font);
+      return(RenderPostscript(image,draw_info,offset,metrics));
     }
   if ((draw_info->metrics != (char *) NULL) &&
       (IsAccessible(draw_info->metrics) != MagickFalse))
@@ -1390,12 +1396,12 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
   {
     case ft_encoding_sjis:
     {
-      text=EncodeSJIS(image,draw_info->text,&length);
+      text=EncodeSJIS(draw_info->text,&length);
       break;
     }
     case ft_encoding_unicode:
     {
-      text=EncodeUnicode(image,draw_info->text,&length);
+      text=EncodeUnicode(draw_info->text,&length);
       break;
     }
     default:
@@ -1404,22 +1410,22 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
         {
           if (LocaleCompare(draw_info->encoding,"SJIS") == 0)
             {
-              text=EncodeSJIS(image,draw_info->text,&length);
+              text=EncodeSJIS(draw_info->text,&length);
               break;
             }
           if ((LocaleCompare(draw_info->encoding,"UTF-8") == 0) ||
               (encoding_type != ft_encoding_none))
             {
-              text=EncodeUnicode(image,draw_info->text,&length);
+              text=EncodeUnicode(draw_info->text,&length);
               break;
             }
         }
       if (encoding_type == ft_encoding_unicode)
         {
-          text=EncodeUnicode(image,draw_info->text,&length);
+          text=EncodeUnicode(draw_info->text,&length);
           break;
         }
-      text=EncodeText(image,draw_info->text,&length);
+      text=EncodeText(draw_info->text,&length);
       break;
     }
   }
@@ -1465,9 +1471,9 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
   (void) CloneString(&annotate_info->primitive,"path '");
   if (draw_info->render != MagickFalse)
     {
-  	  if (image->storage_class != DirectClass)
+      if (image->storage_class != DirectClass)
         (void) SetImageStorageClass(image,DirectClass);
-  	  if (image->matte == MagickFalse)
+      if (image->matte == MagickFalse)
         (void) SetImageOpacity(image,OpaqueOpacity);
     }
   point.x=0.0;
@@ -1476,18 +1482,19 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
   {
     glyph.id=FT_Get_Char_Index(face,text[i]);
     if (glyph.id == 0)
-      glyph.id=text[i];
+      glyph.id=FT_Get_Char_Index(face,'?');
     if ((glyph.id != 0) && (last_glyph.id != 0) && FT_HAS_KERNING(face))
       {
         FT_Vector
           kerning;
 
-        (void) FT_Get_Kerning(face,last_glyph.id,glyph.id,ft_kerning_default,
+        status=FT_Get_Kerning(face,last_glyph.id,glyph.id,ft_kerning_default,
           &kerning);
-        origin.x+=kerning.x;
+        if (status == 0)
+          origin.x+=kerning.x;
       }
     glyph.origin=origin;
-    status=FT_Load_Glyph(face,glyph.id,FT_LOAD_NO_BITMAP);
+    status=FT_Load_Glyph(face,glyph.id,flags);
     if (status != 0)
       continue;
     status=FT_Get_Glyph(face->glyph,&glyph.image);
@@ -1552,7 +1559,8 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
               p+=bitmap->bitmap.width;
               continue;
             }
-          q=GetCacheView(image_view,x_offset,y_offset,bitmap->bitmap.width,1);
+          q=GetCacheViewPixels(image_view,x_offset,y_offset,
+            bitmap->bitmap.width,1);
           active=q != (PixelPacket *) NULL ? MagickTrue : MagickFalse;
           for (x=0; x < (long) bitmap->bitmap.width; x++)
           {
@@ -1568,7 +1576,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
             if (draw_info->text_antialias == MagickFalse)
               fill_opacity=fill_opacity > 0.5 ? 1.0 : 0.0;
             if (active == MagickFalse)
-              q=GetCacheView(image_view,x_offset,y_offset,1,1);
+              q=GetCacheViewPixels(image_view,x_offset,y_offset,1,1);
             if (q == (PixelPacket *) NULL)
               {
                 p++;
@@ -1598,6 +1606,8 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
       FT_Done_Glyph(last_glyph.image);
     last_glyph=glyph;
   }
+  if (last_glyph.id != 0)
+    FT_Done_Glyph(last_glyph.image);
   if ((draw_info->stroke.opacity != TransparentOpacity) ||
       (draw_info->stroke_pattern != (Image *) NULL))
     {
@@ -1612,14 +1622,12 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
           (void) DrawImage(image,annotate_info);
         }
       }
-  if (glyph.id != 0)
-    FT_Done_Glyph(glyph.image);
   /*
     Determine font metrics.
   */
-  glyph.id=0;
+  glyph.id=FT_Get_Char_Index(face,'_');
   glyph.origin=origin;
-  status=FT_Load_Glyph(face,glyph.id,FT_LOAD_NO_BITMAP);
+  status=FT_Load_Glyph(face,glyph.id,flags);
   if (status == 0)
     {
       status=FT_Get_Glyph(face->glyph,&glyph.image);
@@ -1638,6 +1646,8 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
                 metrics->width=bitmap->left;
             }
         }
+      if (glyph.id != 0)
+        FT_Done_Glyph(glyph.image);
     }
   metrics->width-=metrics->bounds.x1/64.0;
   metrics->bounds.x1/=64.0;
@@ -1923,7 +1933,7 @@ static MagickBooleanType RenderPostscript(Image *image,
       annotate_view=OpenCacheView(annotate_image);
       for (y=0; y < (long) annotate_image->rows; y++)
       {
-        q=GetCacheView(annotate_view,0,y,annotate_image->columns,1);
+        q=GetCacheViewPixels(annotate_view,0,y,annotate_image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
         for (x=0; x < (long) annotate_image->columns; x++)
@@ -1978,7 +1988,6 @@ static MagickBooleanType RenderPostscript(Image *image,
 %
 %    o metrics: bounding box of text.
 %
-%
 */
 #if defined(HasX11)
 static MagickBooleanType RenderX11(Image *image,const DrawInfo *draw_info,
@@ -2025,8 +2034,11 @@ static MagickBooleanType RenderX11(Image *image,const DrawInfo *draw_info,
       */
       display=XOpenDisplay(draw_info->server_name);
       if (display == (Display *) NULL)
-        ThrowBinaryException(XServerError,"UnableToOpenXServer",
-          draw_info->server_name);
+        {
+          ThrowXWindowException(XServerError,"UnableToOpenXServer",
+            draw_info->server_name);
+          return(MagickFalse);
+        }
       /*
         Get user defaults from X resource database.
       */
@@ -2040,15 +2052,21 @@ static MagickBooleanType RenderX11(Image *image,const DrawInfo *draw_info,
       resource_info.foreground_color=AcquireString("#000000000000");
       map_info=XAllocStandardColormap();
       if (map_info == (XStandardColormap *) NULL)
-        ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
-          image->filename);
+        {
+          ThrowXWindowException(ResourceLimitError,"MemoryAllocationFailed",
+            image->filename);
+          return(MagickFalse);
+        }
       /*
         Initialize visual info.
       */
       visual_info=XBestVisualInfo(display,map_info,&resource_info);
       if (visual_info == (XVisualInfo *) NULL)
-        ThrowBinaryException(XServerError,"UnableToGetVisual",
-          image->filename);
+        {
+          ThrowXWindowException(XServerError,"UnableToGetVisual",
+            image->filename);
+          return(MagickFalse);
+        }
       map_info->colormap=(Colormap) NULL;
       pixel.pixels=(unsigned long *) NULL;
       /*
@@ -2064,14 +2082,20 @@ static MagickBooleanType RenderX11(Image *image,const DrawInfo *draw_info,
       */
       font_info=XBestFont(display,&resource_info,MagickFalse);
       if (font_info == (XFontStruct *) NULL)
-        ThrowBinaryException(XServerError,"UnableToLoadFont",draw_info->font);
+        {
+          ThrowXWindowException(XServerError,"UnableToLoadFont",
+            draw_info->font);
+          return(MagickFalse);
+        }
       if ((map_info == (XStandardColormap *) NULL) ||
           (visual_info == (XVisualInfo *) NULL) ||
           (font_info == (XFontStruct *) NULL))
         {
           XFreeResources(display,visual_info,map_info,&pixel,font_info,
             &resource_info,(XWindowInfo *) NULL);
-          ThrowBinaryException(XServerError,"UnableToLoadFont",image->filename);
+          ThrowXWindowException(XServerError,"UnableToLoadFont",
+            image->filename);
+          return(MagickFalse);
         }
       cache_info=(*draw_info);
     }
@@ -2089,7 +2113,11 @@ static MagickBooleanType RenderX11(Image *image,const DrawInfo *draw_info,
       (void) CloneString(&resource_info.font,draw_info->font);
       font_info=XBestFont(display,&resource_info,MagickFalse);
       if (font_info == (XFontStruct *) NULL)
-        ThrowBinaryException(XServerError,"UnableToLoadFont",draw_info->font);
+        {
+          ThrowXWindowException(XServerError,"UnableToLoadFont",
+            draw_info->font);
+          return(MagickFalse);
+        }
     }
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(AnnotateEvent,GetMagickModule(),
@@ -2102,11 +2130,11 @@ static MagickBooleanType RenderX11(Image *image,const DrawInfo *draw_info,
     (int) strlen(draw_info->text));
   annotate_info.height=(unsigned int) font_info->ascent+font_info->descent;
   metrics->pixels_per_em.x=(double) font_info->max_bounds.width;
-  metrics->pixels_per_em.y=(double) font_info->max_bounds.width;
-  metrics->ascent=(double) font_info->ascent;
+  metrics->pixels_per_em.y=(double) font_info->ascent+font_info->descent;
+  metrics->ascent=(double) font_info->ascent+4;
   metrics->descent=(double) (-font_info->descent);
   metrics->width=annotate_info.width/ExpandAffine(&draw_info->affine);
-  metrics->height=metrics->pixels_per_em.x+4;
+  metrics->height=font_info->ascent+font_info->descent;
   metrics->max_advance=(double) font_info->max_bounds.width;
   metrics->bounds.x1=0.0;
   metrics->bounds.y1=metrics->descent;
@@ -2138,8 +2166,11 @@ static MagickBooleanType RenderX11(Image *image,const DrawInfo *draw_info,
   pixel.pen_color.blue=ScaleQuantumToShort(draw_info->fill.blue);
   status=XAnnotateImage(display,&pixel,&annotate_info,image);
   if (status == 0)
-    ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
-      image->filename);
+    {
+      ThrowXWindowException(ResourceLimitError,"MemoryAllocationFailed",
+        image->filename);
+      return(MagickFalse);
+    }
   return(MagickTrue);
 }
 #else
