@@ -25,9 +25,7 @@ extern "C" {
 #include "magick/image.h"
 #include "magick/stream.h"
 
-#if !defined(MagickMaxBufferSize)
-#define MagickMaxBufferSize  0x3c005UL
-#endif
+#define MagickMaxBufferSize  262144
 
 typedef enum
 {
