@@ -36,6 +36,9 @@ typedef enum
 typedef void
   *Cache;
 
+typedef const IndexPacket
+  *(*AcquireIndexesFromHandler)(const Image *);
+
 typedef IndexPacket
   *(*GetIndexesFromHandler)(const Image *);
 
@@ -69,6 +72,9 @@ typedef void
 
 typedef struct _CacheMethods
 {
+  AcquireIndexesFromHandler
+    acquire_indexes_from_handler;
+
   AcquireOnePixelFromHandler
     acquire_one_pixel_from_handler;
 
@@ -183,6 +189,9 @@ extern MagickExport ClassType
 extern MagickExport ColorspaceType
   GetCacheColorspace(const Cache);
 
+extern MagickExport const IndexPacket
+  *AcquireNexusIndexes(const Cache,const unsigned long);
+
 extern MagickExport IndexPacket
   *GetNexusIndexes(const Cache,const unsigned long);
 
