@@ -547,46 +547,6 @@ MagickExport ViewInfo *OpenCacheView(const Image *image)
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   O p e n V i r t u a l C a c h e V i e w                                   %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  OpenVirtualCacheView() opens a view into the pixel cache, using the
-%  supplied VirtualPixelMethod, rather than the method defined by the image
-%  itself.
-%
-%  The format of the OpenCacheView method is:
-%
-%      ViewInfo *OpenVirtualCacheView(const Image *image,
-%        const VirtualPixelMethod virtual_pixel_method)
-%
-%  A description of each parameter follows:
-%
-%    o image: The image.
-%
-%    o virtual_pixel_method: The virtual pixel method.
-%
-*/
-MagickExport ViewInfo *OpenVirtualCacheView(const Image *image,
-  const VirtualPixelMethod virtual_pixel_method)
-{
-  ViewInfo
-    *view_info;
-
-  view_info=OpenCacheView(image);
-  if (view_info == (ViewInfo *) NULL)
-    return(view_info);
-  view_info->virtual_pixel_method=virtual_pixel_method;
-  return(view_info);
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
 %   S e t C a c h e V i e w                                                   %
 %                                                                             %
 %                                                                             %
@@ -638,7 +598,7 @@ MagickExport PixelPacket *SetCacheView(ViewInfo *view_info,const long x,
 %
 %  The format of the SetCacheViewStorageClass method is:
 %
-%      MagickBooleanType SetCacheViewStorageClass(const ViewInfo *view_info,
+%      MagickBooleanType SetCacheViewStorageClass(ViewInfo *view_info,
 %        const ClassType storage_class)
 %
 %  A description of each parameter follows:
@@ -665,6 +625,45 @@ MagickExport MagickBooleanType SetCacheViewStorageClass(ViewInfo *view_info,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   S e t C a c h e V i e w V i r t u a l P i x e l M e t h o d               %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  SetCacheViewVirtualPixelMethod() sets the virtual pixel method associated
+%  with the specified cache view.
+%
+%  The format of the SetCacheViewVirtualPixelMethod method is:
+%
+%      MagickBooleanType SetCacheViewVirtualPixelMethod(ViewInfo *view_info,
+%        const VirtualPixelMethod virtual_pixel_method)
+%
+%  A description of each parameter follows:
+%
+%    o view_info: The address of a structure of type ViewInfo.
+%
+%    o virtual_pixel_method: The virtual pixel method.
+%
+*/
+MagickExport MagickBooleanType SetCacheViewVirtualPixelMethod(
+  ViewInfo *view_info,const VirtualPixelMethod virtual_pixel_method)
+{
+  assert(view_info != (ViewInfo *) NULL);
+  assert(view_info->signature == MagickSignature);
+  assert(view_info->image != (Image *) NULL);
+  if (view_info->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      view_info->image->filename);
+  view_info->virtual_pixel_method=virtual_pixel_method;
+  return(MagickTrue);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   S y n c C a c h e V i e w                                                 %
 %                                                                             %
 %                                                                             %
