@@ -73,6 +73,7 @@ static const char
     "  <coder magick=\"8BIM\" name=\"META\" />"
     "  <coder magick=\"8BIMTEXT\" name=\"META\" />"
     "  <coder magick=\"8BIMWTEXT\" name=\"META\" />"
+    "  <coder magick=\"A\" name=\"RAW\" />"
     "  <coder magick=\"AFM\" name=\"TTF\" />"
     "  <coder magick=\"APP1JPEG\" name=\"META\" />"
     "  <coder magick=\"APP1\" name=\"META\" />"
@@ -82,7 +83,10 @@ static const char
     "  <coder magick=\"B\" name=\"GRAY\" />"
     "  <coder magick=\"CMYKA\" name=\"CMYK\" />"
     "  <coder magick=\"C\" name=\"GRAY\" />"
+    "  <coder magick=\"CR2\" name=\"DNG\" />"
+    "  <coder magick=\"CRW\" name=\"DNG\" />"
     "  <coder magick=\"CUR\" name=\"ICON\" />"
+    "  <coder magick=\"DCR\" name=\"DNG\" />"
     "  <coder magick=\"DCX\" name=\"PCX\" />"
     "  <coder magick=\"DFONT\" name=\"TTF\" />"
     "  <coder magick=\"EMF\" name=\"EMF\" />"
@@ -93,6 +97,9 @@ static const char
     "  <coder magick=\"EPSF\" name=\"PS\" />"
     "  <coder magick=\"EPSI\" name=\"PS\" />"
     "  <coder magick=\"EPS\" name=\"PS\" />"
+    "  <coder magick=\"EPT2\" name=\"EPT\" />"
+    "  <coder magick=\"EPT3\" name=\"EPT\" />"
+    "  <coder magick=\"EXIF\" name=\"META\" />"
     "  <coder magick=\"FILE\" name=\"URL\" />"
     "  <coder magick=\"FRACTAL\" name=\"PLASMA\" />"
     "  <coder magick=\"FTP\" name=\"URL\" />"
@@ -101,7 +108,6 @@ static const char
     "  <coder magick=\"GIF87\" name=\"GIF\" />"
     "  <coder magick=\"G\" name=\"GRAY\" />"
     "  <coder magick=\"GRANITE\" name=\"MAGICK\" />"
-    "  <coder magick=\"H5\" name=\"HDF\" />"
     "  <coder magick=\"H\" name=\"MAGICK\" />"
     "  <coder magick=\"HTM\" name=\"HTML\" />"
     "  <coder magick=\"HTTP\" name=\"URL\" />"
@@ -109,6 +115,7 @@ static const char
     "  <coder magick=\"ICC\" name=\"META\" />"
     "  <coder magick=\"ICM\" name=\"META\" />"
     "  <coder magick=\"ICO\" name=\"ICON\" />"
+    "  <coder magick=\"IMPLICIT\" name=\"***\" />"
     "  <coder magick=\"IPTC\" name=\"META\" />"
     "  <coder magick=\"IPTCTEXT\" name=\"META\" />"
     "  <coder magick=\"IPTCWTEXT\" name=\"META\" />"
@@ -124,9 +131,12 @@ static const char
     "  <coder magick=\"MNG\" name=\"PNG\" />"
     "  <coder magick=\"MPG\" name=\"MPEG\" />"
     "  <coder magick=\"MPRI\" name=\"MPR\" />"
+    "  <coder magick=\"MRW\" name=\"DNG\" />"
     "  <coder magick=\"MSVG\" name=\"SVG\" />"
+    "  <coder magick=\"NEF\" name=\"DNG\" />"
     "  <coder magick=\"NETSCAPE\" name=\"MAGICK\" />"
     "  <coder magick=\"O\" name=\"GRAY\" />"
+    "  <coder magick=\"ORF\" name=\"DNG\" />"
     "  <coder magick=\"OTF\" name=\"TTF\" />"
     "  <coder magick=\"P7\" name=\"PNM\" />"
     "  <coder magick=\"PAL\" name=\"UYVY\" />"
@@ -134,6 +144,7 @@ static const char
     "  <coder magick=\"PBM\" name=\"PNM\" />"
     "  <coder magick=\"PCDS\" name=\"PCD\" />"
     "  <coder magick=\"PCT\" name=\"PICT\" />"
+    "  <coder magick=\"PEF\" name=\"DNG\" />"
     "  <coder magick=\"PFA\" name=\"TTF\" />"
     "  <coder magick=\"PFB\" name=\"TTF\" />"
     "  <coder magick=\"PFM\" name=\"PNM\" />"
@@ -146,20 +157,23 @@ static const char
     "  <coder magick=\"PNG32\" name=\"PNG\" />"
     "  <coder magick=\"PNG8\" name=\"PNG\" />"
     "  <coder magick=\"PPM\" name=\"PNM\" />"
-    "  <coder magick=\"PSD\" name=\"PSD\" />"
     "  <coder magick=\"PTIF\" name=\"TIFF\" />"
+    "  <coder magick=\"RAF\" name=\"DNG\" />"
     "  <coder magick=\"RAS\" name=\"SUN\" />"
     "  <coder magick=\"RGBA\" name=\"RGB\" />"
+    "  <coder magick=\"RGBO\" name=\"RGB\" />"
     "  <coder magick=\"R\" name=\"GRAY\" />"
     "  <coder magick=\"ROSE\" name=\"MAGICK\" />"
     "  <coder magick=\"SHTML\" name=\"HTML\" />"
     "  <coder magick=\"SVGZ\" name=\"SVG\" />"
     "  <coder magick=\"TEXT\" name=\"TXT\" />"
+    "  <coder magick=\"TIFF64\" name=\"TIFF\" />"
     "  <coder magick=\"TIF\" name=\"TIFF\" />"
     "  <coder magick=\"TTC\" name=\"TTF\" />"
     "  <coder magick=\"VDA\" name=\"TGA\" />"
     "  <coder magick=\"VST\" name=\"TGA\" />"
     "  <coder magick=\"WMFWIN32\" name=\"EMF\" />"
+    "  <coder magick=\"X3F\" name=\"DNG\" />"
     "  <coder magick=\"XTRNARRAY\" name=\"XTRN\" />"
     "  <coder magick=\"XTRNBLOB\" name=\"XTRN\" />"
     "  <coder magick=\"XTRNBSTR\" name=\"XTRN\" />"
@@ -168,6 +182,7 @@ static const char
     "  <coder magick=\"XTRNSTREAM\" name=\"XTRN\" />"
     "  <coder magick=\"XV\" name=\"VIFF\" />"
     "  <coder magick=\"Y\" name=\"GRAY\" />"
+    "  <coder magick=\"YCbCrA\" name=\"YCbCr\" />"
     "</codermap>";
 
 /*
@@ -323,8 +338,8 @@ MagickExport const CoderInfo **GetCoderInfoList(const char *pattern,
   p=GetCoderInfo("*",exception);
   if (p == (const CoderInfo *) NULL)
     return((const CoderInfo **) NULL);
-  coder_map=(const CoderInfo **) AcquireMagickMemory((size_t)
-    (GetNumberOfNodesInSplayTree(coder_list)+1)*sizeof(*coder_map));
+  coder_map=(const CoderInfo **) AcquireQuantumMemory((size_t)
+    GetNumberOfNodesInSplayTree(coder_list)+1UL,sizeof(*coder_map));
   if (coder_map == (const CoderInfo **) NULL)
     return((const CoderInfo **) NULL);
   /*
@@ -408,8 +423,8 @@ MagickExport char **GetCoderList(const char *pattern,
   p=GetCoderInfo("*",exception);
   if (p == (const CoderInfo *) NULL)
     return((char **) NULL);
-  coder_map=(char **) AcquireMagickMemory((size_t)
-    (GetNumberOfNodesInSplayTree(coder_list)+1)*sizeof(*coder_map));
+  coder_map=(char **) AcquireQuantumMemory((size_t)
+    GetNumberOfNodesInSplayTree(coder_list)+1UL,sizeof(*coder_map));
   if (coder_map == (char **) NULL)
     return((char **) NULL);
   /*
@@ -617,12 +632,12 @@ static MagickBooleanType LoadCoderList(const char *xml,const char *filename,
     return(MagickFalse);
   if (coder_list == (SplayTreeInfo *) NULL)
     {
-      coder_list=NewSplayTree(CompareSplayTreeString,RelinquishMagickMemory,
+      coder_list=NewSplayTree(CompareSplayTreeString,(void *(*)(void *)) NULL,
         DestroyCoderNode);
       if (coder_list == (SplayTreeInfo *) NULL)
         {
-          ThrowFileException(exception,ResourceLimitError,
-            "MemoryAllocationFailed",filename);
+          (void) ThrowMagickException(exception,GetMagickModule(),
+             ResourceLimitError,"MemoryAllocationFailed","`%s'",filename);
           return(MagickFalse);
         }
     }
@@ -671,8 +686,7 @@ static MagickBooleanType LoadCoderList(const char *xml,const char *filename,
     */
     coder_info=(CoderInfo *) AcquireMagickMemory(sizeof(*coder_info));
     if (coder_info == (CoderInfo *) NULL)
-      ThrowMagickFatalException(ResourceLimitFatalError,
-        "MemoryAllocationFailed",filename);
+      ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
     (void) ResetMagickMemory(coder_info,0,sizeof(*coder_info));
     coder_info->path=ConstantString(filename);
     coder_info->signature=MagickSignature;
@@ -685,8 +699,7 @@ static MagickBooleanType LoadCoderList(const char *xml,const char *filename,
     attribute=GetXMLTreeAttribute(coder,"stealth");
     if (attribute != (const char *) NULL)
       coder_info->stealth=IsMagickTrue(attribute);
-    status=AddValueToSplayTree(coder_list,ConstantString(coder_info->magick),
-      coder_info);
+    status=AddValueToSplayTree(coder_list,coder_info->magick,coder_info);
     if (status == MagickFalse)
       (void) ThrowMagickException(exception,GetMagickModule(),
         ResourceLimitError,"MemoryAllocationFailed","`%s'",filename);
