@@ -440,7 +440,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
       */
       density=2.03728;
       gamma=DisplayGamma;
-      value=GetImageProperty(image,"Gamma");
+      value=GetImageProperty(image,"gamma");
       if (value != (const char *) NULL)
         gamma=1.0/atof(value) != 0.0 ? atof(value) : 1.0;
       reference_black=ReferenceBlack;
@@ -645,7 +645,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         if (((double) i/MaxMap) <= 0.03928)
           v/=12.92;
         else
-          v=MaxMap*pow((((double) i/MaxMap)+0.055)/1.055,2.4);
+          v=(double) MaxMap*pow((((double) i/MaxMap)+0.055)/1.055,2.4);
         x_map[i].x=1.0*v;
         y_map[i].x=0.0*v;
         z_map[i].x=0.0*v;
@@ -814,13 +814,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
     case DirectClass:
     default:
     {
-      ExceptionInfo
-        *exception;
-
       /*
         Convert DirectClass image.
       */
-      exception=(&image->exception);
       for (y=0; y < (long) image->rows; y++)
       {
         q=GetImagePixels(image,0,y,image->columns,1);
@@ -1035,12 +1031,12 @@ static inline void ConvertXYZToRGB(const double x,const double y,const double z,
 
 static inline void ConvertCMYKToRGB(MagickPixelPacket *pixel)
 {
-  pixel->red=QuantumRange-(QuantumScale*pixel->red*(QuantumRange-
-    pixel->index)+pixel->index);
-  pixel->green=QuantumRange-(QuantumScale*pixel->green*(QuantumRange-
-    pixel->index)+pixel->index);
-  pixel->blue=QuantumRange-(QuantumScale*pixel->blue*(QuantumRange-
-    pixel->index)+pixel->index);
+  pixel->red=(MagickRealType) QuantumRange-(QuantumScale*pixel->red*
+    (QuantumRange-pixel->index)+pixel->index);
+  pixel->green=(MagickRealType) QuantumRange-(QuantumScale*pixel->green*
+    (QuantumRange-pixel->index)+pixel->index);
+  pixel->blue=(MagickRealType) QuantumRange-(QuantumScale*pixel->blue*
+    (QuantumRange-pixel->index)+pixel->index);
 }
 
 MagickExport MagickBooleanType TransformRGBImage(Image *image,
@@ -1368,7 +1364,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
       */
       density=2.03728;
       gamma=DisplayGamma;
-      value=GetImageProperty(image,"Gamma");
+      value=GetImageProperty(image,"gamma");
       if (value != (const char *) NULL)
         gamma=1.0/atof(value) != 0.0 ? atof(value) : 1.0;
       reference_black=ReferenceBlack;
@@ -1393,7 +1389,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           (pow(10.0,(1024.0*i/MaxMap-reference_white)*
           (gamma/density)*0.002/0.6)-black));
       for ( ; i <= (long) MaxMap; i++)
-        logmap[i]=QuantumRange;
+        logmap[i]=(Quantum) QuantumRange;
       if (SetImageStorageClass(image,DirectClass) == MagickFalse)
         return(MagickFalse);
       for (y=0; y < (long) image->rows; y++)
@@ -1675,13 +1671,9 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
     case DirectClass:
     default:
     {
-      ExceptionInfo
-        *exception;
-
       /*
         Convert DirectClass image.
       */
-      exception=(&image->exception);
       for (y=0; y < (long) image->rows; y++)
       {
         q=GetImagePixels(image,0,y,image->columns,1);
@@ -1717,18 +1709,18 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
               if ((QuantumScale*pixel.red) <= 0.0031308)
                 pixel.red*=12.92f;
               else
-                pixel.red=QuantumRange*(1.055*pow(QuantumScale*pixel.red,
-                  (1.0/2.4))-0.055);
+                pixel.red=(MagickRealType) QuantumRange*(1.055*
+                  pow(QuantumScale*pixel.red,(1.0/2.4))-0.055);
               if ((QuantumScale*pixel.green) <= 0.0031308)
                 pixel.green*=12.92f;
               else
-                pixel.green=QuantumRange*(1.055*pow(QuantumScale*pixel.green,
-                  (1.0/2.4))-0.055);
+                pixel.green=(MagickRealType) QuantumRange*(1.055*
+                  pow(QuantumScale*pixel.green,(1.0/2.4))-0.055);
               if ((QuantumScale*pixel.blue) <= 0.0031308)
                 pixel.blue*=12.92f;
               else
-                pixel.blue=QuantumRange*(1.055*pow(QuantumScale*pixel.blue,
-                  (1.0/2.4))-0.055);
+                pixel.blue=(MagickRealType) QuantumRange*(1.055*
+                  pow(QuantumScale*pixel.blue,(1.0/2.4))-0.055);
             }
             default:
             {
@@ -1791,18 +1783,18 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
             if ((QuantumScale*pixel.red) <= 0.0031308)
               pixel.red*=12.92f;
             else
-              pixel.red=QuantumRange*(1.055*pow(QuantumScale*pixel.red,
-                (1.0/2.4))-0.055);
+              pixel.red=(MagickRealType) QuantumRange*(1.055*pow(QuantumScale*
+                pixel.red,(1.0/2.4))-0.055);
             if ((QuantumScale*pixel.green) <= 0.0031308)
               pixel.green*=12.92f;
             else
-              pixel.green=QuantumRange*(1.055*pow(QuantumScale*pixel.green,
-                (1.0/2.4))-0.055);
+              pixel.green=(MagickRealType) QuantumRange*(1.055*pow(QuantumScale*
+                pixel.green,(1.0/2.4))-0.055);
             if ((QuantumScale*pixel.blue) <= 0.0031308)
               pixel.blue*=12.92f;
             else
-              pixel.blue=QuantumRange*(1.055*pow(QuantumScale*pixel.blue,
-                (1.0/2.4))-0.055);
+              pixel.blue=(MagickRealType) QuantumRange*(1.055*pow(QuantumScale*
+                pixel.blue,(1.0/2.4))-0.055);
           }
           default:
           {
