@@ -129,14 +129,16 @@ MagickExport Image *CompareImageChannels(Image *image,
   MagickStatusType
     difference;
 
+  register const IndexPacket
+    *indexes,
+    *reconstruct_indexes;
+
   register const PixelPacket
     *p,
     *q;
 
   register IndexPacket
-    *difference_indexes,
-    *indexes,
-    *reconstruct_indexes;
+    *difference_indexes;
 
   register long
     x;
@@ -162,10 +164,6 @@ MagickExport Image *CompareImageChannels(Image *image,
   if ((reconstruct_image->columns != image->columns) ||
       (reconstruct_image->rows != image->rows))
     ThrowImageException(ImageError,"ImageSizeDiffers");
-  if (image->colorspace != reconstruct_image->colorspace)
-    ThrowImageException(ImageError,"ImageColorspaceDiffers");
-  if (image->matte != reconstruct_image->matte)
-    ThrowImageException(ImageError,"ImageOpacityDiffers");
   difference_image=CloneImage(image,image->columns,image->rows,MagickTrue,
     exception);
   if (difference_image == (Image *) NULL)
@@ -180,8 +178,8 @@ MagickExport Image *CompareImageChannels(Image *image,
   (void) QueryMagickColor("#ffffff",&white,exception);
   if (difference_image->colorspace == CMYKColorspace)
     {
-      RGBtoCMYK(&red);
-      RGBtoCMYK(&white);
+      ConvertRGBToCMYK(&red);
+      ConvertRGBToCMYK(&white);
     }
   /*
     Generate difference image.
@@ -193,15 +191,15 @@ MagickExport Image *CompareImageChannels(Image *image,
   difference_view=OpenCacheView(difference_image);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireCacheView(image_view,0,y,image->columns,1,exception);
-    q=AcquireCacheView(reconstruct_view,0,y,reconstruct_image->columns,1,
+    p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
+    q=AcquireCacheViewPixels(reconstruct_view,0,y,reconstruct_image->columns,1,
       exception);
     r=SetCacheView(difference_view,0,y,difference_image->columns,1);
     if ((p == (const PixelPacket *) NULL) ||
         (q == (const PixelPacket *) NULL) || (r == (PixelPacket *) NULL))
       break;
-    indexes=GetCacheViewIndexes(image_view);
-    reconstruct_indexes=GetCacheViewIndexes(reconstruct_view);
+    indexes=AcquireCacheViewIndexes(image_view);
+    reconstruct_indexes=AcquireCacheViewIndexes(reconstruct_view);
     difference_indexes=GetCacheViewIndexes(difference_view);
     for (x=0; x < (long) image->columns; x++)
     {
@@ -215,19 +213,20 @@ MagickExport Image *CompareImageChannels(Image *image,
       if ((channel & BlueChannel) != 0)
         if (p->blue != q->blue)
           difference=MagickTrue;
-      if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
+      if ((channel & OpacityChannel) != 0)
         if (p->opacity != q->opacity)
           difference=MagickTrue;
       if (((channel & IndexChannel) != 0) &&
-          (image->colorspace == CMYKColorspace))
+          (image->colorspace == CMYKColorspace) &&
+          (reconstruct_image->colorspace == CMYKColorspace))
         if (indexes[x] != reconstruct_indexes[x])
           difference=MagickTrue;
       SetMagickPixelPacket(reconstruct_image,q,reconstruct_indexes+x,&source);
       if (difference != MagickFalse)
-        MagickPixelCompositeOver(&source,9.0*QuantumRange/10.0,&red,
+        MagickPixelCompositeOver(&source,7.5*QuantumRange/10.0,&red,
           (MagickRealType) red.opacity,&composite);
       else
-        MagickPixelCompositeOver(&source,9.0*QuantumRange/10.0,&white,
+        MagickPixelCompositeOver(&source,7.5*QuantumRange/10.0,&white,
           (MagickRealType) white.opacity,&composite);
       SetPixelPacket(difference_image,&composite,r,difference_indexes+x);
       p++;
@@ -296,10 +295,6 @@ MagickExport MagickBooleanType GetImageDistortion(Image *image,
 static MagickRealType GetAbsoluteError(const Image *image,
   const Image *reconstruct_image,ExceptionInfo *exception)
 {
-  IndexPacket
-    *indexes,
-    *reconstruct_indexes;
-
   long
     y;
 
@@ -310,6 +305,10 @@ static MagickRealType GetAbsoluteError(const Image *image,
   MagickRealType
     distortion;
 
+  register const IndexPacket
+    *indexes,
+    *reconstruct_indexes;
+
   register const PixelPacket
     *p,
     *q;
@@ -331,13 +330,13 @@ static MagickRealType GetAbsoluteError(const Image *image,
   reconstruct_view=OpenCacheView(reconstruct_image);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireCacheView(image_view,0,y,image->columns,1,exception);
-    q=AcquireCacheView(reconstruct_view,0,y,reconstruct_image->columns,1,
+    p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
+    q=AcquireCacheViewPixels(reconstruct_view,0,y,reconstruct_image->columns,1,
       exception);
     if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
       break;
-    indexes=GetCacheViewIndexes(image_view);
-    reconstruct_indexes=GetCacheViewIndexes(reconstruct_view);
+    indexes=AcquireCacheViewIndexes(image_view);
+    reconstruct_indexes=AcquireCacheViewIndexes(reconstruct_view);
     for (x=0; x < (long) image->columns; x++)
     {
       SetMagickPixelPacket(image,p,indexes+x,&image_pixel);
@@ -358,10 +357,6 @@ static MagickRealType GetMeanAbsoluteError(const Image *image,
   const Image *reconstruct_image,const ChannelType channel,
   ExceptionInfo *exception)
 {
-  IndexPacket
-    *indexes,
-    *reconstruct_indexes;
-
   long
     y;
 
@@ -369,6 +364,10 @@ static MagickRealType GetMeanAbsoluteError(const Image *image,
     area,
     distortion;
 
+  register const IndexPacket
+    *indexes,
+    *reconstruct_indexes;
+
   register const PixelPacket
     *p,
     *q;
@@ -386,13 +385,13 @@ static MagickRealType GetMeanAbsoluteError(const Image *image,
   reconstruct_view=OpenCacheView(reconstruct_image);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireCacheView(image_view,0,y,image->columns,1,exception);
-    q=AcquireCacheView(reconstruct_view,0,y,reconstruct_image->columns,1,
+    p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
+    q=AcquireCacheViewPixels(reconstruct_view,0,y,reconstruct_image->columns,1,
       exception);
     if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
       break;
-    indexes=GetCacheViewIndexes(image_view);
-    reconstruct_indexes=GetCacheViewIndexes(reconstruct_view);
+    indexes=AcquireCacheViewIndexes(image_view);
+    reconstruct_indexes=AcquireCacheViewIndexes(reconstruct_view);
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
@@ -410,7 +409,7 @@ static MagickRealType GetMeanAbsoluteError(const Image *image,
           distortion+=fabs(p->blue-(double) q->blue);
           area++;
         }
-      if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
+      if ((channel & OpacityChannel) != 0)
         {
           distortion+=fabs(p->opacity-(double) q->opacity);
           area++;
@@ -434,7 +433,10 @@ static MagickRealType GetMeanErrorPerPixel(Image *image,
   const Image *reconstruct_image,const ChannelType channel,
   ExceptionInfo *exception)
 {
-  double
+  long
+    y;
+
+  MagickRealType
     alpha,
     area,
     beta,
@@ -443,13 +445,10 @@ static MagickRealType GetMeanErrorPerPixel(Image *image,
     mean_error,
     mean_error_per_pixel;
 
-  IndexPacket
+  register const IndexPacket
     *indexes,
     *reconstruct_indexes;
 
-  long
-    y;
-
   register const PixelPacket
     *p,
     *q;
@@ -471,19 +470,21 @@ static MagickRealType GetMeanErrorPerPixel(Image *image,
   reconstruct_view=OpenCacheView(reconstruct_image);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireCacheView(image_view,0,y,image->columns,1,exception);
-    q=AcquireCacheView(reconstruct_view,0,y,reconstruct_image->columns,1,
+    p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
+    q=AcquireCacheViewPixels(reconstruct_view,0,y,reconstruct_image->columns,1,
       exception);
     if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
       break;
-    indexes=GetCacheViewIndexes(image_view);
-    reconstruct_indexes=GetCacheViewIndexes(reconstruct_view);
+    indexes=AcquireCacheViewIndexes(image_view);
+    reconstruct_indexes=AcquireCacheViewIndexes(reconstruct_view);
     for (x=0; x < (long) image->columns; x++)
     {
-      if (image->matte != MagickFalse)
+      if ((channel & OpacityChannel) != 0)
         {
-          alpha=QuantumScale*(QuantumRange-(double) p->opacity);
-          beta=QuantumScale*(QuantumRange-(double) q->opacity);
+          if (image->matte != MagickFalse)
+            alpha=(MagickRealType) (QuantumScale*(QuantumRange-p->opacity));
+          if (reconstruct_image->matte != MagickFalse)
+            beta=(MagickRealType) (QuantumScale*(QuantumRange-q->opacity));
         }
       if ((channel & RedChannel) != 0)
         {
@@ -512,8 +513,18 @@ static MagickRealType GetMeanErrorPerPixel(Image *image,
             maximum_error=distance;
           area++;
         }
+      if ((channel & OpacityChannel) != 0)
+        {
+          distance=fabs(alpha*p->opacity-beta*q->opacity);
+          mean_error_per_pixel+=distance;
+          mean_error+=distance*distance;
+          if (distance > maximum_error)
+            maximum_error=distance;
+          area++;
+        }
       if (((channel & IndexChannel) != 0) &&
-          (image->colorspace == CMYKColorspace))
+          (image->colorspace == CMYKColorspace) &&
+          (reconstruct_image->colorspace == CMYKColorspace))
         {
           distance=fabs(alpha*indexes[x]-beta*reconstruct_indexes[x]);
           mean_error_per_pixel+=distance;
@@ -538,10 +549,6 @@ static MagickRealType GetMeanSquaredError(const Image *image,
   const Image *reconstruct_image,const ChannelType channel,
   ExceptionInfo *exception)
 {
-  IndexPacket
-    *indexes,
-    *reconstruct_indexes;
-
   long
     y;
 
@@ -550,6 +557,10 @@ static MagickRealType GetMeanSquaredError(const Image *image,
     distance,
     distortion;
 
+  register const IndexPacket
+    *indexes,
+    *reconstruct_indexes;
+
   register const PixelPacket
     *p,
     *q;
@@ -567,13 +578,13 @@ static MagickRealType GetMeanSquaredError(const Image *image,
   reconstruct_view=OpenCacheView(reconstruct_image);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireCacheView(image_view,0,y,image->columns,1,exception);
-    q=AcquireCacheView(reconstruct_view,0,y,reconstruct_image->columns,1,
+    p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
+    q=AcquireCacheViewPixels(reconstruct_view,0,y,reconstruct_image->columns,1,
       exception);
     if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
       break;
-    indexes=GetCacheViewIndexes(image_view);
-    reconstruct_indexes=GetCacheViewIndexes(reconstruct_view);
+    indexes=AcquireCacheViewIndexes(image_view);
+    reconstruct_indexes=AcquireCacheViewIndexes(reconstruct_view);
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
@@ -594,14 +605,15 @@ static MagickRealType GetMeanSquaredError(const Image *image,
           distortion+=distance*distance;
           area++;
         }
-      if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
+      if ((channel & OpacityChannel) != 0)
         {
           distance=p->opacity-(MagickRealType) q->opacity;
           distortion+=distance*distance;
           area++;
         }
       if (((channel & IndexChannel) != 0) &&
-          (image->colorspace == CMYKColorspace))
+          (image->colorspace == CMYKColorspace) &&
+          (reconstruct_image->colorspace == CMYKColorspace))
         {
           distance=indexes[x]-(MagickRealType) reconstruct_indexes[x];
           distortion+=distance*distance;
@@ -620,10 +632,6 @@ static MagickRealType GetPeakAbsoluteError(const Image *image,
   const Image *reconstruct_image,const ChannelType channel,
   ExceptionInfo *exception)
 {
-  IndexPacket
-    *indexes,
-    *reconstruct_indexes;
-
   long
     y;
 
@@ -631,6 +639,10 @@ static MagickRealType GetPeakAbsoluteError(const Image *image,
     distance,
     distortion;
 
+  register const IndexPacket
+    *indexes,
+    *reconstruct_indexes;
+
   register const PixelPacket
     *p,
     *q;
@@ -647,13 +659,13 @@ static MagickRealType GetPeakAbsoluteError(const Image *image,
   reconstruct_view=OpenCacheView(reconstruct_image);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireCacheView(image_view,0,y,image->columns,1,exception);
-    q=AcquireCacheView(reconstruct_view,0,y,reconstruct_image->columns,1,
+    p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
+    q=AcquireCacheViewPixels(reconstruct_view,0,y,reconstruct_image->columns,1,
       exception);
     if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
       break;
-    indexes=GetCacheViewIndexes(image_view);
-    reconstruct_indexes=GetCacheViewIndexes(reconstruct_view);
+    indexes=AcquireCacheViewIndexes(image_view);
+    reconstruct_indexes=AcquireCacheViewIndexes(reconstruct_view);
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
@@ -674,14 +686,15 @@ static MagickRealType GetPeakAbsoluteError(const Image *image,
           if (distance > distortion)
             distortion=distance;
         }
-      if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
+      if ((channel & OpacityChannel) != 0)
         {
           distance=fabs(p->opacity-(double) q->opacity);
           if (distance > distortion)
             distortion=distance;
         }
       if (((channel & IndexChannel) != 0) &&
-          (image->colorspace == CMYKColorspace))
+          (image->colorspace == CMYKColorspace) &&
+          (reconstruct_image->colorspace == CMYKColorspace))
         {
           distance=fabs(indexes[x]-(double) reconstruct_indexes[x]);
           if (distance > distortion)
@@ -735,10 +748,6 @@ MagickExport MagickBooleanType GetImageChannelDistortion(Image *image,
   if ((reconstruct_image->columns != image->columns) ||
       (reconstruct_image->rows != image->rows))
     ThrowBinaryException(ImageError,"ImageSizeDiffers",image->filename);
-  if (image->colorspace != reconstruct_image->colorspace)
-    ThrowBinaryException(ImageError,"ImageColorspaceDiffers",image->filename);
-  if (image->matte != reconstruct_image->matte)
-    ThrowBinaryException(ImageError,"ImageOpacityDiffers",image->filename);
   /*
     Get image distortion.
   */
@@ -840,10 +849,6 @@ MagickExport MagickBooleanType GetImageChannelDistortion(Image *image,
 MagickExport MagickBooleanType IsImagesEqual(Image *image,
   const Image *reconstruct_image)
 {
-  IndexPacket
-    *indexes,
-    *reconstruct_indexes;
-
   long
     y;
 
@@ -857,6 +862,10 @@ MagickExport MagickBooleanType IsImagesEqual(Image *image,
     mean_error,
     mean_error_per_pixel;
 
+  register const IndexPacket
+    *indexes,
+    *reconstruct_indexes;
+
   register const PixelPacket
     *p,
     *q;
@@ -875,10 +884,6 @@ MagickExport MagickBooleanType IsImagesEqual(Image *image,
   if ((reconstruct_image->columns != image->columns) ||
       (reconstruct_image->rows != image->rows))
     ThrowBinaryException(ImageError,"ImageSizeDiffers",image->filename);
-  if (image->colorspace != reconstruct_image->colorspace)
-    ThrowBinaryException(ImageError,"ImageColorspaceDiffers",image->filename);
-  if (image->matte != reconstruct_image->matte)
-    ThrowBinaryException(ImageError,"ImageOpacityDiffers",image->filename);
   area=0.0;
   maximum_error=0.0;
   mean_error_per_pixel=0.0;
@@ -887,13 +892,13 @@ MagickExport MagickBooleanType IsImagesEqual(Image *image,
   reconstruct_view=OpenCacheView(reconstruct_image);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireCacheView(image_view,0,y,image->columns,1,&image->exception);
-    q=AcquireCacheView(reconstruct_view,0,y,reconstruct_image->columns,1,
+    p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,&image->exception);
+    q=AcquireCacheViewPixels(reconstruct_view,0,y,reconstruct_image->columns,1,
       &image->exception);
     if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
       break;
-    indexes=GetCacheViewIndexes(image_view);
-    reconstruct_indexes=GetCacheViewIndexes(reconstruct_view);
+    indexes=AcquireCacheViewIndexes(image_view);
+    reconstruct_indexes=AcquireCacheViewIndexes(reconstruct_view);
     for (x=0; x < (long) image->columns; x++)
     {
       distance=fabs(p->red-(double) q->red);
@@ -914,16 +919,14 @@ MagickExport MagickBooleanType IsImagesEqual(Image *image,
       if (distance > maximum_error)
         maximum_error=distance;
       area++;
-      if (image->matte != MagickFalse)
-        {
-          distance=fabs(p->opacity-(double) q->opacity);
-          mean_error_per_pixel+=distance;
-          mean_error+=distance*distance;
-          if (distance > maximum_error)
-            maximum_error=distance;
-          area++;
-        }
-      if (image->colorspace == CMYKColorspace)
+      distance=fabs(p->opacity-(double) q->opacity);
+      mean_error_per_pixel+=distance;
+      mean_error+=distance*distance;
+      if (distance > maximum_error)
+        maximum_error=distance;
+      area++;
+      if ((image->colorspace == CMYKColorspace) &&
+          (reconstruct_image->colorspace == CMYKColorspace))
         {
           distance=fabs(indexes[x]-(double) reconstruct_indexes[x]);
           mean_error_per_pixel+=distance;
