@@ -138,12 +138,12 @@ static inline void MagickPixelCompositePlus(const MagickPixelPacket *p,
   Blend pixel colors p and q by the amount given
 */
 static inline void MagickPixelCompositeBlend(const MagickPixelPacket *p,
-      const MagickRealType alpha,
-       const MagickPixelPacket *q, const MagickRealType beta,
-       MagickPixelPacket *composite)
+  const MagickRealType alpha,const MagickPixelPacket *q,
+  const MagickRealType beta,MagickPixelPacket *composite)
 {
-  MagickPixelCompositePlus(p, QuantumRange-alpha*(QuantumRange-p->opacity),
-       q, QuantumRange-beta*(QuantumRange-q->opacity), composite);
+  MagickPixelCompositePlus(p,(MagickRealType) (QuantumRange-alpha*
+    (QuantumRange-p->opacity)),q,(MagickRealType) (QuantumRange-beta*
+    (QuantumRange-q->opacity)),composite);
 }
 
 #if defined(__cplusplus) || defined(c_plusplus)
