@@ -41,6 +41,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
+#include "magick/artifact.h"
 #include "magick/cache-view.h"
 #include "magick/client.h"
 #include "magick/color.h"
@@ -345,6 +346,30 @@ static inline void CompositeDifference(const MagickPixelPacket *p,
     composite->index=gamma*Difference(p->index,alpha,q->index,beta);
 }
 
+static inline MagickRealType Divide(const MagickRealType p,
+  const MagickRealType q)
+{
+  MagickRealType
+    pixel;
+
+  if (q == 0.0)
+    return(0.0);
+  pixel=p/q;
+  return((MagickRealType) QuantumRange*pixel);
+}
+
+static inline void CompositeDivide(const MagickPixelPacket *p,
+  const MagickRealType alpha,const MagickPixelPacket *q,
+  const MagickRealType beta,MagickPixelPacket *composite)
+{
+  composite->red=Divide(p->red,q->red);
+  composite->green=Divide(p->green,q->green);
+  composite->blue=Divide(p->blue,q->blue);
+  composite->opacity=Divide(alpha,beta);
+  if (q->colorspace == CMYKColorspace)
+    composite->index=Divide(p->index,q->index);
+}
+
 static inline MagickRealType Exclusion(const MagickRealType p,
   const MagickRealType alpha,const MagickRealType q,const MagickRealType beta)
 {
@@ -1090,6 +1115,9 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
       register PixelPacket
         *r;
 
+      ResampleFilter
+        *resample_filter;
+
       ViewInfo
         *composite_view,
         *displace_view,
@@ -1120,6 +1148,7 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
         Shift image pixels as defined by a displacement map.
       */
       GetMagickPixelPacket(displace_image,&pixel);
+      resample_filter=AcquireResampleFilter(image,&image->exception);
       image_view=OpenCacheView(image);
       displace_view=OpenCacheView(displace_image);
       composite_view=OpenCacheView(composite_image);
@@ -1155,9 +1184,8 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
             y_displace=(vertical_scale*(PixelIntensityToQuantum(p)-
               (((MagickRealType) QuantumRange+1.0)/2.0)))/
               (((MagickRealType) QuantumRange+1.0)/2.0);
-          pixel=InterpolatePixelColor(image,image_view,image->interpolate,
-            (double) (x_offset+x+x_displace),(double) (y_offset+y+y_displace),
-            &image->exception);
+          pixel=ResamplePixelColor(resample_filter,(double)
+            (x_offset+x+x_displace),(double) (y_offset+y+y_displace));
           SetPixelPacket(displace_image,&pixel,r,displace_indexes+x);
           p++;
           q++;
@@ -1166,6 +1194,7 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
         if (SyncCacheView(displace_view) == MagickFalse)
           break;
       }
+      resample_filter=DestroyResampleFilter(resample_filter);
       composite_view=CloseCacheView(composite_view);
       displace_view=CloseCacheView(displace_view);
       image_view=CloseCacheView(image_view);
@@ -1208,21 +1237,12 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
         {
           flags=ParseGeometry(composite_image->geometry,&geometry_info);
           source_dissolve=geometry_info.rho/100.0;
-          if ((source_dissolve-MagickEpsilon) < 0.0)
-            source_dissolve=0.0;
-          if ((source_dissolve+MagickEpsilon) > 1.0)
-            source_dissolve=1.0;
           destination_dissolve=1.0-source_dissolve;
           if ((flags & SigmaValue) != 0)
             destination_dissolve=geometry_info.sigma/100.0;
-          if ((destination_dissolve-MagickEpsilon) < 0.0)
-            destination_dissolve=0.0;
           modify_outside_overlay=MagickTrue;
           if ((destination_dissolve+MagickEpsilon) > 1.0)
-            {
-              destination_dissolve=1.0;
-              modify_outside_overlay=MagickFalse;
-            }
+            modify_outside_overlay=MagickFalse;
         }
       break;
     }
@@ -1259,7 +1279,7 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
     default:
       break;
   }
-  value=GetImageProperty(composite_image,"[modify-outside-overlay]");
+  value=GetImageArtifact(composite_image,"modify-outside-overlay");
   if (value != (const char *) NULL)
     modify_outside_overlay=MagickFalse;
   /*
@@ -1398,6 +1418,12 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
         }
       switch (compose)
       {
+        case AddCompositeOp:
+        {
+          CompositeAdd(&source,source.opacity,&destination,destination.opacity,
+            &composite);
+          break;
+        }
         case ClearCompositeOp:
         {
           CompositeClear(&destination,&composite);
@@ -1419,6 +1445,12 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
             composite.opacity=(MagickRealType) OpaqueOpacity;
           break;
         }
+        case DivideCompositeOp:
+        {
+          CompositeDivide(&source,source.opacity,&destination,
+            destination.opacity,&composite);
+          break;
+        }
         case DstCompositeOp:
           break;
         case OverCompositeOp:
@@ -1653,6 +1685,12 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
             composite.opacity=source.opacity;
           break;
         }
+        case SubtractCompositeOp:
+        {
+          CompositeSubtract(&source,source.opacity,&destination,
+            destination.opacity,&composite);
+          break;
+        }
         case LuminizeCompositeOp:
         {
           if (source.opacity == TransparentOpacity)
@@ -1691,37 +1729,25 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
             composite.opacity=source.opacity;
           break;
         }
-        case AddCompositeOp:  /* deprecated */
-        {
-          CompositeAdd(&source,source.opacity,&destination,destination.opacity,
-            &composite);
-          break;
-        }
-        case SubtractCompositeOp:  /* deprecated */
-        {
-          CompositeSubtract(&source,source.opacity,&destination,
-            destination.opacity,&composite);
-          break;
-        }
-        case CopyRedCompositeOp:  /* deprecated */
+        case CopyRedCompositeOp:
         case CopyCyanCompositeOp:
         {
           composite.red=source.red;
           break;
         }
-        case CopyGreenCompositeOp:  /* deprecated */
+        case CopyGreenCompositeOp:
         case CopyMagentaCompositeOp:
         {
           composite.green=source.green;
           break;
         }
-        case CopyBlueCompositeOp:  /* deprecated */
+        case CopyBlueCompositeOp:
         case CopyYellowCompositeOp:
         {
           composite.blue=source.blue;
           break;
         }
-        case CopyOpacityCompositeOp:  /* deprecated */
+        case CopyOpacityCompositeOp:
         {
           if (source.matte == MagickFalse)
             {
