@@ -934,9 +934,6 @@ MagickExport MagickBooleanType Huffman2DEncodeImage(const ImageInfo *image_info,
   int
     unique_file;
 
-  long
-    j;
-
   MagickBooleanType
     status;
 
@@ -952,13 +949,13 @@ MagickExport MagickBooleanType Huffman2DEncodeImage(const ImageInfo *image_info,
   uint16
     fillorder;
 
-  unsigned char
-    *buffer;
-
-  unsigned long
+  uint32
     *byte_count,
     strip_size;
 
+  unsigned char
+    *buffer;
+
   /*
     Write image as CCITTFax4 TIFF image to a temporary file.
   */
@@ -1036,8 +1033,7 @@ MagickExport MagickBooleanType Huffman2DEncodeImage(const ImageInfo *image_info,
       byte_count[i]);
     if (fillorder == FILLORDER_LSB2MSB)
       TIFFReverseBits(buffer,(unsigned long) count);
-    for (j=0; j < (long) count; j++)
-      (void) WriteBlobByte(image,(unsigned char) buffer[j]);
+    (void) WriteBlob(image,count,buffer);
   }
   buffer=(unsigned char *) RelinquishMagickMemory(buffer);
   TIFFClose(tiff);
