@@ -127,7 +127,6 @@ static Image
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image *ConstituteImage(const unsigned long columns,
   const unsigned long rows,const char *map,const StorageType storage,
@@ -181,7 +180,6 @@ MagickExport Image *ConstituteImage(const unsigned long columns,
 %
 %      DestroyConstitute(void)
 %
-%
 */
 MagickExport void DestroyConstitute(void)
 {
@@ -287,7 +285,6 @@ MagickExport Image *PingImage(const ImageInfo *image_info,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image *ReadImage(const ImageInfo *image_info,
   ExceptionInfo *exception)
@@ -382,11 +379,11 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
     }
   image=NewImageList();
   if ((magick_info != (const MagickInfo *) NULL) &&
-      (GetMagickDecoder(magick_info) != (DecoderHandler *) NULL))
+      (GetImageDecoder(magick_info) != (DecodeImageHandler *) NULL))
     {
       if ((GetMagickThreadSupport(magick_info) & DecoderThreadSupport) == 0)
         AcquireSemaphoreInfo(&constitute_semaphore);
-      image=GetMagickDecoder(magick_info)(read_info,exception);
+      image=GetImageDecoder(magick_info)(read_info,exception);
       if ((GetMagickThreadSupport(magick_info) & DecoderThreadSupport) == 0)
         RelinquishSemaphoreInfo(constitute_semaphore);
     }
@@ -427,7 +424,7 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
       (void) SetImageInfo(read_info,MagickFalse,exception);
       magick_info=GetMagickInfo(read_info->magick,exception);
       if ((magick_info == (const MagickInfo *) NULL) ||
-          (GetMagickDecoder(magick_info) == (DecoderHandler *) NULL))
+          (GetImageDecoder(magick_info) == (DecodeImageHandler *) NULL))
         {
           if (IsAccessible(read_info->filename) != MagickFalse)
             (void) ThrowMagickException(exception,GetMagickModule(),
@@ -441,7 +438,7 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
         }
       if ((GetMagickThreadSupport(magick_info) & DecoderThreadSupport) == 0)
         AcquireSemaphoreInfo(&constitute_semaphore);
-      image=(Image *) (GetMagickDecoder(magick_info))(read_info,exception);
+      image=(Image *) (GetImageDecoder(magick_info))(read_info,exception);
       if ((GetMagickThreadSupport(magick_info) & DecoderThreadSupport) == 0)
         RelinquishSemaphoreInfo(constitute_semaphore);
     }
@@ -502,15 +499,15 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
       MaxTextExtent);
     if (IsBlobTemporary(image) != MagickFalse)
       (void) CopyMagickString(next->filename,filename,MaxTextExtent);
-    value=GetImageProperty(next,"EXIF:Orientation");
+    value=GetImageProperty(next,"exif:Orientation");
     if (value != (char *) NULL)
       {
         next->orientation=(OrientationType) atol(value);
-        (void) DeleteImageProperty(next,"EXIF:Orientation");
+        (void) DeleteImageProperty(next,"exif:Orientation");
       }
-    value=GetImageProperty(next,"TIFF:XResolution");
+    value=GetImageProperty(next,"tiff:XResolution");
     if (value == (char *) NULL)
-      value=GetImageProperty(next,"EXIF:XResolution");
+      value=GetImageProperty(next,"exif:XResolution");
     if (value != (char *) NULL)
       {
         geometry_info.rho=next->x_resolution;
@@ -518,12 +515,12 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
         flags=ParseGeometry(value,&geometry_info);
         if (geometry_info.sigma != 0)
           next->x_resolution=geometry_info.rho/geometry_info.sigma;
-        (void) DeleteImageProperty(next,"EXIF:XResolution");
-        (void) DeleteImageProperty(next,"TIFF:XResolution");
+        (void) DeleteImageProperty(next,"exif:XResolution");
+        (void) DeleteImageProperty(next,"tiff:XResolution");
       }
-    value=GetImageProperty(next,"TIFF:YResolution");
+    value=GetImageProperty(next,"tiff:YResolution");
     if (value == (char *) NULL)
-      value=GetImageProperty(next,"EXIF:YResolution");
+      value=GetImageProperty(next,"exif:YResolution");
     if (value != (char *) NULL)
       {
         geometry_info.rho=next->y_resolution;
@@ -531,17 +528,17 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
         flags=ParseGeometry(value,&geometry_info);
         if (geometry_info.sigma != 0)
           next->y_resolution=geometry_info.rho/geometry_info.sigma;
-        (void) DeleteImageProperty(next,"EXIF:YResolution");
-        (void) DeleteImageProperty(next,"TIFF:YResolution");
+        (void) DeleteImageProperty(next,"exif:YResolution");
+        (void) DeleteImageProperty(next,"tiff:YResolution");
       }
-    value=GetImageProperty(next,"TIFF:ResolutionUnit");
+    value=GetImageProperty(next,"tiff:ResolutionUnit");
     if (value == (char *) NULL)
-      value=GetImageProperty(next,"EXIF:YResolution");
+      value=GetImageProperty(next,"exif:ResolutionUnit");
     if (value != (char *) NULL)
       {
         next->units=(ResolutionType) (atoi(value)-1);
-        (void) DeleteImageProperty(next,"EXIF:ResolutionUnit");
-        (void) DeleteImageProperty(next,"TIFF:ResolutionUnit");
+        (void) DeleteImageProperty(next,"exif:ResolutionUnit");
+        (void) DeleteImageProperty(next,"tiff:ResolutionUnit");
       }
     if (next->page.width == 0)
       next->page.width=next->columns;
@@ -741,7 +738,6 @@ static Image *ReadImages(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image *ReadInlineImage(const ImageInfo *image_info,
   const char *content,ExceptionInfo *exception)
@@ -949,14 +945,14 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
         }
     }
   if ((magick_info != (const MagickInfo *) NULL) &&
-      (GetMagickEncoder(magick_info) != (EncoderHandler *) NULL))
+      (GetImageEncoder(magick_info) != (EncodeImageHandler *) NULL))
     {
       /*
         Call appropriate image writer based on image type.
       */
       if ((GetMagickThreadSupport(magick_info) & EncoderThreadSupport) == 0)
         AcquireSemaphoreInfo(&constitute_semaphore);
-      status=GetMagickEncoder(magick_info)(write_info,image);
+      status=GetImageEncoder(magick_info)(write_info,image);
       if ((GetMagickThreadSupport(magick_info) & EncoderThreadSupport) == 0)
         RelinquishSemaphoreInfo(constitute_semaphore);
     }
@@ -989,7 +985,7 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
               magick_info=GetMagickInfo(write_info->magick,&image->exception);
             }
           if ((magick_info == (const MagickInfo *) NULL) ||
-              (GetMagickEncoder(magick_info) == (EncoderHandler *) NULL))
+              (GetImageEncoder(magick_info) == (EncodeImageHandler *) NULL))
             (void) ThrowMagickException(&image->exception,GetMagickModule(),
               MissingDelegateError,"NoEncodeDelegateForThisImageFormat","`%s'",
               image->filename);
@@ -1000,7 +996,7 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
               */
               if ((GetMagickThreadSupport(magick_info) & EncoderThreadSupport) == 0)
                 AcquireSemaphoreInfo(&constitute_semaphore);
-              status=GetMagickEncoder(magick_info)(write_info,image);
+              status=GetImageEncoder(magick_info)(write_info,image);
               if ((GetMagickThreadSupport(magick_info) & EncoderThreadSupport) == 0)
                 RelinquishSemaphoreInfo(constitute_semaphore);
             }
