@@ -16,7 +16,7 @@
 %                               October 1998                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -74,66 +74,53 @@
 */
 static const char
   *DelegateMap = (const char *)
-    "<?xml version=\"1.0\"?>"
+    "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
     "<delegatemap>"
-    "  <delegate decode=\"autotrace\" stealth=\"True\" command='\"autotrace\" -output-format svg -output-file \"%o\" \"%i\"' />"
-    "  <delegate decode=\"browse\" stealth=\"True\" spawn=\"True\" command='\"htmlview\" http://www.imagemagick.org/'  />"
-    "  <delegate decode=\"cgm\" command='\"ralcgm\" -d ps -oC < \"%i\" > \"%o\" 2>/dev/null' />"
-    "  <delegate decode=\"crw\" thread-support=\"False\" command='\"dcraw\" -3 -w -c \"%i\" > \"%o\"' />"
-    "  <delegate decode=\"dcr\" thread-support=\"False\" command='\"dcraw\" -3 -w -c \"%i\" > \"%o\"' />"
-    "  <delegate decode=\"mrw\" thread-support=\"False\" command='\"dcraw\" -3 -w -c \"%i\" > \"%o\"' />"
-    "  <delegate decode=\"nef\" thread-support=\"False\" command='\"dcraw\" -3 -w -c \"%i\" > \"%o\"' />"
-    "  <delegate decode=\"orf\" thread-support=\"False\" command='\"dcraw\" -3 -w -c \"%i\" > \"%o\"' />"
-    "  <delegate decode=\"raf\" thread-support=\"False\" command='\"dcraw\" -3 -w -c \"%i\" > \"%o\"' />"
-    "  <delegate decode=\"x3f\" thread-support=\"False\" command='\"dcraw\" -3 -w -c \"%i\" > \"%o\"' />"
-    "  <delegate decode=\"dvi\" command='\"dvips\" -q -o \"%o\" \"%i\"' />"
-    "  <delegate decode=\"edit\" stealth=\"True\" command='\"xterm\" -title \"Edit Image Comment\" -e vi \"%o\"' />"
-    "  <delegate decode=\"emf\" command='\"wmf2eps\" -o \"%o\" \"%i\"' />"
-    "  <delegate decode=\"eps\" encode=\"pdf\" mode=\"bi\" command='\"gs\" -q -dBATCH -dSAFER -dMaxBitmap=500000000 -dNOPAUSE -dAlignToPixels=0 -sDEVICE=\"pdfwrite\" -sOutputFile=\"%o\" -f\"%i\"' />"
-    "  <delegate decode=\"eps\" encode=\"ps\" mode=\"bi\" command='\"gs\" -q -dBATCH -dSAFER -dMaxBitmap=500000000 -dNOPAUSE -dAlignToPixels=0 -sDEVICE=\"pswrite\" -sOutputFile=\"%o\" -f\"%i\"' />"
-    "  <delegate decode=\"fig\" command='\"fig2dev\" -L ps \"%i\" \"%o\"' />"
-    "  <delegate decode=\"gplt\" command='\"echo\" \"set size 1.25,0.62"
-    "    set terminal postscript portrait color solid; set output \"%o\"; load \"%i\"\" > \"%u\";\"gnuplot\" \"%u\"' />"
-    "  <delegate decode=\"gs-color\" stealth=\"True\" command='\"gs\" -q -dBATCH -dSAFER -dMaxBitmap=500000000 -dNOPAUSE -dAlignToPixels=0 \"-sDEVICE=pnmraw\" -dTextAlphaBits=%u -dGraphicsAlphaBits=%u \"-g%s\" \"-r%s\" %s \"-sOutputFile=%s\" \"-f%s\" \"-f%s\"' />"
-    "  <delegate decode=\"gs-cmyk\" stealth=\"True\" command='\"gs\" -q -dBATCH -dSAFER -dMaxBitmap=500000000 -dNOPAUSE -dAlignToPixels=0 \"-sDEVICE=bmpsep8\" -dTextAlphaBits=%u -dGraphicsAlphaBits=%u \"-g%s\" \"-r%s\" %s \"-sOutputFile=%s\" \"-f%s\" \"-f%s\"' />"
-    "  <delegate decode=\"gs-mono\" stealth=\"True\" command='\"gs\" -q -dBATCH -dSAFER -dMaxBitmap=500000000 -dNOPAUSE -dAlignToPixels=0 \"-sDEVICE=pbmraw\" -dTextAlphaBits=%u -dGraphicsAlphaBits=%u \"-g%s\" \"-r%s\" %s \"-sOutputFile=%s\" \"-f%s\" \"-f%s\"' />"
-    "  <delegate decode=\"hpg\" command='\"hp2xx\" -q -m eps -f `basename \"%o\"` \"%i\""
-    "    mv -f `basename \"%o\"` \"%o\"' />"
-    "  <delegate decode=\"hpgl\" command='if [ -e hp2xx -o -e /usr/bin/hp2xx ]; then"
-    "    hp2xx -q -m eps -f `basename \"%o\"` \"%i\""
-    "    mv -f `basename \"%o\"` \"%o"
-    "  else"
-    "    echo \"You need to install hp2xx to use HPGL files with ImageMagick.\""
-    "    exit 1"
-    "  fi' />"
-    "  <delegate decode=\"htm\" command='\"html2ps\" -U -o \"%o\" \"%i\"' />"
-    "  <delegate decode=\"html\" command='\"html2ps\" -U -o \"%o\" \"%i\"' />"
-    "  <delegate decode=\"https\" command='\"@WWWDecodeDelegateDefault@\" -q -O \"%o\" \"https:%i\"' />"
-    "  <delegate decode=\"ilbm\" command='\"ilbmtoppm\" \"%i\" > \"%o\"' />"
-    "  <delegate decode=\"man\" command='\"groff\" -man -Tps \"%i\" > \"%o\"' />"
-    "  <delegate decode=\"mpeg-decode\" stealth=\"True\" command='\"mpeg2decode\" -q -b \"%i\" -f -r -o3 \"%u%%d\"' />"
-    "  <delegate encode=\"mpeg-encode\" stealth=\"True\" command='\"mpeg2encode\" \"%i\" \"%o\"' />"
-    "  <delegate decode=\"pcl-color\" stealth=\"True\" command='\"pcl6\" -dBATCH -dSAFER -dMaxBitmap=500000000 -dNOPAUSE -dAlignToPixels=0 \"-sDEVICE=ppmraw\" -dTextAlphaBits=%u -dGraphicsAlphaBits=%u \"-g%s\" \"-r%s\" %s \"-sOutputFile=%s\" \"%s\"' />"
-    "  <delegate decode=\"pcl-cmyk\" stealth=\"True\" command='\"pcl6\" -dBATCH -dSAFER -dMaxBitmap=500000000 -dNOPAUSE -dAlignToPixels=0 \"-sDEVICE=@PCLCMYKDevice@\" -dTextAlphaBits=%u -dGraphicsAlphaBits=%u \"-g%s\" \"-r%s\" %s \"-sOutputFile=%s\" \"%s\"' />"
-    "  <delegate decode=\"pcl-mono\" stealth=\"True\" command='\"pcl6\" -dBATCH -dSAFER -dMaxBitmap=500000000 -dNOPAUSE -dAlignToPixels=0 \"-sDEVICE=pbmraw\" -dTextAlphaBits=%u -dGraphicsAlphaBits=%u \"-g%s\" \"-r%s\" %s \"-sOutputFile=%s\" \"%s\"' />"
-    "  <delegate decode=\"pdf\" encode=\"eps\" mode=\"bi\" command='\"gs\" -q -dBATCH -dSAFER -dMaxBitmap=500000000 -dNOPAUSE -dAlignToPixels=0 -sDEVICE=\"epswrite\" -sOutputFile=\"%o\" -f\"%i\"' />"
-    "  <delegate decode=\"pdf\" encode=\"ps\" mode=\"bi\" command='\"gs\" -q -dBATCH -dSAFER -dMaxBitmap=500000000 -dNOPAUSE -dAlignToPixels=0 -sDEVICE=\"pswrite\" -sOutputFile=\"%o\" -f\"%i\"' />"
-    "  <delegate decode=\"pnm\" encode=\"ilbm\" mode=\"encode\" command='\"ppmtoilbm\" -24if \"%i\" > \"%o\"' />"
-    "  <delegate decode=\"pnm\" encode=\"launch\" mode=\"encode\" command='\"gimp\" \"%i\"' />"
-    "  <delegate decode=\"miff\" encode=\"win\" mode=\"encode\" command='\"display\" -immutable \"%i\"' />"
-    "  <delegate decode=\"pov\" command='\"povray\" \"+i\"%i\"\" +o\"%o\" +fn%q +w%w +h%h +a -q9 -kfi\"%s\" -kff\"%n\""
-    "    \"convert\" -concatenate \"%o*.png\" \"%o\"' />"
-    "  <delegate decode=\"ps\" encode=\"eps\" mode=\"bi\" command='\"gs\" -q -dBATCH -dSAFER -dMaxBitmap=500000000 -dNOPAUSE -dAlignToPixels=0 -sDEVICE=\"epswrite\" -sOutputFile=\"%o\" -f\"%i\"' />"
-    "  <delegate decode=\"ps\" encode=\"pdf\" mode=\"bi\" command='\"gs\" -q -dBATCH -dSAFER -dMaxBitmap=500000000 -dNOPAUSE -dAlignToPixels=0 -sDEVICE=\"pdfwrite\" -sOutputFile=\"%o\" -f\"%i\"' />"
-    "  <delegate decode=\"ps\" encode=\"print\" mode=\"encode\" command='lpr \"%i\"' />"
-    "  <delegate decode=\"rad\" command='\"ra_ppm\" -g 1.0 \"%i\" \"%o\"' />"
-    "  <delegate decode=\"rgba\" encode=\"rle\" mode=\"encode\" command='\"modify\" -flip -size %wx%h \"rgba:%i\""
-    "    \"rawtorle\" -w %w -h %h -n 4 -o \"%o\" \"%i\"' />"
-    "  <delegate decode=\"scan\" command='\"scanimage\" -d \"%i\" > \"%o\"' />"
-    "  <delegate decode=\"shtml\" command='\"html2ps\" -U -o \"%o\" \"%i\"' />"
-    "  <delegate decode=\"txt\" encode=\"ps\" mode=\"bi\" command='\"enscript\" -o \"%o\" \"%i\"' />"
-    "  <delegate decode=\"wmf\" command='\"wmf2eps\" -o \"%o\" \"%i\"' />"
-    "  <delegate encode=\"show\" stealth=\"True\" spawn=\"True\" command='\"display\" -immutable -delay 0 -window_group %g -title \"%l of %f\" \"tmp:%i\"' />"
+    "  <delegate decode=\"autotrace\" stealth=\"True\" command=\"&quot;autotrace&quot; -output-format svg -output-file &quot;%o&quot; &quot;%i&quot;\"/>"
+    "  <delegate decode=\"browse\" stealth=\"True\" spawn=\"True\" command=\"&quot;htmlview&quot; http://www.imagemagick.org/\"/>"
+    "  <delegate decode=\"cgm\" thread-support=\"False\" command=\"&quot;ralcgm&quot; -d ps -oC &lt; &quot;%i&quot; &gt; &quot;%o&quot; &gt;&gt;/dev/null\"/>"
+    "  <delegate decode=\"dng:decode\" command=\"&quot;/usr/bin/ufraw-batch&quot; --silent --wb=camera --black-point=auto --exposure=auto --create-id=also --out-type=ppm16 &quot;--output=%u.pnm&quot; &quot;%i&quot;\"/>"
+    "  <delegate decode=\"edit\" stealth=\"True\" command=\"&quot;xterm&quot; -title &quot;Edit Image Comment&quot; -e vi &quot;%o&quot;\"/>"
+    "  <delegate decode=\"eps\" encode=\"pdf\" mode=\"bi\" command=\"&quot;gs&quot; -q -dQUIET -dSAFER -dPARANOIDSAFE -dBATCH -dNOPAUSE -dNOPROMPT -dMaxBitmap=500000000 -dAlignToPixels=0 -dGridFitTT=0 &quot;-sDEVICE=pdfwrite&quot; &quot;-sOutputFile=%o&quot; &quot;-f%i&quot;\"/>"
+    "  <delegate decode=\"eps\" encode=\"ps\" mode=\"bi\" command=\"&quot;gs&quot; -q -dQUIET -dSAFER -dPARANOIDSAFE -dBATCH -dNOPAUSE -dNOPROMPT -dMaxBitmap=500000000 -dAlignToPixels=0 -dGridFitTT=0 &quot;-sDEVICE=pswrite&quot; &quot;-sOutputFile=%o&quot; &quot;-f%i&quot;\"/>"
+    "  <delegate decode=\"fig\" command=\"&quot;fig2dev&quot; -L ps &quot;%i&quot; &quot;%o&quot;\"/>"
+    "  <delegate decode=\"gplt\" command=\"&quot;echo&quot; &quot;set size 1.25,0.62     set terminal postscript portrait color solid; set output &quot;%o&quot;; load &quot;%i&quot;&quot; &gt; &quot;%u&quot;;&quot;gnuplot&quot; &quot;%u&quot;\"/>"
+    "  <delegate decode=\"hdr\" command=\"&quot;ra_pfm&quot; &quot;%i&quot; &quot;%o&quot;\"/>"
+    "  <delegate decode=\"hpg\" command=\"&quot;hp2xx&quot; -q -m eps -f `basename &quot;%o&quot;` &quot;%i&quot;     mv -f `basename &quot;%o&quot;` &quot;%o&quot;\"/>"
+    "  <delegate decode=\"hpgl\" command=\"if [ -e hp2xx -o -e /usr/bin/hp2xx ]; then     hp2xx -q -m eps -f `basename &quot;%o&quot;` &quot;%i&quot;     mv -f `basename &quot;%o&quot;` &quot;%o   else     echo &quot;You need to install hp2xx to use HPGL files with ImageMagick.&quot;     exit 1   fi\"/>"
+    "  <delegate decode=\"htm\" command=\"&quot;html2ps&quot; -U -o &quot;%o&quot; &quot;%i&quot;\"/>"
+    "  <delegate decode=\"html\" command=\"&quot;html2ps&quot; -U -o &quot;%o&quot; &quot;%i&quot;\"/>"
+    "  <delegate decode=\"https\" command=\"&quot;wget&quot; -q -O &quot;%o&quot; &quot;https:%M&quot;\"/>"
+    "  <delegate decode=\"ilbm\" command=\"&quot;ilbmtoppm&quot; &quot;%i&quot; &gt; &quot;%o&quot;\"/>"
+    "  <delegate decode=\"man\" command=\"&quot;groff&quot; -man -Tps &quot;%i&quot; &gt; &quot;%o&quot;\"/>"
+    "  <delegate decode=\"mpeg:decode\" stealth=\"True\" command=\"&quot;mpeg2decode&quot; -q -b &quot;%i&quot; -f -r -o3 &quot;%u%%d&quot;\"/>"
+    "  <delegate encode=\"mpeg:encode\" stealth=\"True\" command=\"&quot;mpeg2encode&quot; &quot;%i&quot; &quot;%o&quot;\"/>"
+    "  <delegate decode=\"pcl:color\" stealth=\"True\" command=\"&quot;pcl6&quot; -dQUIET -dSAFER -dPARANOIDSAFE -dBATCH -dNOPAUSE -dNOPROMPT -dMaxBitmap=500000000 -dAlignToPixels=0 -dGridFitTT=0 &quot;-sDEVICE=ppmraw&quot; -dTextAlphaBits=%u -dGraphicsAlphaBits=%u &quot;-g%s&quot; &quot;-r%s&quot; %s &quot;-sOutputFile=%s&quot; &quot;%s&quot;\"/>"
+    "  <delegate decode=\"pcl:cmyk\" stealth=\"True\" command=\"&quot;pcl6&quot; -dQUIET -dSAFER -dPARANOIDSAFE -dBATCH -dNOPAUSE -dNOPROMPT -dMaxBitmap=500000000 -dAlignToPixels=0 -dGridFitTT=0 &quot;-sDEVICE=bmpsep8&quot; -dTextAlphaBits=%u -dGraphicsAlphaBits=%u &quot;-g%s&quot; &quot;-r%s&quot; %s &quot;-sOutputFile=%s&quot; &quot;%s&quot;\"/>"
+    "  <delegate decode=\"pcl:mono\" stealth=\"True\" command=\"&quot;pcl6&quot; -dQUIET -dSAFER -dPARANOIDSAFE -dBATCH -dNOPAUSE -dNOPROMPT -dMaxBitmap=500000000 -dAlignToPixels=0 -dGridFitTT=0 &quot;-sDEVICE=pbmraw&quot; -dTextAlphaBits=%u -dGraphicsAlphaBits=%u &quot;-g%s&quot; &quot;-r%s&quot; %s &quot;-sOutputFile=%s&quot; &quot;%s&quot;\"/>"
+    "  <delegate decode=\"pdf\" encode=\"eps\" mode=\"bi\" command=\"&quot;gs&quot; -q -dQUIET -dSAFER -dPARANOIDSAFE -dBATCH -dNOPAUSE -dNOPROMPT -dMaxBitmap=500000000 -dAlignToPixels=0 -dGridFitTT=0 &quot;-sDEVICE=epswrite&quot; &quot;-sOutputFile=%o&quot; &quot;-f%i&quot;\"/>"
+    "  <delegate decode=\"pdf\" encode=\"ps\" mode=\"bi\" command=\"&quot;gs&quot; -q -dQUIET -dSAFER -dPARANOIDSAFE -dBATCH -dNOPAUSE -dNOPROMPT -dMaxBitmap=500000000 -dAlignToPixels=0 -dGridFitTT=0 &quot;-sDEVICE=pswrite&quot; &quot;-sOutputFile=%o&quot; &quot;-f%i&quot;\"/>"
+    "  <delegate decode=\"pic\" command=\"&quot;ra_pfm&quot; &quot;%i&quot; &quot;%o&quot;\"/>"
+    "  <delegate decode=\"pnm\" encode=\"ilbm\" mode=\"encode\" command=\"&quot;ppmtoilbm&quot; -24if &quot;%i&quot; &gt; &quot;%o&quot;\"/>"
+    "  <delegate decode=\"pnm\" encode=\"launch\" mode=\"encode\" command=\"&quot;gimp&quot; &quot;%i&quot;\"/>"
+    "  <delegate decode=\"pov\" command=\"&quot;povray&quot; &quot;+i&quot;%i&quot;&quot; -D0 +o&quot;%o&quot; +fn%q +w%w +h%h +a -q9 -kfi&quot;%s&quot; -kff&quot;%n&quot;     &quot;convert&quot; -concatenate &quot;%o*.png&quot; &quot;%o&quot;\"/>"
+    "  <delegate decode=\"ps\" encode=\"eps\" mode=\"bi\" command=\"&quot;gs&quot; -q -dQUIET -dSAFER -dPARANOIDSAFE -dBATCH -dNOPAUSE -dNOPROMPT -dMaxBitmap=500000000 -dAlignToPixels=0 -dGridFitTT=0 &quot;-sDEVICE=epswrite&quot; &quot;-sOutputFile=%o&quot; &quot;-f%i&quot;\"/>"
+    "  <delegate decode=\"ps\" encode=\"pdf\" mode=\"bi\" command=\"&quot;gs&quot; -q -dQUIET -dSAFER -dPARANOIDSAFE -dBATCH -dNOPAUSE -dNOPROMPT -dMaxBitmap=500000000 -dAlignToPixels=0 -dGridFitTT=0 &quot;-sDEVICE=pdfwrite&quot; &quot;-sOutputFile=%o&quot; &quot;-f%i&quot;\"/>"
+    "  <delegate decode=\"ps\" encode=\"print\" mode=\"encode\" command=\"lpr &quot;%i&quot;\"/>"
+    "  <delegate decode=\"ps:alpha\" stealth=\"True\" command=\"&quot;gs&quot; -q -dQUIET -dSAFER -dPARANOIDSAFE -dBATCH -dNOPAUSE -dNOPROMPT -dMaxBitmap=500000000 -dAlignToPixels=0 -dGridFitTT=0 &quot;-sDEVICE=pngalpha&quot; -dTextAlphaBits=%u -dGraphicsAlphaBits=%u &quot;-g%s&quot; &quot;-r%s&quot; %s &quot;-sOutputFile=%s&quot; &quot;-f%s&quot; &quot;-f%s&quot;\"/>"
+    "  <delegate decode=\"ps:bbox\" stealth=\"True\" command=\"&quot;gs&quot; -q -dQUIET -dSAFER -dPARANOIDSAFE -dBATCH -dNOPAUSE -dNOPROMPT -dMaxBitmap=500000000 -dAlignToPixels=0 -dGridFitTT=0 &quot;-sDEVICE=bbox&quot; -dTextAlphaBits=%u -dGraphicsAlphaBits=%u &quot;-g%s&quot; &quot;-r%s&quot; %s &quot;-sOutputFile=%s&quot; &quot;-f%s&quot; &quot;-f%s&quot;\"/>"
+    "  <delegate decode=\"ps:cmyk\" stealth=\"True\" command=\"&quot;gs&quot; -q -dQUIET -dSAFER -dPARANOIDSAFE -dBATCH -dNOPAUSE -dNOPROMPT -dMaxBitmap=500000000 -dAlignToPixels=0 -dGridFitTT=0 &quot;-sDEVICE=pam&quot; -dTextAlphaBits=%u -dGraphicsAlphaBits=%u &quot;-g%s&quot; &quot;-r%s&quot; %s &quot;-sOutputFile=%s&quot; &quot;-f%s&quot; &quot;-f%s&quot;\"/>"
+    "  <delegate decode=\"ps:color\" stealth=\"True\" command=\"&quot;gs&quot; -q -dQUIET -dSAFER -dPARANOIDSAFE -dBATCH -dNOPAUSE -dNOPROMPT -dMaxBitmap=500000000 -dAlignToPixels=0 -dGridFitTT=0 &quot;-sDEVICE=pnmraw&quot; -dTextAlphaBits=%u -dGraphicsAlphaBits=%u &quot;-g%s&quot; &quot;-r%s&quot; %s &quot;-sOutputFile=%s&quot; &quot;-f%s&quot; &quot;-f%s&quot;\"/>"
+    "  <delegate decode=\"ps:mono\" stealth=\"True\" command=\"&quot;gs&quot; -q -dQUIET -dSAFER -dPARANOIDSAFE -dBATCH -dNOPAUSE -dNOPROMPT -dMaxBitmap=500000000 -dAlignToPixels=0 -dGridFitTT=0 &quot;-sDEVICE=pnmraw&quot; -dTextAlphaBits=%u -dGraphicsAlphaBits=%u &quot;-g%s&quot; &quot;-r%s&quot; %s &quot;-sOutputFile=%s&quot; &quot;-f%s&quot; &quot;-f%s&quot;\"/>"
+    "  <delegate decode=\"rad\" command=\"&quot;ra_pfm&quot; &quot;%i&quot; &quot;%o&quot;\"/>"
+    "  <delegate decode=\"rgba\" encode=\"rle\" mode=\"encode\" command=\"&quot;rawtorle&quot; -o &quot;%o&quot; -v &quot;%i&quot;\"/>"
+    "  <delegate decode=\"scan\" command=\"&quot;scanimage&quot; -d &quot;%i&quot; &gt; &quot;%o&quot;\"/>"
+    "  <delegate encode=\"show\" stealth=\"True\" spawn=\"True\" command=\"&quot;/usr/local/bin/display&quot; -immutable -delay 0 -window-group %g -title &quot;%l of %f&quot; &quot;tmp:%i&quot;\"/>"
+    "  <delegate decode=\"shtml\" command=\"&quot;html2ps&quot; -U -o &quot;%o&quot; &quot;%i&quot;\"/>"
+    "  <delegate decode=\"svg\" command=\"&quot;wmf2eps&quot; -o &quot;%o&quot; &quot;%i&quot;\"/>"
+    "  <delegate decode=\"txt\" encode=\"ps\" mode=\"bi\" command=\"&quot;enscript&quot; -o &quot;%o&quot; &quot;%i&quot;\"/>"
+    "  <delegate encode=\"win\" stealth=\"True\" spawn=\"True\" command=\"&quot;/usr/local/bin/display&quot; -immutable -delay 0 -window-group %g -title &quot;%l of %f&quot; &quot;tmp:%i&quot;\"/>"
+    "  <delegate decode=\"wmf\" command=\"&quot;wmf2eps&quot; -o &quot;%o&quot; &quot;%i&quot;\"/>"
     "</delegatemap>";
 
 /*
@@ -181,13 +168,13 @@ static void *DestroyDelegate(void *delegate_info)
 
   p=(DelegateInfo *) delegate_info;
   if (p->path != (char *) NULL)
-    p->path=(char *) RelinquishMagickMemory(p->path);
+    p->path=DestroyString(p->path);
   if (p->decode != (char *) NULL)
-    p->decode=(char *) RelinquishMagickMemory(p->decode);
+    p->decode=DestroyString(p->decode);
   if (p->encode != (char *) NULL)
-    p->encode=(char *) RelinquishMagickMemory(p->encode);
+    p->encode=DestroyString(p->encode);
   if (p->commands != (char *) NULL)
-    p->commands=(char *) RelinquishMagickMemory(p->commands);
+    p->commands=DestroyString(p->commands);
   p=(DelegateInfo *) RelinquishMagickMemory(p);
   return((void *) NULL);
 }
@@ -239,7 +226,6 @@ MagickExport void DestroyDelegateList(void)
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport char *GetDelegateCommand(const ImageInfo *image_info,Image *image,
   const char *decode,const char *encode,ExceptionInfo *exception)
@@ -283,7 +269,7 @@ MagickExport char *GetDelegateCommand(const ImageInfo *image_info,Image *image,
     Free resources.
   */
   for (i=0; commands[i] != (char *) NULL; i++)
-    commands[i]=(char *) RelinquishMagickMemory(commands[i]);
+    commands[i]=DestroyString(commands[i]);
   commands=(char **) RelinquishMagickMemory(commands);
   return(command);
 }
@@ -346,7 +332,6 @@ MagickExport const char *GetDelegateCommands(const DelegateInfo *delegate_info)
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport const DelegateInfo *GetDelegateInfo(const char *decode,
   const char *encode,ExceptionInfo *exception)
@@ -481,8 +466,8 @@ MagickExport const DelegateInfo **GetDelegateInfoList(const char *pattern,
   p=GetDelegateInfo("*","*",exception);
   if (p == (const DelegateInfo *) NULL)
     return((const DelegateInfo **) NULL);
-  delegates=(const DelegateInfo **) AcquireMagickMemory((size_t)
-    (GetNumberOfElementsInLinkedList(delegate_list)+1)*sizeof(*delegates));
+  delegates=(const DelegateInfo **) AcquireQuantumMemory((size_t)
+    GetNumberOfElementsInLinkedList(delegate_list)+1UL,sizeof(*delegates));
   if (delegates == (const DelegateInfo **) NULL)
     return((const DelegateInfo **) NULL);
   /*
@@ -494,8 +479,8 @@ MagickExport const DelegateInfo **GetDelegateInfoList(const char *pattern,
   for (i=0; p != (const DelegateInfo *) NULL; )
   {
     if ((p->stealth == MagickFalse) &&
-        ((GlobExpression(p->decode,pattern) != MagickFalse) ||
-         (GlobExpression(p->encode,pattern) != MagickFalse)))
+        ((GlobExpression(p->decode,pattern,MagickFalse) != MagickFalse) ||
+         (GlobExpression(p->encode,pattern,MagickFalse) != MagickFalse)))
       delegates[i++]=p;
     p=(const DelegateInfo *) GetNextValueInLinkedList(delegate_list);
   }
@@ -577,8 +562,8 @@ MagickExport char **GetDelegateList(const char *pattern,
   p=GetDelegateInfo("*","*",exception);
   if (p == (const DelegateInfo *) NULL)
     return((char **) NULL);
-  delegates=(char **) AcquireMagickMemory((size_t)
-    (GetNumberOfElementsInLinkedList(delegate_list)+1)*sizeof(*delegates));
+  delegates=(char **) AcquireQuantumMemory((size_t)
+    GetNumberOfElementsInLinkedList(delegate_list)+1UL,sizeof(*delegates));
   if (delegates == (char **) NULL)
     return((char **) NULL);
   AcquireSemaphoreInfo(&delegate_semaphore);
@@ -587,10 +572,10 @@ MagickExport char **GetDelegateList(const char *pattern,
   for (i=0; p != (const DelegateInfo *) NULL; )
   {
     if ((p->stealth == MagickFalse) &&
-        (GlobExpression(p->decode,pattern) != MagickFalse))
+        (GlobExpression(p->decode,pattern,MagickFalse) != MagickFalse))
       delegates[i++]=ConstantString(p->decode);
     if ((p->stealth == MagickFalse) &&
-        (GlobExpression(p->encode,pattern) != MagickFalse))
+        (GlobExpression(p->encode,pattern,MagickFalse) != MagickFalse))
       delegates[i++]=ConstantString(p->encode);
     p=(const DelegateInfo *) GetNextValueInLinkedList(delegate_list);
   }
@@ -733,6 +718,13 @@ static MagickBooleanType InitializeDelegateList(ExceptionInfo *exception)
 %
 */
 
+static inline size_t MagickMin(const size_t x,const size_t y)
+{
+  if (x < y)
+    return(x);
+  return(y);
+}
+
 static void CopyDelegateFile(const char *source,const char *destination)
 {
   int
@@ -764,7 +756,7 @@ static void CopyDelegateFile(const char *source,const char *destination)
   /*
     Copy source file to destination.
   */
-  destination_file=open(destination,O_WRONLY | O_BINARY | O_CREAT);
+  destination_file=open(destination,O_WRONLY | O_BINARY | O_CREAT,S_MODE);
   if (destination_file == -1)
     return;
   source_file=open(source,O_RDONLY | O_BINARY);
@@ -773,10 +765,10 @@ static void CopyDelegateFile(const char *source,const char *destination)
       (void) close(destination_file);
       return;
     }
-  quantum=(size_t) (fstat(source_file,&file_info) < 0 ? 0 : file_info.st_size);
-  if ((quantum == 0) || (quantum > MagickMaxBufferSize))
-    quantum=MagickMaxBufferSize;
-  buffer=(unsigned char *) AcquireMagickMemory(quantum*sizeof(*buffer));
+  quantum=(size_t) MagickMaxBufferSize;
+  if ((fstat(source_file,&file_info) == 0) && (file_info.st_size != 0))
+    quantum=MagickMin((size_t) file_info.st_size,MagickMaxBufferSize);
+  buffer=(unsigned char *) AcquireQuantumMemory(quantum,sizeof(*buffer));
   if (buffer == (unsigned char *) NULL)
     {
       (void) close(source_file);
@@ -785,11 +777,11 @@ static void CopyDelegateFile(const char *source,const char *destination)
     }
   for (length=0; ; )
   {
-    count=read(source_file,buffer,quantum);
+    count=(ssize_t) read(source_file,buffer,quantum);
     if (count <= 0)
       break;
     length=(size_t) count;
-    count=write(destination_file,buffer,length);
+    count=(ssize_t) write(destination_file,buffer,length);
     if ((size_t) count != length)
       break;
   }
@@ -903,7 +895,7 @@ MagickExport MagickBooleanType InvokeDelegate(ImageInfo *image_info,
       (void) CopyMagickString((char *) clone_info->magick,magick,
         MaxTextExtent);
       (void) CopyMagickString(image->magick,magick,MaxTextExtent);
-      magick=(char *) RelinquishMagickMemory(magick);
+      magick=DestroyString(magick);
       (void) FormatMagickString(clone_info->filename,MaxTextExtent,"%s:",
         delegate_info->decode);
       (void) SetImageInfo(clone_info,MagickTrue,exception);
@@ -984,7 +976,9 @@ MagickExport MagickBooleanType InvokeDelegate(ImageInfo *image_info,
       (void) ConcatenateString(&command," &");
     status=SystemCommand(image_info->verbose,command) != 0 ?  MagickTrue :
       MagickFalse;
-    command=(char *) RelinquishMagickMemory(command);
+    if (delegate_info->spawn != MagickFalse)
+      (void) sleep(2);
+    command=DestroyString(command);
     (void) RelinquishUniqueFileResource(image->filename);
     (void) RelinquishUniqueFileResource(image_info->unique);
     (void) RelinquishUniqueFileResource(image_info->zero);
@@ -996,7 +990,7 @@ MagickExport MagickBooleanType InvokeDelegate(ImageInfo *image_info,
           "DelegateFailed","`%s'",commands[i]);
         return(MagickFalse);
       }
-    commands[i]=(char *) RelinquishMagickMemory(commands[i]);
+    commands[i]=DestroyString(commands[i]);
   }
   (void) CopyMagickString(image_info->filename,output_filename,MaxTextExtent);
   (void) CopyMagickString(image->filename,input_filename,MaxTextExtent);
@@ -1004,7 +998,7 @@ MagickExport MagickBooleanType InvokeDelegate(ImageInfo *image_info,
     Free resources.
   */
   for ( ; commands[i] != (char *) NULL; i++)
-    commands[i]=(char *) RelinquishMagickMemory(commands[i]);
+    commands[i]=DestroyString(commands[i]);
   commands=(char **) RelinquishMagickMemory(commands);
   if (temporary != MagickFalse)
     (void) RelinquishUniqueFileResource(image->filename);
@@ -1034,7 +1028,6 @@ MagickExport MagickBooleanType InvokeDelegate(ImageInfo *image_info,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport MagickBooleanType ListDelegateInfo(FILE *file,
   ExceptionInfo *exception)
@@ -1090,14 +1083,14 @@ MagickExport MagickBooleanType ListDelegateInfo(FILE *file,
       delegate_info[i]->decode : "",delegate_info[i]->mode <= 0 ? '<' : ' ',
       delegate_info[i]->mode >= 0 ? '>' : ' ',delegate);
     StripString(commands[0]);
-    (void) fprintf(file,"%s\n",commands[0]);
+    (void) fprintf(file,"\"%s\"\n",commands[0]);
     for (j=1; commands[j] != (char *) NULL; j++)
     {
       StripString(commands[j]);
-      (void) fprintf(file,"                     %s\n",commands[j]);
+      (void) fprintf(file,"                     \"%s\"\n",commands[j]);
     }
     for (j=0; commands[j] != (char *) NULL; j++)
-      commands[j]=(char *) RelinquishMagickMemory(commands[j]);
+      commands[j]=DestroyString(commands[j]);
     commands=(char **) RelinquishMagickMemory(commands);
   }
   (void) fflush(file);
@@ -1198,8 +1191,11 @@ static MagickBooleanType LoadDelegateList(const char *xml,const char *filename,
                 MaxTextExtent);
             (void) ConcatenateMagickString(path,attribute,MaxTextExtent);
             xml=FileToString(path,~0,exception);
-            status=LoadDelegateList(xml,path,depth+1,exception);
-            xml=(char *) RelinquishMagickMemory(xml);
+            if (xml != (char *) NULL)
+              {
+                status=LoadDelegateList(xml,path,depth+1,exception);
+                xml=DestroyString(xml);
+              }
           }
       }
     include=GetNextXMLTreeTag(include);
@@ -1215,8 +1211,8 @@ static MagickBooleanType LoadDelegateList(const char *xml,const char *filename,
     */
     delegate_info=(DelegateInfo *) AcquireMagickMemory(sizeof(*delegate_info));
     if (delegate_info == (DelegateInfo *) NULL)
-      ThrowMagickFatalException(ResourceLimitFatalError,
-        "MemoryAllocationFailed",filename);
+      ThrowFatalException(ResourceLimitFatalError,
+        "MemoryAllocationFailed");
     (void) ResetMagickMemory(delegate_info,0,sizeof(*delegate_info));
     delegate_info->path=ConstantString(filename);
     delegate_info->signature=MagickSignature;
@@ -1305,7 +1301,6 @@ static MagickBooleanType LoadDelegateList(const char *xml,const char *filename,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 static MagickBooleanType LoadDelegateLists(const char *filename,
   ExceptionInfo *exception)
