@@ -41,6 +41,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
+#include "magick/artifact.h"
 #include "magick/cache-view.h"
 #include "magick/colorspace-private.h"
 #include "magick/composite-private.h"
@@ -111,54 +112,51 @@
 %    o exception: Return any errors or warnings in this structure
 %
 */
+
+#if 0
+/* This function is no longer requires -- to be removed */
+
 static MagickBooleanType SolveAffineDistortion(
   const unsigned long number_points,const PointInfo *points,double **matrix,
   double *vector)
 {
   /*
-    Given the coordinates of two triangles
-      u0,v0, ... u2,v2,   x3,y3, ... x5,y5
+    Given the transformations of the coordinates for two triangles
+      u0,v0, x0,y0,  u1,v1, x1,y1,  u2,v2, x2,y2, ...
 
     Solve for the 6 cofficients c0..c6 for a affine distortion:
       u = c0*x + c2*y + c4
       v = c1*x + c3*y + c5
   */
+  register int
+    i;
+  double
+    x,y,u,v;
   if (number_points < 6)
     return(MagickFalse);
-  matrix[0][0]=points[3].x;
-  matrix[0][2]=points[3].y;
-  matrix[0][4]=1.0;
-  vector[0]=points[0].x;
+  for( i = 0; i < 6; ) {
+    u = points[i].x;
+    v = points[i].y;
+    x = points[i+1].x;
+    y = points[i+1].y;
 
-  matrix[1][1]=points[3].x;
-  matrix[1][3]=points[3].y;
-  matrix[1][5]=1.0;
-  vector[1]=points[0].y;
+    vector[i]=u;
+    matrix[i][0]=x;
+    matrix[i][2]=y;
+    matrix[i][4]=1.0;
+    i++;
 
-  matrix[2][0]=points[4].x;
-  matrix[2][2]=points[4].y;
-  matrix[2][4]=1.0;
-  vector[2]=points[1].x;
-
-  matrix[3][1]=points[4].x;
-  matrix[3][3]=points[4].y;
-  matrix[3][5]=1.0;
-  vector[3]=points[1].y;
-
-  matrix[4][0]=points[5].x;
-  matrix[4][2]=points[5].y;
-  matrix[4][4]=1.0;
-  vector[4]=points[2].x;
-
-  matrix[5][1]=points[5].x;
-  matrix[5][3]=points[5].y;
-  matrix[5][5]=1.0;
-  vector[5]=points[2].y;
-  return(GaussJordanElimination(matrix,6,vector));
+    vector[i]=v;
+    matrix[i][1]=x;
+    matrix[i][3]=y;
+    matrix[i][5]=1.0;
+    i++;
+  }
+  return(GaussJordanElimination(matrix,&vector,6UL,1UL));
 }
+#endif
 
-static void InvertAffineCoefficients(
-  const double *coefficients,double *inverse)
+static void InvertAffineCoefficients(const double *coefficients,double *inverse)
 {
   double determinant;
 
@@ -171,61 +169,48 @@ static void InvertAffineCoefficients(
   inverse[5]=(-coefficients[4])*inverse[1]-coefficients[5]*inverse[3];
 }
 
+#if 0
+/* This function is no longer requires -- to be removed */
+
 static MagickBooleanType SolveBilinearDistortion(
   const unsigned long number_points,const PointInfo *points,double **matrix,
   double *vector)
 {
   /*
-    Given the coordinates of two quadrilaterals:
-      u0,v0, ... u3,v3,   x4,y4, ... x7,y7
+    Given the transformations of the coordinates of two quadrilaterals:
+      u0,v0, x0,y0,  u1,v1, x1,y1,  u2,v2, x2,y2, ...
 
     Solve for the 8 coeffecients c0..c7 for a bilinear distortion:
       u = c0*x + c1*y + c2*x*y + c3
       v = c4*x + c5*y + c6*x*y + c7
   */
+  register int
+    i;
+  double
+    x,y,u,v;
   if (number_points < 8)
     return(MagickFalse);
-  matrix[0][0]=points[4].x;
-  matrix[0][1]=points[4].y;
-  matrix[0][2]=points[4].x*points[4].y;
-  matrix[0][3]=1.0;
-  vector[0]=points[0].x;
-  matrix[1][4]=points[4].x;
-  matrix[1][5]=points[4].y;
-  matrix[1][6]=points[4].x*points[4].y;
-  matrix[1][7]=1.0;
-  vector[1]=points[0].y;
-  matrix[2][0]=points[5].x;
-  matrix[2][1]=points[5].y;
-  matrix[2][2]=points[5].x*points[5].y;
-  matrix[2][3]=1.0;
-  matrix[3][4]=points[5].x;
-  matrix[3][5]=points[5].y;
-  matrix[3][6]=points[5].x*points[5].y;
-  matrix[3][7]=1.0;
-  matrix[4][0]=points[6].x;
-  matrix[4][1]=points[6].y;
-  matrix[4][2]=points[6].x*points[6].y;
-  matrix[4][3]=1.0;
-  matrix[5][4]=points[6].x;
-  matrix[5][5]=points[6].y;
-  matrix[5][6]=points[6].x*points[6].y;
-  matrix[5][7]=1.0;
-  matrix[6][0]=points[7].x;
-  matrix[6][1]=points[7].y;
-  matrix[6][2]=points[7].x*points[7].y;
-  matrix[6][3]=1.0;
-  matrix[7][4]=points[7].x;
-  matrix[7][5]=points[7].y;
-  matrix[7][6]=points[7].x*points[7].y;
-  matrix[7][7]=1.0;
-  vector[2]=points[1].x;
-  vector[3]=points[1].y;
-  vector[4]=points[2].x;
-  vector[5]=points[2].y;
-  vector[6]=points[3].x;
-  vector[7]=points[3].y;
-  return(GaussJordanElimination(matrix,8,vector));
+  for( i = 0; i < 8; ) {
+    u = points[i].x;
+    v = points[i].y;
+    x = points[i+1].x;
+    y = points[i+1].y;
+
+    vector[i]=u;
+    matrix[i][0]=x;
+    matrix[i][1]=y;
+    matrix[i][2]=x*y;
+    matrix[i][3]=1.0;
+    i++;
+
+    vector[i]=v;
+    matrix[i][4]=x;
+    matrix[i][5]=y;
+    matrix[i][6]=x*y;
+    matrix[i][7]=1.0;
+    i++;
+  }
+  return(GaussJordanElimination(matrix,&vector,8UL,1UL));
 }
 
 static MagickBooleanType SolvePerspectiveDistortion(
@@ -234,73 +219,52 @@ static MagickBooleanType SolvePerspectiveDistortion(
 {
   /*
     Given the coordinates of two quadrilaterals:
-      u0,v0, ... u3,v3,   x4,y4, ... x7,y7
+      u0,v0, x0,y0,  u1,v1, x1,y1,  u2,v2, x2,y2, ...
 
     Solve for the 8 coefficients c0..c7 for a perspective distortion:
-       u = ( c0*x + c1*y + c2 ) / ( c7*x + c8*y + 1 )
-       v = ( c3*x + c4*y + c5 ) / ( c7*x + c8*y + 1 )
+       u = ( c0*x + c1*y + c2 ) / ( c6*x + c7*y + 1 )
+       v = ( c3*x + c4*y + c5 ) / ( c6*x + c7*y + 1 )
    */
+  register int
+    i;
+  double
+    x,y,u,v;
   if (number_points < 8)
     return(MagickFalse);
-  matrix[0][0]=points[4].x;
-  matrix[0][1]=points[4].y;
-  matrix[0][2]=1.0;
-  matrix[0][6]=(-points[4].x*points[0].x);
-  matrix[0][7]=(-points[4].y*points[0].x);
-  matrix[1][3]=points[4].x;
-  matrix[1][4]=points[4].y;
-  matrix[1][5]=1.0;
-  matrix[1][6]=(-points[4].x*points[0].y);
-  matrix[1][7]=(-points[4].y*points[0].y);
-  matrix[2][0]=points[5].x;
-  matrix[2][1]=points[5].y;
-  matrix[2][2]=1.0;
-  matrix[2][6]=(-points[5].x*points[1].x);
-  matrix[2][7]=(-points[5].y*points[1].x);
-  matrix[3][3]=points[5].x;
-  matrix[3][4]=points[5].y;
-  matrix[3][5]=1.0;
-  matrix[3][6]=(-points[5].x*points[1].y);
-  matrix[3][7]=(-points[5].y*points[1].y);
-  matrix[4][0]=points[6].x;
-  matrix[4][1]=points[6].y;
-  matrix[4][2]=1.0;
-  matrix[4][6]=(-points[6].x*points[2].x);
-  matrix[4][7]=(-points[6].y*points[2].x);
-  matrix[5][3]=points[6].x;
-  matrix[5][4]=points[6].y;
-  matrix[5][5]=1.0;
-  matrix[5][6]=(-points[6].x*points[2].y);
-  matrix[5][7]=(-points[6].y*points[2].y);
-  matrix[6][0]=points[7].x;
-  matrix[6][1]=points[7].y;
-  matrix[6][2]=1.0;
-  matrix[6][6]=(-points[7].x*points[3].x);
-  matrix[6][7]=(-points[7].y*points[3].x);
-  matrix[7][3]=points[7].x;
-  matrix[7][4]=points[7].y;
-  matrix[7][5]=1.0;
-  matrix[7][6]=(-points[7].x*points[3].y);
-  matrix[7][7]=(-points[7].y*points[3].y);
-  vector[0]=points[0].x;
-  vector[1]=points[0].y;
-  vector[2]=points[1].x;
-  vector[3]=points[1].y;
-  vector[4]=points[2].x;
-  vector[5]=points[2].y;
-  vector[6]=points[3].x;
-  vector[7]=points[3].y;
-  return(GaussJordanElimination(matrix,8,vector));
-}
+  for( i = 0; i < 8; ) {
+    u = points[i].x;
+    v = points[i].y;
+    x = points[i+1].x;
+    y = points[i+1].y;
 
-static void InvertPerspectiveCoefficients(
-  const double *coefficients,double *inverse)
+    vector[i]=u;
+    matrix[i][0]=x;
+    matrix[i][1]=y;
+    matrix[i][2]=1.0;
+    matrix[i][6]=-x*u;
+    matrix[i][7]=-y*u;
+    i++;
+
+    vector[i]=v;
+    matrix[i][3]=x;
+    matrix[i][4]=y;
+    matrix[i][5]=1.0;
+    matrix[i][6]=-x*v;
+    matrix[i][7]=-y*v;
+    i++;
+  }
+  return(GaussJordanElimination(matrix,&vector,8UL,1UL));
+}
+#endif
+
+static void InvertPerspectiveCoefficients(const double *coefficients,
+  double *inverse)
 {
   double determinant;
-  /* From "Digital Image Warping" p53 by George Wolberg */
+  /* From "Digital Image Warping" by George Wolberg, page 53 */
 
   determinant=1.0/(coefficients[0]*coefficients[4]-coefficients[3]*coefficients[1]);
-  inverse[0]=determinant*(coefficients[4]-coefficients[5]*coefficients[6]);
+  inverse[0]=determinant*(coefficients[4]-coefficients[7]*coefficients[5]);
   inverse[1]=determinant*(coefficients[7]*coefficients[2]-coefficients[1]);
   inverse[2]=determinant*(coefficients[1]*coefficients[5]-coefficients[4]*coefficients[2]);
   inverse[3]=determinant*(coefficients[6]*coefficients[5]-coefficients[3]);
@@ -325,6 +289,9 @@ MagickExport Image *DistortImage(Image *image,const DistortImageMethod method,
 {
 #define DistortImageTag  "Distort/Image"
 
+  const char
+    *artifact;
+
   double
     coefficients[9],
     validity;
@@ -353,8 +320,8 @@ MagickExport Image *DistortImage(Image *image,const DistortImageMethod method,
   register PixelPacket
     *q;
 
-  ResampleInfo
-    *resample_info;
+  ResampleFilter
+    *resample_filter;
 
   ViewInfo
     *distort_view;
@@ -381,49 +348,67 @@ MagickExport Image *DistortImage(Image *image,const DistortImageMethod method,
     case AffineDistortion:
     {
       double
-        *matrix[6];
-
-      PointInfo
-        *points;
+        **matrix,
+        **vectors,
+        terms[3];
 
       /* Affine Distortion
-
             u =   c0*x + c2*y + c4
-
             v =   c1*x + c3*y + c5
 
-         Input Arguments are two sets of control points which are
-         used to generate the above coefficents.  (minimum 3 pairs)
+         Input Arguments are pairs of distorted coodinates (minimum 3 sets)
+         Which will be used to generate the coefficients of the above.
             u1,v1, x1,y1,  u2,v2, x2,y2,  u3,v3, x3,y3, ...
       */
-      if (number_arguments != 12)
+      if (number_arguments < 12) {
+        (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+                     "InvalidArgument","%s : '%s'","distort Affine",
+                     "Minimum of 3 pairs of coords needed (12 numbers)");
+        return((Image *) NULL);
+      }
+      if (number_arguments%4 != 0) {
+        (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+                     "InvalidArgument","%s : '%s'","distort Affine",
+                     "Requires pairs of coords (sX,sY,dX,dY)");
+        return((Image *) NULL);
+      }
+      matrix = AcquireMagickMatrix(3UL,3UL);
+      vectors = AcquireMagickMatrix(2UL,3UL);
+      if (matrix == (double **) NULL || vectors == (double **) NULL)
+      {
+        matrix = RelinquishMagickMatrix(matrix, 3UL);
+        vectors = RelinquishMagickMatrix(vectors, 2UL);
+        ThrowImageException(ResourceLimitError,"MemoryAllocationFailed");
+        return((Image *) NULL);
+      }
+      /* Add control points for least squares solving */
+      for (i=0; i < (long) number_arguments; i+=4) {
+        terms[0] = arguments[i+2];  /* x */
+        terms[1] = arguments[i+3];  /* y */
+        terms[2] = 1;               /* 1 */
+        LeastSquaresAddTerms(matrix,vectors,terms,&(arguments[i]),3UL,2UL);
+      }
+      status=GaussJordanElimination(matrix,vectors,3UL,2UL);
+      matrix = RelinquishMagickMatrix(matrix, 3UL);
+      if ( status == MagickTrue ) {
+        /* Affine has a bit of a weird ordering of coefficents.
+           This ordering is for backward compatibility with the older
+           affine functions of IM.
+        */
+        coefficients[0] = vectors[0][0]; /* u = ... */
+        coefficients[2] = vectors[0][1];
+        coefficients[4] = vectors[0][2];
+        coefficients[1] = vectors[1][0]; /* v = ... */
+        coefficients[3] = vectors[1][1];
+        coefficients[5] = vectors[1][2];
+      }
+      vectors = RelinquishMagickMatrix(vectors, 2UL);
+      if ( status == MagickFalse ) {
+        (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+                     "InvalidArgument","%s : '%s'","distort Affine",
+                     "Unsolvable Matrix");
         return((Image *) NULL);
-      points=(PointInfo *) AcquireQuantumMemory((number_arguments+1UL)/2UL,
-        sizeof(*points));
-      if (points == (PointInfo *) NULL)
-        ThrowImageException(ResourceLimitError,"MemoryAllocationFailed");
-      for (i=0; i < (long) number_arguments; i++)
-        if ((i % 2 ) == 0)
-          points[i/2].x=arguments[i];
-        else
-          points[i/2].y=arguments[i];
-      for (i=0; i < 6; i++)
-      {
-        matrix[i]=(double *) AcquireQuantumMemory(6UL,sizeof(*matrix[i]));
-        if (matrix[i] == (double *) NULL)
-          {
-            for (x=0; x < i; x++)
-              matrix[i]=(double *) RelinquishMagickMemory(matrix[i]);
-            points=(PointInfo *) RelinquishMagickMemory(points);
-            ThrowImageException(ResourceLimitError,"MemoryAllocationFailed");
-          }
-        (void) ResetMagickMemory(matrix[i],0,6*sizeof(*matrix[i]));
       }
-      status=SolveAffineDistortion((number_arguments+1)/2,points,matrix,
-        coefficients);
-      for (i=0; i < 6; i++)
-        matrix[i]=(double *) RelinquishMagickMemory(matrix[i]);
-      points=(PointInfo *) RelinquishMagickMemory(points);
       break;
     }
     case AffineProjectionDistortion:
@@ -432,18 +417,21 @@ MagickExport Image *DistortImage(Image *image,const DistortImageMethod method,
         Arguments: Affine Matrix (forward mapping)
            sx, rx, ry, sy, tx, ty
       */
-      if (number_arguments != 6)
+      if (number_arguments != 6) {
+        (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+                     "InvalidArgument","%s : '%s'","distort AffineProjection",
+                     "Needs 6 numbers");
         return((Image *) NULL);
+      }
       InvertAffineCoefficients(arguments, coefficients);
       break;
     }
     case BilinearDistortion:
     {
       double
-        *matrix[8];
-
-      PointInfo
-        *points;
+        **matrix,
+        *vectors[2],
+        terms[4];
 
       /* Bilinear Distortion (reversed)
 
@@ -451,97 +439,140 @@ MagickExport Image *DistortImage(Image *image,const DistortImageMethod method,
 
             v = c4*x + c5*y + c6*x*y + c7;
 
-         Input Arguments are two sets of control points which are
-         used to generate the above coefficents. (minimum 4 pairs)
+         Input Arguments are pairs of distorted coodinates (minimum 4 pairs)
+         Which will be used to generate the coefficients of the above.
+            u1,v1, x1,y1,  u2,v2, x2,y2,  u3,v3, x3,y3,  u4,v4, x4,y4 ...
       */
-      if (number_arguments != 16)
+      if (number_arguments < 16) {
+        (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+                     "InvalidArgument","%s : '%s'","distort Bilinear",
+                     "Minimum of 4 pairs of coords needed (16 numbers)");
+        return((Image *) NULL);
+      }
+      if (number_arguments%4 != 0) {
+        (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+                     "InvalidArgument","%s : '%s'","distort Bilinear",
+                     "Requires pairs of coords (sX,sY,dX,dY)");
+        return((Image *) NULL);
+      }
+      matrix = AcquireMagickMatrix(4UL,4UL);
+      if (matrix == (double **) NULL) {
+        matrix = RelinquishMagickMatrix(matrix, 4UL);
+        ThrowImageException(ResourceLimitError,"MemoryAllocationFailed");
+        return((Image *) NULL);
+      }
+      /* fake a 2x3 vectors matrix from coefficients array */
+      for (i=0; i < 8L; i++)
+        coefficients[i] = 0.0;
+      vectors[0] = &(coefficients[0]);
+      vectors[1] = &(coefficients[4]);
+      /* Add control points for least squares solving */
+      for (i=0; i < (long) number_arguments; i+=4) {
+        terms[0] = arguments[i+2];     /*  x  */
+        terms[1] = arguments[i+3];     /*  y  */
+        terms[2] = terms[0]*terms[1];  /* x*y */
+        terms[3] = 1;                  /*  1  */
+        LeastSquaresAddTerms(matrix,vectors,terms,&(arguments[i]),4UL,2UL);
+      }
+      status=GaussJordanElimination(matrix,vectors,4UL,2UL);
+      matrix = RelinquishMagickMatrix(matrix, 4UL);
+      if ( status == MagickFalse ) {
+        (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+                     "InvalidArgument","%s : '%s'","distort Bilinear",
+                     "Unsolvable Matrix");
         return((Image *) NULL);
-      points=(PointInfo *) AcquireQuantumMemory((number_arguments+1UL)/2UL,
-        sizeof(*points));
-      if (points == (PointInfo *) NULL)
-        ThrowImageException(ResourceLimitError,"MemoryAllocationFailed");
-      for (i=0; i < (long) number_arguments; i++)
-        if ((i % 2 ) == 0)
-          points[i/2].x=arguments[i];
-        else
-          points[i/2].y=arguments[i];
-      for (i=0; i < 8; i++)
-      {
-        matrix[i]=(double *) AcquireQuantumMemory(8UL,sizeof(*matrix[i]));
-        if (matrix[i] == (double *) NULL)
-          {
-            for (x=0; x < i; x++)
-              matrix[i]=(double *) RelinquishMagickMemory(matrix[i]);
-            points=(PointInfo *) RelinquishMagickMemory(points);
-            ThrowImageException(ResourceLimitError,"MemoryAllocationFailed");
-          }
-        (void) ResetMagickMemory(matrix[i],0,8*sizeof(*matrix[i]));
       }
-      status=SolveBilinearDistortion((number_arguments+1)/2,points,matrix,
-        coefficients);
-      for (i=0; i < 8; i++)
-        matrix[i]=(double *) RelinquishMagickMemory(matrix[i]);
-      points=(PointInfo *) RelinquishMagickMemory(points);
       break;
     }
     case PerspectiveDistortion:
     {
       double
-        *matrix[8];
-
-      PointInfo
-        *points;
+        **matrix,
+        *vectors[1],
+        terms[8];
 
       /* Perspective Distortion (a ratio of affine distortions)
 
-                 p     c0*x + c1*y + c2
-            u = --- = ------------------
-                 r     c6*x + c7*y + 1
+                 p()     c0*x + c1*y + c2
+            u = ----- = ------------------
+                 r()     c6*x + c7*y + 1
 
-                 q     c3*x + c4*y + c5
-            v = --- = ------------------
-                 r     c6*x + c7*y + 1
+                 q()     c3*x + c4*y + c5
+            v = ----- = ------------------
+                 r()     c6*x + c7*y + 1
 
-            c8 = sign of 'r' which determines what part of the distorted image
-                 is 'ground' side of the horizon (on which the image sits)
+            c8 = Sign of 'r', or the denominator affine, for the actual image.
+                 This determines what part of the distorted image is 'ground'
+                 side of the horizon, the other part is 'sky' or invalid.
 
-         Input Arguments are two sets of control points which are
-         used to generate the above coefficents. (minimum 4 pairs)
+         WARNING: Equations are linked, and not separable.
+
+         Input Arguments are pairs of distorted coodinates (minimum 4 pairs)
+         Which will be used to generate the coefficients of the above.
+            u1,v1, x1,y1,  u2,v2, x2,y2,  u3,v3, x3,y3,  u4,v4, x4,y4 ...
       */
-      if (number_arguments != 16)
+      if (number_arguments < 16) {
+        (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+                     "InvalidArgument","%s : '%s'","distort Bilinear",
+                     "Minimum of 4 pairs of coords needed (16 numbers)");
+        return((Image *) NULL);
+      }
+      if (number_arguments%4 != 0) {
+        (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+                     "InvalidArgument","%s : '%s'","distort Bilinear",
+                     "Requires pairs of coords (sX,sY,dX,dY)");
+        return((Image *) NULL);
+      }
+      matrix = AcquireMagickMatrix(8UL,8UL);
+      if (matrix == (double **) NULL) {
+        matrix = RelinquishMagickMatrix(matrix, 8UL);
+        ThrowImageException(ResourceLimitError,"MemoryAllocationFailed");
+        return((Image *) NULL);
+      }
+      /* fake a 1x8 vectors matrix from coefficients array */
+      for (i=0; i < 8L; i++)
+        coefficients[i] = 0.0;
+      vectors[0] = &(coefficients[0]);
+      /* Add control points for least squares solving */
+      for (i=0; i < (long) number_arguments; i+=4) {
+        terms[0] = arguments[i+2];        /*   c0*x   */
+        terms[1] = arguments[i+3];        /*   c1*y   */
+        terms[2]=1.0;                     /*   c2*1   */
+        terms[3]=0.0;
+        terms[4]=0.0;
+        terms[5]=0.0;
+        terms[6]=-terms[0]*arguments[i];  /* 1/(c6*x) */
+        terms[7]=-terms[1]*arguments[i];  /* 1/(c7*y) */
+        LeastSquaresAddTerms(matrix,vectors,terms,&(arguments[i]),
+             8UL,1UL);
+
+        terms[0]=0.0;
+        terms[1]=0.0;
+        terms[2]=0.0;
+        terms[3] = arguments[i+2];          /*   c3*x   */
+        terms[4] = arguments[i+3];          /*   c4*y   */
+        terms[5]=1.0;                       /*   c5*1   */
+        terms[6]=-terms[3]*arguments[i+1];  /* 1/(c6*x) */
+        terms[7]=-terms[4]*arguments[i+1];  /* 1/(c7*y) */
+        LeastSquaresAddTerms(matrix,vectors,terms,&(arguments[i+1]),
+             8UL,1UL);
+      }
+      status=GaussJordanElimination(matrix,vectors,8UL,1UL);
+      matrix = RelinquishMagickMatrix(matrix, 8UL);
+      if ( status == MagickFalse ) {
+        (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+                     "InvalidArgument","%s : '%s'","distort Prespective",
+                     "Unsolvable Matrix");
         return((Image *) NULL);
-      points=(PointInfo *) AcquireQuantumMemory((number_arguments+1UL)/2UL,
-        sizeof(*points));
-      if (points == (PointInfo *) NULL)
-        ThrowImageException(ResourceLimitError,"MemoryAllocationFailed");
-      for (i=0; i < (long) number_arguments; i++)
-        if ((i % 2 ) == 0)
-          points[i/2].x=arguments[i];
-        else
-          points[i/2].y=arguments[i];
-      for (i=0; i < 8; i++)
-      {
-        matrix[i]=(double *) AcquireQuantumMemory(8UL,sizeof(*matrix[i]));
-        if (matrix[i] == (double *) NULL)
-          {
-            for (x=0; x < i; x++)
-              matrix[i]=(double *) RelinquishMagickMemory(matrix[i]);
-            points=(PointInfo *) RelinquishMagickMemory(points);
-            ThrowImageException(ResourceLimitError,"MemoryAllocationFailed");
-          }
-        (void) ResetMagickMemory(matrix[i],0,8*sizeof(*matrix[i]));
       }
-      status=SolvePerspectiveDistortion((number_arguments+1)/2,points,matrix,
-        coefficients);
-      for (i=0; i < 8; i++)
-        matrix[i]=(double *) RelinquishMagickMemory(matrix[i]);
-      points=(PointInfo *) RelinquishMagickMemory(points);
       /*
-        What is the 'ground' of the perspective distortion.
-        Just find the sign of 'r' for any given distorted coordinate.
+        Calculate 9'th coefficient! The ground-sky determination.
+        What is sign of the 'ground' in r() denominator affine function?
+        Just use any valid image cocodinate in destination for determination.
+        Picking destination coordinate from first coordinet pair.  
       */
-      coefficients[8] = coefficients[6]*arguments[number_arguments-2]
-                  + coefficients[7]*arguments[number_arguments-1] + 1.0;
+      coefficients[8] = coefficients[6]*arguments[2]
+                           + coefficients[7]*arguments[3] + 1.0;
       coefficients[8] = (coefficients[8] < 0.0) ? -1.0 : +1.0;
       break;
     }
@@ -550,16 +581,22 @@ MagickExport Image *DistortImage(Image *image,const DistortImageMethod method,
       /*
         Arguments: Perspective Coefficents (forward mapping)
       */
-      if (number_arguments != 8)
+      if (number_arguments != 8) {
+        (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+                     "InvalidArgument","%s : '%s'",
+                     "distort PerspectiveProjection", "Needs 8 numbers");
         return((Image *) NULL);
+      }
       InvertPerspectiveCoefficients(arguments, coefficients);
       /*
-        What is the 'ground' of the perspective distortion.
+        Calculate 9'th coefficient! The ground-sky determination.
+        What is sign of the 'ground' in r() denominator affine function?
+        Just use any valid image cocodinate in destination for determination.
         For a forward mapped perspective the images 0,0 coord will map to
-          c2,c5  in the distorted image get the sign of 'r' of that.
+        c2,c5 in the distorted image, so get the sign of denominator of that.
       */
       coefficients[8] = coefficients[6]*arguments[2]
-                  + coefficients[7]*arguments[5] + 1.0;
+                           + coefficients[7]*arguments[5] + 1.0;
       coefficients[8] = (coefficients[8] < 0.0) ? -1.0 : +1.0;
       break;
     }
@@ -585,8 +622,8 @@ MagickExport Image *DistortImage(Image *image,const DistortImageMethod method,
             nx,ny   move 'center' here         (default = no movement)
          And convert to affine mapping coefficients
       */
-      x = nx = (double)image->rows/2.0;
-      y = ny = (double)image->columns/2.0;
+      x = nx = (double)image->columns/2.0;
+      y = ny = (double)image->rows/2.0;
       if ( bestfit ) {
         x = nx += (double)image->page.x;
         y = ny += (double)image->page.y;
@@ -594,6 +631,10 @@ MagickExport Image *DistortImage(Image *image,const DistortImageMethod method,
       sx = sy = 1.0;
       switch ( number_arguments ) {
       case 0:
+        (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+                     "InvalidArgument","%s : '%s'",
+                     "distort ScaleTranslateRotate",
+                     "Needs at least 1 argument");
         return((Image *) NULL);
       case 1:
         a = arguments[0];
@@ -632,6 +673,10 @@ MagickExport Image *DistortImage(Image *image,const DistortImageMethod method,
           ny = arguments[6];
           break;
         default:
+          (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+                     "InvalidArgument","%s : '%s'",
+                     "distort ScaleTranslateRotate",
+                     "Too Many Arguments (7 or less)");
           return((Image *) NULL);
         }
         break;
@@ -678,10 +723,18 @@ MagickExport Image *DistortImage(Image *image,const DistortImageMethod method,
          for arc angles greater than 360 the sides of the image will be
          trimmed equally.
       */
-      if ( number_arguments >= 1 && arguments[0] < MagickEpsilon )
+      if ( number_arguments >= 1 && arguments[0] < MagickEpsilon ) {
+        (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+                     "InvalidArgument","%s : '%s'", "distort Arc",
+                     "Arc Angle Too Small");
         return((Image *) NULL);
-      if ( number_arguments >= 3 && arguments[2] < MagickEpsilon )
+      }
+      if ( number_arguments >= 3 && arguments[2] < MagickEpsilon ) {
+        (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+                     "InvalidArgument","%s : '%s'", "distort Arc",
+                     "Outer Radius Too Small");
         return((Image *) NULL);
+      }
       coefficients[0] = -MagickPI/2.0;
       if ( number_arguments >= 1 )
         coefficients[1] = DegreesToRadians(arguments[0]);
@@ -713,10 +766,12 @@ MagickExport Image *DistortImage(Image *image,const DistortImageMethod method,
     Determine the size and offset for a 'bestfit' destination.
     Usally the four corners of the source image is enough.
   */
+
+  /* default output image bounds, when no 'bestfit' is requested */
   geometry.width=image->columns;
   geometry.height=image->rows;
-  geometry.x=image->page.x;
-  geometry.y=image->page.y;
+  geometry.x=0;
+  geometry.y=0;
   point.x=0.0;
   point.y=0.0;
 
@@ -745,19 +800,20 @@ MagickExport Image *DistortImage(Image *image,const DistortImageMethod method,
       case ScaleRotateTranslateDistortion:
       { double inverse[6];
         InvertAffineCoefficients(coefficients, inverse);
-        x = geometry.x;  y = geometry.y;
+        x = image->page.x;  y = image->page.y;
         point.x=inverse[0]*x+inverse[2]*y+inverse[4];
         point.y=inverse[1]*x+inverse[3]*y+inverse[5];
         InitalBounds( point.x, point.y );
-        x = geometry.x+geometry.width-1;  y = geometry.y;
+        x = image->page.x+image->columns-1;  y = image->page.y;
         point.x=inverse[0]*x+inverse[2]*y+inverse[4];
         point.y=inverse[1]*x+inverse[3]*y+inverse[5];
         ExpandBounds( point.x, point.y );
-        x = geometry.x;  y = geometry.y+geometry.height-1;
+        x = image->page.x;  y = image->page.y+image->rows-1;
         point.x=inverse[0]*x+inverse[2]*y+inverse[4];
         point.y=inverse[1]*x+inverse[3]*y+inverse[5];
         ExpandBounds( point.x, point.y );
-        x = geometry.x+geometry.width-1;  y = geometry.y+geometry.height-1;
+        x = image->page.x+image->columns-1;
+        y = image->page.y+image->rows-1;
         point.x=inverse[0]*x+inverse[2]*y+inverse[4];
         point.y=inverse[1]*x+inverse[3]*y+inverse[5];
         ExpandBounds( point.x, point.y );
@@ -767,25 +823,26 @@ MagickExport Image *DistortImage(Image *image,const DistortImageMethod method,
       case PerspectiveProjectionDistortion:
       { double inverse[8], scale;
         InvertPerspectiveCoefficients(coefficients, inverse);
-        x = geometry.x;  y = geometry.y;
+        x = image->page.x;  y = image->page.y;
         scale=inverse[6]*x+inverse[7]*y+1.0;
         scale=1.0/(  (fabs(scale) <= MagickEpsilon) ? 1.0 : scale );
         point.x=scale*(inverse[0]*x+inverse[1]*y+inverse[2]);
         point.y=scale*(inverse[3]*x+inverse[4]*y+inverse[5]);
         InitalBounds( point.x, point.y );
-        x = geometry.x+geometry.width-1;  y = geometry.y;
+        x = image->page.x+image->columns-1;  y = image->page.y;
         scale=inverse[6]*x+inverse[7]*y+1.0;
         scale=1.0/(  (fabs(scale) <= MagickEpsilon) ? 1.0 : scale );
         point.x=scale*(inverse[0]*x+inverse[1]*y+inverse[2]);
         point.y=scale*(inverse[3]*x+inverse[4]*y+inverse[5]);
         ExpandBounds( point.x, point.y );
-        x = geometry.x;  y = geometry.y+geometry.height-1;
+        x = image->page.x;  y = image->page.y+image->rows-1;
         scale=inverse[6]*x+inverse[7]*y+1.0;
         scale=1.0/(  (fabs(scale) <= MagickEpsilon) ? 1.0 : scale );
         point.x=scale*(inverse[0]*x+inverse[1]*y+inverse[2]);
         point.y=scale*(inverse[3]*x+inverse[4]*y+inverse[5]);
         ExpandBounds( point.x, point.y );
-        x = geometry.x+geometry.width-1;  y = geometry.y+geometry.height-1;
+        x = image->page.x+image->columns-1;
+        y = image->page.y+image->rows-1;
         scale=inverse[6]*x+inverse[7]*y+1.0;
         scale=1.0/(  (fabs(scale) <= MagickEpsilon) ? 1.0 : scale );
         point.x=scale*(inverse[0]*x+inverse[1]*y+inverse[2]);
@@ -833,6 +890,7 @@ MagickExport Image *DistortImage(Image *image,const DistortImageMethod method,
         /* no bestfit available for this distortion YET */
         bestfit = MagickFalse;
     }
+    /* Set the output image geometry to the 'bestfit' of the image */
     if ( bestfit ) {
       geometry.x=(long) floor(min_x-MagickEpsilon);
       geometry.y=(long) floor(min_y-MagickEpsilon);
@@ -841,11 +899,16 @@ MagickExport Image *DistortImage(Image *image,const DistortImageMethod method,
     }
   }
 
+  /* User provided override of the output geometry */
+  artifact=GetImageArtifact(image,"distort:viewport");
+  if (artifact != (const char *) NULL)
+    (void) ParseAbsoluteGeometry(artifact,&geometry);
+
   /*
     Initialize the distort image attributes.
   */
   distort_image=CloneImage(image,geometry.width,geometry.height,MagickTrue,
-        exception);
+    exception);
   if (distort_image == (Image *) NULL)
     return((Image *) NULL);
   if (SetImageStorageClass(distort_image,DirectClass) == MagickFalse)
@@ -859,27 +922,22 @@ MagickExport Image *DistortImage(Image *image,const DistortImageMethod method,
   if (distort_image->background_color.opacity != OpaqueOpacity)
     distort_image->matte=MagickTrue;
 
-  if ( !bestfit ) {
-    geometry.x = geometry.y = 0;
-  }
-
   /* Open Image views as needed. */
-  resample_info = AcquireResampleInfo(image,exception);
+  resample_filter=AcquireResampleFilter(image,exception);
   GetMagickPixelPacket(distort_image,&pixel);
   distort_view=OpenCacheView(distort_image);
 
-  /* Define constant scaling vectors for some distortions */
+  /* Define constant scaling vectors for Affine Distortions */
   switch (method)
   {
     case AffineDistortion:
     case AffineProjectionDistortion:
     case ScaleRotateTranslateDistortion:
-      ResampleScale( resample_info,
+      ScaleResampleFilter( resample_filter,
         coefficients[0], coefficients[2],
         coefficients[1], coefficients[3] );
       break;
     default:
-      ResampleScale(resample_info, 1.0, 0.0, 0.0, 1.0);
       break;
   }
 
@@ -896,39 +954,39 @@ MagickExport Image *DistortImage(Image *image,const DistortImageMethod method,
         ConvertRGBToCMYK(&invalid);   /* what about other color spaces? */
 
   /* Sample the source image to each pixel in the distort image.  */
-  for (y=0; y < (long) distort_image->rows; y++)
+  for (j=0; j < (long) distort_image->rows; j++)
   {
-    j = y+geometry.y;
-    q=SetCacheView(distort_view,0,y,distort_image->columns,1);
+    q=SetCacheView(distort_view,0,j,distort_image->columns,1);
     if (q == (PixelPacket *) NULL)
       break;
-    indexes=GetIndexes(distort_image);
-    for (x=0; x < (long) distort_image->columns; x++)
+    indexes=GetCacheViewIndexes(distort_view);
+    y = j+geometry.y;
+    for (i=0; i < (long) distort_image->columns; i++)
     {
-      i = x+geometry.x;
+      x = i+geometry.x;
       switch (method)
       {
         case AffineDistortion:
         case AffineProjectionDistortion:
         case ScaleRotateTranslateDistortion:
         {
-          point.x=coefficients[0]*i+coefficients[2]*j+coefficients[4];
-          point.y=coefficients[1]*i+coefficients[3]*j+coefficients[5];
+          point.x=coefficients[0]*x+coefficients[2]*y+coefficients[4];
+          point.y=coefficients[1]*x+coefficients[3]*y+coefficients[5];
           /* Affine partical derivitives are constant -- set above */
           break;
         }
         case BilinearDistortion:
         {
-          point.x=coefficients[0]*i+coefficients[1]*j+coefficients[2]*i*j+
+          point.x=coefficients[0]*x+coefficients[1]*y+coefficients[2]*x*y+
             coefficients[3];
-          point.y=coefficients[4]*i+coefficients[5]*j+coefficients[6]*i*j+
+          point.y=coefficients[4]*x+coefficients[5]*y+coefficients[6]*x*y+
             coefficients[7];
           /* Bilinear partical derivitives of scaling vectors */
-          ResampleScale( resample_info,
-              coefficients[0] + coefficients[2]*j,
-              coefficients[1] + coefficients[2]*i,
-              coefficients[4] + coefficients[6]*j,
-              coefficients[5] + coefficients[6]*i );
+          ScaleResampleFilter( resample_filter,
+              coefficients[0] + coefficients[2]*y,
+              coefficients[1] + coefficients[2]*x,
+              coefficients[4] + coefficients[6]*y,
+              coefficients[5] + coefficients[6]*x );
           break;
         }
         case PerspectiveDistortion:
@@ -937,9 +995,9 @@ MagickExport Image *DistortImage(Image *image,const DistortImageMethod method,
           double
             p,q,r,abs_r,abs_c6,abs_c7,scale;
           /* perspective is a ratio of affines */
-          p=coefficients[0]*i+coefficients[1]*j+coefficients[2];
-          q=coefficients[3]*i+coefficients[4]*j+coefficients[5];
-          r=coefficients[6]*i+coefficients[7]*j+1.0;
+          p=coefficients[0]*x+coefficients[1]*y+coefficients[2];
+          q=coefficients[3]*x+coefficients[4]*y+coefficients[5];
+          r=coefficients[6]*x+coefficients[7]*y+1.0;
           /* Pixel Validity -- is it a 'sky' or 'ground' pixel */
           validity = (r*coefficients[8] < 0.0) ? 0.0 : 1.0;
           /* Determine horizon anti-aliase blending */
@@ -959,7 +1017,7 @@ MagickExport Image *DistortImage(Image *image,const DistortImageMethod method,
             point.y = q*scale;
             /* Perspective Partial Derivatives or Scaling Vectors */
             scale *= scale;
-            ResampleScale( resample_info,
+            ScaleResampleFilter( resample_filter,
               (r*coefficients[0] - p*coefficients[6])*scale,
               (r*coefficients[1] - p*coefficients[7])*scale,
               (r*coefficients[3] - q*coefficients[6])*scale,
@@ -969,12 +1027,22 @@ MagickExport Image *DistortImage(Image *image,const DistortImageMethod method,
         }
         case ArcDistortion:
         {
-          point.x = (atan2(1.0*j,1.0*i) - coefficients[0])/(2*MagickPI);
+          double radius = sqrt((double) x*x+y*y);
+          point.x = (atan2((double)y,(double)x) - coefficients[0])/(2*MagickPI);
           point.x -= MagickRound(point.x);
           point.x = point.x*coefficients[1] + coefficients[4];
-          point.y = coefficients[2] - sqrt(1.0*i*i+j*j);
-          point.y *= coefficients[3];
-          /* FUTURE: determine partial derivities / scaling vectors */
+          point.y = (coefficients[2] - radius) * coefficients[3];
+          /* Polar Distortion Partial Derivatives or Scaling Vectors
+             We give the deritives of  du/dr, dv/dr  and du/da, dv/da
+             rather than provide the complex  du/dx,dv/dx and du/dy,dv/dy.
+             The result will be the same, but it is simplier to calculate.
+          */
+          if ( radius > MagickEpsilon )
+            ScaleResampleFilter( resample_filter,
+                coefficients[1]/(2*MagickPI) / radius, 0, 0, coefficients[3] );
+          else
+            ScaleResampleFilter( resample_filter,
+                 MagickHuge, 0, 0, coefficients[3] );
           break;
         }
         default:
@@ -982,8 +1050,8 @@ MagickExport Image *DistortImage(Image *image,const DistortImageMethod method,
           /*
             Noop distortion (failsafe).
           */
-          point.x=(double) x;
-          point.y=(double) y;
+          point.x=(double) i;
+          point.y=(double) j;
           break;
         }
       }
@@ -998,7 +1066,7 @@ MagickExport Image *DistortImage(Image *image,const DistortImageMethod method,
       }
       else {
         /* resample the source image to find its correct color */
-        pixel=ResamplePixelColor(resample_info,point.x,point.y);
+        pixel=ResamplePixelColor(resample_filter,point.x,point.y);
         /* if validity between 0.0 and 1.0 mix result with invalid pixel */
         if ( validity < 1.0 ) {
           /* Do a blend of sample color and invalid pixel */
@@ -1023,6 +1091,12 @@ MagickExport Image *DistortImage(Image *image,const DistortImageMethod method,
       }
   }
   distort_view=CloseCacheView(distort_view);
-  resample_info=DestroyResampleInfo(resample_info);
+  resample_filter=DestroyResampleFilter(resample_filter);
+
+  /* Arc does not return an offset unless 'bestfit' is in effect */
+  if ( method == ArcDistortion && !bestfit && artifact==(const char *)NULL ) {
+    distort_image->page.x = 0;
+    distort_image->page.y = 0;
+  }
   return(distort_image);
 }
