@@ -55,6 +55,7 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/resample.h"
 #include "magick/string_.h"
 
@@ -73,7 +74,9 @@
 %
 %  The format of the ClutImage method is:
 %
-%      MagickBooleanType ClutImage(Image *image,const ChannelType channel)
+%      MagickBooleanType ClutImage(Image *image,Image *clut_image)
+%      MagickBooleanType ClutImageChannel(Image *image,
+%        const ChannelType channel,Image *clut_image)
 %
 %  A description of each parameter follows:
 %
@@ -87,11 +90,7 @@
 
 MagickExport MagickBooleanType ClutImage(Image *image,const Image *clut_image)
 {
-  MagickBooleanType
-    status;
-
-  status=ClutImageChannel(image,DefaultChannels,clut_image);
-  return(status);
+  return(ClutImageChannel(image,DefaultChannels,clut_image));
 }
 
 MagickExport MagickBooleanType ClutImageChannel(Image *image,
@@ -117,6 +116,9 @@ MagickExport MagickBooleanType ClutImageChannel(Image *image,
   register PixelPacket
     *q;
 
+  ResampleFilter
+    *resample_filter;
+
   ViewInfo
     *clut_view;
 
@@ -132,6 +134,7 @@ MagickExport MagickBooleanType ClutImageChannel(Image *image,
     Clut image.
   */
   GetMagickPixelPacket(clut_image,&pixel);
+  resample_filter=AcquireResampleFilter(clut_image,&image->exception);
   clut_view=OpenCacheView(clut_image);
   for (y=0; y < (long) image->rows; y++)
   {
@@ -143,50 +146,44 @@ MagickExport MagickBooleanType ClutImageChannel(Image *image,
     {
       if ((channel & RedChannel) != 0)
         {
-          pixel=InterpolatePixelColor(clut_image,clut_view,
-            clut_image->interpolate,QuantumScale*q->red*clut_image->columns,
-            QuantumScale*q->red*clut_image->rows,&image->exception);
+          pixel=ResamplePixelColor(resample_filter,QuantumScale*q->red*
+            clut_image->columns,QuantumScale*q->red*clut_image->rows);
           q->red=RoundToQuantum(pixel.red);
         }
       if ((channel & GreenChannel) != 0)
         {
-          pixel=InterpolatePixelColor(clut_image,clut_view,
-            clut_image->interpolate,QuantumScale*q->green*clut_image->columns,
-            QuantumScale*q->green*clut_image->rows,&image->exception);
+          pixel=ResamplePixelColor(resample_filter,QuantumScale*q->green*
+            clut_image->columns,QuantumScale*q->green*clut_image->rows);
           q->green=RoundToQuantum(pixel.green);
         }
       if ((channel & BlueChannel) != 0)
         {
-          pixel=InterpolatePixelColor(clut_image,clut_view,
-            clut_image->interpolate,QuantumScale*q->blue*clut_image->columns,
-            QuantumScale*q->blue*clut_image->rows,&image->exception);
+          pixel=ResamplePixelColor(resample_filter,QuantumScale*q->blue*
+            clut_image->columns,QuantumScale*q->blue*clut_image->rows);
           q->blue=RoundToQuantum(pixel.blue);
         }
       if ((channel & OpacityChannel) != 0)
         {
           if (clut_image->matte == MagickFalse)
             {
-              pixel=InterpolatePixelColor(clut_image,clut_view,
-                clut_image->interpolate,QuantumScale*q->opacity*
-                clut_image->columns,QuantumScale*q->opacity*clut_image->rows,
-                &image->exception);
+              pixel=ResamplePixelColor(resample_filter,QuantumScale*
+                q->opacity*clut_image->columns,QuantumScale*q->opacity*
+                clut_image->rows);
               q->opacity=RoundToQuantum(pixel.opacity);
             }
           else
             {
-              pixel=InterpolatePixelColor(clut_image,clut_view,
-                clut_image->interpolate,QuantumScale*(QuantumRange-q->opacity)*
-                clut_image->columns,QuantumScale*(QuantumRange-q->opacity)*
-                clut_image->rows,&image->exception);
-              q->opacity=QuantumRange-RoundToQuantum(pixel.opacity);
+              pixel=ResamplePixelColor(resample_filter,QuantumScale*
+                (QuantumRange-q->opacity)*clut_image->columns,QuantumScale*
+                (QuantumRange-q->opacity)*clut_image->rows);
+              q->opacity=(Quantum) QuantumRange-RoundToQuantum(pixel.opacity);
             }
         }
       if (((channel & IndexChannel) != 0) &&
           (image->colorspace == CMYKColorspace))
         {
-          pixel=InterpolatePixelColor(clut_image,clut_view,
-            clut_image->interpolate,QuantumScale*indexes[x]*clut_image->columns,
-            QuantumScale*indexes[x]*clut_image->rows,&image->exception);
+          pixel=ResamplePixelColor(resample_filter,QuantumScale*indexes[x]*
+            clut_image->columns,QuantumScale*indexes[x]*clut_image->rows);
           indexes[x]=RoundToQuantum(pixel.index);
         }
       q++;
@@ -202,6 +199,7 @@ MagickExport MagickBooleanType ClutImageChannel(Image *image,
           break;
       }
   }
+  resample_filter=DestroyResampleFilter(resample_filter);
   clut_view=CloseCacheView(clut_view);
   return(MagickTrue);
 }
@@ -955,16 +953,30 @@ MagickExport Image *EnhanceImage(const Image *image,ExceptionInfo *exception)
 %  The format of the EqualizeImage method is:
 %
 %      MagickBooleanType EqualizeImage(Image *image)
+%      MagickBooleanType EqualizeImageChannel(Image *image,
+%        const ChannelType channel)
 %
 %  A description of each parameter follows:
 %
 %    o image: The image.
 %
+%    o channel: The channel.
+%
 */
+
 MagickExport MagickBooleanType EqualizeImage(Image *image)
+{
+  return(EqualizeImageChannel(image,DefaultChannels));
+}
+
+MagickExport MagickBooleanType EqualizeImageChannel(Image *image,
+  const ChannelType channel)
 {
 #define EqualizeImageTag  "Equalize/Image"
 
+  IndexPacket
+    *indexes;
+
   long
     y;
 
@@ -973,14 +985,12 @@ MagickExport MagickBooleanType EqualizeImage(Image *image)
 
   MagickPixelPacket
     black,
+    *equalize_map,
     *histogram,
     intensity,
     *map,
     white;
 
-  PixelPacket
-    *equalize_map;
-
   register const PixelPacket
     *p;
 
@@ -998,16 +1008,24 @@ MagickExport MagickBooleanType EqualizeImage(Image *image)
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
+  equalize_map=(MagickPixelPacket *) AcquireQuantumMemory(MaxMap+1UL,
+    sizeof(*equalize_map));
   histogram=(MagickPixelPacket *) AcquireQuantumMemory(MaxMap+1UL,
     sizeof(*histogram));
   map=(MagickPixelPacket *) AcquireQuantumMemory(MaxMap+1UL,sizeof(*map));
-  equalize_map=(PixelPacket *) AcquireQuantumMemory(MaxMap+1UL,
-    sizeof(*equalize_map));
-  if ((histogram == (MagickPixelPacket *) NULL) ||
-      (map == (MagickPixelPacket *) NULL) ||
-      (equalize_map == (PixelPacket *) NULL))
-    ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
-      image->filename);
+  if ((equalize_map == (MagickPixelPacket *) NULL) ||
+      (histogram == (MagickPixelPacket *) NULL) ||
+      (map == (MagickPixelPacket *) NULL))
+    {
+      if (map != (MagickPixelPacket *) NULL)
+        map=(MagickPixelPacket *) RelinquishMagickMemory(map);
+      if (histogram != (MagickPixelPacket *) NULL)
+        histogram=(MagickPixelPacket *) RelinquishMagickMemory(histogram);
+      if (equalize_map != (MagickPixelPacket *) NULL)
+        equalize_map=(MagickPixelPacket *) RelinquishMagickMemory(equalize_map);
+      ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
+        image->filename);
+    }
   /*
     Form histogram.
   */
@@ -1017,12 +1035,20 @@ MagickExport MagickBooleanType EqualizeImage(Image *image)
     p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
+    indexes=(IndexPacket *) AcquireIndexes(image);
     for (x=0; x < (long) image->columns; x++)
     {
-      histogram[ScaleQuantumToMap(p->red)].red++;
-      histogram[ScaleQuantumToMap(p->green)].green++;
-      histogram[ScaleQuantumToMap(p->blue)].blue++;
-      histogram[ScaleQuantumToMap(p->opacity)].opacity++;
+      if ((channel & RedChannel) != 0)
+        histogram[ScaleQuantumToMap(p->red)].red++;
+      if ((channel & GreenChannel) != 0)
+        histogram[ScaleQuantumToMap(p->green)].green++;
+      if ((channel & BlueChannel) != 0)
+        histogram[ScaleQuantumToMap(p->blue)].blue++;
+      if ((channel & OpacityChannel) != 0)
+        histogram[ScaleQuantumToMap(p->opacity)].opacity++;
+      if (((channel & IndexChannel) != 0) &&
+          (image->colorspace == CMYKColorspace))
+        histogram[ScaleQuantumToMap(indexes[x])].index++;
       p++;
     }
   }
@@ -1032,10 +1058,17 @@ MagickExport MagickBooleanType EqualizeImage(Image *image)
   (void) ResetMagickMemory(&intensity,0,sizeof(intensity));
   for (i=0; i <= (long) MaxMap; i++)
   {
-    intensity.red+=histogram[i].red;
-    intensity.green+=histogram[i].green;
-    intensity.blue+=histogram[i].blue;
-    intensity.opacity+=histogram[i].opacity;
+    if ((channel & RedChannel) != 0)
+      intensity.red+=histogram[i].red;
+    if ((channel & GreenChannel) != 0)
+      intensity.green+=histogram[i].green;
+    if ((channel & BlueChannel) != 0)
+      intensity.blue+=histogram[i].blue;
+    if ((channel & OpacityChannel) != 0)
+      intensity.opacity+=histogram[i].opacity;
+    if (((channel & IndexChannel) != 0) &&
+        (image->colorspace == CMYKColorspace))
+      intensity.index+=histogram[i].index;
     map[i]=intensity;
   }
   black=map[0];
@@ -1043,18 +1076,24 @@ MagickExport MagickBooleanType EqualizeImage(Image *image)
   (void) ResetMagickMemory(equalize_map,0,(MaxMap+1)*sizeof(*equalize_map));
   for (i=0; i <= (long) MaxMap; i++)
   {
-    if (white.red != black.red)
-      equalize_map[i].red=ScaleMapToQuantum((MagickRealType) ((MaxMap*
-        (map[i].red-black.red))/(white.red-black.red)));
-    if (white.green != black.green)
-      equalize_map[i].green=ScaleMapToQuantum((MagickRealType) ((MaxMap*
-        (map[i].green-black.green))/(white.green-black.green)));
-    if (white.blue != black.blue)
-      equalize_map[i].blue=ScaleMapToQuantum((MagickRealType) ((MaxMap*
-        (map[i].blue-black.blue))/(white.blue-black.blue)));
-    if (white.opacity != black.opacity)
-      equalize_map[i].opacity=ScaleMapToQuantum((MagickRealType) ((MaxMap*
-        (map[i].opacity-black.opacity))/(white.opacity-black.opacity)));
+    if (((channel & RedChannel) != 0) && (white.red != black.red))
+      equalize_map[i].red=(MagickRealType) ScaleMapToQuantum((MagickRealType)
+        ((MaxMap*(map[i].red-black.red))/(white.red-black.red)));
+    if (((channel & GreenChannel) != 0) && (white.green != black.green))
+      equalize_map[i].green=(MagickRealType) ScaleMapToQuantum((MagickRealType)
+        ((MaxMap*(map[i].green-black.green))/(white.green-black.green)));
+    if (((channel & BlueChannel) != 0) && (white.blue != black.blue))
+      equalize_map[i].blue=(MagickRealType) ScaleMapToQuantum((MagickRealType)
+        ((MaxMap*(map[i].blue-black.blue))/(white.blue-black.blue)));
+    if (((channel & OpacityChannel) != 0) && (white.opacity != black.opacity))
+      equalize_map[i].opacity=(MagickRealType) ScaleMapToQuantum(
+        (MagickRealType) ((MaxMap*(map[i].opacity-black.opacity))/
+        (white.opacity-black.opacity)));
+    if ((((channel & IndexChannel) != 0) &&
+        (image->colorspace == CMYKColorspace)) &&
+        (white.index != black.index))
+      equalize_map[i].index=(MagickRealType) ScaleMapToQuantum((MagickRealType)
+        ((MaxMap*(map[i].index-black.index))/(white.index-black.index)));
   }
   histogram=(MagickPixelPacket *) RelinquishMagickMemory(histogram);
   map=(MagickPixelPacket *) RelinquishMagickMemory(map);
@@ -1065,15 +1104,19 @@ MagickExport MagickBooleanType EqualizeImage(Image *image)
       */
       for (i=0; i < (long) image->colors; i++)
       {
-        if (black.red != white.red)
-          image->colormap[i].red=equalize_map[ScaleQuantumToMap(
-            image->colormap[i].red)].red;
-        if (black.green != white.green)
-          image->colormap[i].green=equalize_map[ScaleQuantumToMap(
-            image->colormap[i].green)].green;
-        if (black.blue != white.blue)
-          image->colormap[i].blue=equalize_map[ScaleQuantumToMap(
-            image->colormap[i].blue)].blue;
+        if (((channel & RedChannel) != 0) && (white.red != black.red))
+          image->colormap[i].red=RoundToQuantum(equalize_map[
+            ScaleQuantumToMap(image->colormap[i].red)].red);
+        if (((channel & GreenChannel) != 0) && (white.green != black.green))
+          image->colormap[i].green=RoundToQuantum(equalize_map[
+            ScaleQuantumToMap(image->colormap[i].green)].green);
+        if (((channel & BlueChannel) != 0) && (white.blue != black.blue))
+          image->colormap[i].blue=RoundToQuantum(equalize_map[
+            ScaleQuantumToMap(image->colormap[i].blue)].blue);
+        if (((channel & OpacityChannel) != 0) &&
+            (white.opacity != black.opacity))
+          image->colormap[i].opacity=RoundToQuantum(equalize_map[
+            ScaleQuantumToMap(image->colormap[i].opacity)].opacity);
       }
     }
   /*
@@ -1084,16 +1127,24 @@ MagickExport MagickBooleanType EqualizeImage(Image *image)
     q=GetImagePixels(image,0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
       break;
+    indexes=GetIndexes(image);
     for (x=0; x < (long) image->columns; x++)
     {
-      if (black.red != white.red)
-        q->red=equalize_map[ScaleQuantumToMap(q->red)].red;
-      if (black.green != white.green)
-        q->green=equalize_map[ScaleQuantumToMap(q->green)].green;
-      if (black.blue != white.blue)
-        q->blue=equalize_map[ScaleQuantumToMap(q->blue)].blue;
-      if (black.opacity != white.opacity)
-        q->opacity=equalize_map[ScaleQuantumToMap(q->opacity)].opacity;
+      if (((channel & RedChannel) != 0) && (white.red != black.red))
+        q->red=RoundToQuantum(equalize_map[ScaleQuantumToMap(q->red)].red);
+      if (((channel & GreenChannel) != 0) && (white.green != black.green))
+        q->green=RoundToQuantum(equalize_map[ScaleQuantumToMap(
+          q->green)].green);
+      if (((channel & BlueChannel) != 0) && (white.blue != black.blue))
+        q->blue=RoundToQuantum(equalize_map[ScaleQuantumToMap(q->blue)].blue);
+      if (((channel & OpacityChannel) != 0) && (white.opacity != black.opacity))
+        q->opacity=RoundToQuantum(equalize_map[ScaleQuantumToMap(
+          q->opacity)].opacity);
+      if ((((channel & IndexChannel) != 0) &&
+          (image->colorspace == CMYKColorspace)) &&
+          (white.index != black.index))
+        indexes[x]=RoundToQuantum(equalize_map[ScaleQuantumToMap(
+          indexes[x])].index);
       q++;
     }
     if (SyncImagePixels(image) == MagickFalse)
@@ -1107,7 +1158,7 @@ MagickExport MagickBooleanType EqualizeImage(Image *image)
           break;
       }
   }
-  equalize_map=(PixelPacket *) RelinquishMagickMemory(equalize_map);
+  equalize_map=(MagickPixelPacket *) RelinquishMagickMemory(equalize_map);
   return(MagickTrue);
 }
 
@@ -1246,8 +1297,9 @@ MagickExport MagickBooleanType GammaImageChannel(Image *image,
               image->colormap[i].opacity=RoundToQuantum(gamma_map[
                 ScaleQuantumToMap(image->colormap[i].opacity)]);
             else
-              image->colormap[i].opacity=QuantumRange-RoundToQuantum(gamma_map[
-                ScaleQuantumToMap(QuantumRange-image->colormap[i].opacity)]);
+              image->colormap[i].opacity=(Quantum) QuantumRange-RoundToQuantum(
+                gamma_map[ScaleQuantumToMap((Quantum) QuantumRange-
+                image->colormap[i].opacity)]);
           }
       }
     }
@@ -1273,8 +1325,8 @@ MagickExport MagickBooleanType GammaImageChannel(Image *image,
           if (image->matte == MagickFalse)
             q->opacity=RoundToQuantum(gamma_map[ScaleQuantumToMap(q->opacity)]);
           else
-            q->opacity=QuantumRange-RoundToQuantum(gamma_map[ScaleQuantumToMap(
-              QuantumRange-q->opacity)]);
+            q->opacity=(Quantum) QuantumRange-RoundToQuantum(
+              gamma_map[ScaleQuantumToMap((Quantum) QuantumRange-q->opacity)]);
         }
       if (((channel & IndexChannel) != 0) &&
           (image->colorspace == CMYKColorspace))
@@ -1399,9 +1451,6 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
   MagickBooleanType
     status;
 
-  MagickRealType
-    *levels_map;
-
   register long
     i,
     x;
@@ -1409,10 +1458,6 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
   register PixelPacket
     *q;
 
-  unsigned long
-    black,
-    white;
-
   /*
     Allocate and initialize levels map.
   */
@@ -1420,45 +1465,28 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  levels_map=(MagickRealType *) AcquireQuantumMemory(MaxMap+1UL,
-    sizeof(*levels_map));
-  if (levels_map == (MagickRealType *) NULL)
-    ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
-      image->filename);
-  black=ScaleQuantumToMap(RoundToQuantum(black_point));
-  white=ScaleQuantumToMap(RoundToQuantum(white_point));
-  for (i=0; i < (long) black; i++)
-    levels_map[i]=0.0;
-  if (gamma == 1.0)
-    {
-      for ( ; i < (long) white; i++)
-        levels_map[i]=(MagickRealType) (MaxMap*(((MagickRealType) i-black)/
-          (white-black)));
-    }
-  else
-    for ( ; i < (long) white; i++)
-      levels_map[i]=(MagickRealType) (MaxMap*(pow(((double) i-black)/
-        (white-black),1.0/gamma)));
-  for ( ; i <= (long) MaxMap; i++)
-    levels_map[i]=(MagickRealType) MaxMap;
   if (image->storage_class == PseudoClass)
+    for (i=0; i < (long) image->colors; i++)
     {
       /*
         Level colormap.
       */
-      for (i=0; i < (long) image->colors; i++)
-      {
-        if ((channel & RedChannel) != 0)
-          image->colormap[i].red=ScaleMapToQuantum(levels_map[
-            ScaleQuantumToMap(image->colormap[i].red)]);
-        if ((channel & GreenChannel) != 0)
-          image->colormap[i].green=ScaleMapToQuantum(levels_map[
-            ScaleQuantumToMap(image->colormap[i].green)]);
-        if ((channel & BlueChannel) != 0)
-          image->colormap[i].blue=ScaleMapToQuantum(levels_map[
-            ScaleQuantumToMap(image->colormap[i].blue)]);
+      if ((channel & RedChannel) != 0)
+        image->colormap[i].red=RoundToQuantum((MagickRealType) QuantumRange*
+          pow(((double) image->colormap[i].red-black_point)/(white_point-
+          black_point),1.0/gamma));
+      if ((channel & GreenChannel) != 0)
+        image->colormap[i].green=RoundToQuantum((MagickRealType) QuantumRange*
+          pow(((double) image->colormap[i].green-black_point)/(white_point-
+          black_point),1.0/gamma));
+      if ((channel & BlueChannel) != 0)
+        image->colormap[i].blue=RoundToQuantum((MagickRealType) QuantumRange*
+          pow(((double) image->colormap[i].blue-black_point)/(white_point-
+          black_point),1.0/gamma));
+      if ((channel & OpacityChannel) != 0)
+        image->colormap[i].opacity=RoundToQuantum((MagickRealType) QuantumRange*          pow(((double) image->colormap[i].opacity-black_point)/(white_point-
+          black_point),1.0/gamma));
       }
-    }
   /*
     Level image.
   */
@@ -1471,17 +1499,21 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
-        q->red=ScaleMapToQuantum(levels_map[ScaleQuantumToMap(q->red)]);
+        q->red=RoundToQuantum((MagickRealType) QuantumRange*pow(((double)
+          q->red-black_point)/(white_point-black_point),1.0/gamma));
       if ((channel & GreenChannel) != 0)
-        q->green=ScaleMapToQuantum(levels_map[ScaleQuantumToMap(q->green)]);
+        q->green=RoundToQuantum((MagickRealType) QuantumRange*pow(((double)
+          q->green-black_point)/(white_point-black_point),1.0/gamma));
       if ((channel & BlueChannel) != 0)
-        q->blue=ScaleMapToQuantum(levels_map[ScaleQuantumToMap(q->blue)]);
+        q->blue=RoundToQuantum((MagickRealType) QuantumRange*pow(((double)
+          q->blue-black_point)/(white_point-black_point),1.0/gamma));
       if ((channel & OpacityChannel) != 0)
-        q->opacity=ScaleMapToQuantum(levels_map[ScaleQuantumToMap(q->opacity)]);
+        q->opacity=RoundToQuantum((MagickRealType) QuantumRange*pow(((double)
+          q->opacity-black_point)/(white_point-black_point),1.0/gamma));
       if (((channel & IndexChannel) != 0) &&
-          ((image->storage_class == PseudoClass) ||
-           (image->colorspace == CMYKColorspace)))
-        indexes[x]=ScaleMapToQuantum(levels_map[ScaleQuantumToMap(indexes[x])]);
+          (image->colorspace == CMYKColorspace))
+        indexes[x]=RoundToQuantum((MagickRealType) QuantumRange*pow(((double)
+          indexes[x]-black_point)/(white_point-black_point),1.0/gamma));
       q++;
     }
     if (SyncImagePixels(image) == MagickFalse)
@@ -1495,7 +1527,6 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
           break;
       }
   }
-  levels_map=(MagickRealType *) RelinquishMagickMemory(levels_map);
   return(MagickTrue);
 }
 
@@ -1914,11 +1945,14 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
               (image->colormap[i].green != image->colormap[i].blue))
             continue;
         if ((channel & RedChannel) != 0)
-          image->colormap[i].red=QuantumRange-image->colormap[i].red;
+          image->colormap[i].red=(Quantum) QuantumRange-
+            image->colormap[i].red;
         if ((channel & GreenChannel) != 0)
-          image->colormap[i].green=QuantumRange-image->colormap[i].green;
+          image->colormap[i].green=(Quantum) QuantumRange-
+            image->colormap[i].green;
         if ((channel & BlueChannel) != 0)
-          image->colormap[i].blue=QuantumRange-image->colormap[i].blue;
+          image->colormap[i].blue=(Quantum) QuantumRange-
+            image->colormap[i].blue;
       }
     }
   /*
@@ -1940,13 +1974,13 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
               continue;
             }
           if ((channel & RedChannel) != 0)
-            q->red=QuantumRange-q->red;
+            q->red=(Quantum) QuantumRange-q->red;
           if ((channel & GreenChannel) != 0)
-            q->green=QuantumRange-q->green;
+            q->green=(Quantum) QuantumRange-q->green;
           if ((channel & BlueChannel) != 0)
-            q->blue=QuantumRange-q->blue;
+            q->blue=(Quantum) QuantumRange-q->blue;
           if ((channel & OpacityChannel) != 0)
-            q->opacity=QuantumRange-q->opacity;
+            q->opacity=(Quantum) QuantumRange-q->opacity;
           if (((channel & IndexChannel) != 0) &&
               (image->colorspace == CMYKColorspace))
             indexes[x]=(IndexPacket) QuantumRange-indexes[x];
@@ -1977,13 +2011,13 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
-        q->red=QuantumRange-q->red;
+        q->red=(Quantum) QuantumRange-q->red;
       if ((channel & GreenChannel) != 0)
-        q->green=QuantumRange-q->green;
+        q->green=(Quantum) QuantumRange-q->green;
       if ((channel & BlueChannel) != 0)
-        q->blue=QuantumRange-q->blue;
+        q->blue=(Quantum) QuantumRange-q->blue;
       if ((channel & OpacityChannel) != 0)
-        q->opacity=QuantumRange-q->opacity;
+        q->opacity=(Quantum) QuantumRange-q->opacity;
       if (((channel & IndexChannel) != 0) &&
           (image->colorspace == CMYKColorspace))
         indexes[x]=(IndexPacket) QuantumRange-indexes[x];
