@@ -105,15 +105,7 @@ MagickExport ExceptionInfo *AcquireExceptionInfo(void)
 
   exception=(ExceptionInfo *) AcquireMagickMemory(sizeof(*exception));
   if (exception == (ExceptionInfo *) NULL)
-    {
-      char
-        *message;
-
-      message=GetExceptionMessage(errno);
-      ThrowMagickFatalException(ResourceLimitFatalError,
-        "MemoryAllocationFailed",message);
-      message=DestroyString(message);
-    }
+    ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
   (void) ResetMagickMemory(exception,0,sizeof(*exception));
   GetExceptionInfo(exception);
   exception->relinquish=MagickTrue;
@@ -863,15 +855,7 @@ MagickExport MagickBooleanType ThrowException(ExceptionInfo *exception,
     return(MagickTrue);
   p=(ExceptionInfo *) AcquireMagickMemory(sizeof(*p));
   if (p == (ExceptionInfo *) NULL)
-    {
-      char
-        *message;
-
-      message=GetExceptionMessage(errno);
-      ThrowMagickFatalException(ResourceLimitFatalError,
-        "MemoryAllocationFailed",message);
-      message=DestroyString(message);
-    }
+    ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
   (void) ResetMagickMemory(p,0,sizeof(*p));
   p->severity=severity;
   if (reason != (const char *) NULL)
