@@ -180,7 +180,7 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,long *x,long *y,
   (void) strtod(p,&q);
   if (LocaleNCompare(p,"0x",2) == 0)
     (void) strtol(p,&q,10);
-  if ((*q == -41) || (*q == 'x') || (*q == 'X') || (*q == '\0'))
+  if (((int) *q == -41) || (*q == 'x') || (*q == 'X') || (*q == '\0'))
     {
       /*
         Parse width.
@@ -193,7 +193,7 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,long *x,long *y,
       if (p != q)
         flags|=WidthValue;
     }
-  if ((*p == -41) || (*p == 'x') || (*p == 'X'))
+  if (((int) *p == -41) || (*p == 'x') || (*p == 'X'))
     {
       p++;
       if ((*p != '+') && (*p != '-'))
@@ -790,7 +790,7 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
   (void) strtod(p,&q);
   if (LocaleNCompare(p,"0x",2) == 0)
     (void) strtol(p,&q,10);
-  if ((*q == -41) || (*q == 'x') || (*q == 'X') || (*q == ',') ||
+  if (((int) *q == -41) || (*q == 'x') || (*q == 'X') || (*q == ',') ||
       (*q == '/') || (*q == ':') || (*q =='\0'))
     {
       /*
@@ -808,7 +808,7 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
         }
     }
   q=p;
-  if ((*p == -41) || (*p == 'x') || (*p == 'X') || (*p == ',') ||
+  if (((int) *p == -41) || (*p == 'x') || (*p == 'X') || (*p == ',') ||
       (*p == '/') || (*p == ':'))
     {
       /*
@@ -817,7 +817,7 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
       p++;
       while (isspace((int) ((unsigned char) *p)) != 0)
         p++;
-      if (((*q != -41) && (*q != 'x') && (*q != 'X')) ||
+      if ((((int) *q != -41) && (*q != 'x') && (*q != 'X')) ||
           ((*p != '+') && (*p != '-')))
         {
           q=p;
@@ -1092,8 +1092,8 @@ MagickExport MagickStatusType ParseMetaGeometry(const char *geometry,long *x,
       former_width=(*width);
       former_height=(*height);
     }
-  if (((flags & AspectValue) == 0) &&
-      ((*width != former_width) || (*height != former_height)))
+  if (((flags & AspectValue) == 0) && ((*width != former_width) ||
+      (*height != former_height)))
     {
       MagickRealType
         scale_factor;
@@ -1109,18 +1109,18 @@ MagickExport MagickStatusType ParseMetaGeometry(const char *geometry,long *x,
             scale_factor=(MagickRealType) *width/(MagickRealType) former_width;
             if (scale_factor > ((MagickRealType) *height/
                 (MagickRealType) former_height))
-              scale_factor=(MagickRealType)
-                *height/(MagickRealType) former_height;
+              scale_factor=(MagickRealType) *height/(MagickRealType)
+                former_height;
           }
         else
           if ((flags & RhoValue) != 0)
             scale_factor=(MagickRealType) *width/(MagickRealType) former_width;
           else
-            scale_factor=(MagickRealType)
-              *height/(MagickRealType) former_height;
-    *width=(unsigned long) (scale_factor*former_width+0.5);
-    *height=(unsigned long) (scale_factor*former_height+0.5);
-  }
+            scale_factor=(MagickRealType) *height/(MagickRealType)
+              former_height;
+      *width=MagickMax((unsigned long) (scale_factor*former_width+0.5),1UL);
+      *height=MagickMax((unsigned long) (scale_factor*former_height+0.5),1UL);
+    }
   if ((flags & GreaterValue) != 0)
     {
       if (former_width < *width)
