@@ -473,7 +473,7 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
             indexes=AcquireIndexes(image);
             for (x=0; x < (long) image->columns; x++)
             {
-              if (p->opacity == TransparentOpacity)
+              if (p->opacity == (Quantum) TransparentOpacity)
                 break;
               p++;
             }
@@ -637,7 +637,7 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
     if (image->scene != 0)
       (void) fprintf(file,"  Scene: %lu\n",image->scene);
   (void) fprintf(file,"  Compression: %s\n",
-    MagickOptionToMnemonic(MagickComposeOptions,(long) image->compression));
+    MagickOptionToMnemonic(MagickCompressOptions,(long) image->compression));
   if (image->quality != UndefinedCompressionQuality)
     (void) fprintf(file,"  Quality: %lu\n",image->quality);
   (void) fprintf(file,"  Orientation: %s\n",
@@ -688,13 +688,10 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
         property=GetNextImageProperty(tile);
         while (property != (const char *) NULL)
         {
-          if (*property != '[')
-            {
-              (void) fprintf(file,"  %s:\n",property);
-              value=GetImageProperty(tile,property);
-              if (value != (const char *) NULL)
-                (void) fprintf(file,"%s\n",value);
-            }
+          (void) fprintf(file,"  %s:\n",property);
+          value=GetImageProperty(tile,property);
+          if (value != (const char *) NULL)
+            (void) fprintf(file,"%s\n",value);
           property=GetNextImageProperty(tile);
         }
         tile=DestroyImage(tile);
@@ -709,17 +706,14 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
   property=GetNextImageProperty(image);
   while (property != (const char *) NULL)
   {
-    if (*property != '[')
-      {
-        (void) fprintf(file,"  %c",toupper(*property));
-        if (strlen(property) > 1)
-          (void) fprintf(file,"%s: ",property+1);
-        if (strlen(property) > 80)
-          (void) fputc('\n',file);
-        value=GetImageProperty(image,property);
-        if (value != (const char *) NULL)
-          (void) fprintf(file,"%s\n",value);
-      }
+    (void) fprintf(file,"  %c",toupper(*property));
+    if (strlen(property) > 1)
+      (void) fprintf(file,"%s: ",property+1);
+    if (strlen(property) > 80)
+      (void) fputc('\n',file);
+    value=GetImageProperty(image,property);
+    if (value != (const char *) NULL)
+      (void) fprintf(file,"%s\n",value);
     property=GetNextImageProperty(image);
   }
   (void) FormatMagickString(key,MaxTextExtent,"8BIM:1999,2998:#1");
