@@ -25,7 +25,7 @@ extern "C" {
 #define MagickPI  3.14159265358979323846264338327950288419716939937510
 #define MagickSQ1_2  0.7071067811865475244008443621048490
 #define MagickSQ2PI  2.50662827463100024161235523934010416269302368164062
-#define QuantumScale  ((MagickRealType) 1.0/(MagickRealType) QuantumRange)
+#define QuantumScale  ((double) 1.0/(double) QuantumRange)
 #define UndefinedTicksPerSecond  100L
 #define UndefinedCompressionQuality  0UL
 
