@@ -38,7 +38,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/property.h"
+#include "magick/artifact.h"
 #include "magick/color.h"
 #include "magick/color-private.h"
 #include "magick/composite.h"
@@ -52,6 +52,7 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/pixel-private.h"
+#include "magick/property.h"
 #include "magick/profile.h"
 #include "magick/resource_.h"
 #include "magick/resize.h"
@@ -110,7 +111,7 @@ static void ClearBounds(Image *image,RectangleInfo *bounds)
       break;
     for (x=0; x < (long) bounds->width; x++)
     {
-      q->opacity=TransparentOpacity;
+      q->opacity=(Quantum) TransparentOpacity;
       q++;
     }
     if (SyncImagePixels(image) == MagickFalse)
@@ -204,8 +205,8 @@ static MagickBooleanType IsBoundsCleared(const Image *image1,
 %  offsets and disposal methods.  GIF, MIFF, and MNG animation sequences
 %  typically start with an image background and each subsequent image
 %  varies in size and offset.  A new image sequence is returned with all
-%  images the same size as the first and composited with the next image in the
-%  sequence.
+%  images the same size as the first images virtual canvas and composited
+%  with the next image in the sequence.
 %
 %  The format of the CoalesceImages method is:
 %
@@ -240,18 +241,32 @@ MagickExport Image *CoalesceImages(const Image *image,ExceptionInfo *exception)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
+
+  /* initialise first image */
   next=GetFirstImageInList(image);
-  coalesce_image=CloneImage(next,next->page.width,next->page.height,
-    MagickTrue,exception);
+  bounds=next->page;
+  if ( bounds.width == 0 ) {
+    bounds.width = next->columns;
+    if ( bounds.x > 0 )
+      bounds.width += bounds.x;
+  }
+  if ( bounds.height == 0 ) {
+    bounds.height = next->rows;
+    if ( bounds.y > 0 )
+      bounds.height += bounds.y;
+  }
+  bounds.x=0;
+  bounds.y=0;
+  coalesce_image=CloneImage(next,bounds.width,bounds.height,MagickTrue,
+         exception);
   if (coalesce_image == (Image *) NULL)
     return((Image *) NULL);
-  coalesce_image->page.width=coalesce_image->columns;
-  coalesce_image->page.height=coalesce_image->rows;
-  coalesce_image->page.x=0;
-  coalesce_image->page.y=0;
+  coalesce_image->page=bounds;
   coalesce_image->dispose=NoneDispose;
-  coalesce_image->background_color.opacity=TransparentOpacity;
+  coalesce_image->background_color.opacity=(Quantum) TransparentOpacity;
   (void) SetImageBackgroundColor(coalesce_image);
+
+  /* coalesce rest of the images */
   dispose_image=CloneImage(coalesce_image,0,0,MagickTrue,exception);
   (void) CompositeImage(coalesce_image,CopyCompositeOp,next,next->page.x,
     next->page.y);
@@ -302,13 +317,14 @@ MagickExport Image *CoalesceImages(const Image *image,ExceptionInfo *exception)
     */
     coalesce_image->next=CloneImage(dispose_image,0,0,MagickTrue,exception);
     coalesce_image->next->previous=coalesce_image;
-    prev = coalesce_image;
+    prev=coalesce_image;
     coalesce_image=GetNextImageInList(coalesce_image);
     coalesce_image->matte=MagickTrue;
     (void) CompositeImage(coalesce_image,next->matte != MagickFalse ?
       OverCompositeOp : CopyCompositeOp,next,next->page.x,next->page.y);
-    (void) CloneImageProperties(coalesce_image,next);
     (void) CloneImageProfiles(coalesce_image,next);
+    (void) CloneImageProperties(coalesce_image,next);
+    (void) CloneImageArtifacts(coalesce_image,next);
     coalesce_image->page=prev->page;
     /*
       Fix disposal setting of previous image, for correct animation.
@@ -378,7 +394,7 @@ MagickExport Image *DisposeImages(const Image *image,ExceptionInfo *exception)
   dispose_image->page.x=0;
   dispose_image->page.y=0;
   dispose_image->dispose=NoneDispose;
-  dispose_image->background_color.opacity=TransparentOpacity;
+  dispose_image->background_color.opacity=(Quantum) TransparentOpacity;
   (void) SetImageBackgroundColor(dispose_image);
 
   dispose_images=NewImageList();
@@ -440,15 +456,17 @@ MagickExport Image *DisposeImages(const Image *image,ExceptionInfo *exception)
     /*
       Save the dispose image just calculated for return
     */
-    { Image *dispose=CloneImage(dispose_image,0,0,MagickTrue,exception);
+    {
+      Image *dispose=CloneImage(dispose_image,0,0,MagickTrue,exception);
       if (dispose == (Image *) NULL)
         {
           dispose_images=DestroyImageList(dispose_images);
           dispose_image=DestroyImage(dispose_image);
           return((Image *) NULL);
         }
-      (void) CloneImageProperties(dispose,next);
       (void) CloneImageProfiles(dispose,next);
+      (void) CloneImageProperties(dispose,next);
+      (void) CloneImageArtifacts(dispose,next);
       dispose->page.x=0;
       dispose->page.y=0;
       dispose->dispose=next->dispose;
@@ -478,7 +496,7 @@ MagickExport Image *DisposeImages(const Image *image,ExceptionInfo *exception)
 %
 %  The format of the ComparePixels method is:
 %
-%      MagickBooleanType *ComparePixels(const MagickLayerMethod method,
+%      MagickBooleanType *ComparePixels(const ImageLayerMethod method,
 %        const MagickPixelPacket *p,const MagickPixelPacket *q)
 %
 %  A description of each parameter follows:
@@ -490,7 +508,7 @@ MagickExport Image *DisposeImages(const Image *image,ExceptionInfo *exception)
 %
 */
 
-static MagickBooleanType ComparePixels(const MagickLayerMethod method,
+static MagickBooleanType ComparePixels(const ImageLayerMethod method,
   const MagickPixelPacket *p,const MagickPixelPacket *q)
 {
   MagickRealType
@@ -546,7 +564,7 @@ static MagickBooleanType ComparePixels(const MagickLayerMethod method,
 %
 %  The format of the CompareImageBounds method is:
 %
-%      RectangleInfo *CompareImageBounds(const MagickLayerMethod method,
+%      RectangleInfo *CompareImageBounds(const ImageLayerMethod method,
 %        const Image *image1, const Image *image2, ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
@@ -561,7 +579,7 @@ static MagickBooleanType ComparePixels(const MagickLayerMethod method,
 */
 
 static RectangleInfo CompareImageBounds(const Image *image1,const Image *image2,
-  const MagickLayerMethod method,ExceptionInfo *exception)
+  const ImageLayerMethod method,ExceptionInfo *exception)
 {
   RectangleInfo
     bounds;
@@ -704,7 +722,7 @@ static RectangleInfo CompareImageBounds(const Image *image1,const Image *image2,
 %
 %  CompareImageLayers() compares each image with the next in a sequence and
 %  returns the minimum bounding region of all the pixel differences (of the
-%  LayerType specified) it discovers.
+%  ImageLayerMethod specified) it discovers.
 %
 %  Images do NOT have to be the same size, though it is best that all the
 %  images are 'coalesced' (images are all the same size, on a flattened
@@ -716,7 +734,7 @@ static RectangleInfo CompareImageBounds(const Image *image1,const Image *image2,
 %  The format of the CompareImageLayers method is:
 %
 %      Image *CompareImageLayers(const Image *images,
-%        const MagickLayerMethod method,ExceptionInfo *exception)
+%        const ImageLayerMethod method,ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
@@ -730,7 +748,7 @@ static RectangleInfo CompareImageBounds(const Image *image1,const Image *image2,
 */
 
 MagickExport Image *CompareImageLayers(const Image *image,
-  const MagickLayerMethod method, ExceptionInfo *exception)
+  const ImageLayerMethod method, ExceptionInfo *exception)
 {
   Image
     *image_a,
@@ -773,7 +791,7 @@ MagickExport Image *CompareImageLayers(const Image *image,
       bounds=(RectangleInfo *) RelinquishMagickMemory(bounds);
       return((Image *) NULL);
     }
-  image_a->background_color.opacity=TransparentOpacity;
+  image_a->background_color.opacity=(Quantum) TransparentOpacity;
   (void) SetImageBackgroundColor(image_a);
   image_a->page=next->page;
   image_a->page.x=0;
@@ -897,7 +915,7 @@ MagickExport Image *DeconstructImages(const Image *images,
 %  The format of the OptimizeLayerFrames method is:
 %
 %      static Image *OptimizeLayerFrames(const Image *image,
-%               const MagickLayerMethod method, ExceptionInfo *exception)
+%               const ImageLayerMethod method, ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
@@ -921,7 +939,7 @@ MagickExport Image *DeconstructImages(const Image *images,
 #define DelDispose  ((DisposeType)8)
 
 static Image *OptimizeLayerFrames(const Image *image,
-  const MagickLayerMethod method, ExceptionInfo *exception)
+  const ImageLayerMethod method, ExceptionInfo *exception)
 {
   Image
     *prev_image,
@@ -1008,7 +1026,7 @@ static Image *OptimizeLayerFrames(const Image *image,
   prev_image->page.y=0;
   prev_image->dispose=NoneDispose;
 
-  prev_image->background_color.opacity=TransparentOpacity;
+  prev_image->background_color.opacity=(Quantum) TransparentOpacity;
   (void) SetImageBackgroundColor(prev_image);
   /*
     Figure out the area of overlay of the first frame
@@ -1398,7 +1416,7 @@ MagickExport void OptimizeImageTransparency(const Image *image,
   dispose_image->page.x=0;
   dispose_image->page.y=0;
   dispose_image->dispose=NoneDispose;
-  dispose_image->background_color.opacity=TransparentOpacity;
+  dispose_image->background_color.opacity=(Quantum) TransparentOpacity;
   (void) SetImageBackgroundColor(dispose_image);
 
   while ( next != (Image *) NULL )
@@ -1739,3 +1757,180 @@ MagickExport void CompositeLayers(Image *destination,
       destination=GetNextImageInList(destination);
     }
 }
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%     M e r g e I m a g e L a y e r s                                         %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  MergeImageLayers() composes all the image layers from the current given
+%  image onward to produce a single image of the merged layers.
+%
+%  The inital canvas's size depends on the given ImageLayerMethod, and is
+%  initialized using the first images images background color.  The images
+%  are then compositied onto that image in sequence using the given
+%  composition that has been assigned to each individual image.
+%
+%  The format of the MergeImageLayers is:
+%
+%      Image *MergeImageLayers(const Image *image,
+%        const ImageLayerMethod method, ExceptionInfo *exception)
+%
+%  A description of each parameter follows:
+%
+%    o image: The image list to be composited together
+%
+%    o method: The method of selecting the size of the initial canvas.
+%
+%        MergeLayer: Merge all layers onto a canvas just large enough
+%           to hold all the actual images. The virtual canvas of the
+%           first image is preserved but otherwise ignored.
+%
+%        FlattenLayer: Use the virtual canvas size of first image.
+%           Images which fall outside this canvas is clipped.
+%           This can be used to 'fill out' a given virtual canvas.
+%
+%        MosaicLayer: Start with the virtual canvas of the first image,
+%           enlarging left and right edges to contain all images.
+%           Images with negative offsets will be clipped.
+%
+%    o exception: Return any errors or warnings in this structure.
+%
+*/
+MagickExport Image *MergeImageLayers(const Image *image,
+  const ImageLayerMethod method,ExceptionInfo *exception)
+{
+#define MergeLayersTag  "Merge/Layers"
+
+  Image
+    *canvas;
+
+  MagickBooleanType
+    status;
+
+  MagickOffsetType
+    scene;
+
+  RectangleInfo
+    page;
+
+  unsigned long
+    width,
+    height;
+
+  register const Image
+    *next;
+
+  unsigned long
+    number_images;
+
+  assert(image != (Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
+  assert(exception != (ExceptionInfo *) NULL);
+  assert(exception->signature == MagickSignature);
+  /*
+    Determine canvas image size, and its virtual canvas size and offset
+  */
+  page=image->page;
+  width=image->columns;
+  height=image->rows;
+  switch (method)
+  {
+    case MergeLayer:
+    default:
+    {
+      next = GetNextImageInList(image);
+      for ( ; next != (Image *) NULL;  next=GetNextImageInList(next)) {
+        if ( page.x > next->page.x ) {
+             width += next->page.x-page.x;
+             page.x = next->page.x;
+        }
+        if ( page.y > next->page.y ) {
+             width += next->page.y-page.y;
+             page.y = next->page.y;
+        }
+      if ( width < next->page.x + next->columns - page.x )
+           width = next->page.x + next->columns - page.x;
+        if ( height < next->page.y + next->rows - page.y )
+             height = next->page.y + next->rows - page.y;
+      }
+      break;
+    }
+    case FlattenLayer:
+    {
+      if ( page.width != 0 )
+        width=page.width;
+      if ( page.height != 0 )
+        height=page.height;
+      page.x=0;
+      page.y=0;
+      break;
+    }
+    case MosaicLayer:
+    {
+      if ( page.width > 0 )
+        width=page.width;
+      if ( page.height > 0 )
+        height=page.height;
+      for (next=image; next != (Image *) NULL; next=GetNextImageInList(next)) {
+        if (method == MosaicLayer) {
+        page.x=next->page.x;
+          page.y=next->page.y;
+          if ( width < next->page.x + next->columns )
+               width = next->page.x + next->columns;
+          if ( height < next->page.y + next->rows )
+             height = next->page.y + next->rows;
+        }
+      }
+      page.width=width;
+      page.height=height;
+      page.x=0;
+      page.y=0;
+    }
+    break;
+  }
+  /* set virtual canvas size if not defined */
+  if ( page.width == 0 )
+    page.width = (page.x < 0) ? width : width+page.x;
+  if ( page.height == 0 )
+    page.height = (page.y < 0) ? height : height+page.y;
+
+  /*
+    Create canvas size of width and height, and background color.
+  */
+  canvas=CloneImage(image,width,height,MagickTrue,exception);
+  if (canvas == (Image *) NULL)
+    return((Image *) NULL);
+  (void) SetImageBackgroundColor(canvas);
+  canvas->page=page;
+  canvas->dispose=UndefinedDispose;
+
+  /*
+    Compose images onto canvas, with progress monitor
+  */
+  number_images=GetImageListLength(image);
+  for (scene=0; scene < (long) number_images; scene++)
+  {
+    (void) CompositeImage(canvas,image->compose,image,
+         image->page.x-canvas->page.x, image->page.y-canvas->page.y );
+    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+        (QuantumTick(scene,number_images) != MagickFalse))
+      {
+        status=image->progress_monitor(MergeLayersTag,scene,number_images,
+          image->client_data);
+        if (status == MagickFalse)
+          break;
+      }
+    image=GetNextImageInList(image);
+  }
+  return(canvas);
+}
+
