@@ -236,7 +236,8 @@ MagickExport Image *CloneImages(const Image *images,const char *scenes,
     while ((isspace((int) ((unsigned char) *p)) != 0) || (*p == ','))
       p++;
     first=strtol(p,&p,10);
-    if (first < 0) first+=length;
+    if (first < 0)
+      first+=(long) length;
     last=first;
     while (isspace((int) ((unsigned char) *p)) != 0)
       p++;
@@ -244,7 +245,7 @@ MagickExport Image *CloneImages(const Image *images,const char *scenes,
       {
         last=strtol(p+1,&p,10);
         if (last < 0)
-          last+=length;
+          last+=(long) length;
       }
     for (step=first > last ? -1 : 1; first != (last+step); first+=step)
     {
@@ -366,7 +367,7 @@ MagickExport void DeleteImages(Image **images,const char *scenes,
   assert(exception->signature == MagickSignature);
   *images=GetFirstImageInList(*images);
   length=GetImageListLength(*images);
-  delete_list=(MagickBooleanType *) AcquireMagickMemory(length*
+  delete_list=(MagickBooleanType *) AcquireQuantumMemory(length,
     sizeof(*delete_list));
   if (delete_list == (MagickBooleanType *) NULL)
     {
@@ -386,7 +387,7 @@ MagickExport void DeleteImages(Image **images,const char *scenes,
       p++;
     first=strtol(p,&p,10);
     if (first < 0)
-      first+=length;
+      first+=(long) length;
     last=first;
     while (isspace((int) ((unsigned char) *p)) != 0)
       p++;
@@ -394,7 +395,7 @@ MagickExport void DeleteImages(Image **images,const char *scenes,
       {
         last=strtol(p+1,&p,10);
         if (last < 0)
-          last+=length;
+          last+=(long) length;
       }
     if (first > last)
       continue;
@@ -512,6 +513,9 @@ MagickExport Image *GetFirstImageInList(const Image *images)
 */
 MagickExport Image *GetImageFromList(const Image *images,const long index)
 {
+  long
+    offset;
+
   register const Image
     *p;
 
@@ -524,8 +528,9 @@ MagickExport Image *GetImageFromList(const Image *images,const long index)
   if (images->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",images->filename);
   for (p=images; p->previous != (Image *) NULL; p=p->previous);
+  offset=index < 0 ? index+(long) GetImageListLength(images) : index;
   for (i=0; p != (Image *) NULL; p=p->next)
-    if (i++ == ((index < 0) ? (long) GetImageListLength(images)+index : index))
+    if (i++ == offset)
       break;
   if (p == (Image *) NULL)
     return((Image *) NULL);
@@ -747,16 +752,15 @@ MagickExport Image **ImageListToArray(const Image *images,
   assert(images->signature == MagickSignature);
   if (images->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",images->filename);
-  group=(Image **) AcquireMagickMemory((size_t)
-    (GetImageListLength(images)+1)*sizeof(*group));
+  group=(Image **) AcquireQuantumMemory((size_t) GetImageListLength(images)+1UL,
+    sizeof(*group));
   if (group == (Image **) NULL)
     {
       (void) ThrowMagickException(exception,GetMagickModule(),
         ResourceLimitError,"MemoryAllocationFailed","`%s'",images->filename);
       return((Image **) NULL);
     }
-  while (images->previous != (Image *) NULL)
-    images=images->previous;
+  images=GetFirstImageInList(images);
   for (i=0; images != (Image *) NULL; images=images->next)
     group[i++]=(Image *) images;
   group[i]=(Image *) NULL;
