@@ -779,9 +779,6 @@ static char *TranslateEvent(const LogEventType magick_unused(type),
   size_t
     extent;
 
-  struct tm
-    *time_meridian;
-
   time_t
     seconds;
 
@@ -789,7 +786,6 @@ static char *TranslateEvent(const LogEventType magick_unused(type),
   log_info=(LogInfo *) GetLogInfo("*",exception);
   exception=DestroyExceptionInfo(exception);
   seconds=time((time_t *) NULL);
-  time_meridian=localtime(&seconds);
   elapsed_time=GetElapsedTime(&log_info->timer);
   user_time=GetUserTime(&log_info->timer);
   text=AcquireString(event);
@@ -832,10 +828,8 @@ static char *TranslateEvent(const LogEventType magick_unused(type),
     if ((size_t) (q-text+MaxTextExtent) >= extent)
       {
         extent+=MaxTextExtent;
-        text=(char *) NULL;
-        if (~extent >= MaxTextExtent)
-          text=(char *) ResizeQuantumMemory(text,extent+MaxTextExtent,
-            sizeof(*text));
+        text=(char *) ResizeQuantumMemory(text,extent+MaxTextExtent,
+          sizeof(*text));
         if (text == (char *) NULL)
           return((char *) NULL);
         q=text+strlen(text);
@@ -1007,10 +1001,8 @@ static char *TranslateFilename(const LogInfo *log_info)
     if ((size_t) (q-filename+MaxTextExtent) >= extent)
       {
         extent+=MaxTextExtent;
-        filename=(char *) NULL;
-        if (~extent >= MaxTextExtent)
-          filename=(char *) ResizeQuantumMemory(filename,extent+MaxTextExtent,
-            sizeof(*filename));
+        filename=(char *) ResizeQuantumMemory(filename,extent+MaxTextExtent,
+          sizeof(*filename));
         if (filename == (char *) NULL)
           return((char *) NULL);
         q=filename+strlen(filename);
@@ -1119,7 +1111,7 @@ MagickBooleanType LogMagickEventList(const LogEventType type,const char *module,
 #else
   n=vsprintf(event,format,operands);
 #endif
-  if  (n < 0)
+  if (n < 0)
     event[MaxTextExtent-1]='\0';
   text=TranslateEvent(type,module,function,line,domain,event);
   if (text == (char *) NULL)
