@@ -154,6 +154,66 @@ MagickExport void DestroyMagickList(void)
 %                                                                             %
 %                                                                             %
 %                                                                             %
++   G e t I m a g e D e c o d e r                                             %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  GetImageDecoder() returns the image decoder.
+%
+%  The format of the GetImageDecoder method is:
+%
+%      DecodeImageHandler *GetImageDecoder(const MagickInfo *magick_info)
+%
+%  A description of each parameter follows:
+%
+%    o magick_info:  The magick info.
+%
+*/
+MagickExport DecodeImageHandler *GetImageDecoder(const MagickInfo *magick_info)
+{
+  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
+  assert(magick_info != (MagickInfo *) NULL);
+  assert(magick_info->signature == MagickSignature);
+  return(magick_info->decoder);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
++   G e t I m a g e E n c o d e r                                             %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  GetImageEncoder() returns the image encoder.
+%
+%  The format of the GetImageEncoder method is:
+%
+%      EncodeImageHandler *GetImageEncoder(const MagickInfo *magick_info)
+%
+%  A description of each parameter follows:
+%
+%    o magick_info:  The magick info.
+%
+*/
+MagickExport EncodeImageHandler *GetImageEncoder(const MagickInfo *magick_info)
+{
+  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
+  assert(magick_info != (MagickInfo *) NULL);
+  assert(magick_info->signature == MagickSignature);
+  return(magick_info->encoder);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 +   G e t I m a g e M a g i c k                                               %
 %                                                                             %
 %                                                                             %
@@ -196,7 +256,7 @@ MagickExport const char *GetImageMagick(const unsigned char *magick,
   p=(const MagickInfo *) GetNextValueInSplayTree(magick_list);
   while (p != (const MagickInfo *) NULL)
   {
-    if ((p->magick != (MagickHandler *) NULL) &&
+    if ((p->magick != (IsImageFormatHandler *) NULL) &&
         (p->magick(magick,length) != 0))
       break;
     p=(const MagickInfo *) GetNextValueInSplayTree(magick_list);
@@ -273,36 +333,6 @@ MagickExport MagickBooleanType GetMagickBlobSupport(
 %                                                                             %
 %                                                                             %
 %                                                                             %
-+   G e t M a g i c k D e c o d e r                                           %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  GetMagickDecoder() returns the magick decoder.
-%
-%  The format of the GetMagickDecoder method is:
-%
-%      DecoderHandler *GetMagickDecoder(const MagickInfo *magick_info)
-%
-%  A description of each parameter follows:
-%
-%    o magick_info:  The magick info.
-%
-*/
-MagickExport DecoderHandler *GetMagickDecoder(const MagickInfo *magick_info)
-{
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
-  assert(magick_info != (MagickInfo *) NULL);
-  assert(magick_info->signature == MagickSignature);
-  return((DecoderHandler *) magick_info->decoder);
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
 +   G e t M a g i c k D e s c r i p t i o n                                   %
 %                                                                             %
 %                                                                             %
@@ -333,36 +363,6 @@ MagickExport const char *GetMagickDescription(const MagickInfo *magick_info)
 %                                                                             %
 %                                                                             %
 %                                                                             %
-+   G e t M a g i c k E n c o d e r                                           %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  GetMagickEncoder() returns the magick encoder.
-%
-%  The format of the GetMagickEncoder method is:
-%
-%      EncoderHandler *GetMagickEncoder(const MagickInfo *magick_info)
-%
-%  A description of each parameter follows:
-%
-%    o magick_info:  The magick info.
-%
-*/
-MagickExport EncoderHandler *GetMagickEncoder(const MagickInfo *magick_info)
-{
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
-  assert(magick_info != (MagickInfo *) NULL);
-  assert(magick_info->signature == MagickSignature);
-  return((EncoderHandler *) magick_info->encoder);
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
 +   G e t M a g i c k E n d i a n S u p p o r t                               %
 %                                                                             %
 %                                                                             %
@@ -1128,7 +1128,7 @@ MagickExport void MagickCoreGenesis(const char *path,
       events=DestroyString(events);
     }
 #if defined(__WINDOWS__)
-#if defined(_DEBUG) && !defined(__BORLANDC__)
+#if defined(_DEBUG) && !defined(__BORLANDC__) && !defined(__MINGW32__)
   if (IsEventLogging() != MagickFalse)
     {
       int
@@ -1148,7 +1148,7 @@ MagickExport void MagickCoreGenesis(const char *path,
   /*
     Set client name and execution path.
   */
-  (void) GetExecutionPath(execution_path);
+  (void) GetExecutionPath(execution_path,MaxTextExtent);
   if ((path != (const char *) NULL) && (*path != '\0'))
     (void) CopyMagickString(execution_path,path,MaxTextExtent);
   GetPathComponent(execution_path,TailPath,filename);
