@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -13,23 +13,30 @@
   See the License for the specific language governing permissions and
   limitations under the License.
 
-  ImageMagick application programming interface declarations.
+  MagickCore magick methods.
 */
-#ifndef _MAGICK_MAGICK_H
-#define _MAGICK_MAGICK_H
+#ifndef _MAGICKCORE_MAGICK_H
+#define _MAGICKCORE_MAGICK_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
 #endif
 
+typedef enum
+{
+  NoThreadSupport = 0x0000,
+  DecoderThreadSupport = 0x0001,
+  EncoderThreadSupport = 0x0002
+} MagickThreadSupport;
+
 typedef Image
-  *(DecoderHandler)(const ImageInfo *,ExceptionInfo *);
+  *DecodeImageHandler(const ImageInfo *,ExceptionInfo *);
 
 typedef MagickBooleanType
-  (EncoderHandler)(const ImageInfo *,Image *);
+  EncodeImageHandler(const ImageInfo *,Image *);
 
 typedef MagickBooleanType
-  (MagickHandler)(const unsigned char *,const size_t);
+  IsImageFormatHandler(const unsigned char *,const size_t);
 
 typedef struct _MagickInfo
 {
@@ -43,13 +50,13 @@ typedef struct _MagickInfo
   ImageInfo
     *image_info;
 
-  DecoderHandler
+  DecodeImageHandler
     *decoder;
 
-  EncoderHandler
+  EncodeImageHandler
     *encoder;
 
-  MagickHandler
+  IsImageFormatHandler
     *magick;
 
   void
@@ -60,8 +67,12 @@ typedef struct _MagickInfo
     raw,
     endian_support,
     blob_support,
-    seekable_stream,
-    thread_support,
+    seekable_stream;
+
+  MagickStatusType
+    thread_support;
+
+  MagickBooleanType
     stealth;
 
   struct _MagickInfo
@@ -73,25 +84,23 @@ typedef struct _MagickInfo
 } MagickInfo;
 
 extern MagickExport char
-  **GetMagickList(const char *,unsigned long *,ExceptionInfo *),
-  *MagickToMime(const char *);
+  **GetMagickList(const char *,unsigned long *,ExceptionInfo *);
 
 extern MagickExport const char
   *GetImageMagick(const unsigned char *,const size_t),
   *GetMagickDescription(const MagickInfo *);
 
-extern MagickExport DecoderHandler
-  *GetMagickDecoder(const MagickInfo *);
+extern MagickExport DecodeImageHandler
+  *GetImageDecoder(const MagickInfo *);
 
-extern MagickExport EncoderHandler
-  *GetMagickEncoder(const MagickInfo *);
+extern MagickExport EncodeImageHandler
+  *GetImageEncoder(const MagickInfo *);
 
 extern MagickExport MagickBooleanType
   GetMagickAdjoin(const MagickInfo *),
   GetMagickBlobSupport(const MagickInfo *),
   GetMagickEndianSupport(const MagickInfo *),
   GetMagickSeekableStream(const MagickInfo *),
-  GetMagickThreadSupport(const MagickInfo *),
   IsMagickInstantiated(void),
   UnregisterMagickInfo(const char *);
 
@@ -103,10 +112,13 @@ extern MagickExport MagickInfo
   *RegisterMagickInfo(MagickInfo *),
   *SetMagickInfo(const char *);
 
+extern MagickExport MagickStatusType
+  GetMagickThreadSupport(const MagickInfo *);
+
 extern MagickExport void
-  DestroyMagick(void),
   DestroyMagickList(void),
-  InitializeMagick(const char *);
+  MagickCoreGenesis(const char *,const MagickBooleanType),
+  MagickCoreTerminus(void);
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
