@@ -38,20 +38,26 @@ extern "C" {
   EvaluateMagickPrefix(MagickMethodPrefix,method)
 
 #define AcquireCacheNexus  PrependMagickMethod(AcquireCacheNexus)
-#define AcquireCacheView  PrependMagickMethod(AcquireCacheView)
+#define AcquireCacheViewIndexes  PrependMagickMethod(AcquireCacheViewIndexes)
+#define AcquireCacheViewPixels  PrependMagickMethod(AcquireCacheViewPixels)
 #define AcquireDrawInfo  PrependMagickMethod(AcquireDrawInfo)
 #define AcquireExceptionInfo  PrependMagickMethod(AcquireExceptionInfo)
 #define AcquireFxInfo  PrependMagickMethod(AcquireFxInfo)
 #define AcquireImageInfo  PrependMagickMethod(AcquireImageInfo)
 #define AcquireImagePixels  PrependMagickMethod(AcquireImagePixels)
+#define AcquireIndexes  PrependMagickMethod(AcquireIndexes)
 #define AcquireMagickMemory  PrependMagickMethod(AcquireMagickMemory)
 #define AcquireMagickResource  PrependMagickMethod(AcquireMagickResource)
 #define AcquireMemory  PrependMagickMethod(AcquireMemory)
+#define AcquireNexusIndexes  PrependMagickMethod(AcquireNexusIndexes)
 #define AcquireOneCacheViewPixel  PrependMagickMethod(AcquireOneCacheViewPixel)
+#define AcquireOneMagickPixel  PrependMagickMethod(AcquireOneMagickPixel)
 #define AcquireOnePixel  PrependMagickMethod(AcquireOnePixel)
 #define AcquireOneVirtualPixel  PrependMagickMethod(AcquireOneVirtualPixel)
 #define AcquireQuantizeInfo  PrependMagickMethod(AcquireQuantizeInfo)
 #define AcquireQuantumInfo  PrependMagickMethod(AcquireQuantumInfo)
+#define AcquireQuantumMemory  PrependMagickMethod(AcquireQuantumMemory)
+#define AcquireResampleFilter  PrependMagickMethod(AcquireResampleFilter)
 #define AcquireSemaphoreInfo  PrependMagickMethod(AcquireSemaphoreInfo)
 #define AcquireStreamInfo  PrependMagickMethod(AcquireStreamInfo)
 #define AcquireStringInfo  PrependMagickMethod(AcquireStringInfo)
@@ -77,7 +83,6 @@ extern "C" {
 #define AllocateNextImage  PrependMagickMethod(AllocateNextImage)
 #define AllocateSemaphoreInfo  PrependMagickMethod(AllocateSemaphoreInfo)
 #define AllocateString  PrependMagickMethod(AllocateString)
-#define AnalyzeImage  PrependMagickMethod(AnalyzeImage)
 #define AnimateImages  PrependMagickMethod(AnimateImages)
 #define AnnotateImage  PrependMagickMethod(AnnotateImage)
 #define AppendImageFormat  PrependMagickMethod(AppendImageFormat)
@@ -111,9 +116,10 @@ extern "C" {
 #define ClearLinkedList  PrependMagickMethod(ClearLinkedList)
 #define ClearMagickException  PrependMagickMethod(ClearMagickException)
 #define ClipImage  PrependMagickMethod(ClipImage)
-#define ClipPathImage  PrependMagickMethod(ClipPathImage)
+#define ClipImagePath  PrependMagickMethod(ClipImagePath)
 #define CloneBlobInfo  PrependMagickMethod(CloneBlobInfo)
 #define CloneCacheMethods  PrependMagickMethod(CloneCacheMethods)
+#define CloneCacheView  PrependMagickMethod(CloneCacheView)
 #define CloneDrawInfo  PrependMagickMethod(CloneDrawInfo)
 #define CloneImageAttributes  PrependMagickMethod(CloneImageAttributes)
 #define CloneImageInfo  PrependMagickMethod(CloneImageInfo)
@@ -130,7 +136,8 @@ extern "C" {
 #define CloneString  PrependMagickMethod(CloneString)
 #define CloseBlob  PrependMagickMethod(CloseBlob)
 #define CloseCacheView  PrependMagickMethod(CloseCacheView)
-#define CloseMagickLog  PrependMagickMethod(CloseMagickLog)
+#define ClutImageChannel  PrependMagickMethod(ClutImageChannel)
+#define ClutImage  PrependMagickMethod(ClutImage)
 #define CoalesceImages  PrependMagickMethod(CoalesceImages)
 #define ColorFloodfillImage  PrependMagickMethod(ColorFloodfillImage)
 #define ColorizeImage  PrependMagickMethod(ColorizeImage)
@@ -147,6 +154,7 @@ extern "C" {
 #define CompositeImage  PrependMagickMethod(CompositeImage)
 #define CompositeLayers  PrependMagickMethod(CompositeLayers)
 #define CompressImageColormap  PrependMagickMethod(CompressImageColormap)
+#define ConcatenateColorComponent  PrependMagickMethod(ConcatenateColorComponent)
 #define ConcatenateMagickString  PrependMagickMethod(ConcatenateMagickString)
 #define ConcatenateStringInfo  PrependMagickMethod(ConcatenateStringInfo)
 #define ConcatenateString  PrependMagickMethod(ConcatenateString)
@@ -156,9 +164,14 @@ extern "C" {
 #define ConstituteImage  PrependMagickMethod(ConstituteImage)
 #define ContinueTimer  PrependMagickMethod(ContinueTimer)
 #define ContrastImage  PrependMagickMethod(ContrastImage)
-#define Contrast  PrependMagickMethod(Contrast)
 #define ContrastStretchImageChannel  PrependMagickMethod(ContrastStretchImageChannel)
 #define ContrastStretchImage  PrependMagickMethod(ContrastStretchImage)
+#define ConvertHSBToRGB  PrependMagickMethod(ConvertHSBToRGB)
+#define ConvertHSLToRGB  PrependMagickMethod(ConvertHSLToRGB)
+#define ConvertHWBToRGB  PrependMagickMethod(ConvertHWBToRGB)
+#define ConvertRGBToHSB  PrependMagickMethod(ConvertRGBToHSB)
+#define ConvertRGBToHSL  PrependMagickMethod(ConvertRGBToHSL)
+#define ConvertRGBToHWB  PrependMagickMethod(ConvertRGBToHWB)
 #define ConvolveImageChannel  PrependMagickMethod(ConvolveImageChannel)
 #define ConvolveImage  PrependMagickMethod(ConvolveImage)
 #define CopyMagickMemory  PrependMagickMethod(CopyMagickMemory)
@@ -168,13 +181,17 @@ extern "C" {
 #define DeconstructImages  PrependMagickMethod(DeconstructImages)
 #define DefineImageOption  PrependMagickMethod(DefineImageOption)
 #define DefineImageProperty  PrependMagickMethod(DefineImageProperty)
+#define DefineImageRegistry  PrependMagickMethod(DefineImageRegistry)
 #define DeleteImageAttribute  PrependMagickMethod(DeleteImageAttribute)
 #define DeleteImageFromList  PrependMagickMethod(DeleteImageFromList)
-#define DeleteImageList  PrependMagickMethod(DeleteImageList)
 #define DeleteImageOption  PrependMagickMethod(DeleteImageOption)
+#define DeleteImageProfile  PrependMagickMethod(DeleteImageProfile)
 #define DeleteImageProperty  PrependMagickMethod(DeleteImageProperty)
+#define DeleteImageRegistry  PrependMagickMethod(DeleteImageRegistry)
 #define DeleteImages  PrependMagickMethod(DeleteImages)
 #define DeleteMagickRegistry  PrependMagickMethod(DeleteMagickRegistry)
+#define DeleteNodeByValueFromSplayTree  PrependMagickMethod(DeleteNodeByValueFromSplayTree)
+#define DeleteNodeFromSplayTree  PrependMagickMethod(DeleteNodeFromSplayTree)
 #define DescribeImage  PrependMagickMethod(DescribeImage)
 #define DespeckleImage  PrependMagickMethod(DespeckleImage)
 #define DestroyBlob  PrependMagickMethod(DestroyBlob)
@@ -199,6 +216,7 @@ extern "C" {
 #define DestroyImage  PrependMagickMethod(DestroyImage)
 #define DestroyImageProfiles  PrependMagickMethod(DestroyImageProfiles)
 #define DestroyImageProperties  PrependMagickMethod(DestroyImageProperties)
+#define DestroyImageRegistry  PrependMagickMethod(DestroyImageRegistry)
 #define DestroyImages  PrependMagickMethod(DestroyImages)
 #define DestroyLinkedList  PrependMagickMethod(DestroyLinkedList)
 #define DestroyLocaleList  PrependMagickMethod(DestroyLocaleList)
@@ -215,6 +233,7 @@ extern "C" {
 #define DestroyQuantizeInfo  PrependMagickMethod(DestroyQuantizeInfo)
 #define DestroyQuantumInfo  PrependMagickMethod(DestroyQuantumInfo)
 #define DestroyRandomReservoir  PrependMagickMethod(DestroyRandomReservoir)
+#define DestroyResampleFilter  PrependMagickMethod(DestroyResampleFilter)
 #define DestroySemaphoreInfo  PrependMagickMethod(DestroySemaphoreInfo)
 #define DestroySemaphore  PrependMagickMethod(DestroySemaphore)
 #define DestroySplayTree  PrependMagickMethod(DestroySplayTree)
@@ -234,6 +253,7 @@ extern "C" {
 #define DisplayImages  PrependMagickMethod(DisplayImages)
 #define DisposeImages  PrependMagickMethod(DisposeImages)
 #define DistillRandomEvent  PrependMagickMethod(DistillRandomEvent)
+#define DistortImage  PrependMagickMethod(DistortImage)
 #define DrawAffineImage  PrependMagickMethod(DrawAffineImage)
 #define DrawClipPath  PrependMagickMethod(DrawClipPath)
 #define DrawGradientImage  PrependMagickMethod(DrawGradientImage)
@@ -248,7 +268,7 @@ extern "C" {
 #define EscapeString  PrependMagickMethod(EscapeString)
 #define EvaluateImageChannel  PrependMagickMethod(EvaluateImageChannel)
 #define EvaluateImage  PrependMagickMethod(EvaluateImage)
-#define ExecuteModuleProcess  PrependMagickMethod(ExecuteModuleProcess)
+#define ExcerptImage  PrependMagickMethod(ExcerptImage)
 #define ExpandAffine  PrependMagickMethod(ExpandAffine)
 #define ExpandFilename  PrependMagickMethod(ExpandFilename)
 #define ExpandFilenames  PrependMagickMethod(ExpandFilenames)
@@ -286,6 +306,7 @@ extern "C" {
 #define GammaImage  PrependMagickMethod(GammaImage)
 #define GaussianBlurImageChannel  PrependMagickMethod(GaussianBlurImageChannel)
 #define GaussianBlurImage  PrependMagickMethod(GaussianBlurImage)
+#define GaussJordanElimination  PrependMagickMethod(GaussJordanElimination)
 #define GetAffineMatrix  PrependMagickMethod(GetAffineMatrix)
 #define GetBlobError  PrependMagickMethod(GetBlobError)
 #define GetBlobFileHandle  PrependMagickMethod(GetBlobFileHandle)
@@ -304,6 +325,7 @@ extern "C" {
 #define GetCacheViewPixels  PrependMagickMethod(GetCacheViewPixels)
 #define GetCacheView  PrependMagickMethod(GetCacheView)
 #define GetCacheViewStorageClass  PrependMagickMethod(GetCacheViewStorageClass)
+#define GetCacheVirtualPixelMethod  PrependMagickMethod(GetCacheVirtualPixelMethod)
 #define GetClientName  PrependMagickMethod(GetClientName)
 #define GetClientPath  PrependMagickMethod(GetClientPath)
 #define GetCoderInfoList  PrependMagickMethod(GetCoderInfoList)
@@ -370,6 +392,7 @@ extern "C" {
 #define GetImageQuantizeError  PrependMagickMethod(GetImageQuantizeError)
 #define GetImageQuantumDepth  PrependMagickMethod(GetImageQuantumDepth)
 #define GetImageRange  PrependMagickMethod(GetImageRange)
+#define GetImageRegistry  PrependMagickMethod(GetImageRegistry)
 #define GetImageTotalInkDensity  PrependMagickMethod(GetImageTotalInkDensity)
 #define GetImageType  PrependMagickMethod(GetImageType)
 #define GetImageVirtualPixelMethod  PrependMagickMethod(GetImageVirtualPixelMethod)
@@ -381,9 +404,7 @@ extern "C" {
 #define GetLocaleInfo_  PrependMagickMethod(GetLocaleInfo_)
 #define GetLocaleList  PrependMagickMethod(GetLocaleList)
 #define GetLocaleMessage  PrependMagickMethod(GetLocaleMessage)
-#define GetLocaleMonitorMessage  PrependMagickMethod(GetLocaleMonitorMessage)
 #define GetLocaleOptions  PrependMagickMethod(GetLocaleOptions)
-#define GetLocaleValue  PrependMagickMethod(GetLocaleValue)
 #define GetLogInfoList  PrependMagickMethod(GetLogInfoList)
 #define GetLogInfo  PrependMagickMethod(GetLogInfo)
 #define GetLogList  PrependMagickMethod(GetLogList)
@@ -393,9 +414,9 @@ extern "C" {
 #define GetMagickAdjoin  PrependMagickMethod(GetMagickAdjoin)
 #define GetMagickBlobSupport  PrependMagickMethod(GetMagickBlobSupport)
 #define GetMagickCopyright  PrependMagickMethod(GetMagickCopyright)
-#define GetMagickDecoder  PrependMagickMethod(GetMagickDecoder)
+#define GetImageDecoder  PrependMagickMethod(GetImageDecoder)
 #define GetMagickDescription  PrependMagickMethod(GetMagickDescription)
-#define GetMagickEncoder  PrependMagickMethod(GetMagickEncoder)
+#define GetImageEncoder  PrependMagickMethod(GetImageEncoder)
 #define GetMagickEndianSupport  PrependMagickMethod(GetMagickEndianSupport)
 #define GetMagickGeometry  PrependMagickMethod(GetMagickGeometry)
 #define GetMagickHomeURL  PrependMagickMethod(GetMagickHomeURL)
@@ -431,6 +452,7 @@ extern "C" {
 #define GetNextImage  PrependMagickMethod(GetNextImage)
 #define GetNextImageProfile  PrependMagickMethod(GetNextImageProfile)
 #define GetNextImageProperty  PrependMagickMethod(GetNextImageProperty)
+#define GetNextImageRegistry  PrependMagickMethod(GetNextImageRegistry)
 #define GetNextKeyInHashmap  PrependMagickMethod(GetNextKeyInHashmap)
 #define GetNextKeyInSplayTree  PrependMagickMethod(GetNextKeyInSplayTree)
 #define GetNextValueInHashmap  PrependMagickMethod(GetNextValueInHashmap)
@@ -466,7 +488,6 @@ extern "C" {
 #define GetStringInfoDatum  PrependMagickMethod(GetStringInfoDatum)
 #define GetStringInfoLength  PrependMagickMethod(GetStringInfoLength)
 #define GetStringInfoPath  PrependMagickMethod(GetStringInfoPath)
-#define GetThresholdMapFile  PrependMagickMethod(GetThresholdMapFile)
 #define GetThresholdMap  PrependMagickMethod(GetThresholdMap)
 #define GetTimerInfo  PrependMagickMethod(GetTimerInfo)
 #define GetTypeInfoByFamily  PrependMagickMethod(GetTypeInfoByFamily)
@@ -479,6 +500,7 @@ extern "C" {
 #define GetValueFromLinkedList  PrependMagickMethod(GetValueFromLinkedList)
 #define GetValueFromSplayTree  PrependMagickMethod(GetValueFromSplayTree)
 #define GetXMLTreeAttribute  PrependMagickMethod(GetXMLTreeAttribute)
+#define GetXMLTreeAttributes  PrependMagickMethod(GetXMLTreeAttributes)
 #define GetXMLTreeChild  PrependMagickMethod(GetXMLTreeChild)
 #define GetXMLTreeContent  PrependMagickMethod(GetXMLTreeContent)
 #define GetXMLTreeOrdered  PrependMagickMethod(GetXMLTreeOrdered)
@@ -492,13 +514,9 @@ extern "C" {
 #define HashPointerType  PrependMagickMethod(HashPointerType)
 #define HashStringInfoType  PrependMagickMethod(HashStringInfoType)
 #define HashStringType  PrependMagickMethod(HashStringType)
-#define HSBTransform  PrependMagickMethod(HSBTransform)
-#define HSLTransform  PrependMagickMethod(HSLTransform)
 #define Huffman2DEncodeImage  PrependMagickMethod(Huffman2DEncodeImage)
 #define HuffmanDecodeImage  PrependMagickMethod(HuffmanDecodeImage)
 #define HuffmanEncodeImage  PrependMagickMethod(HuffmanEncodeImage)
-#define Hull  PrependMagickMethod(Hull)
-#define HWBTransform  PrependMagickMethod(HWBTransform)
 #define IdentifyImage  PrependMagickMethod(IdentifyImage)
 #define IdentityAffine  PrependMagickMethod(IdentityAffine)
 #define ImageListToArray  PrependMagickMethod(ImageListToArray)
@@ -522,6 +540,7 @@ extern "C" {
 #define InterpretImageFilename  PrependMagickMethod(InterpretImageFilename)
 #define InterpretImageProperties  PrependMagickMethod(InterpretImageProperties)
 #define InvokeDelegate  PrependMagickMethod(InvokeDelegate)
+#define InvokeDynamicImageFilter  PrependMagickMethod(InvokeDynamicImageFilter)
 #define IsAccessible  PrependMagickMethod(IsAccessible)
 #define IsBlobExempt  PrependMagickMethod(IsBlobExempt)
 #define IsBlobSeekable  PrependMagickMethod(IsBlobSeekable)
@@ -532,6 +551,8 @@ extern "C" {
 #define IsGlob  PrependMagickMethod(IsGlob)
 #define IsGrayImage  PrependMagickMethod(IsGrayImage)
 #define IsHashmapEmpty  PrependMagickMethod(IsHashmapEmpty)
+#define IsHighDynamicRangeImage  PrependMagickMethod(IsHighDynamicRangeImage)
+#define IsHistogramImage  PrependMagickMethod(IsHistogramImage)
 #define IsImageObject  PrependMagickMethod(IsImageObject)
 #define IsImagesEqual  PrependMagickMethod(IsImagesEqual)
 #define IsImageSimilar  PrependMagickMethod(IsImageSimilar)
@@ -563,14 +584,12 @@ extern "C" {
 #define ListLogInfo  PrependMagickMethod(ListLogInfo)
 #define ListMagicInfo  PrependMagickMethod(ListMagicInfo)
 #define ListMagickInfo  PrependMagickMethod(ListMagickInfo)
-#define ListMagickOptionInfo  PrependMagickMethod(ListMagickOptionInfo)
+#define ListMagickOptions  PrependMagickMethod(ListMagickOptions)
 #define ListMagickResourceInfo  PrependMagickMethod(ListMagickResourceInfo)
 #define ListMimeInfo  PrependMagickMethod(ListMimeInfo)
 #define ListModuleInfo  PrependMagickMethod(ListModuleInfo)
-#define ListThresholdMapFile  PrependMagickMethod(ListThresholdMapFile)
 #define ListThresholdMaps  PrependMagickMethod(ListThresholdMaps)
 #define ListTypeInfo  PrependMagickMethod(ListTypeInfo)
-#define LoadFontConfigFonts  PrependMagickMethod(LoadFontConfigFonts)
 #define LoadMimeLists  PrependMagickMethod(LoadMimeLists)
 #define LocaleCompare  PrependMagickMethod(LocaleCompare)
 #define LocaleLower  PrependMagickMethod(LocaleLower)
@@ -584,7 +603,6 @@ extern "C" {
 #define MagickCoreTerminus  PrependMagickMethod(MagickCoreTerminus)
 #define MagickError  PrependMagickMethod(MagickError)
 #define MagickFatalError  PrependMagickMethod(MagickFatalError)
-#define MagickIncarnate  PrependMagickMethod(MagickIncarnate)
 #define MagickMonitor  PrependMagickMethod(MagickMonitor)
 #define MagickOpenStream  PrependMagickMethod(MagickOpenStream)
 #define MagickOptionToMnemonic  PrependMagickMethod(MagickOptionToMnemonic)
@@ -598,9 +616,6 @@ extern "C" {
 #define MedianFilterImage  PrependMagickMethod(MedianFilterImage)
 #define MinifyImage  PrependMagickMethod(MinifyImage)
 #define ModifyImage  PrependMagickMethod(ModifyImage)
-#define ModulateHSB  PrependMagickMethod(ModulateHSB)
-#define ModulateHSL  PrependMagickMethod(ModulateHSL)
-#define ModulateHWB  PrependMagickMethod(ModulateHWB)
 #define ModulateImage  PrependMagickMethod(ModulateImage)
 #define MontageImageList  PrependMagickMethod(MontageImageList)
 #define MontageImages  PrependMagickMethod(MontageImages)
@@ -626,7 +641,6 @@ extern "C" {
 #define OpenBlob  PrependMagickMethod(OpenBlob)
 #define OpenCacheView  PrependMagickMethod(OpenCacheView)
 #define OpenStream  PrependMagickMethod(OpenStream)
-#define OpenVirtualCacheView  PrependMagickMethod(OpenVirtualCacheView)
 #define OptimizeImageLayers  PrependMagickMethod(OptimizeImageLayers)
 #define OptimizeImageTransparency  PrependMagickMethod(OptimizeImageTransparency)
 #define OptimizePlusImageLayers  PrependMagickMethod(OptimizePlusImageLayers)
@@ -635,13 +649,13 @@ extern "C" {
 #define OrderedPosterizeImageChannel  PrependMagickMethod(OrderedPosterizeImageChannel)
 #define OrderedPosterizeImage  PrependMagickMethod(OrderedPosterizeImage)
 #define PackbitsEncodeImage  PrependMagickMethod(PackbitsEncodeImage)
+#define PaintFloodfillImage  PrependMagickMethod(PaintFloodfillImage)
 #define PaintOpaqueImageChannel  PrependMagickMethod(PaintOpaqueImageChannel)
 #define PaintOpaqueImage  PrependMagickMethod(PaintOpaqueImage)
 #define PaintTransparentImage  PrependMagickMethod(PaintTransparentImage)
 #define ParseAbsoluteGeometry  PrependMagickMethod(ParseAbsoluteGeometry)
 #define ParseAffineGeometry  PrependMagickMethod(ParseAffineGeometry)
 #define ParseChannelOption  PrependMagickMethod(ParseChannelOption)
-#define ParseCharacterContent  PrependMagickMethod(ParseCharacterContent)
 #define ParseGeometry  PrependMagickMethod(ParseGeometry)
 #define ParseGravityGeometry  PrependMagickMethod(ParseGravityGeometry)
 #define ParseImageGeometry  PrependMagickMethod(ParseImageGeometry)
@@ -681,7 +695,9 @@ extern "C" {
 #define RandomThresholdImage  PrependMagickMethod(RandomThresholdImage)
 #define ReacquireMemory  PrependMagickMethod(ReacquireMemory)
 #define ReadBlobByte  PrependMagickMethod(ReadBlobByte)
+#define ReadBlobDouble  PrependMagickMethod(ReadBlobDouble)
 #define ReadBlobFloat  PrependMagickMethod(ReadBlobFloat)
+#define ReadBlobLongLong  PrependMagickMethod(ReadBlobLongLong)
 #define ReadBlobLong  PrependMagickMethod(ReadBlobLong)
 #define ReadBlobLSBLong  PrependMagickMethod(ReadBlobLSBLong)
 #define ReadBlobLSBShort  PrependMagickMethod(ReadBlobLSBShort)
@@ -689,7 +705,6 @@ extern "C" {
 #define ReadBlobMSBShort  PrependMagickMethod(ReadBlobMSBShort)
 #define ReadBlob  PrependMagickMethod(ReadBlob)
 #define ReadBlobShort  PrependMagickMethod(ReadBlobShort)
-#define ReadBlobStream  PrependMagickMethod(ReadBlobStream)
 #define ReadBlobString  PrependMagickMethod(ReadBlobString)
 #define ReadImage  PrependMagickMethod(ReadImage)
 #define ReadInlineImage  PrependMagickMethod(ReadInlineImage)
@@ -711,7 +726,7 @@ extern "C" {
 #define RegisterCUTImage  PrependMagickMethod(RegisterCUTImage)
 #define RegisterDCMImage  PrependMagickMethod(RegisterDCMImage)
 #define RegisterDIBImage  PrependMagickMethod(RegisterDIBImage)
-#define RegisterDOTImage  PrependMagickMethod(RegisterDOTImage)
+#define RegisterDNGImage  PrependMagickMethod(RegisterDNGImage)
 #define RegisterDPSImage  PrependMagickMethod(RegisterDPSImage)
 #define RegisterDPXImage  PrependMagickMethod(RegisterDPXImage)
 #define RegisterEPTImage  PrependMagickMethod(RegisterEPTImage)
@@ -725,6 +740,7 @@ extern "C" {
 #define RegisterHTMLImage  PrependMagickMethod(RegisterHTMLImage)
 #define RegisterICONImage  PrependMagickMethod(RegisterICONImage)
 #define RegisterINFOImage  PrependMagickMethod(RegisterINFOImage)
+#define RegisterIPLImage  PrependMagickMethod(RegisterIPLImage)
 #define RegisterJP2Image  PrependMagickMethod(RegisterJP2Image)
 #define RegisterJPEGImage  PrependMagickMethod(RegisterJPEGImage)
 #define RegisterLABELImage  PrependMagickMethod(RegisterLABELImage)
@@ -812,18 +828,22 @@ extern "C" {
 #define RemoveImageOption  PrependMagickMethod(RemoveImageOption)
 #define RemoveImageProfile  PrependMagickMethod(RemoveImageProfile)
 #define RemoveImageProperty  PrependMagickMethod(RemoveImageProperty)
+#define RemoveImageRegistry  PrependMagickMethod(RemoveImageRegistry)
 #define RemoveLastElementFromLinkedList  PrependMagickMethod(RemoveLastElementFromLinkedList)
 #define RemoveLastImageFromList  PrependMagickMethod(RemoveLastImageFromList)
 #define RemoveNodeByValueFromSplayTree  PrependMagickMethod(RemoveNodeByValueFromSplayTree)
 #define RemoveNodeFromSplayTree  PrependMagickMethod(RemoveNodeFromSplayTree)
 #define RemoveZeroDelayLayers  PrependMagickMethod(RemoveZeroDelayLayers)
 #define ReplaceImageInList  PrependMagickMethod(ReplaceImageInList)
+#define ResampleImage  PrependMagickMethod(ResampleImage)
+#define ResamplePixelColor  PrependMagickMethod(ResamplePixelColor)
 #define ResetHashmapIterator  PrependMagickMethod(ResetHashmapIterator)
 #define ResetImageAttributeIterator  PrependMagickMethod(ResetImageAttributeIterator)
 #define ResetImageOptionIterator  PrependMagickMethod(ResetImageOptionIterator)
 #define ResetImagePage  PrependMagickMethod(ResetImagePage)
 #define ResetImageProfileIterator  PrependMagickMethod(ResetImageProfileIterator)
 #define ResetImagePropertyIterator  PrependMagickMethod(ResetImagePropertyIterator)
+#define ResetImageRegistryIterator  PrependMagickMethod(ResetImageRegistryIterator)
 #define ResetLinkedListIterator  PrependMagickMethod(ResetLinkedListIterator)
 #define ResetMagickMemory  PrependMagickMethod(ResetMagickMemory)
 #define ResetSplayTreeIterator  PrependMagickMethod(ResetSplayTreeIterator)
@@ -831,12 +851,15 @@ extern "C" {
 #define ResetTimer  PrependMagickMethod(ResetTimer)
 #define ResizeImage  PrependMagickMethod(ResizeImage)
 #define ResizeMagickMemory  PrependMagickMethod(ResizeMagickMemory)
+#define ResizeQuantumMemory  PrependMagickMethod(ResizeQuantumMemory)
 #define ReverseImageList  PrependMagickMethod(ReverseImageList)
 #define RGBTransformImage  PrependMagickMethod(RGBTransformImage)
 #define RollImage  PrependMagickMethod(RollImage)
 #define RotateImage  PrependMagickMethod(RotateImage)
 #define SampleImage  PrependMagickMethod(SampleImage)
 #define ScaleImage  PrependMagickMethod(ScaleImage)
+#define ScaleResampleFilter  PrependMagickMethod(ScaleResampleFilter)
+#define SeedRandomReservoir  PrependMagickMethod(SeedRandomReservoir)
 #define SeekBlob  PrependMagickMethod(SeekBlob)
 #define SegmentImage  PrependMagickMethod(SegmentImage)
 #define SeparateImageChannel  PrependMagickMethod(SeparateImageChannel)
@@ -848,6 +871,8 @@ extern "C" {
 #define SetCacheThreshold  PrependMagickMethod(SetCacheThreshold)
 #define SetCacheView  PrependMagickMethod(SetCacheView)
 #define SetCacheViewStorageClass  PrependMagickMethod(SetCacheViewStorageClass)
+#define SetCacheViewVirtualPixelMethod  PrependMagickMethod(SetCacheViewVirtualPixelMethod)
+#define SetCacheVirtualPixelMethod  PrependMagickMethod(SetCacheVirtualPixelMethod)
 #define SetClientName  PrependMagickMethod(SetClientName)
 #define SetClientPath  PrependMagickMethod(SetClientPath)
 #define SetErrorHandler  PrependMagickMethod(SetErrorHandler)
@@ -875,6 +900,7 @@ extern "C" {
 #define SetImageProfile  PrependMagickMethod(SetImageProfile)
 #define SetImageProgressMonitor  PrependMagickMethod(SetImageProgressMonitor)
 #define SetImageProperty  PrependMagickMethod(SetImageProperty)
+#define SetImageRegistry  PrependMagickMethod(SetImageRegistry)
 #define SetImageStorageClass  PrependMagickMethod(SetImageStorageClass)
 #define SetImageType  PrependMagickMethod(SetImageType)
 #define SetImageVirtualPixelMethod  PrependMagickMethod(SetImageVirtualPixelMethod)
@@ -885,6 +911,7 @@ extern "C" {
 #define SetMagickRegistry  PrependMagickMethod(SetMagickRegistry)
 #define SetMagickResourceLimit  PrependMagickMethod(SetMagickResourceLimit)
 #define SetMonitorHandler  PrependMagickMethod(SetMonitorHandler)
+#define SetResampleFilterVirtualPixelMethod  PrependMagickMethod(SetResampleFilterVirtualPixelMethod)
 #define SetStreamInfoClientData  PrependMagickMethod(SetStreamInfoClientData)
 #define SetStreamInfoMap  PrependMagickMethod(SetStreamInfoMap)
 #define SetStreamInfoStorageType  PrependMagickMethod(SetStreamInfoStorageType)
@@ -930,7 +957,6 @@ extern "C" {
 #define StripString  PrependMagickMethod(StripString)
 #define SubstituteString  PrependMagickMethod(SubstituteString)
 #define SwirlImage  PrependMagickMethod(SwirlImage)
-#define SyncBlob  PrependMagickMethod(SyncBlob)
 #define SyncCacheNexus  PrependMagickMethod(SyncCacheNexus)
 #define SyncCacheView  PrependMagickMethod(SyncCacheView)
 #define SyncImageList  PrependMagickMethod(SyncImageList)
@@ -952,9 +978,6 @@ extern "C" {
 #define TintImage  PrependMagickMethod(TintImage)
 #define Tokenizer  PrependMagickMethod(Tokenizer)
 #define TransformColorspace  PrependMagickMethod(TransformColorspace)
-#define TransformHSB  PrependMagickMethod(TransformHSB)
-#define TransformHSL  PrependMagickMethod(TransformHSL)
-#define TransformHWB  PrependMagickMethod(TransformHWB)
 #define TransformImage  PrependMagickMethod(TransformImage)
 #define TransformImages  PrependMagickMethod(TransformImages)
 #define TransformRGBImage  PrependMagickMethod(TransformRGBImage)
@@ -978,7 +1001,7 @@ extern "C" {
 #define UnregisterCUTImage  PrependMagickMethod(UnregisterCUTImage)
 #define UnregisterDCMImage  PrependMagickMethod(UnregisterDCMImage)
 #define UnregisterDIBImage  PrependMagickMethod(UnregisterDIBImage)
-#define UnregisterDOTImage  PrependMagickMethod(UnregisterDOTImage)
+#define UnregisterDNGImage  PrependMagickMethod(UnregisterDNGImage)
 #define UnregisterDPSImage  PrependMagickMethod(UnregisterDPSImage)
 #define UnregisterDPXImage  PrependMagickMethod(UnregisterDPXImage)
 #define UnregisterEPTImage  PrependMagickMethod(UnregisterEPTImage)
@@ -992,6 +1015,7 @@ extern "C" {
 #define UnregisterHTMLImage  PrependMagickMethod(UnregisterHTMLImage)
 #define UnregisterICONImage  PrependMagickMethod(UnregisterICONImage)
 #define UnregisterINFOImage  PrependMagickMethod(UnregisterINFOImage)
+#define UnregisterIPLImage  PrependMagickMethod(UnregisterIPLImage)
 #define UnregisterJP2Image  PrependMagickMethod(UnregisterJP2Image)
 #define UnregisterJPEGImage  PrependMagickMethod(UnregisterJPEGImage)
 #define UnregisterLABELImage  PrependMagickMethod(UnregisterLABELImage)
@@ -1158,6 +1182,7 @@ extern "C" {
 #define XWindowByProperty  PrependMagickMethod(XWindowByProperty)
 #define ZLIBEncodeImage  PrependMagickMethod(ZLIBEncodeImage)
 #define ZoomImage  PrependMagickMethod(ZoomImage)
+
 #endif
 
 #if defined(__cplusplus) || defined(c_plusplus)
