@@ -149,116 +149,6 @@ MagickExport void DestroyModuleList(void)
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   E x e c u t e M o d u l e P r o c e s s                                   %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  ExecuteModuleProcess() executes a dynamic modules.
-%
-%  The format of the ExecuteModuleProcess module is:
-%
-%      MagickBooleanType ExecuteModuleProcess(const char *tag,Image **image,
-%        const int argc,char **argv)
-%
-%  A description of each parameter follows:
-%
-%    o tag: a character string that represents the name of the particular
-%      module.
-%
-%    o image: The image.
-%
-%    o argc: Specifies a pointer to an integer describing the number of
-%      elements in the argument vector.
-%
-%    o argv: Specifies a pointer to a text array containing the command line
-%      arguments.
-%
-*/
-MagickExport MagickBooleanType ExecuteModuleProcess(const char *tag,
-  Image **image,const int argc,char **argv)
-{
-  char
-    name[MaxTextExtent],
-    path[MaxTextExtent];
-
-  MagickBooleanType
-    (*module)(Image **,const int,char **),
-    status;
-
-  ModuleHandle
-    handle;
-
-  size_t
-    length;
-
-  /*
-    Find the module.
-  */
-  assert(image != (Image **) NULL);
-  assert((*image)->signature == MagickSignature);
-  if ((*image)->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",(*image)->filename);
-#if !defined(BuildMagickModules)
-  status=ExecuteStaticModuleProcess(tag,image,argc,argv);
-  if (status != MagickFalse)
-    return(status);
-#endif
-  status=MagickFalse;
-  TagToFilterModuleName(tag,name);
-  length=GetMagickModulePath(name,MagickFilterModule,path,&(*image)->exception);
-  if (length == 0)
-    return(MagickFalse);
-  /*
-    Open the module.
-  */
-  handle=lt_dlopen(path);
-  if (handle == (ModuleHandle) NULL)
-    {
-      (void) ThrowMagickException(&(*image)->exception,GetMagickModule(),
-        ModuleError,"UnableToLoadModule","`%s': %s",name,lt_dlerror());
-      return(status);
-    }
-  /*
-    Locate the module.
-  */
-#if !defined(MagickMethodPrefix)
-  (void) FormatMagickString(name,MaxTextExtent,"%sImage",tag);
-#else
-  (void) FormatMagickString(name,MaxTextExtent,"%s%sImage",MagickMethodPrefix,
-    tag);
-#endif
-  /*
-    Execute the module.
-  */
-  module=(MagickBooleanType (*)(Image **,const int,char **))
-    lt_dlsym(handle,name);
-  if (module == (MagickBooleanType (*)(Image **,const int,char **)) NULL)
-    (void) ThrowMagickException(&(*image)->exception,GetMagickModule(),
-      ModuleError,"UnableToLoadModule","`%s': %s",name,lt_dlerror());
-  else
-    {
-      if ((*image)->debug != MagickFalse)
-        (void) LogMagickEvent(ModuleEvent,GetMagickModule(),
-          "Invoking \"%s\" dynamic filter module",tag);
-      status=(*module)(image,argc,argv);
-      if ((*image)->debug != MagickFalse)
-        (void) LogMagickEvent(ModuleEvent,GetMagickModule(),"\"%s\" completes",
-          tag);
-    }
-  /*
-    Close the module.
-  */
-  (void) lt_dlclose(handle);
-  return(status);
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
 %   G e t M o d u l e I n f o                                                 %
 %                                                                             %
 %                                                                             %
@@ -476,7 +366,7 @@ MagickExport char **GetModuleList(const char *pattern,
     Locate all modules in the coder path.
   */
   TagToCoderModuleName("magick",filename);
-  length=GetMagickModulePath(filename,MagickCoderModule,module_path,
+  length=GetMagickModulePath(filename,MagickImageCoderModule,module_path,
     exception);
   if (length == 0)
     return((char **) NULL);
@@ -561,7 +451,8 @@ MagickExport char **GetModuleList(const char *pattern,
 %
 %    o filename: The module file name.
 %
-%    o module_type: The module type: MagickCoderModule or MagickFilterModule.
+%    o module_type: The module type: MagickImageCoderModule or
+%      MagickImageFilterModule.
 %
 %    o path: The path associated with the filename.
 %
@@ -582,19 +473,27 @@ static MagickBooleanType GetMagickModulePath(const char *filename,
   module_path=(char *) NULL;
   switch (module_type)
   {
-    case MagickCoderModule:
+    case MagickImageCoderModule:
     default:
     {
       (void) LogMagickEvent(ModuleEvent,GetMagickModule(),
         "Searching for coder module file \"%s\" ...",filename);
       module_path=GetEnvironmentValue("MAGICK_CODER_MODULE_PATH");
+#if defined(MagickImageCodersPath)
+      if (module_path == (char *) NULL)
+        module_path=AcquireString(MagickImageCodersPath);
+#endif
       break;
     }
-    case MagickFilterModule:
+    case MagickImageFilterModule:
     {
       (void) LogMagickEvent(ModuleEvent,GetMagickModule(),
         "Searching for filter module file \"%s\" ...",filename);
       module_path=GetEnvironmentValue("MAGICK_CODER_FILTER_PATH");
+#if defined(MagickImageFiltersPath)
+      if (module_path == (char *) NULL)
+        module_path=AcquireString(MagickImageFiltersPath);
+#endif
       break;
     }
   }
@@ -624,82 +523,83 @@ static MagickBooleanType GetMagickModulePath(const char *filename,
       module_path=DestroyString(module_path);
     }
 #if defined(UseInstalledMagick)
-#if defined(MagickCoderModulesPath)
-  {
-    const char
-      *directory;
-
-    /*
-      Search hard coded paths.
-    */
-    switch (module_type)
+   else
+#if defined(MagickImageCodersPath)
     {
-      case MagickCoderModule:
-      default:
+      const char
+        *directory;
+
+      /*
+        Search hard coded paths.
+      */
+      switch (module_type)
       {
-        directory=MagickCoderModulesPath;
-        break;
-      }
-      case MagickFilterModule:
-      {
-        directory=MagickFilterModulesPath;
-        break;
+        case MagickImageCoderModule:
+        default:
+        {
+          directory=MagickImageCodersPath;
+          break;
+        }
+        case MagickImageFilterModule:
+        {
+          directory=MagickImageFiltersPath;
+          break;
+        }
       }
+      (void) FormatMagickString(path,MaxTextExtent,"%s%s",directory,filename);
+      if (IsAccessible(path) == MagickFalse)
+        {
+          ThrowFileException(exception,ConfigureWarning,
+            "UnableToOpenModuleFile",path);
+          return(MagickFalse);
+        }
+      return(MagickTrue);
     }
-    (void) FormatMagickString(path,MaxTextExtent,"%s%s",directory,filename);
-    if (IsAccessible(path) == MagickFalse)
-      {
-        ThrowFileException(exception,ConfigureWarning,"UnableToOpenModuleFile",
-          path);
-        return(MagickFalse);
-      }
-    return(MagickTrue);
-  }
 #else
 #if defined(__WINDOWS__)
-  {
-    const char
-      *key,
-      *value;
-
-    /*
-      Locate path via registry key.
-    */
-    switch (module_type)
     {
-      case MagickCoderModule:
-      default:
+      const char
+        *key,
+        *value;
+
+      /*
+        Locate path via registry key.
+      */
+      switch (module_type)
       {
-        key="CoderModulesPath";
-        break;
-      }
-      case MagickFilterModule:
-      {
-        key="FilterModulesPath";
-        break;
+        case MagickImageCoderModule:
+        default:
+        {
+          key="CoderModulesPath";
+          break;
+        }
+        case MagickImageFilterModule:
+        {
+          key="FilterModulesPath";
+          break;
+        }
       }
+      value=NTRegistryKeyLookup(key);
+      if (value == (char *) NULL)
+        {
+          ThrowMagickException(exception,GetMagickModule(),ConfigureError,
+            "RegistryKeyLookupFailed","`%s'",key);
+          return(MagickFalse);
+        }
+      (void) FormatMagickString(path,MaxTextExtent,"%s%s%s",value,
+        DirectorySeparator,filename);
+      if (IsAccessible(path) == MagickFalse)
+        {
+          ThrowFileException(exception,ConfigureWarning,
+            "UnableToOpenModuleFile",path);
+          return(MagickFalse);
+        }
+      return(MagickTrue);
     }
-    value=NTRegistryKeyLookup(key);
-    if (value == (char *) NULL)
-      {
-        ThrowMagickException(exception,GetMagickModule(),ConfigureError,
-          "RegistryKeyLookupFailed","`%s'",key);
-        return(MagickFalse);
-      }
-    (void) FormatMagickString(path,MaxTextExtent,"%s%s%s",value,
-      DirectorySeparator,filename);
-    if (IsAccessible(path) == MagickFalse)
-      {
-        ThrowFileException(exception,ConfigureWarning,"UnableToOpenModuleFile",
-          path);
-        return(MagickFalse);
-      }
-    return(MagickTrue);
-  }
 #endif
 #endif
-#if !defined(MagickCoderModulesPath) && !defined(__WINDOWS__)
-# error MagickCoderModulesPath or __WINDOWS__ must be defined when UseInstalledMagick is defined
+#if !defined(MagickImageCodersPath) && !defined(__WINDOWS__)
+# error MagickImageCodersPath or __WINDOWS__ must be defined when UseInstalledMagick is defined
 #endif
 #else
   {
@@ -721,15 +621,15 @@ static MagickBooleanType GetMagickModulePath(const char *filename,
 
         switch (module_type)
         {
-          case MagickCoderModule:
+          case MagickImageCoderModule:
           default:
           {
-            directory=MagickCoderModulesSubdir;
+            directory=MagickImageCoderModulesSubdir;
             break;
           }
-          case MagickFilterModule:
+          case MagickImageFilterModule:
           {
-            directory=MagickFilterModulesSubdir;
+            directory=MagickImageFilterModulesSubdir;
             break;
           }
         }
@@ -758,13 +658,13 @@ static MagickBooleanType GetMagickModulePath(const char *filename,
 
       switch (module_type)
       {
-        case MagickCoderModule:
+        case MagickImageCoderModule:
         default:
         {
           directory="modules";
           break;
         }
-        case MagickFilterModule:
+        case MagickImageFilterModule:
         {
           directory="filters";
           break;
@@ -821,6 +721,7 @@ static MagickBooleanType GetMagickModulePath(const char *filename,
       path);
   return(MagickFalse);
 #endif
+  return(MagickFalse);
 }
 
 /*
@@ -915,6 +816,130 @@ static MagickBooleanType InitializeModuleList(
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   I n v o k e D y n a m i c I m a g e F i l t e r                           %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  InvokeDynamicImageFilter() invokes a dynamic image filter.
+%
+%  The format of the InvokeDynamicImageFilter module is:
+%
+%      MagickBooleanType InvokeDynamicImageFilter(const char *tag,Image **image,
+%        const int argc,char **argv,ExceptionInfo *exception)
+%
+%  A description of each parameter follows:
+%
+%    o tag: a character string that represents the name of the particular
+%      module.
+%
+%    o image: The image.
+%
+%    o argc: Specifies a pointer to an integer describing the number of
+%      elements in the argument vector.
+%
+%    o argv: Specifies a pointer to a text array containing the command line
+%      arguments.
+%
+%    o exception: Return any errors or warnings in this structure.
+%
+*/
+MagickExport MagickBooleanType InvokeDynamicImageFilter(const char *tag,
+  Image **images,const int argc,char **argv,ExceptionInfo *exception)
+{
+  char
+    name[MaxTextExtent],
+    path[MaxTextExtent];
+
+  ImageFilterHandler
+    *image_filter;
+
+  MagickBooleanType
+    status;
+
+  ModuleHandle
+    handle;
+
+  size_t
+    length;
+
+  /*
+    Find the module.
+  */
+  assert(images != (Image **) NULL);
+  assert((*images)->signature == MagickSignature);
+  if ((*images)->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      (*images)->filename);
+#if !defined(BuildMagickModules)
+  status=InvokeStaticImageFilter(tag,images,argc,argv,exception);
+  if (status != MagickFalse)
+    return(status);
+#endif
+  status=MagickFalse;
+  TagToFilterModuleName(tag,name);
+  length=GetMagickModulePath(name,MagickImageFilterModule,path,exception);
+  if (length == 0)
+    return(MagickFalse);
+  /*
+    Open the module.
+  */
+  handle=lt_dlopen(path);
+  if (handle == (ModuleHandle) NULL)
+    {
+      (void) ThrowMagickException(exception,GetMagickModule(),ModuleError,
+        "UnableToLoadModule","`%s': %s",name,lt_dlerror());
+      return(status);
+    }
+  /*
+    Locate the module.
+  */
+#if !defined(MagickMethodPrefix)
+  (void) FormatMagickString(name,MaxTextExtent,"%sImage",tag);
+#else
+  (void) FormatMagickString(name,MaxTextExtent,"%s%sImage",MagickMethodPrefix,
+    tag);
+#endif
+  /*
+    Execute the module.
+  */
+  image_filter=(ImageFilterHandler *) lt_dlsym(handle,name);
+  if (image_filter == (ImageFilterHandler *) NULL)
+    (void) ThrowMagickException(exception,GetMagickModule(),ModuleError,
+      "UnableToLoadModule","`%s': %s",name,lt_dlerror());
+  else
+    {
+      unsigned long
+        signature;
+
+      if ((*images)->debug != MagickFalse)
+        (void) LogMagickEvent(ModuleEvent,GetMagickModule(),
+          "Invoking \"%s\" dynamic image filter",tag);
+      signature=image_filter(images,argc,argv,exception);
+      if ((*images)->debug != MagickFalse)
+        (void) LogMagickEvent(ModuleEvent,GetMagickModule(),"\"%s\" completes",
+          tag);
+      if (signature != MagickImageFilterSignature)
+        {
+          (void) ThrowMagickException(exception,GetMagickModule(),ModuleError,
+            "ImageFilterSignatureMismatch","`%s': %8lx != %8lx",tag,signature,
+            MagickImageFilterSignature);
+          return(MagickFalse);
+        }
+    }
+  /*
+    Close the module.
+  */
+  (void) lt_dlclose(handle);
+  return(status);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %  L i s t M o d u l e I n f o                                                %
 %                                                                             %
 %                                                                             %
@@ -1021,6 +1046,9 @@ MagickExport MagickBooleanType OpenModule(const char *module,
   size_t
     length;
 
+  unsigned long
+    signature;
+
   /*
     Assign module name from alias.
   */
@@ -1046,7 +1074,7 @@ MagickExport MagickBooleanType OpenModule(const char *module,
   (void) LogMagickEvent(ModuleEvent,GetMagickModule(),
     "Searching for module \"%s\" using filename \"%s\"",module_name,filename);
   *path='\0';
-  length=GetMagickModulePath(filename,MagickCoderModule,path,exception);
+  length=GetMagickModulePath(filename,MagickImageCoderModule,path,exception);
   if (length == 0)
     {
       RelinquishSemaphoreInfo(module_semaphore);
@@ -1089,8 +1117,8 @@ MagickExport MagickBooleanType OpenModule(const char *module,
     Define RegisterFORMATImage method.
   */
   TagToModuleName(module_name,"Register%sImage",name);
-  module_info->register_module=(void (*)(void)) lt_dlsym(handle,name);
-  if (module_info->register_module == (void (*)(void)) NULL)
+  module_info->register_module=(unsigned long (*)(void)) lt_dlsym(handle,name);
+  if (module_info->register_module == (unsigned long (*)(void)) NULL)
     {
       (void) ThrowMagickException(exception,GetMagickModule(),ModuleError,
         "UnableToRegisterImageFormat","`%s': %s",module_name,lt_dlerror());
@@ -1115,7 +1143,16 @@ MagickExport MagickBooleanType OpenModule(const char *module,
   (void) LogMagickEvent(ModuleEvent,GetMagickModule(),
     "Method \"%s\" in module \"%s\" at address %p",name,module_name,
     (void *) module_info->unregister_module);
-  module_info->register_module();
+  signature=module_info->register_module();
+  if (signature != MagickImageCoderSignature)
+    {
+      (void) ThrowMagickException(exception,GetMagickModule(),ModuleError,
+        "CoderSignatureMismatch","`%s': %8lx != %8lx",module_name,signature,
+        MagickImageCoderSignature);
+      module_info->unregister_module();
+      RelinquishSemaphoreInfo(module_semaphore);
+      return(MagickFalse);
+    }
   RelinquishSemaphoreInfo(module_semaphore);
   return(MagickTrue);
 }
@@ -1363,7 +1400,7 @@ static void TagToModuleName(const char *tag,const char *format,char *module)
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   U n R e g i s t e r M o d u l e                                           %
+%   U n r e g i s t e r M o d u l e                                           %
 %                                                                             %
 %                                                                             %
 %                                                                             %
@@ -1405,34 +1442,42 @@ static MagickBooleanType UnregisterModule(const ModuleInfo *module_info,
   return(MagickTrue);
 }
 #else
-MagickExport MagickBooleanType ListModuleInfo(FILE *file,
-  ExceptionInfo *exception)
+MagickExport MagickBooleanType ListModuleInfo(FILE *magick_unused(file),
+  ExceptionInfo *magick_unused(exception))
 {
   return(MagickTrue);
 }
 
-MagickExport MagickBooleanType ExecuteModuleProcess(const char *tag,
-  Image **image,const int argc,char **argv)
+MagickExport MagickBooleanType InvokeDynamicImageFilter(const char *tag,
+  Image **image,const int argc,char **argv,ExceptionInfo *exception)
 {
-  MagickBooleanType
-    status;
-
-  status=MagickFalse;
 #if !defined(BuildMagickModules)
   {
-    extern MagickBooleanType
-      analyzeImage(Image **,const int,char **);
+    extern unsigned long
+      analyzeImage(Image **,const int,char **,ExceptionInfo *);
 
-    MagickBooleanType
-      (*method)(Image **,const int,char **);
+    ImageFilterHandler
+      *image_filter;
 
-    method=NULL;
+    image_filter=(ImageFilterHandler *) NULL;
     if (LocaleCompare("analyze",tag) == 0)
-      method=analyzeImage;
-    if (method != NULL)
-      status=(*method)(image,argc,argv);
+      image_filter=analyzeImage;
+    if (image_filter != (ImageFilterHandler *) NULL)
+      {
+        unsigned long
+          signature;
+
+        signature=image_filter(image,argc,argv,exception);
+        if (signature != MagickImageFilterSignature)
+          {
+            (void) ThrowMagickException(exception,GetMagickModule(),ModuleError,
+              "ImageFilterSignatureMismatch","`%s': %8lx != %8lx",tag,signature,
+              MagickImageFilterSignature);
+            return(MagickFalse);
+          }
+      }
   }
 #endif
-  return(status);
+  return(MagickTrue);
 }
 #endif
