@@ -228,7 +228,7 @@ MagickExport void GetMontageInfo(const ImageInfo *image_info,
   montage_info->gravity=CenterGravity;
   montage_info->pointsize=image_info->pointsize;
   montage_info->fill.opacity=OpaqueOpacity;
-  montage_info->stroke.opacity=TransparentOpacity;
+  montage_info->stroke.opacity=(Quantum) TransparentOpacity;
   montage_info->background_color=image_info->background_color;
   montage_info->border_color=image_info->border_color;
   montage_info->matte_color=image_info->matte_color;
@@ -441,10 +441,7 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
     progress_monitor=SetImageProgressMonitor(image,(MagickProgressMonitor) NULL,
       image->client_data);
     flags=ParseSizeGeometry(image,montage_info->geometry,&geometry);
-    if (image->filter == UndefinedFilter)
-      thumbnail=ThumbnailImage(image,geometry.width,geometry.height,exception);
-    else
-      thumbnail=ZoomImage(image,geometry.width,geometry.height,exception);
+    thumbnail=ThumbnailImage(image,geometry.width,geometry.height,exception);
     if (thumbnail == (Image *) NULL)
       break;
     image_list[i]=thumbnail;
@@ -574,7 +571,7 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
   number_lines=0;
   for (i=0; i < (long) number_images; i++)
   {
-    value=GetImageProperty(image_list[i],"Label");
+    value=GetImageProperty(image_list[i],"label");
     if (value == (const char *) NULL)
       continue;
     if (MultilineCensus(value) > number_lines)
@@ -785,7 +782,7 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
           extract_info=frame_info;
           extract_info.width=width+2*frame_info.width;
           extract_info.height=height+2*frame_info.height;
-          value=GetImageProperty(image,"Label");
+          value=GetImageProperty(image,"label");
           if (value != (const char *) NULL)
             extract_info.height+=(unsigned long) ((metrics.ascent-
               metrics.descent+4)*MultilineCensus(value));
@@ -824,7 +821,7 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
           }
           (void) CompositeImage(montage,OverCompositeOp,image,x_offset+x,
             y_offset+y);
-          value=GetImageProperty(image,"Label");
+          value=GetImageProperty(image,"label");
           if (value != (const char *) NULL)
             {
               char
