@@ -492,12 +492,19 @@ MagickExport int NTExitLibrary(void)
 %
 %  The format of the GetExecutionPath method is:
 %
-%      MagickBooleanType NTGetExecutionPath(char *path)
+%      MagickBooleanType NTGetExecutionPath(char *path,const size_t extent)
+%
+%  A description of each parameter follows:
+%
+%    o path: the pathname of the executable that started the process.
+%
+%    o extent: the maximum extent of the path.
 %
 */
-MagickExport MagickBooleanType NTGetExecutionPath(char *path)
+MagickExport MagickBooleanType NTGetExecutionPath(char *path,
+  const size_t extent)
 {
-  GetModuleFileName(0,path,MaxTextExtent);
+  GetModuleFileName(0,path,extent);
   return(MagickTrue);
 }
 
