@@ -1,11 +1,11 @@
 /*
-  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
   
-    http://www.imagemagick.org/www/Copyright.html
+    http://www.imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -13,10 +13,10 @@
   See the License for the specific language governing permissions and
   limitations under the License.
 
-  Windows NT utility methods for ImageMagick.
+  MagickCore Windows NT utility methods.
 */
-#ifndef _MAGICK_NTFEATURE_H
-#define _MAGICK_NTFEATURE_H
+#ifndef _MAGICKCORE_NT_FEATURE_H
+#define _MAGICKCORE_NT_FEATURE_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
@@ -24,12 +24,9 @@ extern "C" {
 
 #include "magick/splay-tree.h"
 
-extern MagickExport char
-  *NTRegistryKeyLookup(const char *key);
-
 extern MagickExport void
   *CropImageToHBITMAP(Image *,const RectangleInfo *,ExceptionInfo *),
-  *ImageToHBITMAP(Image* image);
+  *ImageToHBITMAP(Image *);
 
 #if !defined(XS_VERSION)
 
