@@ -41,6 +41,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
+#include "magick/artifact.h"
 #include "magick/cache.h"
 #include "magick/color.h"
 #include "magick/compare.h"
@@ -114,7 +115,8 @@ static const OptionInfo
     { "Green", (long) GreenChannel },
     { "Hue", (long) RedChannel },
     { "Index", (long) IndexChannel },
-    { "Luminosity", (long) BlueChannel },
+    { "Luminance", (long) BlueChannel },
+    { "Luminosity", (long) BlueChannel },  /* deprecated */
     { "Magenta", (long) MagentaChannel },
     { "Matte", (long) OpacityChannel },
     { "Opacity", (long) OpacityChannel },
@@ -534,8 +536,6 @@ static const OptionInfo
     { "-strokewidth", 1L },
     { "+style", 0L },
     { "-style", 1L },
-    { "+support", 0L },
-    { "-support", 1L },
     { "+swap", 0L },
     { "-swap", 1L },
     { "+swirl", 0L },
@@ -636,6 +636,7 @@ static const OptionInfo
     { "CopyRed", (long) CopyRedCompositeOp },
     { "CopyYellow", (long) CopyYellowCompositeOp },
     { "Darken", (long) DarkenCompositeOp },
+    { "Divide", (long) DivideCompositeOp },
     { "Dst", (long) DstCompositeOp },
     { "Difference", (long) DifferenceCompositeOp },
     { "Displace", (long) DisplaceCompositeOp },
@@ -805,12 +806,16 @@ static const OptionInfo
     { "Hamming", (long) HammingFilter },
     { "Hanning", (long) HanningFilter },
     { "Hermite", (long) HermiteFilter },
+    { "Kaiser", (long) KaiserFilter },
+    { "Lagrangian", (long) LagrangianFilter },
     { "Lanczos", (long) LanczosFilter },
     { "Mitchell", (long) MitchellFilter },
+    { "Parzen", (long) ParzenFilter },
     { "Point", (long) PointFilter },
     { "Quadratic", (long) QuadraticFilter },
     { "Sinc", (long) SincFilter },
     { "Triangle", (long) TriangleFilter },
+    { "Welsh", (long) WelshFilter },
     { (char *) NULL, (long) UndefinedFilter }
   },
   GravityOptions[] =
@@ -864,7 +869,7 @@ static const OptionInfo
     { "Spline", (long) SplineInterpolatePixel },
     { (char *) NULL, (long) UndefinedInterpolatePixel }
   },
-  LayersOptions[] =
+  LayerOptions[] =
   {
     { "Undefined", (long) UndefinedLayer },
     { "Coalesce", (long) CoalesceLayer },
@@ -879,6 +884,9 @@ static const OptionInfo
     { "RemoveDups", (long) RemoveDupsLayer },
     { "RemoveZero", (long) RemoveZeroLayer },
     { "Composite", (long) CompositeLayer },
+    { "Merge", (long) MergeLayer },
+    { "Flatten", (long) FlattenLayer },
+    { "Mosaic", (long) MosaicLayer },
     { (char *) NULL, (long) UndefinedLayer }
   },
   LineCapOptions[] =
@@ -924,7 +932,7 @@ static const OptionInfo
     { "Intent", (long) MagickIntentOptions },
     { "Interlace", (long) MagickInterlaceOptions },
     { "Interpolate", (long) MagickInterpolateOptions },
-    { "Layers", (long) MagickLayersOptions },
+    { "Layers", (long) MagickLayerOptions },
     { "LineCap", (long) MagickLineCapOptions },
     { "LineJoin", (long) MagickLineJoinOptions },
     { "List", (long) MagickListOptions },
@@ -1026,6 +1034,7 @@ static const OptionInfo
     { "flatten", MagickTrue },
     { "fx", MagickTrue },
     { "insert", MagickTrue },
+    { "layers", MagickTrue },
     { "limit", MagickTrue },
     { "map", MagickTrue },
     { "morph", MagickTrue },
@@ -1239,10 +1248,6 @@ static const OptionInfo
 MagickExport MagickBooleanType CloneImageOptions(ImageInfo *image_info,
   const ImageInfo *clone_info)
 {
-  const char
-    *key,
-    *value;
-
   assert(image_info != (ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
@@ -1250,16 +1255,9 @@ MagickExport MagickBooleanType CloneImageOptions(ImageInfo *image_info,
       image_info->filename);
   assert(clone_info != (const ImageInfo *) NULL);
   assert(clone_info->signature == MagickSignature);
-  if (clone_info->options == (void *) NULL)
-    return(MagickTrue);
-  ResetImageOptionIterator(clone_info);
-  for (key=GetNextImageOption(clone_info); key != (const char *) NULL; )
-  {
-    value=GetImageOption(clone_info,key);
-    if (value != (const char *) NULL)
-      (void) SetImageOption(image_info,key,value);
-    key=GetNextImageOption(clone_info);
-  }
+  if (clone_info->options != (void *) NULL)
+    image_info->options=CloneSplayTree((SplayTreeInfo *) clone_info->options,
+      (void *(*)(void *)) ConstantString,(void *(*)(void *)) ConstantString);
   return(MagickTrue);
 }
 
@@ -1475,7 +1473,7 @@ static const OptionInfo *GetOptionInfo(const MagickOption option)
     case MagickIntentOptions: return(IntentOptions);
     case MagickInterlaceOptions: return(InterlaceOptions);
     case MagickInterpolateOptions: return(InterpolateOptions);
-    case MagickLayersOptions: return(LayersOptions);
+    case MagickLayerOptions: return(LayerOptions);
     case MagickLineCapOptions: return(LineCapOptions);
     case MagickLineJoinOptions: return(LineJoinOptions);
     case MagickListOptions: return(ListOptions);
@@ -2058,7 +2056,11 @@ MagickExport MagickBooleanType SetImageOption(ImageInfo *image_info,
 MagickExport MagickBooleanType SyncImageOptions(const ImageInfo *image_info,
   Image *image)
 {
+  char
+    property[MaxTextExtent];
+
   const char
+    *value,
     *option;
 
   MagickStatusType
@@ -2103,6 +2105,10 @@ MagickExport MagickBooleanType SyncImageOptions(const ImageInfo *image_info,
   if (option != (const char *) NULL)
     image->dispose=(DisposeType) ParseMagickOption(MagickDisposeOptions,
       MagickFalse,option);
+  option=GetImageOption(image_info,"filter");
+  if (option != (const char *) NULL)
+    image->filter=(FilterTypes) ParseMagickOption(MagickFilterOptions,
+      MagickFalse,option);
   option=GetImageOption(image_info,"gravity");
   if (option != (const char *) NULL)
     image->gravity=(GravityType) ParseMagickOption(MagickGravityOptions,
@@ -2135,5 +2141,16 @@ MagickExport MagickBooleanType SyncImageOptions(const ImageInfo *image_info,
       flags=ParseAbsoluteGeometry(geometry,&image->page);
       geometry=DestroyString(geometry);
     }
+  ResetImageOptionIterator(image_info);
+  for (option=GetNextImageOption(image_info); option != (const char *) NULL; )
+  {
+    value=GetImageOption(image_info,option);
+    if (value != (const char *) NULL)
+      {
+        (void) FormatMagickString(property,MaxTextExtent,"%s",option);
+        (void) SetImageArtifact(image,property,value);
+      }
+    option=GetNextImageOption(image_info);
+  }
   return(MagickTrue);
 }
