@@ -52,6 +52,7 @@
 #include "magick/profile.h"
 #include "magick/property.h"
 #include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/splay-tree.h"
 #include "magick/string_.h"
 #include "magick/utility.h"
@@ -91,28 +92,19 @@
 MagickExport MagickBooleanType CloneImageProfiles(Image *image,
   const Image *clone_image)
 {
-  const char
-    *name;
-
-  const StringInfo
-    *profile;
-
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(clone_image != (const Image *) NULL);
   assert(clone_image->signature == MagickSignature);
-  if (clone_image->profiles == (SplayTreeInfo *) NULL)
-    return(MagickTrue);
-  ResetImageProfileIterator(clone_image);
-  for (name=GetNextImageProfile(clone_image); name != (char *) NULL; )
-  {
-    profile=GetImageProfile(clone_image,name);
-    if (profile != (StringInfo *) NULL)
-      (void) SetImageProfile(image,name,profile);
-    name=GetNextImageProfile(clone_image);
-  }
+  image->color_profile.length=clone_image->color_profile.length;
+  image->color_profile.info=clone_image->color_profile.info;
+  image->iptc_profile.length=clone_image->iptc_profile.length;
+  image->iptc_profile.info=clone_image->iptc_profile.info;
+  if (clone_image->profiles != (void *) NULL)
+    image->profiles=CloneSplayTree((SplayTreeInfo *) clone_image->profiles,
+      (void *(*)(void *)) ConstantString,(void *(*)(void *)) CloneStringInfo);
   return(MagickTrue);
 }
 
@@ -121,6 +113,58 @@ MagickExport MagickBooleanType CloneImageProfiles(Image *image,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   D e l e t e I m a g e P r o f i l e                                       %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  DeleteImageProfile() deletes a profile from the image by its name.
+%
+%  The format of the DeleteImageProfile method is:
+%
+%      MagickBooleanTyupe DeleteImageProfile(Image *image,const char *name)
+%
+%  A description of each parameter follows:
+%
+%    o image: The image.
+%
+%    o name: The profile name.
+%
+*/
+MagickExport MagickBooleanType DeleteImageProfile(Image *image,
+  const char *name)
+{
+  assert(image != (Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
+  if (image->profiles == (SplayTreeInfo *) NULL)
+    return(MagickFalse);
+  if (LocaleCompare(name,"icc") == 0)
+    {
+      /*
+        Continue to support deprecated color profile for now.
+      */
+      image->color_profile.length=0;
+      image->color_profile.info=(unsigned char *) NULL;
+    }
+  if (LocaleCompare(name,"iptc") == 0)
+    {
+      /*
+        Continue to support deprecated IPTC profile for now.
+      */
+      image->iptc_profile.length=0;
+      image->iptc_profile.info=(unsigned char *) NULL;
+    }
+  return(DeleteNodeFromSplayTree((SplayTreeInfo *) image->profiles,name));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   D e s t r o y I m a g e P r o f i l e s                                   %
 %                                                                             %
 %                                                                             %
@@ -687,14 +731,14 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
           DestroyImageProfiles(image);
           return(MagickTrue);
         }
-      return(RemoveImageProfile(image,name));
+      return(DeleteImageProfile(image,name));
     }
   /*
     Add a ICC, IPTC, or generic profile to the image.
   */
   profile=AcquireStringInfo((size_t) length);
   SetStringInfoDatum(profile,(unsigned char *) datum);
-  if ((LocaleCompare("icc",name) == 0) || (LocaleCompare("icm",name) == 0))
+  if ((LocaleCompare(name,"icc") == 0) || (LocaleCompare(name,"icm") == 0))
     {
       const StringInfo
         *icc_profile;
@@ -706,13 +750,13 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
           const char
             *value;
 
-          value=GetImageProperty(image,"EXIF:ColorSpace");
+          value=GetImageProperty(image,"exif:ColorSpace");
           if (LocaleCompare(value,"1") != 0)
             (void) SetsRGBImageProfile(image);
-          value=GetImageProperty(image,"EXIF:InteroperabilityIndex");
+          value=GetImageProperty(image,"exif:InteroperabilityIndex");
           if (LocaleCompare(value,"R98.") != 0)
             (void) SetsRGBImageProfile(image);
-          value=GetImageProperty(image,"EXIF:InteroperabilityIndex");
+          value=GetImageProperty(image,"exif:InteroperabilityIndex");
           if (LocaleCompare(value,"R03.") != 0)
             (void) SetAdobeRGB1998ImageProfile(image);
           icc_profile=GetImageProfile(image,"icc");
@@ -781,14 +825,14 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
 #else
           (void) cmsErrorAction(LCMS_ERROR_SHOW);
 #endif
-          source_profile=cmsOpenProfileFromMem((unsigned char *)
-            GetStringInfoDatum(icc_profile),(DWORD)
-            GetStringInfoLength(icc_profile));
-          target_profile=cmsOpenProfileFromMem((unsigned char *)
-            GetStringInfoDatum(profile),(DWORD) GetStringInfoLength(profile));
+          source_profile=cmsOpenProfileFromMem(GetStringInfoDatum(icc_profile),
+            (DWORD) GetStringInfoLength(icc_profile));
+          target_profile=cmsOpenProfileFromMem(GetStringInfoDatum(profile),
+            (DWORD) GetStringInfoLength(profile));
           if ((source_profile == (cmsHPROFILE) NULL) ||
               (target_profile == (cmsHPROFILE) NULL))
-            ThrowBinaryException(ResourceLimitError,"UnableToManageColor",name);
+            ThrowBinaryException(ResourceLimitError,
+              "ColorspaceColorProfileMismatch",name);
           switch (cmsGetColorSpace(source_profile))
           {
             case icSigCmykData:
@@ -807,7 +851,7 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
             }
             case icSigLabData:
             {
-              source_colorspace=LABColorspace;
+              source_colorspace=LabColorspace;
               source_type=(DWORD) TYPE_Lab_16;
               source_channels=3;
               break;
@@ -859,7 +903,7 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
             }
             case icSigLabData:
             {
-              target_colorspace=LABColorspace;
+              target_colorspace=LabColorspace;
               target_type=(DWORD) TYPE_Lab_16;
               target_channels=3;
               break;
@@ -900,7 +944,7 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
               ((source_colorspace == CMYKColorspace) &&
                (image->colorspace != CMYKColorspace)) ||
               ((source_colorspace != GRAYColorspace) &&
-               (source_colorspace != LABColorspace) &&
+               (source_colorspace != LabColorspace) &&
                (source_colorspace != CMYKColorspace) &&
                (image->colorspace != RGBColorspace)))
             ThrowProfileException(ImageError,"ColorspaceColorProfileMismatch",
@@ -931,10 +975,11 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
           /*
             Transform image as dictated by the source and target image profiles.
           */
-          length=(size_t) image->columns*source_channels*sizeof(*source_pixels);
-          source_pixels=(unsigned short *) AcquireMagickMemory(length);
-          length=(size_t) image->columns*target_channels*sizeof(*target_pixels);
-          target_pixels=(unsigned short *) AcquireMagickMemory(length);
+          length=(size_t) image->columns;
+          source_pixels=(unsigned short *) AcquireQuantumMemory(length,
+            source_channels*sizeof(*source_pixels));
+          target_pixels=(unsigned short *) AcquireQuantumMemory(length,
+            target_channels*sizeof(*target_pixels));
           if ((source_pixels == (unsigned short *) NULL) ||
               (target_pixels == (unsigned short *) NULL))
             {
@@ -1017,11 +1062,12 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RemoveImageProfile() removes a profile from the image-map by its name.
+%  RemoveImageProfile() removes a named profile from the image and returns its
+%  value.
 %
 %  The format of the RemoveImageProfile method is:
 %
-%      MagickBooleanTyupe RemoveImageProfile(Image *image,const char *name)
+%      void *RemoveImageProfile(Image *image,const char *name)
 %
 %  A description of each parameter follows:
 %
@@ -1030,15 +1076,17 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
 %    o name: The profile name.
 %
 */
-MagickExport MagickBooleanType RemoveImageProfile(Image *image,
-  const char *name)
+MagickExport StringInfo *RemoveImageProfile(Image *image,const char *name)
 {
+  StringInfo
+    *profile;
+
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (image->profiles == (SplayTreeInfo *) NULL)
-    return(MagickFalse);
+    return((StringInfo *) NULL);
   if (LocaleCompare(name,"icc") == 0)
     {
       /*
@@ -1055,7 +1103,9 @@ MagickExport MagickBooleanType RemoveImageProfile(Image *image,
       image->iptc_profile.length=0;
       image->iptc_profile.info=(unsigned char *) NULL;
     }
-  return(RemoveNodeFromSplayTree((SplayTreeInfo *) image->profiles,name));
+  profile=(StringInfo *) RemoveNodeFromSplayTree((SplayTreeInfo *)
+    image->profiles,name);
+  return(profile);
 }
 
 /*
@@ -1132,7 +1182,8 @@ MagickExport MagickBooleanType SetImageProfile(Image *image,const char *name,
   const StringInfo *profile)
 {
   char
-    key[MaxTextExtent];
+    key[MaxTextExtent],
+    property[MaxTextExtent];
 
   MagickBooleanType
     status;
@@ -1157,11 +1208,10 @@ MagickExport MagickBooleanType SetImageProfile(Image *image,const char *name,
         Continue to support deprecated color profile member.
       */
       icc_profile=GetImageProfile(image,name);
-      if (icc_profile != (StringInfo *) NULL)
+      if (icc_profile != (const StringInfo *) NULL)
         {
           image->color_profile.length=GetStringInfoLength(icc_profile);
-          image->color_profile.info=(unsigned char *)
-            GetStringInfoDatum(icc_profile);
+          image->color_profile.info=GetStringInfoDatum(icc_profile);
         }
     }
   if ((status != MagickFalse) &&
@@ -1174,13 +1224,17 @@ MagickExport MagickBooleanType SetImageProfile(Image *image,const char *name,
         Continue to support deprecated IPTC profile member.
       */
       iptc_profile=GetImageProfile(image,name);
-      if (iptc_profile != (StringInfo *) NULL)
+      if (iptc_profile != (const StringInfo *) NULL)
         {
           image->iptc_profile.length=GetStringInfoLength(iptc_profile);
-          image->iptc_profile.info=(unsigned char *)
-            GetStringInfoDatum(iptc_profile);
+          image->iptc_profile.info=GetStringInfoDatum(iptc_profile);
         }
     }
+  /*
+    Inject profile into image properties.
+  */
+  (void) FormatMagickString(property,MaxTextExtent,"%s:sans",name);
+  (void) GetImageProperty(image,property);
   return(status);
 }
 
