@@ -3,11 +3,11 @@
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%           PPPP    RRRR     OOO   PPPP   EEEEE  RRRR   TTTTT  Y   Y          %
-%           P   P   R   R   O   O  P   P  E      R   R    T     Y Y           %
-%           PPPP    RRRR    O   O  PPPP   EEE    RRRR     T      Y            %
-%           P       R R     O   O  P      E      R R      T      Y            %
-%           P       R  R     OOO   P      EEEEE  R  R     T      Y            %
+%            PPPP    RRRR    OOO   PPPP   EEEEE  RRRR   TTTTT  Y   Y          %
+%            P   P   R   R  O   O  P   P  E      R   R    T     Y Y           %
+%            PPPP    RRRR   O   O  PPPP   EEE    RRRR     T      Y            %
+%            P       R R    O   O  P      E      R R      T      Y            %
+%            P       R  R    OOO   P      EEEEE  R  R     T      Y            %
 %                                                                             %
 %                                                                             %
 %                        ImageMagick Property Methods                         %
@@ -41,7 +41,6 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/property.h"
 #include "magick/cache.h"
 #include "magick/color.h"
 #include "magick/compare.h"
@@ -71,6 +70,7 @@
 #include "magick/string_.h"
 #include "magick/token.h"
 #include "magick/utility.h"
+#include "magick/xml-tree.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -100,10 +100,6 @@
 MagickExport MagickBooleanType CloneImageProperties(Image *image,
   const Image *clone_image)
 {
-  const char
-    *property,
-    *value;
-
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
@@ -113,8 +109,6 @@ MagickExport MagickBooleanType CloneImageProperties(Image *image,
   if (clone_image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       clone_image->filename);
-  assert(clone_image != (const Image *) NULL);
-  assert(clone_image->signature == MagickSignature);
   (void) CopyMagickString(image->filename,clone_image->filename,MaxTextExtent);
   (void) CopyMagickString(image->magick_filename,clone_image->magick_filename,
     MaxTextExtent);
@@ -140,9 +134,9 @@ MagickExport MagickBooleanType CloneImageProperties(Image *image,
   image->tile_offset=clone_image->tile_offset;
   image->extract_info=clone_image->extract_info;
   image->bias=clone_image->bias;
+  image->filter=clone_image->filter;
   image->blur=clone_image->blur;
   image->fuzz=clone_image->fuzz;
-  image->filter=clone_image->filter;
   image->interlace=clone_image->interlace;
   image->interpolate=clone_image->interpolate;
   image->endian=clone_image->endian;
@@ -161,16 +155,9 @@ MagickExport MagickBooleanType CloneImageProperties(Image *image,
   image->start_loop=clone_image->start_loop;
   image->error=clone_image->error;
   image->signature=clone_image->signature;
-  if (clone_image->properties == (void *) NULL)
-    return(MagickTrue);
-  ResetImagePropertyIterator(clone_image);
-  for (property=GetNextImageProperty(clone_image); property != (char *) NULL; )
-  {
-    value=GetImageProperty(clone_image,property);
-    if (value != (const char *) NULL)
-      (void) SetImageProperty(image,property,value);
-    property=GetNextImageProperty(clone_image);
-  }
+  if (clone_image->properties != (void *) NULL)
+    image->properties=CloneSplayTree((SplayTreeInfo *) clone_image->properties,
+      (void *(*)(void *)) ConstantString,(void *(*)(void *)) ConstantString);
   return(MagickTrue);
 }
 
@@ -211,7 +198,7 @@ MagickExport MagickBooleanType DefineImageProperty(Image *image,
 
   assert(image != (Image *) NULL);
   assert(property != (const char *) NULL);
-  (void) CopyMagickString(key,property,MaxTextExtent);
+  (void) CopyMagickString(key,property,MaxTextExtent-1);
   for (p=key; *p != '\0'; p++)
     if (*p == '=')
       break;
@@ -233,12 +220,11 @@ MagickExport MagickBooleanType DefineImageProperty(Image *image,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  DeleteImageProperty() deletes an key from the image map.
+%  DeleteImageProperty() deletes an image property.
 %
 %  The format of the DeleteImageProperty method is:
 %
-%      MagickBooleanType DeleteImageProperty(Image *image,
-%        const char *key)
+%      MagickBooleanType DeleteImageProperty(Image *image,const char *property)
 %
 %  A description of each parameter follows:
 %
@@ -257,7 +243,7 @@ MagickExport MagickBooleanType DeleteImageProperty(Image *image,
       image->filename);
   if (image->properties == (void *) NULL)
     return(MagickFalse);
-  return(RemoveNodeFromSplayTree((SplayTreeInfo *) image->properties,property));
+  return(DeleteNodeFromSplayTree((SplayTreeInfo *) image->properties,property));
 }
 
 /*
@@ -385,9 +371,9 @@ MagickExport MagickBooleanType FormatImageProperty(Image *image,
 */
 
 static char
-  *TracePSClippath(unsigned char *,size_t,const unsigned long,
+  *TracePSClippath(const unsigned char *,size_t,const unsigned long,
     const unsigned long),
-  *TraceSVGClippath(unsigned char *,size_t,const unsigned long,
+  *TraceSVGClippath(const unsigned char *,size_t,const unsigned long,
     const unsigned long);
 
 static MagickBooleanType GetIPTCProperty(const Image *image,const char *key)
@@ -429,7 +415,9 @@ static MagickBooleanType GetIPTCProperty(const Image *image,const char *key)
     if (((long) GetStringInfoDatum(profile)[i+1] == dataset) &&
         ((long) GetStringInfoDatum(profile)[i+2] == record))
       {
-        message=(char *) AcquireMagickMemory((length+1)*sizeof(message));
+        message=(char *) NULL;
+        if (~length >= 1)
+          message=(char *) AcquireQuantumMemory(length+1UL,sizeof(*message));
         if (message != (char *) NULL)
           {
             (void) CopyMagickString(message,(char *) GetStringInfoDatum(
@@ -460,7 +448,7 @@ static inline long MagickMax(const long x,const long y)
   return(y);
 }
 
-static inline int ReadPropertyByte(unsigned char **p,size_t *length)
+static inline int ReadPropertyByte(const unsigned char **p,size_t *length)
 {
   int
     c;
@@ -472,7 +460,7 @@ static inline int ReadPropertyByte(unsigned char **p,size_t *length)
   return(c);
 }
 
-static inline unsigned long ReadPropertyMSBLong(unsigned char **p,
+static inline unsigned long ReadPropertyMSBLong(const unsigned char **p,
   size_t *length)
 {
   int
@@ -502,7 +490,7 @@ static inline unsigned long ReadPropertyMSBLong(unsigned char **p,
   return(value & 0xffffffff);
 }
 
-static inline unsigned short ReadPropertyMSBShort(unsigned char **p,
+static inline unsigned short ReadPropertyMSBShort(const unsigned char **p,
   size_t *length)
 {
   int
@@ -541,6 +529,9 @@ static MagickBooleanType Get8BIMProperty(const Image *image,const char *key)
   const StringInfo
     *profile;
 
+  const unsigned char
+    *info;
+
   long
     id,
     start,
@@ -559,9 +550,6 @@ static MagickBooleanType Get8BIMProperty(const Image *image,const char *key)
   size_t
     length;
 
-  unsigned char
-    *info;
-
   /*
     There's no newlines in path names, so it's safe as terminator.
   */
@@ -604,7 +592,10 @@ static MagickBooleanType Get8BIMProperty(const Image *image,const char *key)
     count=(ssize_t) ReadPropertyByte(&info,&length);
     if ((count != 0) && ((size_t) count <= length))
       {
-        resource=(char *) AcquireMagickMemory((size_t) count+MaxTextExtent);
+        resource=(char *) NULL;
+        if (~(1UL*count) >= MaxTextExtent)
+          resource=(char *) AcquireQuantumMemory((size_t) count+MaxTextExtent,
+            sizeof(*resource));
         if (resource != (char *) NULL)
           {
             for (i=0; i < (long) count; i++)
@@ -638,7 +629,10 @@ static MagickBooleanType Get8BIMProperty(const Image *image,const char *key)
     /*
       We have the resource of interest.
     */
-    attribute=(char *) AcquireMagickMemory((size_t) count+MaxTextExtent);
+    attribute=(char *) NULL;
+    if (~(1UL*count) >= MaxTextExtent)
+      attribute=(char *) AcquireQuantumMemory((size_t) count+MaxTextExtent,
+        sizeof(*attribute));
     if (attribute != (char *) NULL)
       {
         (void) CopyMagickMemory(attribute,(char *) info,(size_t) count);
@@ -672,7 +666,7 @@ static MagickBooleanType Get8BIMProperty(const Image *image,const char *key)
 }
 
 static inline unsigned short ReadPropertyShort(const EndianType endian,
-  unsigned char *buffer)
+  const unsigned char *buffer)
 {
   unsigned short
     value;
@@ -688,7 +682,7 @@ static inline unsigned short ReadPropertyShort(const EndianType endian,
 }
 
 static inline unsigned long ReadPropertyLong(const EndianType endian,
-  unsigned char *buffer)
+  const unsigned char *buffer)
 {
   unsigned long
     value;
@@ -727,7 +721,7 @@ static MagickBooleanType GetEXIFProperty(const Image *image,
 
   typedef struct _DirectoryInfo
   {
-    unsigned char
+    const unsigned char
       *directory;
 
     unsigned long
@@ -992,6 +986,10 @@ static MagickBooleanType GetEXIFProperty(const Image *image,
   const StringInfo
     *profile;
 
+  const unsigned char
+    *directory,
+    *exif;
+
   DirectoryInfo
     directory_stack[MaxDirectoryStack];
 
@@ -1016,10 +1014,6 @@ static MagickBooleanType GetEXIFProperty(const Image *image,
   static int
     tag_bytes[] = {0, 1, 1, 2, 4, 8, 1, 1, 2, 4, 8, 4, 8};
 
-  unsigned char
-    *directory,
-    *exif;
-
   unsigned long
     entry,
     number_entries,
@@ -1285,8 +1279,10 @@ static MagickBooleanType GetEXIFProperty(const Image *image,
             case EXIF_FMT_BYTE:
             case EXIF_FMT_STRING:
             {
-              value=(char *) AcquireMagickMemory((size_t) (number_bytes+1)*
-                sizeof(*value));
+              value=(char *) NULL;
+              if (~(1UL*number_bytes) >= 1)
+                value=(char *) AcquireQuantumMemory((size_t) number_bytes+1UL,
+                  sizeof(*value));
               if (value != (char *) NULL)
                 {
                   register long
@@ -1308,6 +1304,9 @@ static MagickBooleanType GetEXIFProperty(const Image *image,
               char
                 key[MaxTextExtent];
 
+              register const char
+                *p;
+
               (void) CopyMagickString(key,property,MaxTextExtent);
               switch (all)
               {
@@ -1341,7 +1340,10 @@ static MagickBooleanType GetEXIFProperty(const Image *image,
                   break;
                 }
               }
-              (void) SetImageProperty((Image *) image,key,value);
+              p=(const char *) GetValueFromSplayTree((SplayTreeInfo *)
+                image->properties,key);
+              if (p == (const char *) NULL)
+                (void) SetImageProperty((Image *) image,key,value);
               value=DestroyString(value);
             }
         }
@@ -1379,7 +1381,62 @@ static MagickBooleanType GetEXIFProperty(const Image *image,
   return(MagickTrue);
 }
 
-static char *TracePSClippath(unsigned char *blob,size_t length,
+static MagickBooleanType GetXMPProperty(const Image *image,
+  const char *property)
+{
+  const StringInfo
+    *profile;
+
+  ExceptionInfo
+    *exception;
+
+  MagickBooleanType
+    status;
+
+  register long
+    i;
+
+  register unsigned char
+    *p;
+
+  XMLTreeInfo
+    *child,
+    *xmp;
+
+  profile=GetImageProfile(image,"xmp");
+  if (profile == (StringInfo *) NULL)
+    return(MagickFalse);
+  if ((property == (const char *) NULL) || (*property == '\0'))
+    return(MagickFalse);
+  p=GetStringInfoDatum(profile);
+  for (i=0; (i < (long) GetStringInfoLength(profile)) && (*p != '\0'); i++)
+    p++;
+  if (i == (long) GetStringInfoLength(profile))
+    return(MagickFalse);
+  exception=AcquireExceptionInfo();
+  xmp=NewXMLTree((char *) ++p,exception);
+  exception=DestroyExceptionInfo(exception);
+  if (xmp == (XMLTreeInfo *) NULL)
+    return(MagickFalse);
+  status=MagickFalse;
+  child=GetXMLTreeChild(xmp,"rdf:RDF");
+  if (child != (XMLTreeInfo *) NULL)
+    {
+      child=GetXMLTreeChild(child,"rdf:Description");
+      if (child != (XMLTreeInfo *) NULL)
+        {
+          if (image->properties == (void *) NULL)
+            ((Image *) image)->properties=NewSplayTree(CompareSplayTreeString,
+              RelinquishMagickMemory,RelinquishMagickMemory);
+          status=GetXMLTreeAttributes(child,(SplayTreeInfo *)
+            image->properties);
+        }
+    }
+  xmp=DestroyXMLTree(xmp);
+  return(status);
+}
+
+static char *TracePSClippath(const unsigned char *blob,size_t length,
   const unsigned long magick_unused(columns),
   const unsigned long magick_unused(rows))
 {
@@ -1575,7 +1632,7 @@ static char *TracePSClippath(unsigned char *blob,size_t length,
   return(path);
 }
 
-static char *TraceSVGClippath(unsigned char *blob,size_t length,
+static char *TraceSVGClippath(const unsigned char *blob,size_t length,
   const unsigned long columns,const unsigned long rows)
 {
   char
@@ -1854,25 +1911,22 @@ MagickExport const char *GetImageProperty(const Image *image,
 
           GetMagickPixelPacket(image,&pixel);
           fx_info=AcquireFxInfo(image,property+6);
-          status=FxEvaluateChannelExpression(fx_info,RedChannel,&alpha,
+          status=FxEvaluateChannelExpression(fx_info,RedChannel,0,0,&alpha,
             exception);
           pixel.red=(MagickRealType) QuantumRange*alpha;
-          status|=FxEvaluateChannelExpression(fx_info,GreenChannel,&alpha,
+          status|=FxEvaluateChannelExpression(fx_info,GreenChannel,0,0,&alpha,
             exception);
           pixel.green=(MagickRealType) QuantumRange*alpha;
-          status|=FxEvaluateChannelExpression(fx_info,BlueChannel,&alpha,
+          status|=FxEvaluateChannelExpression(fx_info,BlueChannel,0,0,&alpha,
             exception);
           pixel.blue=(MagickRealType) QuantumRange*alpha;
-          if (image->matte != MagickFalse)
-            {
-              status|=FxEvaluateChannelExpression(fx_info,OpacityChannel,&alpha,
-                exception);
-              pixel.opacity=(MagickRealType) QuantumRange*(1.0-alpha);
-            }
+          status|=FxEvaluateChannelExpression(fx_info,OpacityChannel,0,0,&alpha,
+            exception);
+          pixel.opacity=(MagickRealType) QuantumRange*(1.0-alpha);
           if (image->colorspace == CMYKColorspace)
             {
-              status|=FxEvaluateChannelExpression(fx_info,BlackChannel,&alpha,
-                exception);
+              status|=FxEvaluateChannelExpression(fx_info,BlackChannel,0,0,
+                &alpha,exception);
               pixel.index=(MagickRealType) QuantumRange*alpha;
             }
           fx_info=DestroyFxInfo(fx_info);
@@ -1889,6 +1943,20 @@ MagickExport const char *GetImageProperty(const Image *image,
         }
       break;
     }
+    case 'X':
+    case 'x':
+    {
+      if (LocaleNCompare("xmp:",property,4) == 0)
+        {
+          if (GetXMPProperty(image,property) != MagickFalse)
+            {
+              p=(const char *) GetValueFromSplayTree((SplayTreeInfo *)
+                image->properties,property);
+              return(p);
+            }
+        }
+      break;
+    }
   }
   return(p);
 }
@@ -2206,8 +2274,8 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
     if ((size_t) (q-interpret_text+MaxTextExtent) >= extent)
       {
         extent+=MaxTextExtent;
-        interpret_text=(char *) ResizeMagickMemory(interpret_text,(extent+
-          MaxTextExtent+1)*sizeof(*interpret_text));
+        interpret_text=(char *) ResizeQuantumMemory(interpret_text,extent+
+          MaxTextExtent+1,sizeof(*interpret_text));
         if (interpret_text == (char *) NULL)
           break;
         q=interpret_text+strlen(interpret_text);
@@ -2257,8 +2325,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
           length);
         if (length != (MagickSizeType) ((size_t) length))
           (void) FormatMagickSize(length,format);
-        (void) ConcatenateMagickString(q,format,extent);
-        q+=strlen(format);
+        q+=ConcatenateMagickString(q,format,extent);
         break;
       }
       case 'c':
@@ -2266,15 +2333,15 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
         /*
           Image comment.
         */
-        value=GetImageProperty(image,"Comment");
+        value=GetImageProperty(image,"comment");
         if (value == (const char *) NULL)
           break;
         length=strlen(value);
         if ((size_t) (q-interpret_text+length+1) >= extent)
           {
             extent+=length;
-            interpret_text=(char *) ResizeMagickMemory(interpret_text,
-              (extent+MaxTextExtent)*sizeof(*interpret_text));
+            interpret_text=(char *) ResizeQuantumMemory(interpret_text,
+              extent+MaxTextExtent,sizeof(*interpret_text));
             if (interpret_text == (char *) NULL)
               break;
             q=interpret_text+strlen(interpret_text);
@@ -2301,8 +2368,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
               Directory.
             */
             GetPathComponent(image->magick_filename,HeadPath,filename);
-            (void) CopyMagickString(q,filename,extent);
-            q+=strlen(filename);
+            q+=CopyMagickString(q,filename,extent);
             break;
           }
           case 'e':
@@ -2311,8 +2377,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
               Filename extension.
             */
             GetPathComponent(image->magick_filename,ExtensionPath,filename);
-            (void) CopyMagickString(q,filename,extent);
-            q+=strlen(filename);
+            q+=CopyMagickString(q,filename,extent);
             break;
           }
           case 'f':
@@ -2321,8 +2386,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
               Filename.
             */
             GetPathComponent(image->magick_filename,TailPath,filename);
-            (void) CopyMagickString(q,filename,extent);
-            q+=strlen(filename);
+            q+=CopyMagickString(q,filename,extent);
             break;
           }
           case 't':
@@ -2331,8 +2395,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
               Base filename.
             */
             GetPathComponent(image->magick_filename,BasePath,filename);
-            (void) CopyMagickString(q,filename,extent);
-            q+=strlen(filename);
+            q+=CopyMagickString(q,filename,extent);
             break;
           }
         }
@@ -2361,8 +2424,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
         /*
           Image filename.
         */
-        (void) CopyMagickString(q,image->filename,extent);
-        q+=strlen(image->filename);
+        q+=CopyMagickString(q,image->filename,extent);
         break;
       }
       case 'k':
@@ -2379,21 +2441,20 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
         /*
           Image label.
         */
-        value=GetImageProperty(image,"Label");
+        value=GetImageProperty(image,"label");
         if (value == (const char *) NULL)
           break;
         length=strlen(value);
         if ((size_t) (q-interpret_text+length+1) >= extent)
           {
             extent+=length;
-            interpret_text=(char *) ResizeMagickMemory(interpret_text,
-              (extent+MaxTextExtent)*sizeof(*interpret_text));
+            interpret_text=(char *) ResizeQuantumMemory(interpret_text,
+              extent+MaxTextExtent,sizeof(*interpret_text));
             if (interpret_text == (char *) NULL)
               break;
             q=interpret_text+strlen(interpret_text);
           }
-        (void) CopyMagickString(q,value,extent);
-        q+=length;
+        q+=CopyMagickString(q,value,extent);
         break;
       }
       case 'm':
@@ -2401,8 +2462,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
         /*
           Image format.
         */
-        (void) CopyMagickString(q,image->magick,extent);
-        q+=strlen(image->magick);
+        q+=CopyMagickString(q,image->magick,extent);
         break;
       }
       case 'M':
@@ -2410,8 +2470,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
         /*
           Image magick filename.
         */
-        (void) CopyMagickString(q,image->magick_filename,extent);
-        q+=strlen(image->magick_filename);
+        q+=CopyMagickString(q,image->magick_filename,extent);
         break;
       }
       case 'n':
@@ -2428,8 +2487,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
         /*
           Image output filename.
         */
-        (void) CopyMagickString(q,text_info->filename,extent);
-        q+=strlen(text_info->filename);
+        q+=CopyMagickString(q,text_info->filename,extent);
         break;
       }
       case 'p':
@@ -2491,8 +2549,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
           Unique filename.
         */
         (void) CopyMagickString(filename,text_info->unique,extent);
-        (void) CopyMagickString(q,filename,extent);
-        q+=strlen(filename);
+        q+=CopyMagickString(q,filename,extent);
         break;
       }
       case 'w':
@@ -2537,7 +2594,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
           Image compression method.
         */
         q+=FormatMagickString(q,extent,"%s",MagickOptionToMnemonic(
-          MagickCompressionOptions,(long) image->compression));
+          MagickCompressOptions,(long) image->compression));
         break;
       }
       case 'D':
@@ -2607,8 +2664,8 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
             if ((size_t) (q-interpret_text+length+1) >= extent)
               {
                 extent+=length;
-                interpret_text=(char *) ResizeMagickMemory(interpret_text,
-                  (extent+MaxTextExtent)*sizeof(*interpret_text));
+                interpret_text=(char *) ResizeQuantumMemory(interpret_text,
+                  extent+MaxTextExtent,sizeof(*interpret_text));
                 if (interpret_text == (char *) NULL)
                   break;
                 q=interpret_text+strlen(interpret_text);
@@ -2636,8 +2693,8 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
                         if ((size_t) (q-interpret_text+length+1) >= extent)
                           {
                             extent+=length;
-                            interpret_text=(char *) ResizeMagickMemory(
-                              interpret_text,(extent+MaxTextExtent)*
+                            interpret_text=(char *) ResizeQuantumMemory(
+                              interpret_text,extent+MaxTextExtent,
                               sizeof(*interpret_text));
                             if (interpret_text == (char *) NULL)
                               break;
@@ -2656,8 +2713,8 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
             if ((size_t) (q-interpret_text+length+1) >= extent)
               {
                 extent+=length;
-                interpret_text=(char *) ResizeMagickMemory(interpret_text,
-                  (extent+MaxTextExtent)*sizeof(*interpret_text));
+                interpret_text=(char *) ResizeQuantumMemory(interpret_text,
+                  extent+MaxTextExtent,sizeof(*interpret_text));
                 if (interpret_text == (char *) NULL)
                   break;
                 q=interpret_text+strlen(interpret_text);
@@ -2674,8 +2731,8 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
             if ((size_t) (q-interpret_text+length+1) >= extent)
               {
                 extent+=length;
-                interpret_text=(char *) ResizeMagickMemory(interpret_text,
-                  (extent+MaxTextExtent)*sizeof(*interpret_text));
+                interpret_text=(char *) ResizeQuantumMemory(interpret_text,
+                  extent+MaxTextExtent,sizeof(*interpret_text));
                 if (interpret_text == (char *) NULL)
                   break;
                 q=interpret_text+strlen(interpret_text);
@@ -2704,11 +2761,10 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
           Image signature.
         */
         (void) SignatureImage(image);
-        value=GetImageProperty(image,"Signature");
+        value=GetImageProperty(image,"signature");
         if (value == (const char *) NULL)
           break;
-        (void) CopyMagickString(q,value,extent);
-        q+=strlen(value);
+        q+=CopyMagickString(q,value,extent);
         break;
       }
       case '%':
@@ -2744,12 +2800,12 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RemoveImageProperty() removes an property from the image map.
+%  RemoveImageProperty() removes a property from the image and returns its
+%  value.
 %
 %  The format of the RemoveImageProperty method is:
 %
-%      MagickBooleanType RemoveImageProperty(Image *image,
-%        const char *property)
+%      char *RemoveImageProperty(Image *image,const char *property)
 %
 %  A description of each parameter follows:
 %
@@ -2758,17 +2814,22 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
 %    o property: The image property.
 %
 */
-MagickExport MagickBooleanType RemoveImageProperty(Image *image,
+MagickExport char *RemoveImageProperty(Image *image,
   const char *property)
 {
+  char
+    *value;
+
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       image->filename);
   if (image->properties == (void *) NULL)
-    return(MagickFalse);
-  return(RemoveNodeFromSplayTree((SplayTreeInfo *) image->properties,property));
+    return((char *) NULL);
+  value=(char *) RemoveNodeFromSplayTree((SplayTreeInfo *) image->properties,
+    property);
+  return(value);
 }
 
 /*
@@ -2782,7 +2843,7 @@ MagickExport MagickBooleanType RemoveImageProperty(Image *image,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  ResetImagePropertyIterator() resets the image values iterator.  Use it
+%  ResetImagePropertyIterator() resets the image properties iterator.  Use it
 %  in conjunction with GetNextImageProperty() to iterate over all the values
 %  associated with an image property.
 %
@@ -2924,21 +2985,6 @@ MagickExport MagickBooleanType SetImageProperty(Image *image,
         }
       break;
     }
-    case 'O':
-    case 'o':
-    {
-      if (LocaleCompare(property,"tile-offset") == 0)
-        {
-          char
-            *geometry;
-
-          geometry=GetPageGeometry(value);
-          flags=ParseAbsoluteGeometry(geometry,&image->tile_offset);
-          geometry=DestroyString(geometry);
-          break;
-        }
-      break;
-    }
     case 'P':
     case 'p':
     {
@@ -2954,6 +3000,21 @@ MagickExport MagickBooleanType SetImageProperty(Image *image,
         }
       break;
     }
+    case 'T':
+    case 't':
+    {
+      if (LocaleCompare(property,"tile-offset") == 0)
+        {
+          char
+            *geometry;
+
+          geometry=GetPageGeometry(value);
+          flags=ParseAbsoluteGeometry(geometry,&image->tile_offset);
+          geometry=DestroyString(geometry);
+          break;
+        }
+      break;
+    }
     default:
       break;
   }
