@@ -17,7 +17,7 @@
 %                              July 1992                                      %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -197,7 +197,7 @@
   Define declarations.
 */
 #define CacheShift  2
-#define ExceptionQueueLength  16
+#define ErrorQueueLength  16
 #define MaxNodes  266817
 #define MaxTreeDepth  8
 #define NodesInAList  1920
@@ -273,10 +273,10 @@ typedef struct _CubeInfo
     *cache;
 
   MagickPixelPacket
-    error[ExceptionQueueLength];
+    error[ErrorQueueLength];
 
   MagickRealType
-    weights[ExceptionQueueLength];
+    weights[ErrorQueueLength];
 
   QuantizeInfo
     *quantize_info;
@@ -346,15 +346,7 @@ MagickExport QuantizeInfo *AcquireQuantizeInfo(const ImageInfo *image_info)
 
   quantize_info=(QuantizeInfo *) AcquireMagickMemory(sizeof(*quantize_info));
   if (quantize_info == (QuantizeInfo *) NULL)
-    {
-      char
-        *message;
-
-      message=GetExceptionMessage(errno);
-      ThrowMagickFatalException(ResourceLimitFatalError,
-        "MemoryAllocationFailed",message);
-      message=(char *) RelinquishMagickMemory(message);
-    }
+    ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
   GetQuantizeInfo(quantize_info);
   if (image_info != (ImageInfo *) NULL)
     {
@@ -435,7 +427,7 @@ static inline RealPixelPacket AssociateAlphaPixel(const Image *image,
       alpha_pixel.opacity=(MagickRealType) pixel->opacity;
       return(alpha_pixel);
     }
-  alpha=QuantumScale*(QuantumRange-(MagickRealType) pixel->opacity);
+  alpha=(MagickRealType) (QuantumScale*(QuantumRange-pixel->opacity));
   alpha_pixel.red=alpha*pixel->red;
   alpha_pixel.green=alpha*pixel->green;
   alpha_pixel.blue=alpha*pixel->blue;
@@ -498,7 +490,8 @@ static MagickBooleanType AssignImageColors(Image *image,CubeInfo *cube_info)
       cube_info->quantize_info->colorspace);
   else
     if ((image->colorspace != GRAYColorspace) &&
-        (image->colorspace != RGBColorspace))
+        (image->colorspace != RGBColorspace) &&
+        (image->colorspace != CMYColorspace))
       (void) SetImageColorspace((Image *) image,RGBColorspace);
   if (AllocateImageColormap(image,cube_info->colors) == MagickFalse)
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
@@ -520,7 +513,7 @@ static MagickBooleanType AssignImageColors(Image *image,CubeInfo *cube_info)
       image_view=OpenCacheView(image);
       for (y=0; y < (long) image->rows; y++)
       {
-        q=GetCacheView(image_view,0,y,image->columns,1);
+        q=GetCacheViewPixels(image_view,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
         indexes=GetCacheViewIndexes(image_view);
@@ -545,7 +538,7 @@ static MagickBooleanType AssignImageColors(Image *image,CubeInfo *cube_info)
           cube_info->distance=4.0*((MagickRealType) QuantumRange+1.0)*
             ((MagickRealType) QuantumRange+1.0);
           ClosestColor(image,cube_info,node_info->parent);
-          index=(IndexPacket) cube_info->color_number;
+          index=cube_info->color_number;
           if (image->storage_class == PseudoClass)
             indexes[x]=(IndexPacket) index;
           if (cube_info->quantize_info->measure_error == MagickFalse)
@@ -585,17 +578,21 @@ static MagickBooleanType AssignImageColors(Image *image,CubeInfo *cube_info)
       q=image->colormap;
       for (i=0; i < (long) image->colors; i++)
       {
-        intensity=(Quantum) (PixelIntensity(q) < (QuantumRange/2.0) ? 0 : 
-          QuantumRange);
+        intensity=(Quantum) (PixelIntensity(q) < ((MagickRealType)
+          QuantumRange/2.0) ? 0 : QuantumRange);
         q->red=intensity;
         q->green=intensity;
         q->blue=intensity;
         q++;
       }
     }
-  if ((IsAssociatedAlpha(image,cube_info) != MagickFalse) &&
+  if (0 && (IsAssociatedAlpha(image,cube_info) != MagickFalse) &&
       (cube_info->transparent_index >= 0))
     {
+      /*
+        Introduces black bar:
+          convert -size 100x100 gradient:blue-none -colors 256 image.png
+      */
       image->colormap[cube_info->transparent_index].red=
         image->transparent_color.red;
       image->colormap[cube_info->transparent_index].green=
@@ -716,13 +713,14 @@ static MagickBooleanType ClassifyImageColors(CubeInfo *cube_info,
       cube_info->quantize_info->colorspace);
   else
     if ((image->colorspace != GRAYColorspace) &&
+        (image->colorspace != CMYColorspace) &&
         (image->colorspace != RGBColorspace))
       (void) SetImageColorspace((Image *) image,RGBColorspace);
   error.opacity=0.0;
   image_view=OpenCacheView(image);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireCacheView(image_view,0,y,image->columns,1,exception);
+    p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
     if (p == (const PixelPacket *) NULL)
       break;
     if (cube_info->nodes > MaxNodes)
@@ -792,11 +790,7 @@ static MagickBooleanType ClassifyImageColors(CubeInfo *cube_info,
       if (IsAssociatedAlpha(image,cube_info) != MagickFalse)
         node_info->total_color.opacity+=QuantumScale*pixel.opacity;
       p++;
-      if (cube_info->colors >= cube_info->maximum_colors)
-        break;
     }
-    if (cube_info->colors >= cube_info->maximum_colors)
-      break;
     if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
         (QuantumTick(y,image->rows) != MagickFalse))
       {
@@ -805,22 +799,15 @@ static MagickBooleanType ClassifyImageColors(CubeInfo *cube_info,
         if (status == MagickFalse)
           break;
       }
+    if (cube_info->colors > cube_info->maximum_colors)
+      {
+        PruneToCubeDepth(image,cube_info,cube_info->root);
+        break;
+      }
   }
-  if (cube_info->colors < cube_info->maximum_colors)
-    {
-      image_view=CloseCacheView(image_view);
-      if ((cube_info->quantize_info->colorspace != UndefinedColorspace) &&
-          (cube_info->quantize_info->colorspace != CMYKColorspace))
-        (void) SetImageColorspace((Image *) image,RGBColorspace);
-      return(MagickTrue);
-    }
-  /*
-    More than maximim colors;  classify to the cube_info->depth tree depth.
-  */
-  PruneToCubeDepth(image,cube_info,cube_info->root);
-  for ( ; y < (long) image->rows; y++)
+  for (y++; y < (long) image->rows; y++)
   {
-    p=AcquireCacheView(image_view,0,y,image->columns,1,exception);
+    p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
     if (p == (const PixelPacket *) NULL)
       break;
     if (cube_info->nodes > MaxNodes)
@@ -939,15 +926,7 @@ MagickExport QuantizeInfo *CloneQuantizeInfo(const QuantizeInfo *quantize_info)
 
   clone_info=(QuantizeInfo *) AcquireMagickMemory(sizeof(*clone_info));
   if (clone_info == (QuantizeInfo *) NULL)
-    {
-      char
-        *message;
-
-      message=GetExceptionMessage(errno);
-      ThrowMagickFatalException(ResourceLimitFatalError,
-        "MemoryAllocationFailed",message);
-      message=(char *) RelinquishMagickMemory(message);
-    }
+    ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
   GetQuantizeInfo(clone_info);
   if (quantize_info == (QuantizeInfo *) NULL)
     return(clone_info);
@@ -991,17 +970,18 @@ MagickExport QuantizeInfo *CloneQuantizeInfo(const QuantizeInfo *quantize_info)
 static void ClosestColor(const Image *image,CubeInfo *cube_info,
   const NodeInfo *node_info)
 {
-  long
-    number_children;
-
   register long
     i;
 
+  unsigned long
+    number_children;
+
   /*
     Traverse any children.
   */
-  number_children=IsAssociatedAlpha(image,cube_info) == MagickFalse ? 8L : 16L;
-  for (i=0; i < number_children; i++)
+  number_children=IsAssociatedAlpha(image,cube_info) == MagickFalse ?
+    8UL : 16UL;
+  for (i=0; i < (long) number_children; i++)
     if (node_info->child[i] != (NodeInfo *) NULL)
       ClosestColor(image,cube_info,node_info->child[i]);
   if (node_info->number_unique != 0)
@@ -1125,17 +1105,18 @@ MagickExport void CompressImageColormap(Image *image)
 static unsigned long DefineImageColormap(Image *image,CubeInfo *cube_info,
   NodeInfo *node_info)
 {
-  long
-    number_children;
-
   register long
     i;
 
+  unsigned long
+    number_children;
+
   /*
     Traverse any children.
   */
-  number_children=IsAssociatedAlpha(image,cube_info) == MagickFalse ? 8L : 16L;
-  for (i=0; i < number_children; i++)
+  number_children=IsAssociatedAlpha(image,cube_info) == MagickFalse ?
+    8UL : 16UL;
+  for (i=0; i < (long) number_children; i++)
     if (node_info->child[i] != (NodeInfo *) NULL)
       DefineImageColormap(image,cube_info,node_info->child[i]);
   if (node_info->number_unique != 0)
@@ -1154,11 +1135,12 @@ static unsigned long DefineImageColormap(Image *image,CubeInfo *cube_info,
       alpha=1.0/(fabs(alpha) <= MagickEpsilon ? 1.0 : alpha);
       if (IsAssociatedAlpha(image,cube_info) == MagickFalse)
         {
-          q->red=RoundToQuantum(alpha*QuantumRange*node_info->total_color.red);
-          q->green=RoundToQuantum(alpha*QuantumRange*
-            node_info->total_color.green);
-          q->blue=RoundToQuantum(alpha*QuantumRange*
-            node_info->total_color.blue);
+          q->red=RoundToQuantum((MagickRealType) (alpha*QuantumRange*
+            node_info->total_color.red));
+          q->green=RoundToQuantum((MagickRealType) (alpha*QuantumRange*
+            node_info->total_color.green));
+          q->blue=RoundToQuantum((MagickRealType) (alpha*QuantumRange*
+            node_info->total_color.blue));
           q->opacity=OpaqueOpacity;
         }
       else
@@ -1166,30 +1148,32 @@ static unsigned long DefineImageColormap(Image *image,CubeInfo *cube_info,
           MagickRealType
             opacity;
 
-          opacity=alpha*QuantumRange*node_info->total_color.opacity;
+          opacity=(MagickRealType) (alpha*QuantumRange*
+            node_info->total_color.opacity);
           q->opacity=RoundToQuantum(opacity);
           if (q->opacity == OpaqueOpacity)
             {
-              q->red=RoundToQuantum(alpha*QuantumRange*
-                node_info->total_color.red);
-              q->green=RoundToQuantum(alpha*QuantumRange*
-                node_info->total_color.green);
-              q->blue=RoundToQuantum(alpha*QuantumRange*
-                node_info->total_color.blue);
+              q->red=RoundToQuantum((MagickRealType) (alpha*QuantumRange*
+                node_info->total_color.red));
+              q->green=RoundToQuantum((MagickRealType) (alpha*QuantumRange*
+                node_info->total_color.green));
+              q->blue=RoundToQuantum((MagickRealType) (alpha*QuantumRange*
+                node_info->total_color.blue));
             }
           else
             {
               MagickRealType
                 gamma;
 
-              gamma=QuantumScale*(QuantumRange-(MagickRealType) q->opacity);
+              gamma=(MagickRealType) (QuantumScale*(QuantumRange-
+                (MagickRealType) q->opacity));
               gamma=1.0/(fabs(gamma) <= MagickEpsilon ? 1.0 : gamma);
-              q->red=RoundToQuantum(alpha*gamma*QuantumRange*
-                node_info->total_color.red);
-              q->green=RoundToQuantum(alpha*gamma*QuantumRange*
-                node_info->total_color.green);
-              q->blue=RoundToQuantum(alpha*gamma*QuantumRange*
-                node_info->total_color.blue);
+              q->red=RoundToQuantum((MagickRealType) (alpha*gamma*QuantumRange*
+                node_info->total_color.red));
+              q->green=RoundToQuantum((MagickRealType) (alpha*gamma*
+                QuantumRange*node_info->total_color.green));
+              q->blue=RoundToQuantum((MagickRealType) (alpha*gamma*QuantumRange*
+                node_info->total_color.blue));
               if (node_info->number_unique > cube_info->transparent_pixels)
                 {
                   cube_info->transparent_pixels=node_info->number_unique;
@@ -1293,7 +1277,8 @@ MagickExport QuantizeInfo *DestroyQuantizeInfo(QuantizeInfo *quantize_info)
 %
 %  Dither() distributes the difference between an original image and the
 %  corresponding color reduced algorithm to neighboring pixels along a Hilbert
-%  curve.
+%  curve with restricted error proliferation as described here:
+%  http://www.compuphase.com/riemer.htm.
 %
 %  The format of the Dither method is:
 %
@@ -1343,12 +1328,12 @@ static MagickBooleanType Dither(const Image *image,ViewInfo *image_view,
       /*
         Distribute error.
       */
-      q=GetCacheView(image_view,p->x,p->y,1,1);
+      q=GetCacheViewPixels(image_view,p->x,p->y,1,1);
       if (q == (PixelPacket *) NULL)
         return(MagickFalse);
       indexes=GetCacheViewIndexes(image_view);
       pixel=AssociateAlphaPixel(image,cube_info,q);
-      for (i=0; i < ExceptionQueueLength; i++)
+      for (i=0; i < ErrorQueueLength; i++)
       {
         pixel.red+=p->weights[i]*p->error[i].red;
         pixel.green+=p->weights[i]*p->error[i].green;
@@ -1398,7 +1383,7 @@ static MagickBooleanType Dither(const Image *image,ViewInfo *image_view,
       /*
         Assign pixel to closest colormap entry.
       */
-      index=(IndexPacket) p->cache[i];
+      index=1UL*p->cache[i];
       if (image->storage_class == PseudoClass)
         *indexes=(IndexPacket) index;
       if (cube_info->quantize_info->measure_error == MagickFalse)
@@ -1414,14 +1399,14 @@ static MagickBooleanType Dither(const Image *image,ViewInfo *image_view,
       /*
         Propagate the error as the last entry of the error queue.
       */
-      for (i=0; i < (ExceptionQueueLength-1); i++)
-        p->error[i]=p->error[i+1];
+      (void) CopyMagickMemory(p->error,p->error+1,(ErrorQueueLength-1)*
+        sizeof(p->error[0]));
       color=AssociateAlphaPixel(image,cube_info,image->colormap+index);
-      p->error[i].red=pixel.red-color.red;
-      p->error[i].green=pixel.green-color.green;
-      p->error[i].blue=pixel.blue-color.blue;
+      p->error[ErrorQueueLength-1].red=pixel.red-color.red;
+      p->error[ErrorQueueLength-1].green=pixel.green-color.green;
+      p->error[ErrorQueueLength-1].blue=pixel.blue-color.blue;
       if (IsAssociatedAlpha(image,cube_info) != MagickFalse)
-        p->error[i].opacity=pixel.opacity-color.opacity;
+        p->error[ErrorQueueLength-1].opacity=pixel.opacity-color.opacity;
       if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
           (QuantumTick(p->offset,p->span) != MagickFalse))
         {
@@ -1475,6 +1460,23 @@ static MagickBooleanType Dither(const Image *image,ViewInfo *image_view,
 %    o cube_info: A pointer to the Cube structure.
 %
 */
+
+static inline unsigned long MagickMax(const unsigned long x,
+  const unsigned long y)
+{
+  if (x > y)
+    return(x);
+  return(y);
+}
+
+static inline unsigned long MagickMin(const unsigned long x,
+  const unsigned long y)
+{
+  if (x < y)
+    return(x);
+  return(y);
+}
+
 static MagickBooleanType DitherImage(Image *image,CubeInfo *cube_info)
 {
   register unsigned long
@@ -1489,17 +1491,20 @@ static MagickBooleanType DitherImage(Image *image,CubeInfo *cube_info)
   /*
     Distribute quantization error along a Hilbert curve.
   */
-  (void) ResetMagickMemory(cube_info->error,0,ExceptionQueueLength*
+  (void) ResetMagickMemory(cube_info->error,0,ErrorQueueLength*
     sizeof(*cube_info->error));
   cube_info->x=0;
   cube_info->y=0;
-  i=image->columns > image->rows ? image->columns : image->rows;
+  i=MagickMax(image->columns,image->rows);
   for (depth=1; i != 0; depth++)
     i>>=1;
+  if ((1UL << depth) < MagickMax(image->columns,image->rows))
+    depth++;
   cube_info->offset=0;
   cube_info->span=(MagickSizeType) image->columns*image->rows;
   image_view=OpenCacheView(image);
-  HilbertCurve(image,image_view,cube_info,depth-1,NorthGravity);
+  if (depth > 1)
+    HilbertCurve(image,image_view,cube_info,depth-1,NorthGravity);
   (void) Dither(image,image_view,cube_info,ForgetGravity);
   image_view=CloseCacheView(image_view);
   return(MagickTrue);
@@ -1520,14 +1525,11 @@ static MagickBooleanType DitherImage(Image *image,CubeInfo *cube_info)
 %
 %  The format of the GetCubeInfo method is:
 %
-%      CubeInfo GetCubeInfo(const Image *image,
-%        const QuantizeInfo *quantize_info,const unsigned long depth,
-%        const unsigned long maximum_colors)
+%      CubeInfo GetCubeInfo(const QuantizeInfo *quantize_info,
+%        const unsigned long depth,const unsigned long maximum_colors)
 %
 %  A description of each parameter follows.
 %
-%    o image: The image.
-%
 %    o quantize_info: Specifies a pointer to an QuantizeInfo structure.
 %
 %    o depth: Normally, this integer value is zero or one.  A zero or
@@ -1542,9 +1544,8 @@ static MagickBooleanType DitherImage(Image *image,CubeInfo *cube_info)
 %    o maximum_colors: maximum colors.
 %
 */
-static CubeInfo *GetCubeInfo(const Image *image,
-  const QuantizeInfo *quantize_info,const unsigned long depth,
-  const unsigned long maximum_colors)
+static CubeInfo *GetCubeInfo(const QuantizeInfo *quantize_info,
+  const unsigned long depth,const unsigned long maximum_colors)
 {
   CubeInfo
     *cube_info;
@@ -1585,9 +1586,8 @@ static CubeInfo *GetCubeInfo(const Image *image,
   /*
     Initialize dither resources.
   */
-  length=(size_t) (1 << ((IsAssociatedAlpha(image,cube_info) == MagickFalse ?
-    3 : 4)*(8-CacheShift)));
-  cube_info->cache=(long *) AcquireMagickMemory(length*
+  length=(size_t) (1UL << (4*(8-CacheShift)));
+  cube_info->cache=(long *) AcquireQuantumMemory(length,
     sizeof(*cube_info->cache));
   if (cube_info->cache == (long *) NULL)
     return((CubeInfo *) NULL);
@@ -1600,19 +1600,19 @@ static CubeInfo *GetCubeInfo(const Image *image,
     Distribute weights along a curve of exponential decay.
   */
   weight=1.0;
-  for (i=0; i < ExceptionQueueLength; i++)
+  for (i=0; i < ErrorQueueLength; i++)
   {
-    cube_info->weights[ExceptionQueueLength-i-1]=1.0/weight;
-    weight*=exp(log(((double) QuantumRange+1.0))/(ExceptionQueueLength-1.0));
+    cube_info->weights[ErrorQueueLength-i-1]=1.0/weight;
+    weight*=exp(log(((double) QuantumRange+1.0))/(ErrorQueueLength-1.0));
   }
   /*
     Normalize the weighting factors.
   */
   weight=0.0;
-  for (i=0; i < ExceptionQueueLength; i++)
+  for (i=0; i < ErrorQueueLength; i++)
     weight+=cube_info->weights[i];
   sum=0.0;
-  for (i=0; i < ExceptionQueueLength; i++)
+  for (i=0; i < ErrorQueueLength; i++)
   {
     cube_info->weights[i]/=weight;
     sum+=cube_info->weights[i];
@@ -1666,7 +1666,7 @@ static NodeInfo *GetNodeInfo(CubeInfo *cube_info,const unsigned long id,
       nodes=(Nodes *) AcquireMagickMemory(sizeof(*nodes));
       if (nodes == (Nodes *) NULL)
         return((NodeInfo *) NULL);
-      nodes->nodes=(NodeInfo *) AcquireMagickMemory(NodesInAList*
+      nodes->nodes=(NodeInfo *) AcquireQuantumMemory(NodesInAList,
         sizeof(*nodes->nodes));
       if (nodes->nodes == (NodeInfo *) NULL)
         return((NodeInfo *) NULL);
@@ -1771,33 +1771,30 @@ MagickExport MagickBooleanType GetImageQuantizeError(Image *image)
   image_view=OpenCacheView(image);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireCacheView(image_view,0,y,image->columns,1,&image->exception);
+    p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
     indexes=GetCacheViewIndexes(image_view);
     for (x=0; x < (long) image->columns; x++)
     {
-      index=indexes[x];
+      index=1UL*indexes[x];
       if (image->matte != MagickFalse)
         {
-          alpha=QuantumScale*(QuantumRange-(MagickRealType) p->opacity);
-          beta=QuantumScale*(QuantumRange-(MagickRealType)
-            image->colormap[index].opacity);
+          alpha=(MagickRealType) (QuantumScale*(QuantumRange-p->opacity));
+          beta=(MagickRealType) (QuantumScale*(QuantumRange-
+            image->colormap[index].opacity));
         }
-      distance=(MagickRealType) fabs((double) (alpha*p->red-beta*
-        image->colormap[index].red));
+      distance=fabs(alpha*p->red-beta*image->colormap[index].red);
       mean_error_per_pixel+=distance;
       mean_error+=distance*distance;
       if (distance > maximum_error)
         maximum_error=distance;
-      distance=(MagickRealType) fabs((double) (alpha*p->green-beta*
-        image->colormap[index].green));
+      distance=fabs(alpha*p->green-beta*image->colormap[index].green);
       mean_error_per_pixel+=distance;
       mean_error+=distance*distance;
       if (distance > maximum_error)
         maximum_error=distance;
-      distance=(MagickRealType) fabs((double) (alpha*p->blue-beta*
-        image->colormap[index].blue));
+      distance=fabs(alpha*p->blue-beta*image->colormap[index].blue);
       mean_error_per_pixel+=distance;
       mean_error+=distance*distance;
       if (distance > maximum_error)
@@ -1806,10 +1803,10 @@ MagickExport MagickBooleanType GetImageQuantizeError(Image *image)
     }
   }
   image_view=CloseCacheView(image_view);
-  image->error.mean_error_per_pixel=(double) (mean_error_per_pixel/area);
-  image->error.normalized_mean_error=(double) (QuantumScale*QuantumScale*
-    mean_error/area);
-  image->error.normalized_maximum_error=(double) (QuantumScale*maximum_error);
+  image->error.mean_error_per_pixel=(double) mean_error_per_pixel/area;
+  image->error.normalized_mean_error=(double) QuantumScale*QuantumScale*
+    mean_error/area;
+  image->error.normalized_maximum_error=(double) QuantumScale*maximum_error;
   return(MagickTrue);
 }
 
@@ -1885,91 +1882,89 @@ static void HilbertCurve(const Image *image,ViewInfo *image_view,
   CubeInfo *cube_info,const unsigned long level,const unsigned int direction)
 {
   if (level == 1)
+    switch (direction)
     {
-      switch (direction)
+      case WestGravity:
       {
-        case WestGravity:
-        {
-          (void) Dither(image,image_view,cube_info,EastGravity);
-          (void) Dither(image,image_view,cube_info,SouthGravity);
-          (void) Dither(image,image_view,cube_info,WestGravity);
-          break;
-        }
-        case EastGravity:
-        {
-          (void) Dither(image,image_view,cube_info,WestGravity);
-          (void) Dither(image,image_view,cube_info,NorthGravity);
-          (void) Dither(image,image_view,cube_info,EastGravity);
-          break;
-        }
-        case NorthGravity:
-        {
-          (void) Dither(image,image_view,cube_info,SouthGravity);
-          (void) Dither(image,image_view,cube_info,EastGravity);
-          (void) Dither(image,image_view,cube_info,NorthGravity);
-          break;
-        }
-        case SouthGravity:
-        {
-          (void) Dither(image,image_view,cube_info,NorthGravity);
-          (void) Dither(image,image_view,cube_info,WestGravity);
-          (void) Dither(image,image_view,cube_info,SouthGravity);
-          break;
-        }
-        default:
-          break;
+        (void) Dither(image,image_view,cube_info,EastGravity);
+        (void) Dither(image,image_view,cube_info,SouthGravity);
+        (void) Dither(image,image_view,cube_info,WestGravity);
+        break;
       }
-      return;
+      case EastGravity:
+      {
+        (void) Dither(image,image_view,cube_info,WestGravity);
+        (void) Dither(image,image_view,cube_info,NorthGravity);
+        (void) Dither(image,image_view,cube_info,EastGravity);
+        break;
+      }
+      case NorthGravity:
+      {
+        (void) Dither(image,image_view,cube_info,SouthGravity);
+        (void) Dither(image,image_view,cube_info,EastGravity);
+        (void) Dither(image,image_view,cube_info,NorthGravity);
+        break;
+      }
+      case SouthGravity:
+      {
+        (void) Dither(image,image_view,cube_info,NorthGravity);
+        (void) Dither(image,image_view,cube_info,WestGravity);
+        (void) Dither(image,image_view,cube_info,SouthGravity);
+        break;
+      }
+      default:
+        break;
     }
-  switch (direction)
-  {
-    case WestGravity:
+  else
+    switch (direction)
     {
-      HilbertCurve(image,image_view,cube_info,level-1,NorthGravity);
-      (void) Dither(image,image_view,cube_info,EastGravity);
-      HilbertCurve(image,image_view,cube_info,level-1,WestGravity);
-      (void) Dither(image,image_view,cube_info,SouthGravity);
-      HilbertCurve(image,image_view,cube_info,level-1,WestGravity);
-      (void) Dither(image,image_view,cube_info,WestGravity);
-      HilbertCurve(image,image_view,cube_info,level-1,SouthGravity);
-      break;
+      case WestGravity:
+      {
+        HilbertCurve(image,image_view,cube_info,level-1,NorthGravity);
+        (void) Dither(image,image_view,cube_info,EastGravity);
+        HilbertCurve(image,image_view,cube_info,level-1,WestGravity);
+        (void) Dither(image,image_view,cube_info,SouthGravity);
+        HilbertCurve(image,image_view,cube_info,level-1,WestGravity);
+        (void) Dither(image,image_view,cube_info,WestGravity);
+        HilbertCurve(image,image_view,cube_info,level-1,SouthGravity);
+        break;
+      }
+      case EastGravity:
+      {
+        HilbertCurve(image,image_view,cube_info,level-1,SouthGravity);
+        (void) Dither(image,image_view,cube_info,WestGravity);
+        HilbertCurve(image,image_view,cube_info,level-1,EastGravity);
+        (void) Dither(image,image_view,cube_info,NorthGravity);
+        HilbertCurve(image,image_view,cube_info,level-1,EastGravity);
+        (void) Dither(image,image_view,cube_info,EastGravity);
+        HilbertCurve(image,image_view,cube_info,level-1,NorthGravity);
+        break;
+      }
+      case NorthGravity:
+      {
+        HilbertCurve(image,image_view,cube_info,level-1,WestGravity);
+        (void) Dither(image,image_view,cube_info,SouthGravity);
+        HilbertCurve(image,image_view,cube_info,level-1,NorthGravity);
+        (void) Dither(image,image_view,cube_info,EastGravity);
+        HilbertCurve(image,image_view,cube_info,level-1,NorthGravity);
+        (void) Dither(image,image_view,cube_info,NorthGravity);
+        HilbertCurve(image,image_view,cube_info,level-1,EastGravity);
+        break;
+      }
+      case SouthGravity:
+      {
+        HilbertCurve(image,image_view,cube_info,level-1,EastGravity);
+        (void) Dither(image,image_view,cube_info,NorthGravity);
+        HilbertCurve(image,image_view,cube_info,level-1,SouthGravity);
+        (void) Dither(image,image_view,cube_info,WestGravity);
+        HilbertCurve(image,image_view,cube_info,level-1,SouthGravity);
+        (void) Dither(image,image_view,cube_info,SouthGravity);
+        HilbertCurve(image,image_view,cube_info,level-1,WestGravity);
+        break;
+      }
+      default:
+        break;
     }
-    case EastGravity:
-    {
-      HilbertCurve(image,image_view,cube_info,level-1,SouthGravity);
-      (void) Dither(image,image_view,cube_info,WestGravity);
-      HilbertCurve(image,image_view,cube_info,level-1,EastGravity);
-      (void) Dither(image,image_view,cube_info,NorthGravity);
-      HilbertCurve(image,image_view,cube_info,level-1,EastGravity);
-      (void) Dither(image,image_view,cube_info,EastGravity);
-      HilbertCurve(image,image_view,cube_info,level-1,NorthGravity);
-      break;
-    }
-    case NorthGravity:
-    {
-      HilbertCurve(image,image_view,cube_info,level-1,WestGravity);
-      (void) Dither(image,image_view,cube_info,SouthGravity);
-      HilbertCurve(image,image_view,cube_info,level-1,NorthGravity);
-      (void) Dither(image,image_view,cube_info,EastGravity);
-      HilbertCurve(image,image_view,cube_info,level-1,NorthGravity);
-      (void) Dither(image,image_view,cube_info,NorthGravity);
-      HilbertCurve(image,image_view,cube_info,level-1,EastGravity);
-      break;
-    }
-    case SouthGravity:
-    {
-      HilbertCurve(image,image_view,cube_info,level-1,EastGravity);
-      (void) Dither(image,image_view,cube_info,NorthGravity);
-      HilbertCurve(image,image_view,cube_info,level-1,SouthGravity);
-      (void) Dither(image,image_view,cube_info,WestGravity);
-      HilbertCurve(image,image_view,cube_info,level-1,SouthGravity);
-      (void) Dither(image,image_view,cube_info,SouthGravity);
-      HilbertCurve(image,image_view,cube_info,level-1,WestGravity);
-      break;
-    }
-    default:
-      break;
-  }
 }
 
 /*
@@ -2025,7 +2020,7 @@ MagickExport MagickBooleanType MapImage(Image *image,const Image *map_image,
   assert(map_image->signature == MagickSignature);
   GetQuantizeInfo(&quantize_info);
   quantize_info.dither=dither;
-  cube_info=GetCubeInfo(image,&quantize_info,MaxTreeDepth,
+  cube_info=GetCubeInfo(&quantize_info,MaxTreeDepth,
     quantize_info.number_colors);
   if (cube_info == (CubeInfo *) NULL)
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
@@ -2036,7 +2031,8 @@ MagickExport MagickBooleanType MapImage(Image *image,const Image *map_image,
       /*
         Classify image colors from the reference image.
       */
-      quantize_info.number_colors=cube_info->colors;
+      cube_info->quantize_info->dither=dither;
+      cube_info->quantize_info->number_colors=cube_info->colors;
       status=AssignImageColors(image,cube_info);
     }
   DestroyCubeInfo(cube_info);
@@ -2106,7 +2102,7 @@ MagickExport MagickBooleanType MapImages(Image *images,const Image *map_image,
   /*
     Classify image colors from the reference image.
   */
-  cube_info=GetCubeInfo(image,&quantize_info,MaxTreeDepth,
+  cube_info=GetCubeInfo(&quantize_info,MaxTreeDepth,
     quantize_info.number_colors);
   if (cube_info == (CubeInfo *) NULL)
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
@@ -2117,7 +2113,8 @@ MagickExport MagickBooleanType MapImages(Image *images,const Image *map_image,
       /*
         Classify image colors from the reference image.
       */
-      quantize_info.number_colors=cube_info->colors;
+      cube_info->quantize_info->dither=dither;
+      cube_info->quantize_info->number_colors=cube_info->colors;
       image=images;
       for ( ; image != (Image *) NULL; image=GetNextImageInList(image))
       {
@@ -2161,20 +2158,6 @@ MagickExport MagickBooleanType MapImages(Image *images,const Image *map_image,
 %
 */
 
-static inline long MagickMax(const long x,const long y)
-{
-  if (x > y)
-    return(x);
-  return(y);
-}
-
-static inline long MagickMin(const long x,const long y)
-{
-  if (x < y)
-    return(x);
-  return(y);
-}
-
 MagickExport MagickBooleanType PosterizeImage(Image *image,
   const unsigned long levels,const MagickBooleanType dither)
 {
@@ -2213,7 +2196,7 @@ MagickExport MagickBooleanType PosterizeImage(Image *image,
   if (posterize_image == (Image *) NULL)
     return(MagickFalse);
   l=1;
-  while ((l*l*l) < MagickMin((long) levels*levels*levels,MaxColormapSize+1))
+  while ((l*l*l) < (long) MagickMin(levels*levels*levels,MaxColormapSize+1))
     l++;
   status=SetImageExtent(posterize_image,(unsigned long) (l*l*l),1);
   if (status == MagickFalse)
@@ -2242,11 +2225,11 @@ MagickExport MagickBooleanType PosterizeImage(Image *image,
       for (k=0; k < l; k++)
       {
         posterize_image->colormap[n].red=(Quantum) (QuantumRange*i/
-          MagickMax(l-1,1));
+          MagickMax(1UL*l-1UL,1UL));
         posterize_image->colormap[n].green=(Quantum)
-          (QuantumRange*j/MagickMax(l-1,1));
+          (QuantumRange*j/MagickMax(1UL*l-1UL,1UL));
         posterize_image->colormap[n].blue=(Quantum) (QuantumRange*k/
-          MagickMax(l-1,1));
+          MagickMax(1UL*l-1UL,1UL));
         posterize_image->colormap[n].opacity=OpaqueOpacity;
         *q++=posterize_image->colormap[n];
         indexes[n]=(IndexPacket) n;
@@ -2295,20 +2278,21 @@ MagickExport MagickBooleanType PosterizeImage(Image *image,
 static void PruneChild(const Image *image,CubeInfo *cube_info,
   const NodeInfo *node_info)
 {
-  long
-    number_children;
-
   NodeInfo
     *parent;
 
   register long
     i;
 
+  unsigned long
+    number_children;
+
   /*
     Traverse any children.
   */
-  number_children=IsAssociatedAlpha(image,cube_info) == MagickFalse ? 8L : 16L;
-  for (i=0; i < number_children; i++)
+  number_children=IsAssociatedAlpha(image,cube_info) == MagickFalse ?
+    8UL : 16UL;
+  for (i=0; i < (long) number_children; i++)
     if (node_info->child[i] != (NodeInfo *) NULL)
       PruneChild(image,cube_info,node_info->child[i]);
   /*
@@ -2355,17 +2339,18 @@ static void PruneChild(const Image *image,CubeInfo *cube_info,
 static void PruneLevel(const Image *image,CubeInfo *cube_info,
   const NodeInfo *node_info)
 {
-  long
-    number_children;
-
   register long
     i;
 
+  unsigned long
+    number_children;
+
   /*
     Traverse any children.
   */
-  number_children=IsAssociatedAlpha(image,cube_info) == MagickFalse ? 8L : 16L;
-  for (i=0; i < number_children; i++)
+  number_children=IsAssociatedAlpha(image,cube_info) == MagickFalse ?
+    8UL : 16UL;
+  for (i=0; i < (long) number_children; i++)
     if (node_info->child[i] != (NodeInfo *) NULL)
       PruneLevel(image,cube_info,node_info->child[i]);
   if (node_info->level == cube_info->depth)
@@ -2402,17 +2387,18 @@ static void PruneLevel(const Image *image,CubeInfo *cube_info,
 static void PruneToCubeDepth(const Image *image,CubeInfo *cube_info,
   const NodeInfo *node_info)
 {
-  long
-    number_children;
-
   register long
     i;
 
+  unsigned long
+    number_children;
+
   /*
     Traverse any children.
   */
-  number_children=IsAssociatedAlpha(image,cube_info) == MagickFalse ? 8L : 16L;
-  for (i=0; i < number_children; i++)
+  number_children=IsAssociatedAlpha(image,cube_info) == MagickFalse ?
+    8UL : 16UL;
+  for (i=0; i < (long) number_children; i++)
     if (node_info->child[i] != (NodeInfo *) NULL)
       PruneToCubeDepth(image,cube_info,node_info->child[i]);
   if (node_info->level > cube_info->depth)
@@ -2483,13 +2469,15 @@ MagickExport MagickBooleanType QuantizeImage(const QuantizeInfo *quantize_info,
       colors=maximum_colors;
       for (depth=1; colors != 0; depth++)
         colors>>=2;
-      if (quantize_info->dither != MagickFalse)
+      if ((quantize_info->dither != MagickFalse) && (depth > 2))
+        depth--;
+      if ((image->matte != MagickFalse) && (depth > 5))
         depth--;
     }
   /*
     Initialize color cube.
   */
-  cube_info=GetCubeInfo(image,quantize_info,depth,maximum_colors);
+  cube_info=GetCubeInfo(quantize_info,depth,maximum_colors);
   if (cube_info == (CubeInfo *) NULL)
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
       image->filename);
@@ -2595,7 +2583,7 @@ MagickExport MagickBooleanType QuantizeImages(const QuantizeInfo *quantize_info,
   /*
     Initialize color cube.
   */
-  cube_info=GetCubeInfo(images,quantize_info,depth,maximum_colors);
+  cube_info=GetCubeInfo(quantize_info,depth,maximum_colors);
   if (cube_info == (CubeInfo *) NULL)
     {
       (void) ThrowMagickException(&images->exception,GetMagickModule(),
@@ -2683,17 +2671,18 @@ MagickExport MagickBooleanType QuantizeImages(const QuantizeInfo *quantize_info,
 static void Reduce(const Image *image,CubeInfo *cube_info,
   const NodeInfo *node_info)
 {
-  long
-    number_children;
-
   register long
     i;
 
+  unsigned long
+    number_children;
+
   /*
     Traverse any children.
   */
-  number_children=IsAssociatedAlpha(image,cube_info) == MagickFalse ? 8L : 16L;
-  for (i=0; i < number_children; i++)
+  number_children=IsAssociatedAlpha(image,cube_info) == MagickFalse ?
+    8UL : 16UL;
+  for (i=0; i < (long) number_children; i++)
     if (node_info->child[i] != (NodeInfo *) NULL)
       Reduce(image,cube_info,node_info->child[i]);
   if (node_info->quantize_error <= cube_info->pruning_threshold)
