@@ -629,15 +629,13 @@ MagickExport void InitializeMagickResources(void)
 #elif defined(HAVE_GETPAGESIZE) && defined(POSIX)
   pagesize=getpagesize();
 #endif
-  if (pagesize <= 0)
-    pagesize=4096;
   pages=(-1);
 #if defined(HAVE_SYSCONF) && defined(_SC_PHYS_PAGES)
   pages=sysconf(_SC_PHYS_PAGES);
 #endif
-  if (pages <= 0)
-    pages=62500;
   memory=(unsigned long) ((pages+512)/1024)*((pagesize+512)/1024);
+  if ((pagesize <= 0) || (pages <= 0))
+    memory=2048UL;
 #if defined(PixelCacheThreshold)
   memory=PixelCacheThreshold;
 #endif
