@@ -93,6 +93,7 @@
 #include "magick/monitor.h"
 #include "magick/quantize.h"
 #include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/segment.h"
 #include "magick/string_.h"
 
@@ -175,7 +176,7 @@ static const int
   Green = 1,
   Red = 0,
   SafeMargin = 3,
-  TreeLength = 600UL;
+  TreeLength = 600;
 
 /*
   Method prototypes.
@@ -1320,7 +1321,8 @@ static IntervalTree *InitializeIntervalTree(const ZeroCrossing *zero_crossing,
   /*
     Allocate interval tree.
   */
-  list=(IntervalTree **) AcquireQuantumMemory(TreeLength,sizeof(*list));
+  list=(IntervalTree **) AcquireQuantumMemory((size_t) TreeLength,
+    sizeof(*list));
   if (list == (IntervalTree **) NULL)
     return((IntervalTree *) NULL);
   /*
@@ -1488,7 +1490,8 @@ static MagickRealType OptimalTau(const long *histogram,const double max_tau,
   /*
     Allocate interval tree.
   */
-  list=(IntervalTree **) AcquireQuantumMemory(TreeLength,sizeof(*list));
+  list=(IntervalTree **) AcquireQuantumMemory((size_t) TreeLength,
+    sizeof(*list));
   if (list == (IntervalTree **) NULL)
     return(0.0);
   /*
