@@ -115,13 +115,16 @@ static volatile LONG
 %
 %    o semaphore_info: Specifies a pointer to an SemaphoreInfo structure.
 %
-%
 */
 MagickExport void AcquireSemaphoreInfo(SemaphoreInfo **semaphore_info)
 {
   assert(semaphore_info != (SemaphoreInfo **) NULL);
 #if defined(HAVE_PTHREAD)
-  (void) pthread_mutex_lock(&semaphore_mutex);
+  if (pthread_mutex_lock(&semaphore_mutex) != 0)
+    {
+      (void) fprintf(stderr,"pthread_mutex_lock failed %s\n",strerror(errno));
+      _exit(1);
+    }
 #endif
 #if defined(__WINDOWS__)
   while (InterlockedCompareExchange(&semaphore_mutex,1L,0L) != 0)
@@ -130,7 +133,11 @@ MagickExport void AcquireSemaphoreInfo(SemaphoreInfo **semaphore_info)
   if (*semaphore_info == (SemaphoreInfo *) NULL)
     *semaphore_info=AllocateSemaphoreInfo();
 #if defined(HAVE_PTHREAD)
-  (void) pthread_mutex_unlock(&semaphore_mutex);
+  if (pthread_mutex_unlock(&semaphore_mutex) != 0)
+    {
+      (void) fprintf(stderr,"pthread_mutex_unlock failed %s\n",strerror(errno));
+      _exit(1);
+    }
 #endif
 #if defined(__WINDOWS__)
   InterlockedExchange(&semaphore_mutex,0L);
@@ -160,7 +167,6 @@ MagickExport void AcquireSemaphoreInfo(SemaphoreInfo **semaphore_info)
 %    o semaphore_info: Method AllocateSemaphoreInfo returns a pointer to an
 %      initialized SemaphoreInfo structure.
 %
-%
 */
 MagickExport SemaphoreInfo *AllocateSemaphoreInfo(void)
 {
@@ -172,15 +178,7 @@ MagickExport SemaphoreInfo *AllocateSemaphoreInfo(void)
   */
   semaphore_info=(SemaphoreInfo *) malloc(sizeof(SemaphoreInfo));
   if (semaphore_info == (SemaphoreInfo *) NULL)
-    {
-      char
-        *message;
-
-      message=GetExceptionMessage(errno);
-      ThrowMagickFatalException(ResourceLimitFatalError,
-        "MemoryAllocationFailed",message);
-      message=DestroyString(message);
-    }
+    ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
   (void) ResetMagickMemory(semaphore_info,0,sizeof(SemaphoreInfo));
   /*
     Initialize the semaphore.
@@ -197,23 +195,33 @@ MagickExport SemaphoreInfo *AllocateSemaphoreInfo(void)
     if (status != 0)
       {
         free(semaphore_info);
-        return((SemaphoreInfo *) NULL);
+        ThrowFatalException(ResourceLimitFatalError,
+          "UnableToInitializeSemaphore");
       }
 #if defined(PTHREAD_MUTEX_RECURSIVE)
-    (void) pthread_mutexattr_settype(&mutex_info,PTHREAD_MUTEX_RECURSIVE);
+    status=pthread_mutexattr_settype(&mutex_info,PTHREAD_MUTEX_RECURSIVE);
+    if (status != 0)
+      {
+        (void) pthread_mutexattr_destroy(&mutex_info);
+        free(semaphore_info);
+        ThrowFatalException(ResourceLimitFatalError,
+          "UnableToInitializeSemaphore");
+      }
 #endif
     status=pthread_mutex_init(&semaphore_info->mutex,&mutex_info);
+    (void) pthread_mutexattr_destroy(&mutex_info);
     if (status != 0)
       {
         free(semaphore_info);
-        return((SemaphoreInfo *) NULL);
+        ThrowFatalException(ResourceLimitFatalError,
+          "UnableToInitializeSemaphore");
       }
-    (void) pthread_mutexattr_destroy(&mutex_info);
     semaphore_info->id=0;
   }
 #endif
 #if defined(__WINDOWS__)
   InitializeCriticalSection(&semaphore_info->mutex);
+  semaphore_info->id=0;
 #endif
   semaphore_info->reference_count=0;
   semaphore_info->signature=MagickSignature;
@@ -237,12 +245,16 @@ MagickExport SemaphoreInfo *AllocateSemaphoreInfo(void)
 %
 %      DestroySemaphore(void)
 %
-%
 */
 MagickExport void DestroySemaphore(void)
 {
 #if defined(HAVE_PTHREAD)
-  (void) pthread_mutex_destroy(&semaphore_mutex);
+  if (pthread_mutex_destroy(&semaphore_mutex) != 0)
+    {
+      (void) fprintf(stderr,"pthread_mutex_destroy failed %s\n",
+        strerror(errno));
+      _exit(1);
+    }
 #endif
 }
 
@@ -267,7 +279,6 @@ MagickExport void DestroySemaphore(void)
 %
 %    o semaphore_info: Specifies a pointer to an SemaphoreInfo structure.
 %
-%
 */
 MagickExport SemaphoreInfo *DestroySemaphoreInfo(SemaphoreInfo *semaphore_info)
 {
@@ -359,15 +370,15 @@ MagickExport MagickBooleanType LockSemaphoreInfo(SemaphoreInfo *semaphore_info)
     pthread_t
       id;
 
+    status=pthread_mutex_lock(&semaphore_info->mutex);
+    if (status != 0)
+      return(MagickFalse);
     id=pthread_self();
     if ((semaphore_info->reference_count > 0) && (semaphore_info->id == id))
       {
         (void) fprintf(stderr,"Warning: recursive semaphore lock detected!\n");
         (void) fflush(stderr);
       }
-    status=pthread_mutex_lock(&semaphore_info->mutex);
-    if (status != 0)
-      return(MagickFalse);
     semaphore_info->id=id;
   }
 #endif
