@@ -154,7 +154,7 @@ MagickExport Image *AffineTransformImage(const Image *image,
     (unsigned long) (max.y-min.y+0.5),MagickTrue,exception);
   if (affine_image == (Image *) NULL)
     return((Image *) NULL);
-  affine_image->background_color.opacity=TransparentOpacity;
+  affine_image->background_color.opacity=(Quantum) TransparentOpacity;
   (void) SetImageBackgroundColor(affine_image);
   /*
     Adjust transform translation for direct image to image transformation.
@@ -417,17 +417,17 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
         {
           tile_width=TileWidth;
           if ((tile_x+TileWidth) > (long) image->columns)
-            tile_width=(TileWidth-(tile_x+TileWidth-image->columns));
+            tile_width=1UL*(TileWidth-(tile_x+TileWidth-image->columns));
           tile_height=TileHeight;
           if ((tile_y+TileHeight) > (long) image->rows)
-            tile_height=(TileHeight-(tile_y+TileHeight-image->rows));
+            tile_height=1UL*(TileHeight-(tile_y+TileHeight-image->rows));
           tile_pixels=AcquireImagePixels(image,tile_x,tile_y,tile_width,
             tile_height,exception);
           if (tile_pixels == (const PixelPacket *) NULL)
             break;
           for (y=0; y < (long) tile_width; y++)
           {
-            q=SetImagePixels(rotate_image,rotate_image->columns-(tile_y+
+            q=SetImagePixels(rotate_image,(long) rotate_image->columns-(tile_y+
               tile_height),tile_x+y,tile_height,1);
             if (q == (PixelPacket *) NULL)
               break;
@@ -504,31 +504,47 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
     case 3:
     {
       /*
-        Rotate 90 degrees.
+        Rotate 270 degrees.
       */
-      for (y=0; y < (long) image->rows; y++)
+      for (tile_y=0; tile_y < (long) image->rows; tile_y+=TileHeight)
       {
-        p=AcquireImagePixels(image,0,y,image->columns,1,exception);
-        q=SetImagePixels(rotate_image,y,0,1,rotate_image->rows);
-        if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
-          break;
-        q+=image->columns;
-        indexes=GetIndexes(image);
-        rotate_indexes=GetIndexes(rotate_image);
-        for (x=0; x < (long) image->columns; x++)
+        for (tile_x=0; tile_x < (long) image->columns; tile_x+=TileWidth)
         {
-          q--;
-          SetMagickPixelPacket(image,p,indexes+x,&pixel);
-          SetPixelPacket(rotate_image,&pixel,q,rotate_indexes+(image->columns-
-            x-1));
-          p++;
-        }
-        if (SyncImagePixels(rotate_image) == MagickFalse)
-          break;
-        if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-            (QuantumTick(y,image->rows) != MagickFalse))
+          tile_width=TileWidth;
+          if ((tile_x+TileWidth) > (long) image->columns)
+            tile_width=1UL*(TileWidth-(tile_x+TileWidth-image->columns));
+          tile_height=TileHeight;
+          if ((tile_y+TileHeight) > (long) image->rows)
+            tile_height=1UL*(TileHeight-(tile_y+TileHeight-image->rows));
+          tile_pixels=AcquireImagePixels(image,tile_x,tile_y,tile_width,
+            tile_height,exception);
+          if (tile_pixels == (const PixelPacket *) NULL)
+            break;
+          for (y=0; y < (long) tile_width; y++)
           {
-            status=image->progress_monitor(RotateImageTag,y,image->rows,
+            q=SetImagePixels(rotate_image,tile_y,(long) rotate_image->rows-
+              (tile_x+tile_width)+y,tile_height,1);
+            if (q == (PixelPacket *) NULL)
+              break;
+            rotate_indexes=GetIndexes(rotate_image);
+            p=tile_pixels+(tile_width-1)-y;
+            indexes=GetIndexes(image)+(tile_width-1)-y;
+            for (x=0; x < (long) tile_height; x++)
+            {
+              SetMagickPixelPacket(image,p,indexes,&pixel);
+              SetPixelPacket(rotate_image,&pixel,q,rotate_indexes+x);
+              p+=tile_width;
+              indexes+=tile_width;
+              q++;
+            }
+            if (SyncImagePixels(rotate_image) == MagickFalse)
+              break;
+          }
+        }
+        if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+            (QuantumTick(tile_y,image->rows) != MagickFalse))
+          {
+            status=image->progress_monitor(RotateImageTag,tile_y,image->rows,
               image->client_data);
             if (status == MagickFalse)
               break;
@@ -606,21 +622,21 @@ static inline void MagickCompositeBlend(const MagickPixelPacket *p,
   gamma=1.0/(fabs(gamma) <= MagickEpsilon ? 1.0 : gamma);
   composite->red=gamma*Blend_((MagickRealType) p->red,
     (MagickRealType) QuantumRange-(1.0-area)*(QuantumRange-alpha),
-    (MagickRealType) q->red,(MagickRealType) QuantumRange-area*(QuantumRange-
-    beta));
+    (MagickRealType) q->red,(MagickRealType) (QuantumRange-area*(QuantumRange-
+    beta)));
   composite->green=gamma*Blend_((MagickRealType) p->green,
     (MagickRealType) QuantumRange-(1.0-area)*(QuantumRange-alpha),
-    (MagickRealType) q->green,(MagickRealType) QuantumRange-area*(QuantumRange-
-    beta));
+    (MagickRealType) q->green,(MagickRealType) (QuantumRange-area*(QuantumRange-
+    beta)));
   composite->blue=gamma*Blend_((MagickRealType) p->blue,
     (MagickRealType) QuantumRange-(1.0-area)*(QuantumRange-alpha),
-    (MagickRealType) q->blue,(MagickRealType) QuantumRange-area*(QuantumRange-
-    beta));
+    (MagickRealType) q->blue,(MagickRealType) (QuantumRange-area*(QuantumRange-
+    beta)));
   if (q->colorspace == CMYKColorspace)
     composite->index=gamma*Blend_((MagickRealType) p->index,
       (MagickRealType) QuantumRange-(1.0-area)*(QuantumRange-alpha),
-      (MagickRealType) q->index,(MagickRealType) QuantumRange-area*
-      (QuantumRange-beta));
+      (MagickRealType) q->index,(MagickRealType) (QuantumRange-area*
+      (QuantumRange-beta)));
 }
 
 static void XShearImage(Image *image,const MagickRealType degrees,
