@@ -46,6 +46,7 @@
 #include "magick/image.h"
 #include "magick/memory_.h"
 #include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/signature.h"
 #include "magick/string_.h"
 
@@ -189,7 +190,7 @@ MagickExport MagickBooleanType SignatureImage(Image *image)
   char
     signature[MaxTextExtent];
 
-  IndexPacket
+  const IndexPacket
     *indexes;
 
   long
@@ -237,7 +238,7 @@ MagickExport MagickBooleanType SignatureImage(Image *image)
     p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
-    indexes=GetIndexes(image);
+    indexes=AcquireIndexes(image);
     q=message;
     for (x=0; x < (long) image->columns; x++)
     {
@@ -256,11 +257,6 @@ MagickExport MagickBooleanType SignatureImage(Image *image)
       *q++=(unsigned char) (quantum >> 16);
       *q++=(unsigned char) (quantum >> 8);
       *q++=(unsigned char) quantum;
-      quantum=ScaleQuantumToLong(p->opacity);
-      *q++=(unsigned char) (quantum >> 24);
-      *q++=(unsigned char) (quantum >> 16);
-      *q++=(unsigned char) (quantum >> 8);
-      *q++=(unsigned char) quantum;
       if (image->colorspace == CMYKColorspace)
         {
           quantum=ScaleQuantumToLong(indexes[x]);
@@ -269,6 +265,14 @@ MagickExport MagickBooleanType SignatureImage(Image *image)
           *q++=(unsigned char) (quantum >> 8);
           *q++=(unsigned char) quantum;
         }
+      if (image->matte != MagickFalse)
+        {
+          quantum=ScaleQuantumToLong(p->opacity);
+          *q++=(unsigned char) (quantum >> 24);
+          *q++=(unsigned char) (quantum >> 16);
+          *q++=(unsigned char) (quantum >> 8);
+          *q++=(unsigned char) quantum;
+        }
       p++;
     }
     UpdateSignature(&signature_info,message,(size_t) (q-message));
@@ -283,8 +287,8 @@ MagickExport MagickBooleanType SignatureImage(Image *image)
     signature_info.digest[1],signature_info.digest[2],signature_info.digest[3],
     signature_info.digest[4],signature_info.digest[5],signature_info.digest[6],
     signature_info.digest[7]);
-  (void) DeleteImageProperty(image,"Signature");
-  (void) SetImageProperty(image,"Signature",signature);
+  (void) DeleteImageProperty(image,"signature");
+  (void) SetImageProperty(image,"signature",signature);
   return(MagickTrue);
 }
 
