@@ -52,18 +52,18 @@
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   E x e c u t e S t a t i c M o d u l e P r o c e s s                       %
+%   I n v o k e S t a t i c I m a g e F i l t e r                             %
 %                                                                             %
 %                                                                             %
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  ExecuteStaticModuleProcess() is just a template method.
+%  InvokeStaticImageFilter() invokes a static image filter.
 %
-%  The format of the ExecuteStaticModuleProcess method is:
+%  The format of the InvokeStaticImageFilter method is:
 %
-%      MagickBooleanType ExecuteStaticModuleProcess(const char *tag,
-%        Image **image,const int argc,char **argv)
+%      MagickBooleanType InvokeStaticImageFilter(const char *tag,Image **image,
+%        const int argc,char **argv)
 %
 %  A description of each parameter follows:
 %
@@ -75,41 +75,58 @@
 %
 %    o argv: A text array containing the command line arguments.
 %
+%    o argv: A text array containing the command line arguments.
+%
+%    o exception: Return any errors or warnings in this structure.
+%
 */
 #if defined(SupportMagickModules)
-MagickExport MagickBooleanType ExecuteStaticModuleProcess(const char *tag,
-  Image **image,const int argc,char **argv)
+MagickExport MagickBooleanType InvokeStaticImageFilter(const char *tag,
+  Image **image,const int argc,char **argv,ExceptionInfo *exception)
 {
-  MagickBooleanType
-    status;
-
   assert(image != (Image **) NULL);
   assert((*image)->signature == MagickSignature);
   if ((*image)->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",(*image)->filename);
-  status=MagickFalse;
-#if !defined(BuildMagickModules)
+#if defined(BuildMagickModules)
+  (void) tag;
+  (void) argc;
+  (void) argv;
+  (void) exception;
+#else
   {
-    MagickBooleanType
-      analyzeImage(Image **,const int,char **),
-      (*module)(Image **,const int,char **);
+    extern unsigned long
+      analyzeImage(Image **,const int,char **,ExceptionInfo *);
 
-    module=(MagickBooleanType (*)(Image **,const int,char **)) NULL;
+    ImageFilterHandler
+      *image_filter;
+
+    image_filter=(ImageFilterHandler *) NULL;
     if (LocaleCompare("analyze",tag) == 0)
-      module=analyzeImage;
-    if (module != (MagickBooleanType (*)(Image **,const int,char **)) NULL)
+      image_filter=analyzeImage;
+    if (image_filter != (ImageFilterHandler *) NULL)
       {
+        unsigned long
+          signature;
+
         if ((*image)->debug != MagickFalse)
           (void) LogMagickEvent(CoderEvent,GetMagickModule(),
-            "Invoking \"%s\" static filter module",tag);
-        status=(*module)(image,argc,argv);
+            "Invoking \"%s\" static image filter",tag);
+        signature=image_filter(image,argc,argv,exception);
         if ((*image)->debug != MagickFalse)
           (void) LogMagickEvent(CoderEvent,GetMagickModule(),"\"%s\" completes",
             tag);
+        if (signature != MagickImageFilterSignature)
+          {
+            (void) ThrowMagickException(exception,GetMagickModule(),ModuleError,
+              "ImageFilterSignatureMismatch","`%s': %8lx != %8lx",tag,signature,
+              MagickImageFilterSignature);
+            return(MagickFalse);
+          }
       }
   }
 #endif
-  return(status);
+  return(MagickTrue);
 }
 #endif
 
@@ -124,148 +141,149 @@ MagickExport MagickBooleanType ExecuteStaticModuleProcess(const char *tag,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RegisterStaticModules() statically registers all the available module
+%  (void) RegisterStaticModules() statically registers all the available module
 %  handlers.
 %
 %  The format of the RegisterStaticModules method is:
 %
-%      RegisterStaticModules(void)
-%
+%      (void) RegisterStaticModules(void)
 %
 */
 MagickExport void RegisterStaticModules(void)
 {
 #if !defined(BuildMagickModules)
-  RegisterARTImage();
-  RegisterAVIImage();
-  RegisterAVSImage();
-  RegisterBMPImage();
-  RegisterCAPTIONImage();
-  RegisterCINImage();
-  RegisterCIPImage();
-  RegisterCLIPImage();
+  (void) RegisterARTImage();
+  (void) RegisterAVIImage();
+  (void) RegisterAVSImage();
+  (void) RegisterBMPImage();
+  (void) RegisterCAPTIONImage();
+  (void) RegisterCINImage();
+  (void) RegisterCIPImage();
+  (void) RegisterCLIPImage();
 #if defined(HasWINGDI32)
-  RegisterCLIPBOARDImage();
+  (void) RegisterCLIPBOARDImage();
 #endif
-  RegisterCMYKImage();
-  RegisterCUTImage();
-  RegisterDCMImage();
-  RegisterDIBImage();
+  (void) RegisterCMYKImage();
+  (void) RegisterCUTImage();
+  (void) RegisterDCMImage();
+  (void) RegisterDIBImage();
 #if defined(HasDJVU)
-  RegisterDJVUImage();
+  (void) RegisterDJVUImage();
 #endif
-  RegisterDNGImage();
-  RegisterDPSImage();
-  RegisterDPXImage();
+  (void) RegisterDNGImage();
+  (void) RegisterDPSImage();
+  (void) RegisterDPXImage();
 #if defined(HasWINGDI32)
-  RegisterEMFImage();
+  (void) RegisterEMFImage();
 #endif
 #if defined(HasTIFF)
-  RegisterEPTImage();
+  (void) RegisterEPTImage();
 #endif
-  RegisterEXRImage();
-  RegisterFAXImage();
-  RegisterFITSImage();
+#if defined(HasOPENEXR)
+  (void) RegisterEXRImage();
+#endif
+  (void) RegisterFAXImage();
+  (void) RegisterFITSImage();
 #if defined(HasFPX)
-  RegisterFPXImage();
+  (void) RegisterFPXImage();
 #endif
-  RegisterGIFImage();
-  RegisterGRAYImage();
-  RegisterGRADIENTImage();
-  RegisterHISTOGRAMImage();
-  RegisterHTMLImage();
-  RegisterICONImage();
-  RegisterINFOImage();
-  RegisterIPLImage();
+  (void) RegisterGIFImage();
+  (void) RegisterGRAYImage();
+  (void) RegisterGRADIENTImage();
+  (void) RegisterHISTOGRAMImage();
+  (void) RegisterHTMLImage();
+  (void) RegisterICONImage();
+  (void) RegisterINFOImage();
+  (void) RegisterIPLImage();
 #if defined(HasJBIG)
-  RegisterJBIGImage();
+  (void) RegisterJBIGImage();
 #endif
 #if defined(HasJPEG)
-  RegisterJPEGImage();
+  (void) RegisterJPEGImage();
 #endif
 #if defined(HasJP2)
-  RegisterJP2Image();
+  (void) RegisterJP2Image();
 #endif
-  RegisterLABELImage();
-  RegisterMAGICKImage();
-  RegisterMAPImage();
-  RegisterMATImage();
-  RegisterMATTEImage();
-  RegisterMETAImage();
-  RegisterMIFFImage();
-  RegisterMONOImage();
-  RegisterMPCImage();
-  RegisterMPEGImage();
-  RegisterMPRImage();
-  RegisterMSLImage();
-  RegisterMTVImage();
-  RegisterMVGImage();
-  RegisterNULLImage();
-  RegisterOTBImage();
-  RegisterPALMImage();
-  RegisterPATTERNImage();
-  RegisterPCDImage();
-  RegisterPCLImage();
-  RegisterPCXImage();
-  RegisterPDBImage();
-  RegisterPDFImage();
-  RegisterPICTImage();
-  RegisterPIXImage();
-  RegisterPLASMAImage();
+  (void) RegisterLABELImage();
+  (void) RegisterMAGICKImage();
+  (void) RegisterMAPImage();
+  (void) RegisterMATImage();
+  (void) RegisterMATTEImage();
+  (void) RegisterMETAImage();
+  (void) RegisterMIFFImage();
+  (void) RegisterMONOImage();
+  (void) RegisterMPCImage();
+  (void) RegisterMPEGImage();
+  (void) RegisterMPRImage();
+  (void) RegisterMSLImage();
+  (void) RegisterMTVImage();
+  (void) RegisterMVGImage();
+  (void) RegisterNULLImage();
+  (void) RegisterOTBImage();
+  (void) RegisterPALMImage();
+  (void) RegisterPATTERNImage();
+  (void) RegisterPCDImage();
+  (void) RegisterPCLImage();
+  (void) RegisterPCXImage();
+  (void) RegisterPDBImage();
+  (void) RegisterPDFImage();
+  (void) RegisterPICTImage();
+  (void) RegisterPIXImage();
+  (void) RegisterPLASMAImage();
 #if defined(HasPNG)
-  RegisterPNGImage();
+  (void) RegisterPNGImage();
 #endif
-  RegisterPNMImage();
-  RegisterPREVIEWImage();
-  RegisterPSImage();
-  RegisterPS2Image();
-  RegisterPS3Image();
-  RegisterPSDImage();
-  RegisterPWPImage();
-  RegisterRAWImage();
-  RegisterRGBImage();
-  RegisterRLAImage();
-  RegisterRLEImage();
-  RegisterSCRImage();
-  RegisterSCTImage();
-  RegisterSFWImage();
-  RegisterSGIImage();
-  RegisterSTEGANOImage();
-  RegisterSUNImage();
-  RegisterSVGImage();
-  RegisterTGAImage();
-  RegisterTHUMBNAILImage();
+  (void) RegisterPNMImage();
+  (void) RegisterPREVIEWImage();
+  (void) RegisterPSImage();
+  (void) RegisterPS2Image();
+  (void) RegisterPS3Image();
+  (void) RegisterPSDImage();
+  (void) RegisterPWPImage();
+  (void) RegisterRAWImage();
+  (void) RegisterRGBImage();
+  (void) RegisterRLAImage();
+  (void) RegisterRLEImage();
+  (void) RegisterSCRImage();
+  (void) RegisterSCTImage();
+  (void) RegisterSFWImage();
+  (void) RegisterSGIImage();
+  (void) RegisterSTEGANOImage();
+  (void) RegisterSUNImage();
+  (void) RegisterSVGImage();
+  (void) RegisterTGAImage();
+  (void) RegisterTHUMBNAILImage();
 #if defined(HasTIFF)
-  RegisterTIFFImage();
+  (void) RegisterTIFFImage();
 #endif
-  RegisterTILEImage();
-  RegisterTIMImage();
-  RegisterTTFImage();
-  RegisterTXTImage();
-  RegisterUILImage();
-  RegisterURLImage();
-  RegisterUYVYImage();
-  RegisterVICARImage();
-  RegisterVIDImage();
-  RegisterVIFFImage();
-  RegisterWBMPImage();
-  RegisterWMFImage();
-  RegisterWPGImage();
+  (void) RegisterTILEImage();
+  (void) RegisterTIMImage();
+  (void) RegisterTTFImage();
+  (void) RegisterTXTImage();
+  (void) RegisterUILImage();
+  (void) RegisterURLImage();
+  (void) RegisterUYVYImage();
+  (void) RegisterVICARImage();
+  (void) RegisterVIDImage();
+  (void) RegisterVIFFImage();
+  (void) RegisterWBMPImage();
+  (void) RegisterWMFImage();
+  (void) RegisterWPGImage();
 #if defined(HasX11)
-  RegisterXImage();
+  (void) RegisterXImage();
 #endif
-  RegisterXBMImage();
-  RegisterXCImage();
-  RegisterXCFImage();
-  RegisterXPMImage();
+  (void) RegisterXBMImage();
+  (void) RegisterXCImage();
+  (void) RegisterXCFImage();
+  (void) RegisterXPMImage();
 #if defined(_VISUALC_)
-  RegisterXTRNImage();
+  (void) RegisterXTRNImage();
 #endif
 #if defined(HasX11)
-  RegisterXWDImage();
+  (void) RegisterXWDImage();
 #endif
-  RegisterYCBCRImage();
-  RegisterYUVImage();
+  (void) RegisterYCBCRImage();
+  (void) RegisterYUVImage();
 #endif
 }
 
@@ -319,7 +337,9 @@ MagickExport void UnregisterStaticModules(void)
 #if defined(HasTIFF)
   UnregisterEPTImage();
 #endif
+#if defined(HasOPENEXR)
   UnregisterEXRImage();
+#endif
   UnregisterFAXImage();
   UnregisterFITSImage();
 #if defined(HasFPX)
