@@ -22,8 +22,7 @@
 extern "C" {
 #endif
 
-#if !defined(BuildMagickModules)
-extern ModuleExport void
+extern ModuleExport unsigned long
   RegisterARTImage(void),
   RegisterAVIImage(void),
   RegisterAVSImage(void),
@@ -162,7 +161,9 @@ extern ModuleExport void
   RegisterXVImage(void),
   RegisterXWDImage(void),
   RegisterYCBCRImage(void),
-  RegisterYUVImage(void),
+  RegisterYUVImage(void);
+
+extern ModuleExport void
   UnregisterARTImage(void),
   UnregisterAVIImage(void),
   UnregisterAVSImage(void),
@@ -303,7 +304,6 @@ extern ModuleExport void
   UnregisterXWDImage(void),
   UnregisterYCBCRImage(void),
   UnregisterYUVImage(void);
-#endif
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
