@@ -218,7 +218,6 @@ MagickExport char *CloneString(char **destination,const char *source)
       *destination=AcquireString(source);
       return(*destination);
     }
-  *destination=(char *) NULL;
   length=strlen(source);
   if (~length < MaxTextExtent)
     ThrowFatalException(ResourceLimitFatalError,"UnableToAcquireString");
@@ -1008,7 +1007,7 @@ MagickExport long FormatMagickSize(const MagickSizeType size,char *format)
   register long
     i;
 
-  static char
+  static const char
     *units[7] = { "b", "kb", "mb", "gb", "tb", "pb", "eb" };
 
   length=(double) ((MagickOffsetType) (size/2))*2.0;
