@@ -50,6 +50,7 @@
 #include "magick/geometry.h"
 #include "magick/image.h"
 #include "magick/memory_.h"
+#include "magick/layer.h"
 #include "magick/list.h"
 #include "magick/monitor.h"
 #include "magick/pixel-private.h"
@@ -473,7 +474,7 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
       crop_image=CloneImage(image,1,1,MagickTrue,exception);
       if (crop_image == (Image *) NULL)
         return((Image *) NULL);
-      crop_image->background_color.opacity=TransparentOpacity;
+      crop_image->background_color.opacity=(Quantum) TransparentOpacity;
       (void) SetImageBackgroundColor(crop_image);
       crop_image->page=bounding_box;
       crop_image->page.x=(-1);
@@ -677,7 +678,9 @@ MagickExport Image *ExcerptImage(const Image *image,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  ExtentImage() extends the image as defined by the geometry and gravity.
+%  ExtentImage() extends the image as defined by the geometry, gravity, and
+%  image background color.  Set the (x,y) offset of the geometry to move the 
+%  original image relative to the extended image.
 %
 %  The format of the ExtentImage method is:
 %
@@ -733,95 +736,6 @@ MagickExport Image *ExtentImage(const Image *image,
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%     F l a t t e n I m a g e                                                 %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  FlattenImage() composites all images from the current image pointer to the
-%  end of the image list and returns a single flattened image.
-%
-%  The format of the FlattenImage method is:
-%
-%      Image *FlattenImage(Image *image,ExceptionInfo *exception)
-%
-%  A description of each parameter follows:
-%
-%    o image: The image sequence.
-%
-%    o exception: Return any errors or warnings in this structure.
-%
-*/
-MagickExport Image *FlattenImages(Image *image,ExceptionInfo *exception)
-{
-#define FlattenImageTag  "Flatten/Image"
-
-  Image
-    *flatten_image;
-
-  MagickBooleanType
-    status;
-
-  MagickOffsetType
-    scene;
-
-  RectangleInfo
-    page;
-
-  unsigned long
-    number_images;
-
-  /*
-    Determine flatten bounding box.
-  */
-  assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  assert(exception != (ExceptionInfo *) NULL);
-  assert(exception->signature == MagickSignature);
-  page=image->page;
-  if (page.width == 0)
-    page.width=image->columns;
-  if (page.height == 0)
-    page.height=image->rows;
-  page.x=0;
-  page.y=0;
-  /*
-    Allocate flatten image.
-  */
-  flatten_image=CloneImage(image,page.width,page.height,MagickTrue,exception);
-  if (flatten_image == (Image *) NULL)
-    return((Image *) NULL);
-  (void) SetImageBackgroundColor(flatten_image);
-  flatten_image->page=page;
-  /*
-    Flatten the images.
-  */
-  number_images=GetImageListLength(image)-GetImageIndexInList(image);
-  for (scene=0; image != (Image *) NULL; scene++)
-  {
-    (void) CompositeImage(flatten_image,image->compose,image,image->page.x,
-      image->page.y);
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(scene,number_images) != MagickFalse))
-      {
-        status=image->progress_monitor(FlattenImageTag,scene,number_images,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
-    image=GetNextImageInList(image);
-  }
-  return(flatten_image);
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
 %   F l i p I m a g e                                                         %
 %                                                                             %
 %                                                                             %
@@ -1010,109 +924,6 @@ MagickExport Image *FlopImage(const Image *image,ExceptionInfo *exception)
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
 %                                                                             %
-%     M o s a i c I m a g e s                                                 %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  MosaicImages() inlays an image sequence to form a single coherent picture.
-%  It returns a single image with each image in the sequence composited at
-%  the location defined by the page member of the image structure.
-%
-%  The format of the MosaicImage method is:
-%
-%      Image *MosaicImages(const Image *image,ExceptionInfo *exception)
-%
-%  A description of each parameter follows:
-%
-%    o image: The image.
-%
-%    o exception: Return any errors or warnings in this structure.
-%
-*/
-MagickExport Image *MosaicImages(Image *image,ExceptionInfo *exception)
-{
-#define MosaicImageTag  "Mosaic/Image"
-
-  Image
-    *mosaic_image;
-
-  MagickBooleanType
-    status;
-
-  MagickOffsetType
-    scene;
-
-  RectangleInfo
-    page;
-
-  register const Image
-    *next;
-
-  unsigned long
-    number_images;
-
-  /*
-    Determine mosaic bounding box.
-  */
-  assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  assert(exception != (ExceptionInfo *) NULL);
-  assert(exception->signature == MagickSignature);
-  (void) ResetMagickMemory(&page,0,sizeof(page));
-  page.width=image->columns;
-  page.height=image->rows;
-  for (next=image; next != (Image *) NULL; next=GetNextImageInList(next))
-  {
-    page.x=next->page.x;
-    page.y=next->page.y;
-    if ((next->columns+page.x) > page.width)
-      page.width=next->columns+page.x;
-    if (next->page.width > page.width)
-      page.width=next->page.width;
-    if ((next->rows+page.y) > page.height)
-      page.height=next->rows+page.y;
-    if (next->page.height > page.height)
-      page.height=next->page.height;
-  }
-  page.x=0;
-  page.y=0;
-  /*
-    Allocate mosaic image.
-  */
-  mosaic_image=CloneImage(image,page.width,page.height,MagickTrue,exception);
-  if (mosaic_image == (Image *) NULL)
-    return((Image *) NULL);
-  (void) SetImageBackgroundColor(mosaic_image);
-  mosaic_image->page=page;
-  /*
-    Mosaic the images.
-  */
-  number_images=GetImageListLength(image);
-  for (scene=0; scene < (long) number_images; scene++)
-  {
-    (void) CompositeImage(mosaic_image,image->compose,image,image->page.x,
-      image->page.y);
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(scene,number_images) != MagickFalse))
-      {
-        status=image->progress_monitor(MosaicImageTag,scene,number_images,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
-    image=GetNextImageInList(image);
-  }
-  return(mosaic_image);
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
 %                                                                             %
 %   R o l l I m a g e                                                         %
 %                                                                             %
@@ -1995,7 +1806,7 @@ MagickExport Image *TrimImage(const Image *image,ExceptionInfo *exception)
       crop_image=CloneImage(image,1,1,MagickTrue,exception);
       if (crop_image == (Image *) NULL)
         return((Image *) NULL);
-      crop_image->background_color.opacity=TransparentOpacity;
+      crop_image->background_color.opacity=(Quantum) TransparentOpacity;
       (void) SetImageBackgroundColor(crop_image);
       crop_image->page=image->page;
       crop_image->page.x=(-1);
