@@ -57,6 +57,9 @@
 #include "magick/string_.h"
 #include "magick/token.h"
 #include "magick/utility.h"
+#if defined(HAVE_MACH_O_DYLD_H)
+#include <mach-o/dyld.h>
+#endif
 /*
   Static declarations.
 */
@@ -827,20 +830,59 @@ MagickExport MagickBooleanType ExpandFilenames(int *argc,char ***argv)
 %
 %  The format of the GetExecutionPath method is:
 %
-%      MagickBooleanType GetExecutionPath(char *path)
+%      MagickBooleanType GetExecutionPath(char *path,const size_t extent)
 %
 %  A description of each parameter follows:
 %
 %    o path: The pathname of the executable that started the process.
 %
+%    o extent: the maximum extent of the path.
+%
 */
-MagickExport MagickBooleanType GetExecutionPath(char *path)
+MagickExport MagickBooleanType GetExecutionPath(char *path,const size_t extent)
 {
   *path='\0';
-  if (getcwd(path,MaxTextExtent) == (char *) NULL)
-    return(MagickFalse);
-#if defined(__WINDOWS__)
-  return(NTGetExecutionPath(path));
+  (void) getcwd(path,extent);
+#if defined(HAVE_GETPID) && defined(HAVE_READLINK)
+  {
+    char
+      link_path[MaxTextExtent],
+      real_path[PATH_MAX+1];
+
+    int
+      length;
+
+    (void) FormatMagickString(link_path,MaxTextExtent,"/proc/%ld/exe",
+      (long) getpid());
+    length=readlink(link_path,real_path,PATH_MAX);
+    if (length == -1)
+      {
+        (void) FormatMagickString(link_path,MaxTextExtent,"/proc/%ld/file",
+          (long) getpid());
+        length=readlink(link_path,real_path,PATH_MAX);
+      }
+    if ((length > 0) && (length <= PATH_MAX))
+      {
+        real_path[length]='\0';
+        (void) CopyMagickString(path,real_path,extent);
+      }
+  }
+#endif
+#if defined(HAVE__NSGETEXECUTABLEPATH)
+  {
+
+    char
+      executable_path[PATH_MAX << 1],
+      real_path[PATH_MAX+1];
+   
+    uint32_t
+      length;
+
+    length=sizeof(executable_path);
+    if ((_NSGetExecutablePath(executable_path,&length) == 0) &&
+        (realpath(executable_path,real_path) != (char *) NULL))
+      (void) CopyMagickString(path,real_path,extent);
+  }
 #endif
 #if defined(HAVE_GETEXECNAME)
   {
@@ -851,12 +893,15 @@ MagickExport MagickBooleanType GetExecutionPath(char *path)
     if (execution_path != (const char *) NULL)
       {
         if (*execution_path != *DirectorySeparator)
-          (void) ConcatenateMagickString(path,DirectorySeparator,MaxTextExtent);
-        (void) ConcatenateMagickString(path,execution_path,MaxTextExtent);
+          (void) ConcatenateMagickString(path,DirectorySeparator,extent);
+        (void) ConcatenateMagickString(path,execution_path,extent);
       }
   }
 #endif
-  return(MagickTrue);
+#if defined(__WINDOWS__)
+  NTGetExecutionPath(path,extent);
+#endif
+  return(IsAccessible(path));
 }
 
 /*
@@ -1530,7 +1575,7 @@ MagickExport int SystemCommand(const MagickBooleanType verbose,
 #if !defined(HAVE_EXECVP)
   status=system(command);
 #else
-  if (strspn(command,"&;<>|") != 0)
+  if (strspn(command,"&;<>|") == 0)
     status=system(command);
   else
     {
