@@ -1356,8 +1356,8 @@ static char *ParseEntities(char *xml,char **entities,char state)
   return(p == q ? ConstantString(p) : p);
 }
 
-void ParseCharacterContent(XMLTreeRoot *root,char *xml,const size_t length,
-  const char state)
+static void ParseCharacterContent(XMLTreeRoot *root,char *xml,
+  const size_t length,const char state)
 {
   XMLTreeInfo
     *xml_info;
@@ -2087,7 +2087,7 @@ MagickExport XMLTreeInfo *NewXMLTree(const char *xml,ExceptionInfo *exception)
 */
 MagickExport XMLTreeInfo *NewXMLTreeTag(const char *tag)
 {
-  static char
+  static const char
     *predefined_entities[NumberPredefinedEntities+1] =
     {
       "lt;", "&#60;", "gt;", "&#62;", "quot;", "&#34;",
@@ -2400,7 +2400,7 @@ static char *XMLTreeTagToXML(XMLTreeInfo *xml_info,char **source,size_t *length,
   size_t
     offset;
 
-  content="";
+  content=(char *) "";
   if (xml_info->parent != (XMLTreeInfo *) NULL)
     content=xml_info->parent->content;
   offset=0;
