@@ -133,6 +133,10 @@ if (0)
                 }
               (void) CloneString(&imageInfo->size,argv[arg]);
             }
+          else if (LocaleCompare("verbose",option+1) == 0)
+            {
+              imageInfo->verbose+=1;
+            }
         }
       else
         break;
@@ -140,7 +144,7 @@ if (0)
   if (arg != argc-2)
     {
       (void) printf("arg=%d, argc=%d\n", arg, argc);
-      (void) printf ( "Usage: %s [-compress algorithm -debug events -depth integer -log format -size geometry] infile format\n", argv[0] );
+      (void) printf ( "Usage: %s [-compress algorithm -debug events -depth integer -log format -size geometry -verbose] infile format\n", argv[0] );
       (void) fflush(stdout);
       exit_status = 1;
       goto program_exit;
@@ -282,10 +286,16 @@ if (0)
        !strcmp( "CMYK", format ) ||
        !strcmp( "PCD", format ) ||
        !strcmp( "PCDS", format ) ||
+       !strcmp( "PGM", format ) ||
+       !strcmp( "PPM", format ) ||
+       !strcmp( "PNM", format ) ||
+       !strcmp( "SGI", format ) ||
+       !strcmp( "XPM", format ) ||
        !strcmp( "UYVY", format ) ||
        !strcmp( "YUV", format ) || (final->compression == JPEGCompression))
     fuzz_factor = 0.06;
 
+  SetImageColorspace(final,original->colorspace);
   if ( !IsImagesEqual(original, final ) &&
        (original->error.normalized_mean_error > fuzz_factor) )
     {
