@@ -71,7 +71,7 @@ int main(int argc,char **argv)
     *option;
 
   ExceptionInfo
-    exception;
+    *exception;
 
   ImageInfo
     *image_info;
@@ -84,27 +84,29 @@ int main(int argc,char **argv)
     i;
 
   MagickCoreGenesis(*argv,MagickTrue);
-  GetExceptionInfo(&exception);
+  exception=AcquireExceptionInfo();
   regard_warnings=MagickFalse;
   for (i=1; i < (long) argc; i++)
   {
     option=argv[i];
     if ((strlen(option) == 1) || ((*option != '-') && (*option != '+')))
       continue;
+    if (LocaleCompare("debug",option+1) == 0)
+      (void) SetLogEventMask(argv[++i]);
     if (LocaleCompare("regard-warnings",option+1) == 0)
       regard_warnings=MagickTrue;
   }
   image_info=AcquireImageInfo();
-  status=MogrifyImageCommand(image_info,argc,argv,(char **) NULL,&exception);
-  if ((status == MagickFalse) || (exception.severity != UndefinedException))
+  status=MogrifyImageCommand(image_info,argc,argv,(char **) NULL,exception);
+  if ((status == MagickFalse) || (exception->severity != UndefinedException))
     {
-      if ((exception.severity < ErrorException) &&
+      if ((exception->severity < ErrorException) &&
           (regard_warnings == MagickFalse))
         status=MagickTrue;
-      CatchException(&exception);
+      CatchException(exception);
     }
   image_info=DestroyImageInfo(image_info);
-  (void) DestroyExceptionInfo(&exception);
+  exception=DestroyExceptionInfo(exception);
   MagickCoreTerminus();
   return(status == MagickFalse ? 1 : 0);
 }
