@@ -33,9 +33,9 @@
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Use Stream is a lightweight utility designed to extract pixels from large
-%  image files to a raw format using a minimum of system resources.  The
-%  entire image or any regular portion of the image can be extracted.
+%  Stream is a lightweight utility designed to extract pixels from large image
+%  files to a raw format using a minimum of system resources.  The entire
+%  image or any regular portion of the image can be extracted.
 %
 %
 */
