@@ -129,6 +129,7 @@ static void AnimateUsage(void)
       "-depth value         image depth",
       "-display server      display image to this X server",
       "-dither              apply Floyd/Steinberg error diffusion to image",
+      "-filter type         use this filter when resizing an image",
       "-format \"string\"     output formatted image characteristics",
       "-gamma value         level of gamma correction",
       "-geometry geometry   preferred size and location of the Image window",
@@ -153,7 +154,6 @@ static void AnimateUsage(void)
       "-seed value          seed a new sequence of pseudo-random numbers",
       "-set attribute value set an image attribute",
       "-size geometry       width and height of image",
-      "-support factor      resize support: > 1.0 is blurry, < 1.0 is sharp",
       "-transparent-color color",
       "                     transparent color",
       "-treedepth value     color tree depth",
@@ -761,6 +761,22 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
       }
       case 'f':
       {
+        if (LocaleCompare("filter",option+1) == 0)
+          {
+            long
+              filter;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowAnimateException(OptionError,"MissingArgument",option);
+            filter=ParseMagickOption(MagickFilterOptions,MagickFalse,argv[i]);
+            if (filter < 0)
+              ThrowAnimateException(OptionError,"UnrecognizedImageFilter",
+                argv[i]);
+            break;
+          }
         if (LocaleCompare("flatten",option+1) == 0)
           break;
         if (LocaleCompare("font",option+1) == 0)
@@ -1194,13 +1210,7 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
           break;
         if (LocaleCompare("support",option+1) == 0)
           {
-            if (*option == '+')
-              break;
-            i++;
-            if (i == (long) argc)
-              ThrowAnimateException(OptionError,"MissingArgument",option);
-            if (IsGeometry(argv[i]) == MagickFalse)
-              ThrowAnimateInvalidArgumentException(option,argv[i]);
+            i++;  /* deprecated */
             break;
           }
         ThrowAnimateException(OptionError,"UnrecognizedOption",option);
