@@ -76,7 +76,6 @@
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 
 static void CompareUsage(void)
@@ -87,6 +86,7 @@ static void CompareUsage(void)
   static const char
     *settings[]=
     {
+      "-alpha option        activate, deactivate, reset, or set the alpha channel",
       "-authenticate value  decrypt image with this password",
       "-channel type        apply option to select image channels",
       "-colorspace type     alternate image colorspace",
@@ -104,7 +104,6 @@ static void CompareUsage(void)
       "-interlace type      type of image interlacing scheme",
       "-limit type value    pixel cache resource limit",
       "-log format          format of debugging information",
-      "-matte               store matte channel if the image has one",
       "-metric type         measure differences between images with this metric",
       "-monitor             monitor progress",
       "-profile filename    add, delete, or apply an image profile",
@@ -114,6 +113,7 @@ static void CompareUsage(void)
       "-regard-warnings     pay attention to warning messages",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
+      "-seed value          seed a new sequence of pseudo-random numbers",
       "-set attribute value set an image attribute",
       "-size geometry       width and height of image",
       "-transparent-color color",
@@ -303,6 +303,35 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
     pend=image_stack[k] != (Image *) NULL ? MagickTrue : MagickFalse;
     switch (*(option+1))
     {
+      case 'a':
+      {
+        if (LocaleCompare("alpha",option+1) == 0)
+          {
+            long
+              type;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowCompareException(OptionError,"MissingArgument",option);
+            type=ParseMagickOption(MagickAlphaOptions,MagickFalse,argv[i]);
+            if (type < 0)
+              ThrowCompareException(OptionError,"UnrecognizedAlphaChannelType",
+                argv[i]);
+            break;
+          }
+        if (LocaleCompare("authenticate",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowCompareException(OptionError,"MissingArgument",option);
+            break;
+          }
+        ThrowCompareException(OptionError,"UnrecognizedOption",option);
+      }
       case 'c':
       {
         if (LocaleCompare("cache",option+1) == 0)
@@ -352,18 +381,18 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
         if (LocaleCompare("compress",option+1) == 0)
           {
             long
-              compression;
+              compress;
 
             if (*option == '+')
               break;
             i++;
             if (i == (long) (argc-1))
               ThrowCompareException(OptionError,"MissingArgument",option);
-            compression=ParseMagickOption(MagickCompressionOptions,
-              MagickFalse,argv[i]);
-            if (compression < 0)
-              ThrowCompareException(OptionError,
-                "UnrecognizedImageCompression",argv[i]);
+            compress=ParseMagickOption(MagickCompressOptions,MagickFalse,
+              argv[i]);
+            if (compress < 0)
+              ThrowCompareException(OptionError,"UnrecognizedImageCompression",
+                argv[i]);
             break;
           }
         ThrowCompareException(OptionError,"UnrecognizedOption",option)
@@ -539,16 +568,19 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
           break;
         if (LocaleCompare("metric",option+1) == 0)
           {
+            long
+              type;
+
             if (*option == '+')
               break;
             i++;
             if (i == (long) argc)
               ThrowCompareException(OptionError,"MissingArgument",option);
-            metric=(MetricType) ParseMagickOption(MagickMetricOptions,
-              MagickTrue,argv[i]);
-            if (metric <= UndefinedMetric)
+            type=ParseMagickOption(MagickMetricOptions,MagickTrue,argv[i]);
+            if (type < 0)
               ThrowCompareException(OptionError,"UnrecognizedMetricType",
                 argv[i]);
+            metric=(MetricType) type;
             break;
           }
         if (LocaleCompare("monitor",option+1) == 0)
@@ -619,6 +651,26 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
               ThrowCompareInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("seed",option+1) == 0)
+          {
+            unsigned long
+              seed;
+
+            if (*option == '+')
+              {
+                seed=(unsigned long) time((time_t *) NULL);
+                SeedRandomReservoir(seed);
+                break;
+              }
+            i++;
+            if (i == (long) (argc-1))
+              ThrowCompareException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowCompareInvalidArgumentException(option,argv[i]);
+            seed=(unsigned long) atol(argv[i]);
+            SeedRandomReservoir(seed);
+            break;
+          }
         if (LocaleCompare("set",option+1) == 0)
           {
             i++;
@@ -665,7 +717,7 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowCompareException(OptionError,"MissingArgument",option);
-            type=ParseMagickOption(MagickImageOptions,MagickFalse,argv[i]);
+            type=ParseMagickOption(MagickTypeOptions,MagickFalse,argv[i]);
             if (type < 0)
               ThrowCompareException(OptionError,"UnrecognizedImageType",
                 argv[i]);
@@ -754,8 +806,33 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
           text=DestroyString(text);
         }
       difference_image=DestroyImageList(difference_image);
-      if (metric != UndefinedMetric)
-        (void) fprintf(stdout,"%g\n",distortion);
+      switch (metric)
+      {
+        case MeanAbsoluteErrorMetric:
+        case RootMeanSquaredErrorMetric:
+        case PeakAbsoluteErrorMetric:
+        {
+          (void) fprintf(stderr,"%g (%g)\n",distortion,(double) (QuantumScale*
+            distortion));
+          break;
+        }
+        case AbsoluteErrorMetric:
+        case MeanSquaredErrorMetric:
+        case PeakSignalToNoiseRatioMetric:
+        {
+          (void) fprintf(stderr,"%g\n",distortion);
+          break;
+        }
+        case MeanErrorPerPixelMetric:
+        {
+          (void) fprintf(stderr,"%g (%g, %g)\n",distortion,
+            image->error.normalized_mean_error,
+            image->error.normalized_maximum_error);
+          break;
+        }
+        case UndefinedMetric:
+          break;
+      }
     }
   DestroyCompare();
   return(status != 0 ? MagickTrue : MagickFalse);
