@@ -182,8 +182,8 @@ static MagickBooleanType CompositeImageList(ImageInfo *image_info,Image **image,
               /*
                 Tile the composite image.
               */
-              (void) SetImageProperty(composite_image,
-                "[modify-outside-overlay]","false");
+              (void) SetImageArtifact(composite_image,"modify-outside-overlay",
+                "false");
               columns=composite_image->columns;
               for (y=0; y < (long) (*image)->rows; y+=composite_image->rows)
                 for (x=0; x < (long) (*image)->columns; x+=columns)
@@ -298,7 +298,6 @@ static void CompositeUsage(void)
       "-scene value         image scene number",
       "-seed value          seed a new sequence of pseudo-random numbers",
       "-size geometry       width and height of image",
-      "-support factor      resize support: > 1.0 is blurry, < 1.0 is sharp",
       "-transparent-color color",
       "                     transparent color",
       "-treedepth value     color tree depth",
@@ -875,8 +874,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowCompositeException(OptionError,"MissingArgument",option);
-            filter=ParseMagickOption(MagickFilterOptions,MagickFalse,
-              argv[i]);
+            filter=ParseMagickOption(MagickFilterOptions,MagickFalse,argv[i]);
             if (filter < 0)
               ThrowCompositeException(OptionError,"UnrecognizedImageFilter",
                 argv[i]);
@@ -1260,13 +1258,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
           break;
         if (LocaleCompare("support",option+1) == 0)
           {
-            if (*option == '+')
-              break;
-            i++;
-            if (i == (long) argc)
-              ThrowCompositeException(OptionError,"MissingArgument",option);
-            if (IsGeometry(argv[i]) == MagickFalse)
-              ThrowCompositeInvalidArgumentException(option,argv[i]);
+            i++;  /* deprecated */
             break;
           }
         ThrowCompositeException(OptionError,"UnrecognizedOption",option)
