@@ -56,14 +56,11 @@
 */
 #define ThrowFileException(exception,severity,tag,context) \
 { \
-  char \
-    *message; \
- \
-  message=GetExceptionMessage(errno); \
-  (void) ThrowMagickException(exception,GetMagickModule(),severity,tag, \
-    "`%s': %s",context,message); \
-  message=DestroyString(message); \
+  (void) ThrowMagickException(exception,GetMagickModule(),severity, \
+    tag == (const char *) NULL ? "unknown" : tag,"`%s': %s",context, \
+    strerror(errno)); \
 }
+
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -96,7 +93,6 @@
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 
 static MagickBooleanType ConcatenateImages(int argc,char **argv,
@@ -144,9 +140,11 @@ static void ConvertUsage(void)
       "-adaptive-blur geometry",
       "                     adaptively blur pixels; decrease effect near edges",
       "-adaptive-resize geometry",
-      "                     adaptively resize image with data dependent triangulation",
+      "                     adaptively resize image with data dependent",
+      "                     triangulation",
       "-adaptive-sharpen geometry",
       "                     adaptively sharpen pixels; increase effect near edges",
+      "-alpha option        activate, deactivate, reset, or set the alpha channel",
       "-annotate geometry text",
       "                     annotate the image with text",
       "-auto-orient         automatically orient image",
@@ -167,13 +165,16 @@ static void ConvertUsage(void)
       "                     apply a convolution kernel to the image",
       "-cycle amount        cycle the image colormap",
       "-despeckle           reduce the speckles within an image",
+      "-distort type coefficients",
+      "                     distort the image",
       "-draw string         annotate the image with a graphic primitive",
       "-edge radius         apply a filter to detect edges in the image",
       "-emboss radius       emboss an image",
       "-enhance             apply a digital filter to enhance a noisy image",
       "-equalize            perform histogram equalization to an image",
       "-evaluate operator value",
-      "                     evaluate an arithmetic, relational, or logical expression",
+      "                     evaluate an arithmetic, relational, or logical",
+      "                     expression",
       "-extent geometry     set the image size",
       "-extract geometry    extract area from image",
       "-flip                flip image vertically",
@@ -189,7 +190,7 @@ static void ConvertUsage(void)
       "-identify            identify the format and characteristics of the image",
       "-implode amount      implode image pixels about the center",
       "-lat geometry        local adaptive thresholding",
-      "-layers method       optimize or compare image layers",
+      "-layers method       optimize, merge,  or compare image layers",
       "-level value         adjust the level of image contrast",
       "-linear-stretch geometry",
       "                     improve contrast by `stretching with saturation'",
@@ -203,7 +204,8 @@ static void ConvertUsage(void)
       "-normalize           transform image to span the full range of colors",
       "-opaque color        change this color to the fill color",
       "-ordered-dither NxN",
-      "                     add a noise pattern to the image with specific amplitudes",
+      "                     add a noise pattern to the image with specific",
+      "                     amplitudes",
       "-paint radius        simulate an oil painting",
       "-polaroid angle      simulate a Polaroid picture",
       "-posterize levels    reduce the image to a limited number of color levels",
@@ -234,7 +236,8 @@ static void ConvertUsage(void)
       "-shave geometry      shave pixels from the image edges",
       "-shear geometry      slide one edge of the image along the X or Y axis",
       "-sigmoidal-contrast geometry",
-      "                     lightness rescaling using sigmoidal contrast enhancement",
+      "                     lightness rescaling using sigmoidal contrast",
+      "                     enhancement",
       "-sketch geometry     simulate a pencil sketch",
       "-solarize threshold  negate all pixels above the threshold level",
       "-splice geometry     splice the background color into the image",
@@ -264,6 +267,7 @@ static void ConvertUsage(void)
     {
       "-append              append an image sequence",
       "-average             average an image sequence",
+      "-clut                apply a color lookup table to the image",
       "-coalesce            merge a sequence of images",
       "-combine             combine a sequence of images",
       "-composite           composite image",
@@ -284,8 +288,10 @@ static void ConvertUsage(void)
     {
       "-adjoin              join images into a single multi-image file",
       "-affine matrix       affine transform matrix",
+      "-alpha option        activate, deactivate, reset, or set the alpha channel",
       "-antialias           remove pixel-aliasing",
       "-authenticate value  decrypt image with this password",
+      "-attenuate value     lessen (or intensify) when adding noise to an image",
       "-background color    background color",
       "-bias value          add bias when convolving an image",
       "-black-point-compensation",
@@ -326,7 +332,6 @@ static void ConvertUsage(void)
       "-log format          format of debugging information",
       "-loop iterations     add Netscape loop extension to your GIF animation",
       "-mask filename       associate a mask with the image",
-      "-matte               store matte channel if the image has one",
       "-mattecolor color    frame color",
       "-monitor             monitor progress",
       "-orient type         image orientation",
@@ -341,13 +346,12 @@ static void ConvertUsage(void)
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
       "-scene value         image scene number",
-      "-seed value          pseudo-random number generator seed value",
+      "-seed value          seed a new sequence of pseudo-random numbers",
       "-size geometry       width and height of image",
       "-stretch type        render text with this font stretch",
       "-stroke color        graphic primitive stroke color",
       "-strokewidth value   graphic primitive stroke width",
       "-style type          render text with this font style",
-      "-support factor      resize support: > 1.0 is blurry, < 1.0 is sharp",
       "-taint               image as ineligible for bi-modal delegate",
       "-texture filename    name of texture to tile onto the image background",
       "-tile-offset geometry",
@@ -597,6 +601,22 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("alpha",option+1) == 0)
+          {
+            long
+              type;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            type=ParseMagickOption(MagickAlphaOptions,MagickFalse,argv[i]);
+            if (type < 0)
+              ThrowConvertException(OptionError,"UnrecognizedAlphaChannelType",
+                argv[i]);
+            break;
+          }
         if (LocaleCompare("annotate",option+1) == 0)
           {
             if (*option == '+')
@@ -823,6 +843,8 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
             AppendImageToList(&image_stack[k],clone_images);
             break;
           }
+        if (LocaleCompare("clut",option+1) == 0)
+          break;
         if (LocaleCompare("coalesce",option+1) == 0)
           break;
         if (LocaleCompare("colorize",option+1) == 0)
@@ -884,11 +906,11 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowConvertException(OptionError,"MissingArgument",option);
-            compose=ParseMagickOption(MagickCompositeOptions,MagickFalse,
+            compose=ParseMagickOption(MagickComposeOptions,MagickFalse,
               argv[i]);
             if (compose < 0)
-              ThrowConvertException(OptionError,
-                "UnrecognizedComposeOperator",argv[i]);
+              ThrowConvertException(OptionError,"UnrecognizedComposeOperator",
+                argv[i]);
             break;
           }
         if (LocaleCompare("composite",option+1) == 0)
@@ -896,18 +918,18 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
         if (LocaleCompare("compress",option+1) == 0)
           {
             long
-              compression;
+              compress;
 
             if (*option == '+')
               break;
             i++;
             if (i == (long) (argc-1))
               ThrowConvertException(OptionError,"MissingArgument",option);
-            compression=ParseMagickOption(MagickCompressionOptions,
-              MagickFalse,argv[i]);
-            if (compression < 0)
-              ThrowConvertException(OptionError,
-                "UnrecognizedImageCompression",argv[i]);
+            compress=ParseMagickOption(MagickCompressOptions,MagickFalse,
+              argv[i]);
+            if (compress < 0)
+              ThrowConvertException(OptionError,"UnrecognizedImageCompression",
+                argv[i]);
             break;
           }
         if (LocaleCompare("contrast",option+1) == 0)
@@ -976,7 +998,6 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
                 argv[i]);
             (void) SetLogEventMask(argv[i]);
             break;
-            break;
           }
         if (LocaleCompare("define",option+1) == 0)
           {
@@ -1066,6 +1087,29 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
                 argv[i]);
             break;
           }
+        if (LocaleCompare("distort",option+1) == 0)
+          {
+            char
+              *p;
+
+            long
+              op;
+
+            i++;
+            if (i == (long) argc)
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            op=ParseMagickOption(MagickDistortOptions,MagickFalse,argv[i]);
+            if (op < 0)
+              ThrowConvertException(OptionError,"UnrecognizedDistortType",
+                argv[i]);
+            i++;
+            if (i == (long) (argc-1))
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            (void) strtod(argv[i],&p);
+            if (p == argv[i])
+              ThrowConvertInvalidArgumentException(option,argv[i]);
+            break;
+          }
         if (LocaleCompare("dither",option+1) == 0)
           break;
         if (LocaleCompare("draw",option+1) == 0)
@@ -1145,8 +1189,8 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertException(OptionError,"MissingArgument",option);
             op=ParseMagickOption(MagickEvaluateOptions,MagickFalse,argv[i]);
             if (op < 0)
-              ThrowConvertException(OptionError,
-                "UnrecognizedEvaluateOperator",argv[i]);
+              ThrowConvertException(OptionError,"UnrecognizedEvaluateOperator",
+                argv[i]);
             i++;
             if (i == (long) (argc-1))
               ThrowConvertException(OptionError,"MissingArgument",option);
@@ -1208,8 +1252,7 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) (argc-1))
               ThrowConvertException(OptionError,"MissingArgument",option);
-            filter=ParseMagickOption(MagickFilterOptions,MagickFalse,
-              argv[i]);
+            filter=ParseMagickOption(MagickFilterOptions,MagickFalse,argv[i]);
             if (filter < 0)
               ThrowConvertException(OptionError,"UnrecognizedImageFilter",
                 argv[i]);
@@ -1467,7 +1510,7 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) (argc-1))
               ThrowConvertException(OptionError,"MissingArgument",option);
-            type=ParseMagickOption(MagickLayersOptions,MagickFalse,argv[i]);
+            type=ParseMagickOption(MagickLayerOptions,MagickFalse,argv[i]);
             if (type < 0)
               ThrowConvertException(OptionError,"UnrecognizedLayerMethod",
                 argv[i]);
@@ -2030,14 +2073,18 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               seed;
 
             if (*option == '+')
-              break;
+              {
+                seed=(unsigned long) time((time_t *) NULL);
+                SeedRandomReservoir(seed);
+                break;
+              }
             i++;
             if (i == (long) (argc-1))
               ThrowConvertException(OptionError,"MissingArgument",option);
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowConvertInvalidArgumentException(option,argv[i]);
             seed=(unsigned long) atol(argv[i]);
-            DistillRandomEvent((unsigned char *) &seed,sizeof(seed));
+            SeedRandomReservoir(seed);
             break;
           }
         if (LocaleCompare("segment",option+1) == 0)
@@ -2245,13 +2292,7 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("support",option+1) == 0)
           {
-            if (*option == '+')
-              break;
-            i++;
-            if (i == (long) (argc-1))
-              ThrowConvertException(OptionError,"MissingArgument",option);
-            if (IsGeometry(argv[i]) == MagickFalse)
-              ThrowConvertInvalidArgumentException(option,argv[i]);
+            i++;  /* deprecated */
             break;
           }
         if (LocaleCompare("swap",option+1) == 0)
@@ -2391,7 +2432,7 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) (argc-1))
               ThrowConvertException(OptionError,"MissingArgument",option);
-            type=ParseMagickOption(MagickImageOptions,MagickFalse,argv[i]);
+            type=ParseMagickOption(MagickTypeOptions,MagickFalse,argv[i]);
             if (type < 0)
               ThrowConvertException(OptionError,"UnrecognizedImageType",
                 argv[i]);
