@@ -50,12 +50,50 @@
 */
 #define ThrowWandException(severity,tag,context) \
 { \
-  (void) ThrowMagickException(&wand->exception,GetMagickModule(),severity, \
+  (void) ThrowMagickException(wand->exception,GetMagickModule(),severity, \
     tag,"`%s'",context); \
   return(MagickFalse); \
 }
 
 #if !defined(ExcludeMagickDeprecated)
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   M a g i c k C l i p P a t h I m a g e                                     %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  MagickClipPathImage() clips along the named paths from the 8BIM profile, if
+%  present. Later operations take effect inside the path.  Id may be a number
+%  if preceded with #, to work on a numbered path, e.g., "#1" to use the first
+%  path.
+%
+%  The format of the MagickClipPathImage method is:
+%
+%      MagickBooleanType MagickClipPathImage(MagickWand *wand,
+%        const char *pathname,const MagickBooleanType inside)
+%
+%  A description of each parameter follows:
+%
+%    o wand: The magick wand.
+%
+%    o pathname: name of clipping path resource. If name is preceded by #, use
+%      clipping path numbered by name.
+%
+%    o inside: if non-zero, later operations take effect inside clipping path.
+%      Otherwise later operations take effect outside clipping path.
+%
+*/
+WandExport MagickBooleanType MagickClipPathImage(MagickWand *wand,
+  const char *pathname,const MagickBooleanType inside)
+{
+  return(MagickClipImagePath(wand,pathname,inside));
+}
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -318,14 +356,14 @@ WandExport MagickBooleanType MagickColorFloodfillImage(MagickWand *wand,
   draw_info=CloneDrawInfo(wand->image_info,(DrawInfo *) NULL);
   PixelGetQuantumColor(fill,&draw_info->fill);
   target=AcquireOnePixel(wand->images,x % wand->images->columns,
-    y % wand->images->rows,&wand->exception);
+    y % wand->images->rows,wand->exception);
   if (bordercolor != (PixelWand *) NULL)
     PixelGetQuantumColor(bordercolor,&target);
   wand->images->fuzz=fuzz;
   status=ColorFloodfillImage(wand->images,draw_info,target,x,y,
     bordercolor != (PixelWand *) NULL ? FillToBorderMethod : FloodfillMethod);
   if (status == MagickFalse)
-    InheritException(&wand->exception,&wand->images->exception);
+    InheritException(wand->exception,&wand->images->exception);
   draw_info=DestroyDrawInfo(draw_info);
   return(status);
 }
@@ -363,6 +401,77 @@ WandExport char *MagickDescribeImage(MagickWand *wand)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   M a g i c k F l a t t e n I m a g e s                                     %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  MagickFlattenImages() merges a sequence of images.  This is useful for
+%  combining Photoshop layers into a single image.
+%
+%  The format of the MagickFlattenImages method is:
+%
+%      MagickWand *MagickFlattenImages(MagickWand *wand)
+%
+%  A description of each parameter follows:
+%
+%    o wand: The magick wand.
+%
+*/
+
+static MagickWand *CloneMagickWandFromImages(const MagickWand *wand,
+  Image *images)
+{
+  MagickWand
+    *clone_wand;
+
+  assert(wand != (MagickWand *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  clone_wand=(MagickWand *) AcquireMagickMemory(sizeof(*clone_wand));
+  if (clone_wand == (MagickWand *) NULL)
+    ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
+      images->filename);
+  (void) ResetMagickMemory(clone_wand,0,sizeof(*clone_wand));
+  clone_wand->id=AcquireWandId();
+  (void) FormatMagickString(clone_wand->name,MaxTextExtent,"%s-%lu",
+    MagickWandId,clone_wand->id);
+  clone_wand->exception=AcquireExceptionInfo();
+  InheritException(clone_wand->exception,wand->exception);
+  clone_wand->image_info=CloneImageInfo(wand->image_info);
+  clone_wand->quantize_info=CloneQuantizeInfo(wand->quantize_info);
+  clone_wand->images=images;
+  clone_wand->debug=IsEventLogging();
+  if (clone_wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",clone_wand->name);
+  clone_wand->signature=WandSignature;
+  return(clone_wand);
+}
+
+WandExport MagickWand *MagickFlattenImages(MagickWand *wand)
+{
+  Image
+    *flatten_image;
+
+  assert(wand != (MagickWand *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  if (wand->images == (Image *) NULL)
+    return((MagickWand *) NULL);
+  flatten_image=FlattenImages(wand->images,wand->exception);
+  if (flatten_image == (Image *) NULL)
+    return((MagickWand *) NULL);
+  return(CloneMagickWandFromImages(wand,flatten_image));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   M a g i c k G e t I m a g e A t t r i b u t e                             %
 %                                                                             %
 %                                                                             %
@@ -459,7 +568,7 @@ WandExport MagickBooleanType MagickGetImageChannelExtrema(MagickWand *wand,
   if (wand->images == (Image *) NULL)
     ThrowWandException(WandError,"ContainsNoImages",wand->name);
   status=GetImageChannelExtrema(wand->images,channel,minima,maxima,
-    &wand->exception);
+    wand->exception);
   return(status);
 }
 
@@ -502,7 +611,7 @@ WandExport MagickBooleanType MagickGetImageExtrema(MagickWand *wand,
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
   if (wand->images == (Image *) NULL)
     ThrowWandException(WandError,"ContainsNoImages",wand->name);
-  status=GetImageExtrema(wand->images,minima,maxima,&wand->exception);
+  status=GetImageExtrema(wand->images,minima,maxima,wand->exception);
   return(status);
 }
 
@@ -568,7 +677,7 @@ WandExport MagickBooleanType MagickMatteFloodfillImage(MagickWand *wand,
     ThrowWandException(WandError,"ContainsNoImages",wand->name);
   draw_info=CloneDrawInfo(wand->image_info,(DrawInfo *) NULL);
   target=AcquireOnePixel(wand->images,x % wand->images->columns,
-    y % wand->images->rows,&wand->exception);
+    y % wand->images->rows,wand->exception);
   if (bordercolor != (PixelWand *) NULL)
     PixelGetQuantumColor(bordercolor,&target);
   wand->images->fuzz=fuzz;
@@ -576,7 +685,7 @@ WandExport MagickBooleanType MagickMatteFloodfillImage(MagickWand *wand,
     (MagickRealType) QuantumRange-QuantumRange*alpha),x,y,bordercolor !=
     (PixelWand *) NULL ? FillToBorderMethod : FloodfillMethod);
   if (status == MagickFalse)
-    InheritException(&wand->exception,&wand->images->exception);
+    InheritException(wand->exception,&wand->images->exception);
   draw_info=DestroyDrawInfo(draw_info);
   return(status);
 }
@@ -586,6 +695,47 @@ WandExport MagickBooleanType MagickMatteFloodfillImage(MagickWand *wand,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   M a g i c k M o s a i c I m a g e s                                       %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  MagickMosaicImages() inlays an image sequence to form a single coherent
+%  picture.  It returns a wand with each image in the sequence composited at
+%  the location defined by the page offset of the image.
+%
+%  The format of the MagickMosaicImages method is:
+%
+%      MagickWand *MagickMosaicImages(MagickWand *wand)
+%
+%  A description of each parameter follows:
+%
+%    o wand: The magick wand.
+%
+*/
+WandExport MagickWand *MagickMosaicImages(MagickWand *wand)
+{
+  Image
+    *mosaic_image;
+
+  assert(wand != (MagickWand *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  if (wand->images == (Image *) NULL)
+    return((MagickWand *) NULL);
+  mosaic_image=MosaicImages(wand->images,wand->exception);
+  if (mosaic_image == (Image *) NULL)
+    return((MagickWand *) NULL);
+  return(CloneMagickWandFromImages(wand,mosaic_image));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   M a g i c k O p a q u e I m a g e                                         %
 %                                                                             %
 %                                                                             %
