@@ -17,7 +17,7 @@
 %                                July 1992                                    %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -134,6 +134,7 @@ static void DisplayUsage(void)
     },
     *settings[]=
     {
+      "-alpha option        activate, deactivate, reset, or set the alpha channel",
       "-antialias           remove pixel-aliasing",
       "-authenticate value  decrypt image with this password",
       "-backdrop            display image centered on a backdrop",
@@ -165,22 +166,21 @@ static void DisplayUsage(void)
       "-log format          format of debugging information",
       "-loop iterations     loop images then exit",
       "-map type            display image using this Standard Colormap",
-      "-matte               store matte channel if the image has one",
       "-monitor             monitor progress",
       "-page geometry       size and location of an image canvas",
       "-profile filename    add, delete, or apply an image profile",
       "-quality value       JPEG/MIFF/PNG compression level",
       "-quantize colorspace reduce colors in this colorspace",
-      "-quiet               suppress all error or warning messages",
+      "-quiet               suppress all warning messages",
       "-regard-warnings     pay attention to warning messages",
       "-remote command      execute a command in an remote display process",
       "-repage geometry     size and location of an image canvas (operator)",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
       "-scenes range        image scene range",
+      "-seed value          seed a new sequence of pseudo-random numbers",
       "-set property value  set an image property",
       "-size geometry       width and height of image",
-      "-support factor      resize support: > 1.0 is blurry, < 1.0 is sharp",
       "-texture filename    name of texture to tile onto the image background",
       "-transparent-color color",
       "                     transparent color",
@@ -257,7 +257,7 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
   if (image_marker != (unsigned long *) NULL) \
     image_marker=(unsigned long *) RelinquishMagickMemory(image_marker); \
   for (i=0; i < (long) argc; i++) \
-    argv[i]=(char *) RelinquishMagickMemory(argv[i]); \
+    argv[i]=DestroyString(argv[i]); \
   argv=(char **) RelinquishMagickMemory(argv); \
 }
 #define ThrowDisplayException(asperity,tag,option) \
@@ -329,6 +329,18 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
   if (image_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(exception != (ExceptionInfo *) NULL);
+  if (argc == 2)
+    {
+      option=argv[1];
+      if ((LocaleCompare("version",option+1) == 0) ||
+          (LocaleCompare("-version",option+1) == 0))
+        {
+          (void) fprintf(stdout,"Version: %s\n",
+            GetMagickVersion((unsigned long *) NULL));
+          (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
+          return(MagickTrue);
+        }
+    }
   SetNotifyHandlers;
   display=(Display *) NULL;
   first_scene=0;
@@ -356,9 +368,9 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
       message=GetExceptionMessage(errno);
       ThrowDisplayException(ResourceLimitError,"MemoryAllocationFailed",
         message);
-      message=(char *) RelinquishMagickMemory(message);
+      message=DestroyString(message);
     }
-  image_marker=(unsigned long *) AcquireMagickMemory((argc+1)*
+  image_marker=(unsigned long *) AcquireQuantumMemory((size_t) argc+1UL,
     sizeof(*image_marker));
   if (image_marker == (unsigned long *) NULL)
     {
@@ -368,7 +380,7 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
       message=GetExceptionMessage(errno);
       ThrowDisplayException(ResourceLimitError,"MemoryAllocationFailed",
         message);
-      message=(char *) RelinquishMagickMemory(message);
+      message=DestroyString(message);
     }
   for (i=0; i <= argc; i++)
     image_marker[i]=(unsigned long) argc;
@@ -670,6 +682,22 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
     {
       case 'a':
       {
+        if (LocaleCompare("alpha",option+1) == 0)
+          {
+            long
+              type;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowDisplayException(OptionError,"MissingArgument",option);
+            type=ParseMagickOption(MagickAlphaOptions,MagickFalse,argv[i]);
+            if (type < 0)
+              ThrowDisplayException(OptionError,"UnrecognizedAlphaChannelType",
+                argv[i]);
+            break;
+          }
         if (LocaleCompare("antialias",option+1) == 0)
           break;
         if (LocaleCompare("authenticate",option+1) == 0)
@@ -838,18 +866,18 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
         if (LocaleCompare("compress",option+1) == 0)
           {
             long
-              compression;
+              compress;
 
             if (*option == '+')
               break;
             i++;
             if (i == (long) argc)
               ThrowDisplayException(OptionError,"MissingArgument",option);
-            compression=ParseMagickOption(MagickCompressionOptions,
-              MagickFalse,argv[i]);
-            if (compression < 0)
-              ThrowDisplayException(OptionError,
-                "UnrecognizedImageCompression",argv[i]);
+            compress=ParseMagickOption(MagickCompressOptions,MagickFalse,
+              argv[i]);
+            if (compress < 0)
+              ThrowDisplayException(OptionError,"UnrecognizedImageCompression",
+                argv[i]);
             break;
           }
         if (LocaleCompare("contrast",option+1) == 0)
@@ -1027,8 +1055,7 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowDisplayException(OptionError,"MissingArgument",option);
-            filter=ParseMagickOption(MagickFilterOptions,MagickFalse,
-              argv[i]);
+            filter=ParseMagickOption(MagickFilterOptions,MagickFalse,argv[i]);
             if (filter < 0)
               ThrowDisplayException(OptionError,"UnrecognizedImageFilter",
                 argv[i]);
@@ -1487,6 +1514,26 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
             (void) sscanf(argv[i],"%ld-%ld",&first_scene,&last_scene);
             break;
           }
+        if (LocaleCompare("seed",option+1) == 0)
+          {
+            unsigned long
+              seed;
+
+            if (*option == '+')
+              {
+                seed=(unsigned long) time((time_t *) NULL);
+                SeedRandomReservoir(seed);
+                break;
+              }
+            i++;
+            if (i == (long) (argc-1))
+              ThrowDisplayException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowDisplayInvalidArgumentException(option,argv[i]);
+            seed=(unsigned long) atol(argv[i]);
+            SeedRandomReservoir(seed);
+            break;
+          }
         if (LocaleCompare("segment",option+1) == 0)
           {
             if (*option == '+')
@@ -1542,13 +1589,7 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
           break;
         if (LocaleCompare("support",option+1) == 0)
           {
-            if (*option == '+')
-              break;
-            i++;
-            if (i == (long) argc)
-              ThrowDisplayException(OptionError,"MissingArgument",option);
-            if (IsGeometry(argv[i]) == MagickFalse)
-              ThrowDisplayInvalidArgumentException(option,argv[i]);
+            i++;  /* deprecated */
             break;
           }
         ThrowDisplayException(OptionError,"UnrecognizedOption",option);
@@ -1653,7 +1694,12 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
           break;
         if ((LocaleCompare("version",option+1) == 0) ||
             (LocaleCompare("-version",option+1) == 0))
-          break;
+          {
+            (void) fprintf(stdout,"Version: %s\n",
+              GetMagickVersion((unsigned long *) NULL));
+            (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
+            break;
+          }
         if (LocaleCompare("visual",option+1) == 0)
           {
             resource_info.visual_type=(char *) NULL;
