@@ -17,7 +17,7 @@
 %                              July 1992                                      %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -93,7 +93,6 @@
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 
 static void ImportUsage(void)
@@ -144,6 +143,7 @@ static void ImportUsage(void)
       "-delay value         display the next image after pausing",
       "-endian type         endianness (MSB or LSB) of the image",
       "-encoding type       text encoding type",
+      "-filter type         use this filter when resizing an image",
       "-format \"string\"     output formatted image characteristics",
       "-frame               include window manager frame",
       "-gravity direction   which direction to gravitate towards",
@@ -158,16 +158,16 @@ static void ImportUsage(void)
       "-pause value         seconds delay between snapshots",
       "-pointsize value     font point size",
       "-quality value       JPEG/MIFF/PNG compression level",
-      "-quiet               suppress all error or warning messages",
+      "-quiet               suppress all warning messages",
       "-regard-warnings     pay attention to warning messages",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
       "-scene value         image scene number",
       "-screen              select image from root window",
+      "-seed value          seed a new sequence of pseudo-random numbers",
       "-set property value  set an image property",
       "-silent              operate silently, i.e. don't ring any bells ",
       "-snaps value         number of screen snapshots",
-      "-support factor      resize support: > 1.0 is blurry, < 1.0 is sharp",
       "-transparent-color color",
       "                     transparent color",
       "-treedepth value     color tree depth",
@@ -222,7 +222,7 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
   for ( ; k >= 0; k--) \
     image_stack[k]=DestroyImageList(image_stack[k]); \
   for (i=0; i < (long) argc; i++) \
-    argv[i]=(char *) RelinquishMagickMemory(argv[i]); \
+    argv[i]=DestroyString(argv[i]); \
   argv=(char **) RelinquishMagickMemory(argv); \
 }
 #define ThrowImportException(asperity,tag,option) \
@@ -288,6 +288,18 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
   if (image_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(exception != (ExceptionInfo *) NULL);
+  if (argc == 2)
+    {
+      option=argv[1];
+      if ((LocaleCompare("version",option+1) == 0) ||
+          (LocaleCompare("-version",option+1) == 0))
+        {
+          (void) fprintf(stdout,"Version: %s\n",
+            GetMagickVersion((unsigned long *) NULL));
+          (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
+          return(MagickTrue);
+        }
+    }
   display=(Display *) NULL;
   j=1;
   k=0;
@@ -312,7 +324,7 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
       message=GetExceptionMessage(errno);
       ThrowImportException(ResourceLimitError,"MemoryAllocationFailed",
         message);
-      message=(char *) RelinquishMagickMemory(message);
+      message=DestroyString(message);
     }
   for (i=1; i < (long) argc; i++)
   {
@@ -564,12 +576,12 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("comment",option+1) == 0)
           {
-            if (*option == '-')
+            if (*option == '+')
               break;
             i++;
             if (i == (long) argc)
               ThrowImportException(OptionError,"MissingArgument",option);
-            status=SetImageOption(image_info,"Comment",argv[i]);
+            status=SetImageOption(image_info,"comment",argv[i]);
             if (status == MagickFalse)
               ThrowImportException(OptionError,"UnrecognizedOption",argv[i]);
             break;
@@ -577,16 +589,16 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
         if (LocaleCompare("compress",option+1) == 0)
           {
             long
-              compression;
+              compress;
 
             if (*option == '+')
               break;
             i++;
             if (i == (long) argc)
               ThrowImportException(OptionError,"MissingArgument",option);
-            compression=ParseMagickOption(MagickCompressionOptions,
-              MagickFalse,argv[i]);
-            if (compression < 0)
+            compress=ParseMagickOption(MagickCompressOptions,MagickFalse,
+              argv[i]);
+            if (compress < 0)
               ThrowImportException(OptionError,"UnrecognizedImageCompression",
                 argv[i]);
             break;
@@ -744,6 +756,22 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
       }
       case 'f':
       {
+        if (LocaleCompare("filter",option+1) == 0)
+          {
+            long
+              filter;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowImportException(OptionError,"MissingArgument",option);
+            filter=ParseMagickOption(MagickFilterOptions,MagickFalse,argv[i]);
+            if (filter < 0)
+              ThrowImportException(OptionError,"UnrecognizedImageFilter",
+                argv[i]);
+            break;
+          }
         if (LocaleCompare("frame",option+1) == 0)
           {
             ximage_info.frame=(*option == '-') ? MagickTrue : MagickFalse;
@@ -934,7 +962,7 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
             break;
           }
         if (LocaleCompare("ping",option+1) == 0)
-          ThrowImportException(OptionError,"DeprecatedOption",option);
+          break;  /* deprecated option */
         if (LocaleCompare("pointsize",option+1) == 0)
           {
             if (*option == '+')
@@ -1060,6 +1088,26 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
             ximage_info.screen=(*option == '-') ? MagickTrue : MagickFalse;
             break;
           }
+        if (LocaleCompare("seed",option+1) == 0)
+          {
+            unsigned long
+              seed;
+
+            if (*option == '+')
+              {
+                seed=(unsigned long) time((time_t *) NULL);
+                SeedRandomReservoir(seed);
+                break;
+              }
+            i++;
+            if (i == (long) (argc-1))
+              ThrowImportException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowImportInvalidArgumentException(option,argv[i]);
+            seed=(unsigned long) atol(argv[i]);
+            SeedRandomReservoir(seed);
+            break;
+          }
         if (LocaleCompare("silent",option+1) == 0)
           {
             ximage_info.silent=(*option == '-') ? MagickTrue : MagickFalse;
@@ -1080,13 +1128,7 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
           break;
         if (LocaleCompare("support",option+1) == 0)
           {
-            if (*option == '+')
-              break;
-            i++;
-            if (i == (long) argc)
-              ThrowImportException(OptionError,"MissingArgument",option);
-            if (IsGeometry(argv[i]) == MagickFalse)
-              ThrowImportInvalidArgumentException(option,argv[i]);
+            i++;  /* deprecated */
             break;
           }
         ThrowImportException(OptionError,"UnrecognizedOption",option);
@@ -1147,7 +1189,7 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowImportException(OptionError,"MissingArgument",option);
-            type=ParseMagickOption(MagickImageOptions,MagickFalse,argv[i]);
+            type=ParseMagickOption(MagickTypeOptions,MagickFalse,argv[i]);
             if (type < 0)
               ThrowImportException(OptionError,"UnrecognizedImageType",argv[i]);
             break;
@@ -1168,7 +1210,12 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
           break;
         if ((LocaleCompare("version",option+1) == 0) ||
             (LocaleCompare("-version",option+1) == 0))
-          break;
+          {
+            (void) fprintf(stdout,"Version: %s\n",
+              GetMagickVersion((unsigned long *) NULL));
+            (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
+            break;
+          }
         ThrowImportException(OptionError,"UnrecognizedOption",option);
       }
       case '?':
