@@ -29,7 +29,6 @@ extern WandExport ChannelStatistics
 extern WandExport char
   *MagickGetImageFilename(MagickWand *),
   *MagickGetImageFormat(MagickWand *),
-  *MagickGetImageProperty(MagickWand *,const char *),
   *MagickGetImageSignature(MagickWand *),
   *MagickIdentifyImage(MagickWand *);
 
@@ -90,7 +89,9 @@ extern WandExport MagickBooleanType
   MagickChopImage(MagickWand *,const unsigned long,const unsigned long,
     const long,const long),
   MagickClipImage(MagickWand *),
-  MagickClipPathImage(MagickWand *,const char *,const MagickBooleanType),
+  MagickClipImagePath(MagickWand *,const char *,const MagickBooleanType),
+  MagickClutImage(MagickWand *,const MagickWand *),
+  MagickClutImageChannel(MagickWand *,const ChannelType,const MagickWand *),
   MagickColorizeImage(MagickWand *,const PixelWand *,const PixelWand *),
   MagickCommentImage(MagickWand *,const char *),
   MagickCompositeImage(MagickWand *,const MagickWand *,const CompositeOperator,
@@ -111,11 +112,14 @@ extern WandExport MagickBooleanType
   MagickDespeckleImage(MagickWand *),
   MagickDisplayImage(MagickWand *,const char *),
   MagickDisplayImages(MagickWand *,const char *),
+  MagickDistortImage(MagickWand *,const DistortImageMethod,const unsigned long,
+    const double *,const MagickBooleanType),
   MagickDrawImage(MagickWand *,const DrawingWand *),
   MagickEdgeImage(MagickWand *,const double),
   MagickEmbossImage(MagickWand *,const double,const double),
   MagickEnhanceImage(MagickWand *),
   MagickEqualizeImage(MagickWand *),
+  MagickEqualizeImageChannel(MagickWand *,const ChannelType),
   MagickEvaluateImage(MagickWand *,const MagickEvaluateOperator,const double),
   MagickEvaluateImageChannel(MagickWand *,const ChannelType,
     const MagickEvaluateOperator,const double),
@@ -194,7 +198,6 @@ extern WandExport MagickBooleanType
   MagickPosterizeImage(MagickWand *,const unsigned long,
     const MagickBooleanType),
   MagickPreviousImage(MagickWand *),
-  MagickProfileImage(MagickWand *,const char *,const void *,const size_t),
   MagickQuantizeImage(MagickWand *,const unsigned long,const ColorspaceType,
     const unsigned long,const MagickBooleanType,const MagickBooleanType),
   MagickQuantizeImages(MagickWand *,const unsigned long,const ColorspaceType,
@@ -225,6 +228,7 @@ extern WandExport MagickBooleanType
   MagickSeparateImageChannel(MagickWand *,const ChannelType),
   MagickSepiaToneImage(MagickWand *,const double),
   MagickSetImage(MagickWand *,const MagickWand *),
+  MagickSetImageAlphaChannel(MagickWand *,const AlphaChannelType),
   MagickSetImageBackgroundColor(MagickWand *,const PixelWand *),
   MagickSetImageBias(MagickWand *,const double),
   MagickSetImageBluePrimary(MagickWand *,const double,const double),
@@ -259,8 +263,6 @@ extern WandExport MagickBooleanType
   MagickResetImagePage(MagickWand *,const char *),
   MagickSetImagePixels(MagickWand *,const long,const long,const unsigned long,
     const unsigned long,const char *,const StorageType,const void *),
-  MagickSetImageProfile(MagickWand *,const char *,const void *,const size_t),
-  MagickSetImageProperty(MagickWand *,const char *,const char *),
   MagickSetImageRedPrimary(MagickWand *,const double,const double),
   MagickSetImageRenderingIntent(MagickWand *,const RenderingIntent),
   MagickSetImageResolution(MagickWand *,const double,const double),
@@ -323,17 +325,16 @@ extern WandExport MagickWand
     const MetricType,double *),
   *MagickCompareImages(MagickWand *,const MagickWand *,const MetricType,
     double *),
-  *MagickCompareImageLayers(MagickWand *,const MagickLayerMethod),
+  *MagickCompareImageLayers(MagickWand *,const ImageLayerMethod),
   *MagickDeconstructImages(MagickWand *),
-  *MagickFlattenImages(MagickWand *),
   *MagickFxImage(MagickWand *,const char *),
   *MagickFxImageChannel(MagickWand *,const ChannelType,const char *),
   *MagickGetImage(MagickWand *),
   *MagickGetImageClipMask(MagickWand *),
   *MagickGetImageRegion(MagickWand *,const unsigned long,const unsigned long,
     const long,const long),
+  *MagickMergeImageLayers(MagickWand *,const ImageLayerMethod),
   *MagickMorphImages(MagickWand *,const unsigned long),
-  *MagickMosaicImages(MagickWand *),
   *MagickMontageImage(MagickWand *,const DrawingWand *,const char *,
     const char *,const MontageMode,const char *),
   *MagickOptimizeImageLayers(MagickWand *),
@@ -358,9 +359,7 @@ extern WandExport ResolutionType
 
 extern WandExport unsigned char
   *MagickGetImageBlob(MagickWand *,size_t *),
-  *MagickGetImagesBlob(MagickWand *,size_t *),
-  *MagickGetImageProfile(MagickWand *,const char *,size_t *),
-  *MagickRemoveImageProfile(MagickWand *,const char *,size_t *);
+  *MagickGetImagesBlob(MagickWand *,size_t *);
 
 extern WandExport unsigned long
   MagickGetImageColors(MagickWand *),
