@@ -328,6 +328,39 @@ WandExport char *MagickGetFilename(const MagickWand *wand)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   M a g i c k G e t F o n t                                                 %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  MagickGetFont() returns the font associated with the MagickWand.
+%
+%  The format of the MagickGetFont method is:
+%
+%      char *MagickGetFont(MagickWand *wand)
+%
+%  A description of each parameter follows:
+%
+%    o wand: The magick wand.
+%
+*/
+WandExport char *MagickGetFont(MagickWand *wand)
+{
+  assert(wand != (MagickWand *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  if (wand->image_info->font == (char *) NULL)
+    return((char *) NULL);
+  return(AcquireString(wand->image_info->font));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   M a g i c k G e t F o r m a t                                             %
 %                                                                             %
 %                                                                             %
@@ -977,6 +1010,38 @@ WandExport MagickBooleanType MagickGetPage(const MagickWand *wand,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   M a g i c k G e t P o i n t s i z e                                       %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  MagickGetPointsize() returns the font pointsize associated with the
+%  MagickWand.
+%
+%  The format of the MagickGetPointsize method is:
+%
+%      double MagickGetPointsize(MagickWand *wand)
+%
+%  A description of each parameter follows:
+%
+%    o wand: The magick wand.
+%
+*/
+WandExport double MagickGetPointsize(MagickWand *wand)
+{
+  assert(wand != (MagickWand *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  return(wand->image_info->pointsize);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   M a g i c k G e t Q u a n t u m D e p t h                                 %
 %                                                                             %
 %                                                                             %
@@ -1657,6 +1722,42 @@ WandExport MagickBooleanType MagickSetFilename(MagickWand *wand,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   M a g i c k S e t F o n t                                                 %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  MagickSetFont() sets the font associated with the MagickWand.
+%
+%  The format of the MagickSetFont method is:
+%
+%      MagickBooleanType MagickSetFont(MagickWand *wand, const char *font)
+%
+%  A description of each parameter follows:
+%
+%    o wand: The magick wand.
+%
+%    o font: the font
+%
+*/
+WandExport MagickBooleanType MagickSetFont(MagickWand *wand,const char *font)
+{
+  if ((font == (const char *) NULL) || (*font == '\0'))
+    return(MagickFalse);
+  assert(wand != (MagickWand *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  (void) CloneString(&wand->image_info->font,font);
+  return(MagickTrue);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   M a g i c k S e t F o r m a t                                             %
 %                                                                             %
 %                                                                             %
@@ -2040,6 +2141,42 @@ WandExport MagickBooleanType MagickSetPassphrase(MagickWand *wand,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   M a g i c k S e t P o i n t s i z e                                       %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  MagickSetPointsize() sets the font pointsize associated with the MagickWand.
+%
+%  The format of the MagickSetPointsize method is:
+%
+%      MagickBooleanType MagickSetPointsize(MagickWand *wand,
+%        const double pointsize)
+%
+%  A description of each parameter follows:
+%
+%    o wand: The magick wand.
+%
+%    o pointsize: the size of the font
+%
+*/
+WandExport MagickBooleanType MagickSetPointsize(MagickWand *wand,
+  const double pointsize)
+{
+  assert(wand != (MagickWand *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  wand->image_info->pointsize=pointsize;
+  return(MagickTrue);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   M a g i c k S e t P r o g r e s s M o n i t o r                           %
 %                                                                             %
 %                                                                             %
