@@ -56,11 +56,10 @@
 */
 #define ThrowWandException(severity,tag,context) \
 { \
-  (void) ThrowMagickException(&wand->exception,GetMagickModule(),severity, \
+  (void) ThrowMagickException(wand->exception,GetMagickModule(),severity, \
     tag,"`%s'",context); \
   return(MagickFalse); \
 }
-#define MagickWandId  "MagickWand"
 
 /*
   Global declarations.
@@ -100,10 +99,9 @@ WandExport void ClearMagickWand(MagickWand *wand)
   wand->quantize_info=DestroyQuantizeInfo(wand->quantize_info);
   wand->image_info=DestroyImageInfo(wand->image_info);
   wand->images=DestroyImageList(wand->images);
-  (void) DestroyExceptionInfo(&wand->exception);
   wand->quantize_info=CloneQuantizeInfo((QuantizeInfo *) NULL);
   wand->image_info=AcquireImageInfo();
-  GetExceptionInfo(&wand->exception);
+  ClearMagickException(wand->exception);
   wand->debug=IsEventLogging();
 }
 
@@ -128,7 +126,6 @@ WandExport void ClearMagickWand(MagickWand *wand)
 %
 %    o wand: The magick wand.
 %
-%
 */
 WandExport MagickWand *CloneMagickWand(const MagickWand *wand)
 {
@@ -152,13 +149,13 @@ WandExport MagickWand *CloneMagickWand(const MagickWand *wand)
     }
   (void) ResetMagickMemory(clone_wand,0,sizeof(*clone_wand));
   clone_wand->id=AcquireWandId();
-  (void) FormatMagickString(clone_wand->name,MaxTextExtent,"MagickWand-%lu",
-    clone_wand->id);
-  GetExceptionInfo(&clone_wand->exception);
-  InheritException(&clone_wand->exception,&wand->exception);
+  (void) FormatMagickString(clone_wand->name,MaxTextExtent,"%s-%lu",
+    MagickWandId,clone_wand->id);
+  clone_wand->exception=AcquireExceptionInfo();
+  InheritException(clone_wand->exception,wand->exception);
   clone_wand->image_info=CloneImageInfo(wand->image_info);
   clone_wand->quantize_info=CloneQuantizeInfo(wand->quantize_info);
-  clone_wand->images=CloneImageList(wand->images,&clone_wand->exception);
+  clone_wand->images=CloneImageList(wand->images,clone_wand->exception);
   clone_wand->debug=IsEventLogging();
   if (clone_wand->debug != MagickFalse)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",clone_wand->name);
@@ -198,7 +195,7 @@ WandExport MagickWand *DestroyMagickWand(MagickWand *wand)
   wand->quantize_info=DestroyQuantizeInfo(wand->quantize_info);
   wand->image_info=DestroyImageInfo(wand->image_info);
   wand->images=DestroyImageList(wand->images);
-  (void) DestroyExceptionInfo(&wand->exception);
+  wand->exception=DestroyExceptionInfo(wand->exception);
   RelinquishWandId(wand->id);
   wand->signature=(~WandSignature);
   wand=(MagickWand *) RelinquishMagickMemory(wand);
@@ -249,7 +246,7 @@ WandExport MagickBooleanType IsMagickWand(const MagickWand *wand)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  MagickClearException() clear any exceptions associated with the wand.
+%  MagickClearException() clears any exceptions associated with the wand.
 %
 %  The format of the MagickClearException method is:
 %
@@ -266,7 +263,7 @@ WandExport MagickBooleanType MagickClearException(MagickWand *wand)
   assert(wand->signature == WandSignature);
   if (wand->debug != MagickFalse)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
-  ClearMagickException(&wand->exception);
+  ClearMagickException(wand->exception);
   return(MagickTrue);
 }
 
@@ -275,6 +272,97 @@ WandExport MagickBooleanType MagickClearException(MagickWand *wand)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   M a g i c k G e t E x c e p t i o n                                       %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  MagickGetException() returns the severity, reason, and description of any
+%  error that occurs when using other methods in this API.
+%
+%  The format of the MagickGetException method is:
+%
+%      char *MagickGetException(const MagickWand *wand,ExceptionType *severity)
+%
+%  A description of each parameter follows:
+%
+%    o wand: The magick wand.
+%
+%    o severity: The severity of the error is returned here.
+%
+*/
+WandExport char *MagickGetException(const MagickWand *wand,
+  ExceptionType *severity)
+{
+  char
+    *description;
+
+  assert(wand != (const MagickWand *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  assert(severity != (ExceptionType *) NULL);
+  *severity=wand->exception->severity;
+  description=(char *) AcquireQuantumMemory(2UL*MaxTextExtent,
+    sizeof(*description));
+  if (description == (char *) NULL)
+    {
+      (void) ThrowMagickException(wand->exception,GetMagickModule(),WandError,
+        "MemoryAllocationFailed","`%s'",wand->name);
+      return((char *) NULL);
+    }
+  *description='\0';
+  if (wand->exception->reason != (char *) NULL)
+    (void) CopyMagickString(description,GetLocaleExceptionMessage(
+      wand->exception->severity,wand->exception->reason),MaxTextExtent);
+  if (wand->exception->description != (char *) NULL)
+    {
+      (void) ConcatenateMagickString(description," (",MaxTextExtent);
+      (void) ConcatenateMagickString(description,GetLocaleExceptionMessage(
+        wand->exception->severity,wand->exception->description),MaxTextExtent);
+      (void) ConcatenateMagickString(description,")",MaxTextExtent);
+    }
+  return(description);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   M a g i c k G e t  E x c e p t i o n T y p e                              %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  MagickGetExceptionType() returns the exception type associated with the
+%  wand.  If no exception has occurred, UndefinedExceptionType is returned.
+%
+%  The format of the MagickGetExceptionType method is:
+%
+%      ExceptionType MagickGetExceptionType(const MagickWand *wand)
+%
+%  A description of each parameter follows:
+%
+%    o wand: The magick wand.
+%
+*/
+WandExport ExceptionType MagickGetExceptionType(const MagickWand *wand)
+{
+  assert(wand != (MagickWand *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  return(wand->exception->severity);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   M a g i c k G e t I t e r a t o r I n d e x                               %
 %                                                                             %
 %                                                                             %
@@ -286,7 +374,7 @@ WandExport MagickBooleanType MagickClearException(MagickWand *wand)
 %
 %  The format of the MagickGetIteratorIndex method is:
 %
-%      MagickBooleanType MagickGetIteratorIndex(MagickWand *wand)
+%      long MagickGetIteratorIndex(MagickWand *wand)
 %
 %  A description of each parameter follows:
 %
@@ -301,7 +389,7 @@ WandExport long MagickGetIteratorIndex(MagickWand *wand)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
   if (wand->images == (Image *) NULL)
     {
-      (void) ThrowMagickException(&wand->exception,GetMagickModule(),WandError,
+      (void) ThrowMagickException(wand->exception,GetMagickModule(),WandError,
         "ContainsNoIterators","`%s'",wand->name);
       return(-1);
     }
@@ -465,11 +553,11 @@ WandExport double *MagickQueryFontMetrics(MagickWand *wand,
   assert(drawing_wand != (const DrawingWand *) NULL);
   if (wand->images == (Image *) NULL)
     {
-      (void) ThrowMagickException(&wand->exception,GetMagickModule(),WandError,
+      (void) ThrowMagickException(wand->exception,GetMagickModule(),WandError,
         "ContainsNoImages","`%s'",wand->name);
       return((double *) NULL);
     }
-  font_metrics=(double *) AcquireMagickMemory(13*sizeof(*font_metrics));
+  font_metrics=(double *) AcquireQuantumMemory(13UL,sizeof(*font_metrics));
   if (font_metrics == (double *) NULL)
     return((double *) NULL);
   draw_info=PeekDrawingWand(drawing_wand);
@@ -484,7 +572,7 @@ WandExport double *MagickQueryFontMetrics(MagickWand *wand,
   draw_info=DestroyDrawInfo(draw_info);
   if (status == MagickFalse)
     {
-      InheritException(&wand->exception,&wand->images->exception);
+      InheritException(wand->exception,&wand->images->exception);
       font_metrics=(double *) RelinquishMagickMemory(font_metrics);
       return((double *) NULL);
     }
@@ -573,11 +661,11 @@ WandExport double *MagickQueryMultilineFontMetrics(MagickWand *wand,
   assert(drawing_wand != (const DrawingWand *) NULL);
   if (wand->images == (Image *) NULL)
     {
-      (void) ThrowMagickException(&wand->exception,GetMagickModule(),WandError,
+      (void) ThrowMagickException(wand->exception,GetMagickModule(),WandError,
         "ContainsNoImages","`%s'",wand->name);
       return((double *) NULL);
     }
-  font_metrics=(double *) AcquireMagickMemory(7*sizeof(*font_metrics));
+  font_metrics=(double *) AcquireQuantumMemory(13UL,sizeof(*font_metrics));
   if (font_metrics == (double *) NULL)
     return((double *) NULL);
   draw_info=PeekDrawingWand(drawing_wand);
@@ -592,7 +680,7 @@ WandExport double *MagickQueryMultilineFontMetrics(MagickWand *wand,
   draw_info=DestroyDrawInfo(draw_info);
   if (status == MagickFalse)
     {
-      InheritException(&wand->exception,&wand->images->exception);
+      InheritException(wand->exception,&wand->images->exception);
       font_metrics=(double *) RelinquishMagickMemory(font_metrics);
       return((double *) NULL);
     }
@@ -834,7 +922,7 @@ WandExport MagickBooleanType MagickSetIteratorIndex(MagickWand *wand,
   image=GetImageFromList(wand->images,index);
   if (image == (Image *) NULL)
     {
-      InheritException(&wand->exception,&wand->images->exception);
+      InheritException(wand->exception,&wand->images->exception);
       return(MagickFalse);
     }
   wand->active=MagickTrue;
@@ -909,7 +997,7 @@ WandExport void MagickWandGenesis(void)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  MagickWandTerminus() initializes the MagickWand environment.
+%  MagickWandTerminus() terminates the MagickWand environment.
 %
 %  The format of the MaickWandTerminus method is:
 %
@@ -969,7 +1057,7 @@ WandExport MagickWand *NewMagickWand(void)
   wand->id=AcquireWandId();
   (void) FormatMagickString(wand->name,MaxTextExtent,"%s-%lu",MagickWandId,
     wand->id);
-  GetExceptionInfo(&wand->exception);
+  wand->exception=AcquireExceptionInfo();
   wand->image_info=AcquireImageInfo();
   wand->quantize_info=CloneQuantizeInfo((QuantizeInfo *) NULL);
   wand->images=NewImageList();
@@ -991,11 +1079,11 @@ WandExport MagickWand *NewMagickWand(void)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  NewMagickWandWithImage() returns a wand with an image.
+%  NewMagickWandFromImage() returns a wand with an image.
 %
-%  The format of the NewMagickWandWithImage method is:
+%  The format of the NewMagickWandFromImage method is:
 %
-%      MagickWand NewMagickWandWithImage(const Image *image)
+%      MagickWand NewMagickWandFromImage(const Image *image)
 %
 %  A description of each parameter follows:
 %
@@ -1008,6 +1096,6 @@ WandExport MagickWand *NewMagickWandFromImage(const Image *image)
     *wand;
 
   wand=NewMagickWand();
-  wand->images=CloneImage(image,0,0,MagickTrue,&wand->exception);
+  wand->images=CloneImage(image,0,0,MagickTrue,wand->exception);
   return(wand);
 }
