@@ -76,7 +76,6 @@
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 
 static void MontageUsage(void)
@@ -112,6 +111,7 @@ static void MontageUsage(void)
     {
       "-adjoin              join images into a single multi-image file",
       "-affine matrix       affine transform matrix",
+      "-alpha option        activate, deactivate, reset, or set the alpha channel",
       "-authenticate value  decrypt image with this password",
       "-blue-primary point  chromaticity blue primary point",
       "-bordercolor color   border color",
@@ -149,26 +149,26 @@ static void MontageUsage(void)
       "-label string        assign a label to an image",
       "-limit type value    pixel cache resource limit",
       "-log format          format of debugging information",
-      "-matte               store matte channel if the image has one",
       "-mattecolor color    frame color",
       "-mode type           framing style",
       "-monitor             monitor progress",
+      "-origin geometry     image origin",
       "-page geometry       size and location of an image canvas (setting)",
       "-pointsize value     font point size",
       "-profile filename    add, delete, or apply an image profile",
       "-quality value       JPEG/MIFF/PNG compression level",
       "-quantize colorspace reduce colors in this colorspace",
-      "-quiet               suppress all error or warning messages",
+      "-quiet               suppress all warning messages",
       "-red-primary point   chromaticity red primary point",
       "-regard-warnings     pay attention to warning messages",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
       "-scenes range        image scene range",
+      "-seed value          seed a new sequence of pseudo-random numbers",
       "-set attribute value set an image attribute",
       "-shadow              add a shadow beneath a tile to simulate depth",
       "-size geometry       width and height of image",
       "-stroke color        color to use when stroking a graphic primitive",
-      "-support factor      resize support: > 1.0 is blurry, < 1.0 is sharp",
       "-texture filename    name of texture to tile onto the image background",
       "-thumbnail geometry  create a thumbnail of the image",
       "-tile geometry       number of tiles per row and column",
@@ -237,7 +237,7 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
   for ( ; k >= 0; k--) \
     image_stack[k]=DestroyImageList(image_stack[k]); \
   for (i=0; i < (long) argc; i++) \
-    argv[i]=(char *) RelinquishMagickMemory(argv[i]); \
+    argv[i]=DestroyString(argv[i]); \
   argv=(char **) RelinquishMagickMemory(argv); \
 }
 #define ThrowMontageException(asperity,tag,option) \
@@ -297,6 +297,18 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
   if (image_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(exception != (ExceptionInfo *) NULL);
+  if (argc == 2)
+    {
+      option=argv[1];
+      if ((LocaleCompare("version",option+1) == 0) ||
+          (LocaleCompare("-version",option+1) == 0))
+        {
+          (void) fprintf(stdout,"Version: %s\n",
+            GetMagickVersion((unsigned long *) NULL));
+          (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
+          return(MagickTrue);
+        }
+    }
   if (argc < 3)
    MontageUsage();
   format="%w,%h,%m";
@@ -327,7 +339,7 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
       message=GetExceptionMessage(errno);
       ThrowMontageException(ResourceLimitError,"MemoryAllocationFailed",
         message);
-      message=(char *) RelinquishMagickMemory(message);
+      message=DestroyString(message);
     }
   for (i=1; i < (long) (argc-1); i++)
   {
@@ -416,6 +428,22 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
               ThrowMontageInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("alpha",option+1) == 0)
+          {
+            long
+              type;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowMontageException(OptionError,"MissingArgument",option);
+            type=ParseMagickOption(MagickAlphaOptions,MagickFalse,argv[i]);
+            if (type < 0)
+              ThrowMontageException(OptionError,"UnrecognizedAlphaChannelType",
+                argv[i]);
+            break;
+          }
         if (LocaleCompare("annotate",option+1) == 0)
           {
             if (*option == '+')
@@ -631,28 +659,27 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowMontageException(OptionError,"MissingArgument",option);
-            compose=ParseMagickOption(MagickCompositeOptions,MagickFalse,
-              argv[i]);
+            compose=ParseMagickOption(MagickComposeOptions,MagickFalse,argv[i]);
             if (compose < 0)
-              ThrowMontageException(OptionError,
-                "UnrecognizedComposeOperator",argv[i]);
+              ThrowMontageException(OptionError,"UnrecognizedComposeOperator",
+                argv[i]);
             break;
           }
         if (LocaleCompare("compress",option+1) == 0)
           {
             long
-              compression;
+              compress;
 
             if (*option == '+')
               break;
             i++;
             if (i == (long) argc)
               ThrowMontageException(OptionError,"MissingArgument",option);
-            compression=ParseMagickOption(MagickCompressionOptions,
-              MagickFalse,argv[i]);
-            if (compression < 0)
-              ThrowMontageException(OptionError,
-                "UnrecognizedCompressionType",argv[i]);
+            compress=ParseMagickOption(MagickCompressOptions,MagickFalse,
+              argv[i]);
+            if (compress < 0)
+              ThrowMontageException(OptionError,"UnrecognizedCompressType",
+                argv[i]);
             break;
           }
         if (LocaleCompare("crop",option+1) == 0)
@@ -821,8 +848,7 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowMontageException(OptionError,"MissingArgument",option);
-            filter=ParseMagickOption(MagickFilterOptions,MagickFalse,
-              argv[i]);
+            filter=ParseMagickOption(MagickFilterOptions,MagickFalse,argv[i]);
             if (filter < 0)
               ThrowMontageException(OptionError,"UnrecognizedImageFilter",
                 argv[i]);
@@ -1093,6 +1119,21 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
           break;
         ThrowMontageException(OptionError,"UnrecognizedOption",option)
       }
+      case 'o':
+      {
+        if (LocaleCompare("origin",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowMontageException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowMontageInvalidArgumentException(option,argv[i]);
+            break;
+          }
+        ThrowMontageException(OptionError,"UnrecognizedOption",option)
+      }
       case 'p':
       {
         if (LocaleCompare("page",option+1) == 0)
@@ -1234,6 +1275,26 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
               ThrowMontageInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("seed",option+1) == 0)
+          {
+            unsigned long
+              seed;
+
+            if (*option == '+')
+              {
+                seed=(unsigned long) time((time_t *) NULL);
+                SeedRandomReservoir(seed);
+                break;
+              }
+            i++;
+            if (i == (long) (argc-1))
+              ThrowMontageException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowMontageInvalidArgumentException(option,argv[i]);
+            seed=(unsigned long) atol(argv[i]);
+            SeedRandomReservoir(seed);
+            break;
+          }
         if (LocaleCompare("scenes",option+1) == 0)
           {
             first_scene=0;
@@ -1315,13 +1376,7 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("support",option+1) == 0)
           {
-            if (*option == '+')
-              break;
-            i++;
-            if (i == (long) argc)
-              ThrowMontageException(OptionError,"MissingArgument",option);
-            if (IsGeometry(argv[i]) == MagickFalse)
-              ThrowMontageInvalidArgumentException(option,argv[i]);
+            i++;  /* deprecated */
             break;
           }
         ThrowMontageException(OptionError,"UnrecognizedOption",option)
@@ -1364,6 +1419,17 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
             (void) CloneString(&montage_info->tile,argv[i]);
             break;
           }
+        if (LocaleCompare("tile-offset",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowMontageException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowMontageInvalidArgumentException(option,argv[i]);
+            break;
+          }
         if (LocaleCompare("tint",option+1) == 0)
           {
             if (*option == '+')
@@ -1435,7 +1501,7 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowMontageException(OptionError,"MissingArgument",option);
-            type=ParseMagickOption(MagickImageOptions,MagickFalse,argv[i]);
+            type=ParseMagickOption(MagickTypeOptions,MagickFalse,argv[i]);
             if (type < 0)
               ThrowMontageException(OptionError,"UnrecognizedImageType",
                 argv[i]);
@@ -1472,7 +1538,12 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
           }
         if ((LocaleCompare("version",option+1) == 0) ||
             (LocaleCompare("-version",option+1) == 0))
-          break;
+          {
+            (void) fprintf(stdout,"Version: %s\n",
+              GetMagickVersion((unsigned long *) NULL));
+            (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
+            break;
+          }
         if (LocaleCompare("virtual-pixel",option+1) == 0)
           {
             long
@@ -1553,11 +1624,11 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
               message=GetExceptionMessage(errno);
               ThrowMontageException(ResourceLimitError,"MemoryAllocationFailed",
                 message);
-              message=(char *) RelinquishMagickMemory(message);
+              message=DestroyString(message);
             }
           (void) ConcatenateString(&(*metadata),text);
           (void) ConcatenateString(&(*metadata),"\n");
-          text=(char *) RelinquishMagickMemory(text);
+          text=DestroyString(text);
         }
     }
   montage_info=DestroyMontageInfo(montage_info);
